<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\AssetCategory;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class AssetCategoryController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $assetCategoryList = AssetCategory::whereNull('deleted_at')->get();
        return view('admin.assets.category.index', compact('assetCategoryList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $assetCategory = ((new AssetCategory())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new AssetCategory())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($assetCategory->isEmpty()) {
            
        }else{
            foreach($assetCategory as $assetCategory){
                $data['data'][] = [
                    'id' => $assetCategory->id,
                    'asset_category' => $assetCategory->asset_category,
                    'asset_type' => $assetCategory->asset_type,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($assetCategory->created_at)) ,
                    'action' => '<a href="'. route('asset-category.edit', ['asset_category' => $assetCategory->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('asset-category.destroy', ['asset_category' => $assetCategory->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'asset_category' => [
                    'required',
                    Rule::unique('asset_category')->ignore($request->all()['id']),
                ],
                'asset_type' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'asset_category' => 'required|unique:asset_category,asset_category',
                'asset_type' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.assets.category.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $assetCategory = AssetCategory::create($requestData);
        return redirect('admin/asset-category')->with('flash_message', 'Asset Category added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $assetCategory = AssetCategory::findOrFail($id);
        return view('admin.assets.category.show', compact('assetCategory'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $assetCategory = AssetCategory::findOrFail($id);
        
        return view('admin.assets.category.edit', compact('assetCategory'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $assetCategory = AssetCategory::findOrFail($id);
        $assetCategory->update($requestData);

        return redirect('admin/asset-category')->with('flash_message', 'Asset Category updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        AssetCategory::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'AssetCategory deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset-category')->with('flash_message', 'Asset Category deleted!');
    }
}
