<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Asset;
use App\Models\AssetCategory;
use App\Models\AssetDocuments;
use App\Models\Users\WalletHistory;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;


class AssetController extends AppController
{
    public function __construct()
    {
        
        $assetCategoryList = AssetCategory::whereNull('deleted_at')->get();

        View::share('assetCategoryList', $assetCategoryList);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $assets = Asset::whereNull('deleted_at')->get();
        return view('admin.assets.asset.index', compact('assets'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $assets = ((new Asset())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Asset())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($assets->isEmpty()) {
            
        }else{
            foreach($assets as $asset){
                $data['data'][] = [
                    'id' => $asset->id,
                    'name' => $asset->name,
                    'category' => (isset($asset->assetCategory)) ? $asset->assetCategory->asset_category : '',
                    'asset_type' => $asset->asset_type,
                    'oem' => $asset->oem,
                    'model_name' => $asset->model_name,
                    'model_number' => $asset->model_number,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($asset->created_at)) ,
                    'action' => ' <a href="'. route('assets.asset.edit', ['asset' => $asset->id]) . '"><i
                            class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                            <a href="'. route('assets.asset.destroy', ['asset' => $asset->id]).'"><i class="mdi mdi-eye font-size-16  text-info me-1"></i></a>
                            <a href="'. route('assets.asset.show', ['asset' => $asset->id]).'"><i
                                class="mdi mdi-trash-can font-size-16 text-danger me-1"></i></a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        $asset = new Asset();
        return $asset->validate($request);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.assets.asset.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $requestData['category_id'] = $requestData['category'];
        $asset = Asset::create($requestData);
        if($files = $request->file('file')){
            foreach($files as $file){
             (new AssetDocuments())->uploadFile($file, $asset);
            }
         }
        return redirect('admin/assets')->with('flash_message', 'Assets added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $asset = Asset::findOrFail($id);
        $assetDocuments = AssetDocuments::where('asset_id', $id)->get()->toArray();
        return view('admin.assets.asset.show', compact('asset',  'assetDocuments'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $asset = Asset::findOrFail($id);
        
        return view('admin.assets.asset.edit', compact('asset'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $requestData['category_id'] = $requestData['category'];
        $asset = Asset::findOrFail($id);
        $asset->update($requestData);

        return redirect('admin/assets')->with('flash_message', 'Assets updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        Asset::destroy($id);

        return redirect('admin/assets')->with('flash_message', 'Assets deleted!');
    }
    public function categories(){
        
        $categories = Category::whereNull('deleted_at')->get();
        return view('admin.assets.asset.categories', compact('categories'));
    }
    public function category_tab_index(Request $request){
        $requestData = $request->all();
        
        $assets = ((new Asset())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Asset())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($assets->isEmpty()) {
            
        }else{
            foreach($assets as $asset){
                $data['data'][] = [
                    'id' => $asset->id,
                    'name' => $asset->name,
                    'category' => (isset($asset->category)) ? $asset->category->category_name : '',
                    'asset_type' => $asset->asset_type,
                    'oem' => $asset->oem,
                    'model_name' => $asset->model_name,
                    'model_number' => $asset->model_number,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($asset->created_at)) ,
                    'action' => ' <a href="'. route('assets.asset.edit', ['asset' => $asset->id]) . '"><i
                            class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                            <a href="'. route('assets.asset.destroy', ['asset' => $asset->id]).'"><i class="mdi mdi-eye font-size-16  text-info me-1"></i></a>
                            <a href="'. route('assets.asset.show', ['asset' => $asset->id]).'"><i
                                class="mdi mdi-trash-can font-size-16 text-danger me-1"></i></a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    public function categories_create()
    {
        return view('admin.assets.asset.category_create');
    }
    public function categories_validate(Request $request)
    {   
        $validate = Validator::make($request->all(), [
            'category_name' => 'required|unique:categories,category_name',
        ]);
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    public function caegory_store(Request $request)
    {
        
        $requestData = $request->all();
        
        Category::create($requestData);

        return redirect('admin/asset/categories')->with('flash_message', 'Category added!');
    }
    public function caegory_edit($id)
    {
        $category = Category::findOrFail($id);

        return view('admin.assets.asset.categories_edit', compact('category'));
    }
    public function caegory_update(Request $request, $id)
    {
        
        $requestData = $request->all();
        
        $category = Category::findOrFail($id);
        $category->update($requestData);

        return redirect('admin/asset/categories')->with('flash_message', 'Category updated!');
    }
    public function caegory_destroy($id)
    {
        //Category::destroy($id);
        $category = Category::findOrFail($id);
        $requestData = [
            'deleted_at' => date('Y-m-d H:i:s')
        ];
        $category->update($requestData);

        return redirect('admin/assets/categories')->with('flash_message', 'Assets deleted!');
    }
}
