<?php

namespace App\Http\Controllers\Admin\Assets;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Assets\Battery;
use App\Models\Assets\Vehicle;
use App\Models\Vendors\Battery as Dealer;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Vendors\VendorCategory;
use App\Models\Vendors\VendorOem;
use App\Models\Location;
use App\Models\Master\ProductType;
use App\Models\Master\PropertyType;
use App\Models\Master\MaintenanceType;
use App\Models\Master\InsuranceType;
use App\Models\Assets\BatteryParts;
use App\Models\Assets\BatteryImages;
use App\Models\Assets\BatteryServicePlan;
use App\Models\Assets\BatteryInsurancePlan;
use App\Models\Assets\BatteryVehicleModel;
use App\Models\Assets\BatteryVehicleOem;
use App\Models\Master\Duration;
use App\Models\VehicleOem;



class BatteryController extends AppController
{
    public function __construct()
    {
        $productTypeList = ProductType::whereNull('deleted_at')->get();
        $propertyList = PropertyType::whereNull('deleted_at')->get();
        $MaintenanceTypeList = MaintenanceType::whereNull('deleted_at')->get();
        $insuranceTypeList = InsuranceType::whereNull('deleted_at')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $dealerList = Dealer::whereNull('deleted_at')->get();
        $vendorOemList = VendorOem::whereNull('deleted_at')->where('vendor_category_id', 2)->get(); //battery OEM
        $durationList = Duration::whereNull('deleted_at')->get();
        $vehicleOEMList = VendorOem::whereNull('deleted_at')->where('vendor_category_id', 1)->get(); //Vehicle OEM
        $vehicleModelList = Vehicle::whereNull('deleted_at')->groupBy('model_name')->get();
        View::share([
            'productTypeList' => $productTypeList, 
            'propertyList' => $propertyList, 
            'MaintenanceTypeList' => $MaintenanceTypeList, 
            'insuranceTypeList' => $insuranceTypeList, 
            'dealerList' => $dealerList, 
            'locationList' => $locationList, 
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'vendorOemList' => $vendorOemList, 
            'durationList' => $durationList, 
            'vehicleOEMList' => $vehicleOEMList, 
            'vehicleModelList' => $vehicleModelList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $batteryList = Battery::whereNull('deleted_at')->get();
        return view('admin.assets.battery.index', compact('batteryList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $battery = ((new Battery())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Battery())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($battery->isEmpty()) {
            
        }else{
            foreach($battery as $battery){
                $data['data'][] = [
                    'id' => $battery->id,
                    'product_id' => isset($battery->product) ? $battery->product->product_type :'',
                    'property_id' => isset($battery->property) ? $battery->property->property_type :'',
                    'battery_type' => $battery->battery_type,
                    'model_name' => $battery->model_name,
                    'model_number' => $battery->model_number,
                    'kwh_units' => $battery->kwh_units,
                    'qr_code' => '<a href="#" id="' . $battery->id . '" class="view_asset_qr">View</a>',
                    'oem_id' => isset($battery->vendorOem) ? $battery->vendorOem->vendor_oem :'',
                    'battery_dealer_id' => isset($battery->batteryDealer) ? $battery->batteryDealer->battery_dealer :'',
                    'purchased_invoice_number' => $battery->purchased_invoice_number,
                    'purchased_date' => $battery->purchased_date,
                    'location_id' => isset($battery->location) ? $battery->location->location :'',
                    'parts' => isset($battery->parts) ? '<a href="#" id="' . $battery->id . '" class="view_asset_parts_qr">'. count($battery->parts) .'</a>' : '',                  
                    'service_plan' => isset($battery->servicePlan) ? count($battery->servicePlan) : '',
                    'insurance_plan' => isset($battery->insurancePlan) ? count($battery->insurancePlan) : '',
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($battery->created_at)) ,
                    'created_by' => isset($battery->createdUser) ? $battery->createdUser->name :'',
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($battery->updated_at)) ,
                    'updated_by' => isset($battery->updatedUser) ? $battery->updatedUser->name :'',
                    'action' => '
                    <a href="'. route('asset.battery.show', ['battery' => $battery->id]) . '"><i class="mdi mdi-eye font-size-16 text-success me-1"></i></a>
                    <a href="'. route('asset.battery.edit', ['battery' => $battery->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('asset.battery.destroy', ['battery' => $battery->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    public function asset_battery_list(Request $request){
        $batteryList = Battery::whereNull('deleted_at')->where('model_name', $request->model_name)->get();
        $data = [];
        if( $request->with == 'parts'){
            foreach($batteryList as $battery){
                if($battery->parts){
                    foreach($battery->parts as $parts){
                        if($parts){
                            //$productType = ProductType::whereNull('deleted_at')->where('id', $parts->product_id)->first();
                            $data[$parts->id] = $parts?->product?->product_type . ' ' . $parts->part_id;
                        }
                    }
                }
            }
        }
        return response()->json([
            'mode' => true,
            'message' => 'Asset battery List',
            'errors' => '',
            'data' => $data
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'model_number' => [
                    'required',
                    Rule::unique('a_battery')->ignore($request->all()['id']),
                ],
                'product_id' => 'required',
                'oem_id' => 'required',
                'battery_dealer_id' => 'required',
                'location_id' => 'required',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
                'purchased_invoice_number' => 'required',
                'purchased_date' => 'required',
                'model_name' => 'required',
                'battery_type' => 'required',
                'vehicle_oem_id' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'model_number' => 'required|unique:a_battery,model_number',
                'product_id' => 'required',
                'oem_id' => 'required',
                'battery_dealer_id' => 'required',
                'location_id' => 'required',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
                'purchased_invoice_number' => 'required',
                'purchased_date' => 'required',
                'model_name' => 'required',
                'battery_type' => 'required',
                'vehicle_oem_id' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $vehicleList = VehicleOem::get();

        return view('admin.assets.battery.create',compact('vehicleList'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $this->save_data($request);

        return redirect('admin/asset/battery')->with('flash_message', 'Battery Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $battery = Battery::findOrFail($id);
        return view('admin.assets.battery.show', compact('battery'));
    }


    public function batterydealer(Request $request)
    {
      //$id = $_POST['id'];
      $id = $request->input('id');
      $products = Dealer::where('oem_id', $id)->get();
     // dd($products);
       return response()->json($products);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $battery = Battery::findOrFail($id);
        
        return view('admin.assets.battery.edit', compact('battery'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $this->save_data($request);

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery updated!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/battery')->with('flash_message', 'Battery updated!');
    }

    public function save_data($request){

        $requestData = $request->all();

        $battery = [];
        if($request->id){
            $battery = Battery::findOrFail($request->id);
        }
      
        if($battery){
            $battery->update($requestData);
        }else{
            $battery = Battery::create($requestData);
        }
        $requestData['purchased_date'] =  $requestData['purchased_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['purchased_date'] )) : $battery->purchased_date;
        $battery->update($requestData);
        
        if(isset($requestData['asset_image'])){
            foreach($requestData['asset_image'] as $image){
                $file = $image;
                $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                //$filePath = $file->storeAs('uploads/assets/battery/'.$battery->id, $savedAs, 'public');
                $path = '/uploads/assets/battery/'.$battery->id. '/' . $savedAs;
                $filePath = $this->uploadFile($path, $file);
                
                $assetImageData = [
                    'battery_id' => $battery->id,
                    'name' => $file->getClientOriginalName(),
                    'path' => $path,
                    'saved_as' => $savedAs,
                ];
                $assetImage = BatteryImages::create($assetImageData);
            }
        }

        $linkedVehicleOems = BatteryVehicleOem::where('battery_id', $battery->id)->pluck('vehicle_oem_id')->toArray();
        foreach($linkedVehicleOems as $linkedVehicleOem){
            if(!in_array($linkedVehicleOem, $requestData['vehicle_model'])){
                $deleteb = BatteryVehicleOem::where('battery_id', $battery->id)->where('vehicle_oem_id', $linkedVehicleOem)->delete();
            }
        }
        if(isset($requestData['vehicle_oem_id'])){
            foreach($requestData['vehicle_oem_id'] as $vehicle_oem_id){
                $batteryVehicleOemData = [
                    'battery_id' => $battery->id,
                    'vehicle_oem_id' => $vehicle_oem_id,
                ];
                $batteryVehicleOem = BatteryVehicleOem::where('battery_id', $battery->id)->where('vehicle_oem_id', $vehicle_oem_id)->first();
                if(empty($batteryVehicleOem)){
                    $batteryVehicleOem = BatteryVehicleOem::create($batteryVehicleOemData);
                }
            }
        }
        $linkedVehicleModels = BatteryVehicleModel::where('battery_id', $battery->id)->pluck('vehicle_model')->toArray();
        foreach($linkedVehicleModels as $linkedVehicleModel){
            if(!in_array($linkedVehicleModel, $requestData['vehicle_model'])){
                $deleteb = BatteryVehicleModel::where('battery_id', $battery->id)->where('vehicle_model', $linkedVehicleModel)->delete();
            }
        }
        if(isset($requestData['vehicle_model'])){
            foreach($requestData['vehicle_model'] as $vehicle_model){
                $batteryVehicleModelData = [
                    'battery_id' => $battery->id,
                    'vehicle_model' => $vehicle_model,
                ];
                $batteryVehicleModel = BatteryVehicleModel::where('battery_id', $battery->id)->where('vehicle_model', $vehicle_model)->first();
                if(empty($batteryVehicleModel)){
                    $batteryVehicleModel = BatteryVehicleModel::create($batteryVehicleModelData);
                }
            }
        }
        foreach($requestData['asset-parts'] as $assetParts){
            $assetPartsData = [
                'battery_id' => $battery->id,
                'product_id' => $assetParts['asset_part'],
                'part_id' => $assetParts['part_id'],
                //'qr_code' => $assetParts['field_name'],
            ];
            
            if(isset($assetParts['asset_part_id'])){
                if($assetParts['asset_part_id'] != ''){
                    $assetPart =  BatteryParts::findOrFail($assetParts['asset_part_id']);
                    $assetPart->update($assetPartsData);
                }else{
                    $assetPart = BatteryParts::create($assetPartsData);
                }
            }else{
                $assetPart = BatteryParts::create($assetPartsData);
            }
        }
        if(isset($requestData['asset-maintenance'])){
            foreach($requestData['asset-maintenance'] as $servicePlanField){
                if($servicePlanField['maintenance_type_id']){
                        $servicePlanData = [
                        'battery_id' => $battery->id,
                        'maintenance_type_id' => $servicePlanField['maintenance_type_id'],
                        'maintenance_duration' => $servicePlanField['maintenance_duration'],
                        'maintenance_duration_date' => ($servicePlanField['maintenance_duration_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['maintenance_duration_date'] )) : null,
                        'maintenance_cost' => $servicePlanField['maintenance_cost'],
                        'service_reminder' => $servicePlanField['service_reminder'],
                        'service_reminder_date' => ($servicePlanField['service_reminder_date']) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['service_reminder_date'] )) : null,
                    ];
                    if(isset($servicePlanField['asset_service_id'])){
                        if($servicePlanField['asset_service_id'] != ''){
                            $servicePlan =  BatteryServicePlan::findOrFail($servicePlanField['asset_service_id']);
                            $servicePlan->update($servicePlanData);
                        }else{
                            $servicePlan = BatteryServicePlan::create($servicePlanData);
                        }
                    }else{
                        $servicePlan = BatteryServicePlan::create($servicePlanData);
                    }
                }
            }
        }

        if(isset($requestData['asset-insurance'])){
            foreach($requestData['asset-insurance'] as $insurancePlanField){

                if($insurancePlanField['insurance_type_id']){
                    $insurancePlan = [];
                    if(isset($insurancePlanField['asset_insurance_id'])){
                        if($insurancePlanField['asset_insurance_id'] != ''){
                            $insurancePlan =  BatteryInsurancePlan::findOrFail($insurancePlanField['asset_insurance_id']);
                        }else{
                            $insurancePlan = [];
                        }
                    }
                    $insurancePlannData = [
                        'battery_id' => $battery->id,
                        'insurance_type_id' => $insurancePlanField['insurance_type_id'],
                        'insurance_duration' => ((isset($insurancePlanField['insurance_duration'])) ? $insurancePlanField['insurance_duration'] : (($insurancePlan) ? $insurancePlan->insurance_duration : null)),
                        'insurance_duration_date' => ($insurancePlanField['insurance_duration_date']) ? date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_duration_date'] )) : null,
                        'maintenance_cost' => isset($insurancePlanField['maintenance_cost']) ? $insurancePlanField['maintenance_cost'] : '',
                        'service_reminder' => $insurancePlanField['insurance_service_reminder'],
                        'service_reminder_date' => ($insurancePlanField['insurance_service_reminder_date']) ?  date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_service_reminder_date'] )) : null,
                    ];
                    
                    if(isset($insurancePlanField['asset_insurance_id'])){
                        if($insurancePlanField['asset_insurance_id'] != ''){
                            $insurancePlan =  BatteryInsurancePlan::findOrFail($insurancePlanField['asset_insurance_id']);
                            $insurancePlan->update($insurancePlannData);
                        }else{
                            $insurancePlan = BatteryInsurancePlan::create($insurancePlannData);
                        }
                    }else{
                        $insurancePlan = BatteryInsurancePlan::create($insurancePlannData);
                    }
                }
            }
        }
    }

    public function asset_qr($id)
    {
        $battery = Battery::findOrFail($id);
        return view('admin.assets.battery.asset_qr', compact('battery'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Battery::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/battery')->with('flash_message', 'Battery deleted!');
    }
    public function destroy_parts(Request $request, $id)
    {
        BatteryParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_service_plan(Request $request, $id)
    {
        BatteryServicePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery Service Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_insurance_plan(Request $request, $id)
    {
        BatteryInsurancePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery Insurance Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function list_by_type(Request $request)
    {
        if(!isset($request->product_id)){
            $request->product_id = $request->asset_type_id;
        }
        $batteryList = Battery::whereNull('deleted_at')->where('product_id', $request->product_id)->get();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery list',
                'errors' => '',
                'data' => $batteryList
            ], 200);
        }
    }
    public function destroy_images(Request $request, $id)
    {
        if($request->path){
            $batteryImages = BatteryImages::where('path', $request->path)->where('battery_id', $id)->first();
            $this->deleteFile($batteryImages->path);
            BatteryImages::destroy($batteryImages->id);
        }else{
            $batteryImages = BatteryImages::findOrFail($id);
            $this->deleteFile($battery->path);
            BatteryImages::destroy($id);
            if($request->ajax()){
                return response()->json([
                    'mode' => true,
                    'message' => 'Battery Images deleted!',
                    'errors' => ''
                ], 200);
            }
        }
        return true;
    }
}
