<?php

namespace App\Http\Controllers\Admin\Assets;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Assets\Charger;
use App\Models\Vendors\ChargingStation as Dealer;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Vendors\VendorCategory;
use App\Models\Vendors\VendorOem;
use App\Models\Location;
use App\Models\Master\ProductType;
use App\Models\Master\MaintenanceType;
use App\Models\Master\InsuranceType;
use App\Models\Assets\ChargerParts;
use App\Models\Assets\ChargerImages;
use App\Models\Assets\ChargerServicePlan;
use App\Models\Assets\ChargerInsurancePlan;
use App\Models\Master\Duration;


class ChargerController extends AppController
{
    public function __construct()
    {
        $productTypeList = ProductType::whereNull('deleted_at')->get();
        $MaintenanceTypeList = MaintenanceType::whereNull('deleted_at')->get();
        $insuranceTypeList = InsuranceType::whereNull('deleted_at')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $dealerList = Dealer::whereNull('deleted_at')->get();
        $vendorOemList = VendorOem::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        View::share([
            'productTypeList' => $productTypeList, 
            'MaintenanceTypeList' => $MaintenanceTypeList, 
            'insuranceTypeList' => $insuranceTypeList, 
            'dealerList' => $dealerList, 
            'locationList' => $locationList, 
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'vendorOemList' => $vendorOemList, 
            'durationList' => $durationList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $chargerList = Charger::whereNull('deleted_at')->get();
        return view('admin.assets.charger.index', compact('chargerList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $charger = ((new Charger())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Charger())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($charger->isEmpty()) {
            
        }else{
            foreach($charger as $charger){
                $data['data'][] = [
                    'id' => $charger->id,
                    'product_id' => isset($charger->product) ? $charger->product->product_type :'',
                //    'charger_type' => $charger->charger_type,
                    'model_name' => $charger->model_name,
                    'charger_type' => $charger->charger_type,
                    'vin_number' => $charger->vin_number,
                    'oem_id' => isset($charger->vendorOem) ? $charger->vendorOem->vendor_oem :'',
                    'charger_dealer_id' => isset($charger->chargerDealer) ? $charger->chargerDealer->station_dealer :'',
                    'purchased_invoice_number' => $charger->purchased_invoice_number,
                    'purchased_date' => $charger->purchased_date,
                    'location_id' => isset($charger->location) ? $charger->location->location :'',
                    'city_id' => isset($charger->city) ? $charger->city->city :'',
                    'district_id' => isset($charger->district) ? $charger->district->district :'',
                    'state_id' => isset($charger->state) ? $charger->state->state :'',
                    'zone_id' => isset($charger->zone) ? $charger->zone->zone :'',
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($charger->created_at)) ,
                    'action' => '
                    <a href="'. route('asset.charger.show', ['charger' => $charger->id]) . '"><i class="mdi mdi-eye font-size-16 text-success me-1"></i></a>
                    <a href="'. route('asset.charger.edit', ['charger' => $charger->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('asset.charger.destroy', ['charger' => $charger->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'vin_number' => [
                    'required',
                    Rule::unique('a_charger')->ignore($request->all()['id']),
                ],
                'product_id' => 'required',
               // 'oem_id' => 'required',
               // 'charger_dealer_id' => 'required',
                //'location_id' => 'required',
                //'city_id' => 'required',
                //'district_id' => 'required',
                //'state_id' => 'required',
                //'zone_id' => 'required',
                //'purchased_invoice_number' => 'required',
                //'purchased_date' => 'required',
                'model_name' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'vin_number' => 'required|unique:a_charger,vin_number',
                'product_id' => 'required',
               // 'oem_id' => 'required',
              //  'charger_dealer_id' => 'required',
              //  'location_id' => 'required',
               // 'city_id' => 'required',
                //'district_id' => 'required',
                //'state_id' => 'required',
                //'zone_id' => 'required',
          
                'model_name' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.assets.charger.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
       // $formData = $requestData['data'];
       // print_r($requestData); exit;

        $requestData['purchased_date'] =  $requestData['purchased_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['purchased_date'] )) : null;

        $charger = Charger::create($requestData);

        foreach($requestData['asset-parts'] as $assetParts){
            $assetPartsData = [
                'charger_id' => $charger->id,
                'product_id' => $assetParts['asset_part'],
                'part_id' => $assetParts['part_id'],
                //'qr_code' => $assetParts['field_name'],
            ];
            
            $assetPart = ChargerParts::create($assetPartsData);
        }
        foreach($requestData['asset-maintenance'] as $servicePlanField){
            if($servicePlanField['maintenance_type_id']){
                $servicePlanData = [
                'charger_id' => $charger->id,
                'maintenance_type_id' => $servicePlanField['maintenance_type_id'],
                'maintenance_duration' => $servicePlanField['maintenance_duration'],
                'maintenance_duration_date' => $servicePlanField['maintenance_duration_date'] ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['maintenance_duration_date'] )) : null,
                'maintenance_cost' => $servicePlanField['maintenance_cost'],
                'service_reminder' => $servicePlanField['service_reminder'],
                'service_reminder_date' => ($servicePlanField['service_reminder_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['service_reminder_date'] )) : null,
                
                ];

                $servicePlan = ChargerServicePlan::create($servicePlanData);
            }
        }

        foreach($requestData['asset-insurance'] as $insurancePlanField){
            if($insurancePlanField['insurance_type_id']){
                $insurancePlannData = [
                'charger_id' => $charger->id,
                'insurance_type_id' => $insurancePlanField['insurance_type_id'],
                'insurance_duration' => isset($insurancePlanField['insurance_duration']) ? $insurancePlanField['insurance_duration'] : '',
                'insurance_duration_date' => $insurancePlanField['insurance_duration_date'] ? date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_duration_date'] )) : null,
                'maintenance_cost' => isset($insurancePlanField['maintenance_cost']) ? $insurancePlanField['maintenance_cost'] : '',
                'service_reminder' => $insurancePlanField['insurance_service_reminder'],
                'service_reminder_date' => ($insurancePlanField['insurance_service_reminder_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_service_reminder_date'] )) : null,
                ];
                $insurancePlan = ChargerInsurancePlan::create($servicePlanData);
            }
        }
        if(isset($requestData['asset_image'])){
            foreach($requestData['asset_image'] as $image){
                $file = $image;
                $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                //$filePath = $file->storeAs('uploads/assets/charger/'.$charger->id, $savedAs, 'public');
                $path = '/uploads/assets/charger/'.$charger->id. '/'.  $savedAs;
                $filePath = $this->uploadFile($path, $file);
                
                $assetImageData = [
                    'charger_id' => $charger->id,
                    'name' => $file->getClientOriginalName(),
                    'path' => $path,
                    'saved_as' => $savedAs,
                ];
                
                $assetPart = ChargerImages::create($assetImageData);
            }
        }
        return redirect('admin/asset/charger')->with('flash_message', 'Charger Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $charger = Charger::findOrFail($id);
        return view('admin.assets.charger.show', compact('charger'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $charger = Charger::findOrFail($id);
        
        return view('admin.assets.charger.edit', compact('charger'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $charger = Charger::findOrFail($id);
        $requestData['purchased_date'] =  $requestData['purchased_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['purchased_date'] )) : $charger->purchased_date;
        $charger->update($requestData);
        foreach($requestData['asset-parts'] as $assetParts){
            $assetPartsData = [
                'charger_id' => $charger->id,
                'product_id' => $assetParts['asset_part'],
                'part_id' => $assetParts['part_id'],
                //'qr_code' => $assetParts['field_name'],
            ];
            
            if(isset($assetParts['asset_part_id'])){
                if($assetParts['asset_part_id'] != ''){
                    $assetPart =  ChargerParts::findOrFail($assetParts['asset_part_id']);
                    $assetPart->update($assetPartsData);
                }else{
                    $assetPart = ChargerParts::create($assetPartsData);
                }
            }else{
                $assetPart = ChargerParts::create($assetPartsData);
            }
        }
        foreach($requestData['asset-maintenance'] as $servicePlanField){
            if($servicePlanField['maintenance_type_id']){
                $servicePlanData = [
                    'charger_id' => $charger->id,
                    'maintenance_type_id' => $servicePlanField['maintenance_type_id'],
                    'maintenance_duration' => $servicePlanField['maintenance_duration'],
                    'maintenance_duration_date' => ($servicePlanField['maintenance_duration_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['maintenance_duration_date'] )) : null,
                    'maintenance_cost' => $servicePlanField['maintenance_cost'],
                    'service_reminder' => $servicePlanField['service_reminder'],
                    'service_reminder_date' => ($servicePlanField['service_reminder_date']) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['service_reminder_date'] )) : null,
                ];
                if(isset($servicePlanField['asset_service_id'])){
                    if($servicePlanField['asset_service_id'] != ''){
                        $servicePlan =  ChargerServicePlan::findOrFail($servicePlanField['asset_service_id']);
                        $servicePlan->update($servicePlanData);
                    }else{
                        $servicePlan = ChargerServicePlan::create($servicePlanData);
                    }
                }else{
                    $servicePlan = ChargerServicePlan::create($servicePlanData);
                }
            }
        }

        foreach($requestData['asset-insurance'] as $insurancePlanField){
            if($insurancePlanField['insurance_type_id']){
                $insurancePlannData = [
                'charger_id' => $charger->id,
                'insurance_type_id' => $insurancePlanField['insurance_type_id'],
                'insurance_duration' => isset($insurancePlanField['insurance_duration']) ? $insurancePlanField['insurance_duration'] : '',
                'insurance_duration_date' => ($insurancePlanField['insurance_duration_date']) ? date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_duration_date'] )) : null,
                'maintenance_cost' => isset($insurancePlanField['maintenance_cost']) ? $insurancePlanField['maintenance_cost'] : '',
                'service_reminder' => $insurancePlanField['insurance_service_reminder'],
                'service_reminder_date' => ($insurancePlanField['insurance_service_reminder_date']) ?  date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_service_reminder_date'] )) : null,
                ];
                
                if(isset($insurancePlanField['asset_insurance_id'])){
                    if($insurancePlanField['asset_insurance_id'] != ''){
                        $insurancePlan =  ChargerInsurancePlan::findOrFail($insurancePlanField['asset_insurance_id']);
                        $insurancePlan->update($insurancePlannData);
                    }else{
                        $insurancePlan = ChargerInsurancePlan::create($insurancePlannData);
                    }
                }else{
                    $insurancePlan = ChargerInsurancePlan::create($insurancePlannData);
                }
            }
        }
        if(isset($requestData['asset_image'])){
            foreach($requestData['asset_image'] as $image){
                $file = $image;
                $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                //$filePath = $file->storeAs('uploads/assets/charger/'.$charger->id, $savedAs, 'public');
                $path = '/uploads/assets/charger/'.$charger->id. '/' . $savedAs;
                $filePath = $this->uploadFile($path, $file);
                
                $assetImageData = [
                    'charger_id' => $charger->id,
                    'name' => $file->getClientOriginalName(),
                    'path' => $path,
                    'saved_as' => $savedAs,
                ];
                $assetImage = ChargerImages::create($assetImageData);
            }
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charger updated!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/charger')->with('flash_message', 'Charger updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Charger::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charger deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/charger')->with('flash_message', 'Charger deleted!');
    }
    public function destroy_parts(Request $request, $id)
    {
        ChargerParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charger Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_service_plan(Request $request, $id)
    {
        ChargerServicePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charger Service Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_insurance_plan(Request $request, $id)
    {
        ChargerInsurancePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charger Insurance Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
}
