<?php

namespace App\Http\Controllers\Admin\Assets;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Assets\ChargingEquipment;
use App\Models\Vendors\ChargingStation as Dealer;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Vendors\VendorCategory;
use App\Models\Vendors\VendorOem;
use App\Models\Location;
use App\Models\Master\ProductType;
use App\Models\Master\MaintenanceType;
use App\Models\Master\InsuranceType;
use App\Models\Assets\ChargingEquipmentParts;
use App\Models\Assets\ChargingEquipmentImages;
use App\Models\Assets\ChargingEquipmentServicePlan;
use App\Models\Assets\ChargingEquipmentInsurancePlan;
use App\Models\Master\Duration;


class ChargingEquipmentController extends AppController
{
    public function __construct()
    {
        $productTypeList = ProductType::whereNull('deleted_at')->get();
        $MaintenanceTypeList = MaintenanceType::whereNull('deleted_at')->get();
        $insuranceTypeList = InsuranceType::whereNull('deleted_at')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $dealerList = Dealer::whereNull('deleted_at')->get();
        $vendorOemList = VendorOem::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        $vehicleOemList  = VendorOem::whereNull('deleted_at')->where('vendor_category_id', 1)->get();
        View::share([
            'productTypeList' => $productTypeList, 
            'MaintenanceTypeList' => $MaintenanceTypeList, 
            'insuranceTypeList' => $insuranceTypeList, 
            'dealerList' => $dealerList, 
            'locationList' => $locationList, 
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'vendorOemList' => $vendorOemList, 
            'vehicleOemList' => $vehicleOemList, 
            'durationList' => $durationList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $chargingEquipmentList = ChargingEquipment::whereNull('deleted_at')->get();
        return view('admin.assets.charging_equipment.index', compact('chargingEquipmentList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $chargingEquipment = ((new ChargingEquipment())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ChargingEquipment())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($chargingEquipment->isEmpty()) {
            
        }else{
            foreach($chargingEquipment as $chargingEquipment){
                $data['data'][] = [
                    'id' => $chargingEquipment->id,
                    'product_id' => isset($chargingEquipment->product) ? $chargingEquipment->product->product_type :'',
                    'oem_id' => isset($chargingEquipment->vendorOem) ? $chargingEquipment->vendorOem->vendor_oem :'',
                    'charger_type' => $chargingEquipment->charger_type,
                    'model_name' => $chargingEquipment->model_name,
                    'model_number' => $chargingEquipment->model_number,
                    'kwh_units' => $chargingEquipment->kwh_units,
                    'gun_type' => $chargingEquipment->gun_type,
                    'qr_code' => '<a href="#" id="' . $chargingEquipment->id . '" class="view_asset_qr">View</a>',
                    'charging_equipment_dealer_id' => isset($chargingEquipment->chargingEquipmentDealer) ? $chargingEquipment->chargingEquipmentDealer->battery_dealer :'',
                    'purchased_invoice_number' => $chargingEquipment->purchased_invoice_number,
                    'parts' => isset($chargingEquipment->parts) ? '<a href="#" id="' . $chargingEquipment->id . '" class="view_asset_parts_qr">'. count($chargingEquipment->parts) .'</a>' : '',
                    'location_id' => isset($chargingEquipment->location) ? $chargingEquipment->location->location :'',
                    'service_plan' => isset($chargingEquipment->servicePlan) ? count($chargingEquipment->servicePlan) : '',
                    'insurance_plan' => isset($chargingEquipment->insurancePlan) ? count($chargingEquipment->insurancePlan) : '',
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($chargingEquipment->created_at)) ,
                    'created_by' => isset($chargingEquipment->createdUser) ? $chargingEquipment->createdUser->name :'',
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($chargingEquipment->updated_at)) ,
                    'updated_by' => isset($chargingEquipment->updatedUser) ? $chargingEquipment->updatedUser->name :'',
                    'action' => '
                    
                    <a href="'. route('asset.charging-equipment.edit', ['charging_equipment' => $chargingEquipment->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('asset.charging-equipment.destroy', ['charging_equipment' => $chargingEquipment->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        $validateData = [

            'product_id' => 'required',
            'oem_id' => 'required',
            'charging_equipment_dealer_id' => 'required',
            'location_id' => 'required',
            'city_id' => 'required',
            'district_id' => 'required',
            'state_id' => 'required',
            'zone_id' => 'required',
            'purchased_invoice_number' => 'required',
            'purchased_date' => 'required',
            'model_name' => 'required',
        ];
        if($request->id){
            $validateData['model_number'] = [
                'required',
                Rule::unique('a_charging_equipment')->ignore($request->all()['id']),
            ];
        }else{
            $validateData['model_number'] = 'required|unique:a_charging_equipment,model_number';
        }
        $validate = Validator::make($request->all(), $validateData);
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        $requestData = $request->all();
        if(isset($requestData['asset-parts'])){
            $errors = [];
            foreach($requestData['asset-parts'] as $assetParts){
                // print_r($assetParts); exit;
                if($assetParts['adapter_id']){
                    
                }else{
                    $errors['adapter_id'] = 'Adapter ID can not be blank';
                    return response()->json([
                        'mode' => false,
                        'toast' => true,
                        'message' => 'Validation errors in your request',
                        'errors' => $errors
                    ], 400);
                }
            }
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $chargingEquipment = new ChargingEquipment();
        
        return view('admin.assets.charging_equipment.edit', compact('chargingEquipment'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $this->save_data($request);

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Equipment updated!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/charging-equipment')->with('flash_message', 'Charging Equipment Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $chargingEquipment = ChargingEquipment::findOrFail($id);
        return view('admin.assets.charging_equipment.show', compact('chargingEquipment'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $chargingEquipment = ChargingEquipment::findOrFail($id);
        
        return view('admin.assets.charging_equipment.edit', compact('chargingEquipment'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $this->save_data($request);

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Equipment updated!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/charging-equipment')->with('flash_message', 'ChargingEquipment updated!');
    }
    public function save_data($request){

        $requestData = $request->all();
        $chargingEquipment = [];
        if($request->id){
            $chargingEquipment = ChargingEquipment::findOrFail($request->id);
        }
      
        if($chargingEquipment){
            $requestData['purchased_date'] =  $requestData['purchased_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['purchased_date'] )) : $chargingEquipment->purchased_date;
            $chargingEquipment->update($requestData);
        }else{
            
            $requestData['purchased_date'] =  $requestData['purchased_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['purchased_date'] )) : null;
            $chargingEquipment = ChargingEquipment::create($requestData);

        }
        if(isset($requestData['asset_image'])){
            foreach($requestData['asset_image'] as $image){
                $file = $image;
                $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                //$filePath = $file->storeAs('uploads/assets/charging-equipment/'.$chargingEquipment->id, $savedAs, 'public');
                $path = '/uploads/assets/charging-equipment/'.$chargingEquipment->id. '/' . $savedAs;
                $filePath = $this->uploadFile($path, $file);
                
                $assetImageData = [
                    'charging_equipment_id' => $chargingEquipment->id,
                    'name' => $file->getClientOriginalName(),
                    'path' => $path,
                    'saved_as' => $savedAs,
                ];
                $chargingEquipmentImages = ChargingEquipmentImages::create($assetImageData);
            }
        }

        if(isset($requestData['asset-parts'])){
            foreach($requestData['asset-parts'] as $assetParts){
               // print_r($assetParts); exit;
                if($assetParts['adapter_id']){
                    $assetPartsData = [
                        'charging_equipment_id' => $chargingEquipment->id,
                        'adapter_name' => $assetParts['adapter_name'],
                        'adapter_id' => $assetParts['adapter_id'],
                        'adapter_model' => $assetParts['adapter_model'],
                        'plug_pin_points' => $assetParts['plug_pin_points'],
                        'adapter_description' => $assetParts['adapter_description'],
                        'dispesing_units' => $assetParts['dispesing_units'],
                        'vehicle_oem' => isset($assetParts['vehicle_oem']) ? implode(",", $assetParts['vehicle_oem']) : '',
                        'market_vehicle_oem' => $assetParts['market_vehicle_oem'],
                        'market_vehicle_model' => $assetParts['market_vehicle_model'],
                        //'product_id' => $assetParts['asset_part'],
                        //'part_id' => $assetParts['part_id'],
                        //'qr_code' => $assetParts['field_name'],
                    ];
                    
                    if(isset($assetParts['asset_part_id'])){
                        if($assetParts['asset_part_id'] != ''){
                            $assetPart =  ChargingEquipmentParts::findOrFail($assetParts['asset_part_id']);
                            $assetPart->update($assetPartsData);
                        }else{
                            $assetPart = ChargingEquipmentParts::create($assetPartsData);
                        }
                    }else{
                        $assetPart = ChargingEquipmentParts::create($assetPartsData);
                    }
                }
            }
        }
        if(isset($requestData['asset-maintenance'])){
            foreach($requestData['asset-maintenance'] as $servicePlanField){
                if($servicePlanField['maintenance_type_id']){
                    $servicePlanData = [
                    'charging_equipment_id' => $chargingEquipment->id,
                    'maintenance_type_id' => $servicePlanField['maintenance_type_id'],
                    'maintenance_duration' => $servicePlanField['maintenance_duration'],
                    'maintenance_duration_date' => ($servicePlanField['maintenance_duration_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['maintenance_duration_date'] )) : null,
                    'maintenance_cost' => $servicePlanField['maintenance_cost'],
                    'service_reminder' => $servicePlanField['service_reminder'],
                    'service_reminder_date' => ($servicePlanField['service_reminder_date']) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['service_reminder_date'] )) : null,
                    ];
                    if(isset($servicePlanField['asset_service_id'])){
                        if($servicePlanField['asset_service_id'] != ''){
                            $servicePlan =  ChargingEquipmentServicePlan::findOrFail($servicePlanField['asset_service_id']);
                            $servicePlan->update($servicePlanData);
                        }else{
                            $servicePlan = ChargingEquipmentServicePlan::create($servicePlanData);
                        }
                    }else{
                        $servicePlan = ChargingEquipmentServicePlan::create($servicePlanData);
                    }
                }
            }
        }

        if(isset($requestData['asset-insurance'])){
            foreach($requestData['asset-insurance'] as $insurancePlanField){
                if($insurancePlanField['insurance_type_id']){
                    $insurancePlannData = [
                    'charging_equipment_id' => $chargingEquipment->id,
                    'insurance_type_id' => $insurancePlanField['insurance_type_id'],
                    'insurance_duration' => isset($insurancePlanField['insurance_duration']) ? $insurancePlanField['insurance_duration'] : '',
                    'insurance_duration_date' => ($insurancePlanField['insurance_duration_date']) ? date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_duration_date'] )) : null,
                    'maintenance_cost' => isset($insurancePlanField['maintenance_cost']) ? $insurancePlanField['maintenance_cost'] : '',
                    'service_reminder' => $insurancePlanField['insurance_service_reminder'],
                    'service_reminder_date' => ($insurancePlanField['insurance_service_reminder_date']) ?  date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_service_reminder_date'] )) : null,
                    ];
                    
                    if(isset($insurancePlanField['asset_insurance_id'])){
                        if($insurancePlanField['asset_insurance_id'] != ''){
                            $insurancePlan =  ChargingEquipmentInsurancePlan::findOrFail($insurancePlanField['asset_insurance_id']);
                            $insurancePlan->update($insurancePlannData);
                        }else{
                            $insurancePlan = ChargingEquipmentInsurancePlan::create($insurancePlannData);
                        }
                    }else{
                        $insurancePlan = ChargingEquipmentInsurancePlan::create($insurancePlannData);
                    }
                }
            }
        }
    }
    public function asset_qr($id)
    {
        $chargingEquipment = ChargingEquipment::findOrFail($id);
        return view('admin.assets.charging_equipment.asset_qr', compact('chargingEquipment'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    
     public function asset_charging_equipment_list(Request $request){
        $chargingEquipmentList = ChargingEquipment::whereNull('deleted_at')->where('model_name', $request->model_name)->get();
        $data = [];
        if( $request->with == 'parts'){
            foreach($chargingEquipmentList as $chargingEquipment){
                if($chargingEquipment->parts){
                    foreach($chargingEquipment->parts as $parts){
                        if($parts){
                            //$productType = ProductType::whereNull('deleted_at')->where('id', $parts->product_id)->first();
                            $data[$parts->id] = $parts->adapter_name . ' ' . $parts->adapter_id;
                        }
                    }
                }
            }
        }
        return response()->json([
            'mode' => true,
            'message' => 'Charging Equipment List',
            'errors' => '',
            'data' => $data
        ], 200);
    }
    public function list_by_type(Request $request)
    {
        if(!isset($request->product_id)){
            $request->product_id = $request->asset_type_id;
        }
        $chargingEquipmentList = ChargingEquipment::whereNull('deleted_at')->where('product_id', $request->product_id)->groupBy('model_name')->get();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Equipment list',
                'errors' => '',
                'data' => $chargingEquipmentList
            ], 200);
        }
    }
    public function list_by_model(Request $request)
    {
        if(!isset($request->product_id)){
            $request->product_id = $request->asset_type_id;
        }
        $chargingEquipmentList = ChargingEquipment::whereNull('deleted_at')->where('model_name', $request->model_name)->get();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Equipment list',
                'errors' => '',
                'data' => $chargingEquipmentList
            ], 200);
        }
    }
    public function part_list_by_asset(Request $request)
    {
        if(!isset($request->id)){
            $request->id = $request->asset_id;
        }
        $chargingEquipmentList = ChargingEquipment::whereNull('deleted_at')->where('id', $request->id)->first();
        foreach($chargingEquipmentList->parts as $parts){

            $chargingEquipmentList->parts->product = $parts->product;
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Equipment list',
                'errors' => '',
                'data' => $chargingEquipmentList->parts
            ], 200);
        }
    }
    public function destroy(Request $request, $id)
    {
        $chargingEquipment = ChargingEquipment::findOrFail($id);
        if($chargingEquipment->parts){
            foreach($chargingEquipment->parts as $parts){
                $this->destroy_parts($request, $parts->id);
            }
        }
        if($chargingEquipment->servicePlan){
            foreach($chargingEquipment->servicePlan as $servicePlan){
                $this->destroy_service_plan($request, $servicePlan->id);
            }
        }
        if($chargingEquipment->insurancePlan){
            foreach($chargingEquipment->insurancePlan as $insurancePlan){
                $this->destroy_insurance_plan($request, $insurancePlan->id);
            }
        }
        if($chargingEquipment->images){
            foreach($chargingEquipment->images as $images){
                $this->destroy_images($request, $images->id);
            }
        }
        ChargingEquipment::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/charging-equipment')->with('flash_message', 'ChargingEquipment deleted!');
    }
    public function destroy_parts(Request $request, $id)
    {
        ChargingEquipmentParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_service_plan(Request $request, $id)
    {
        ChargingEquipmentServicePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment Service Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_insurance_plan(Request $request, $id)
    {
        ChargingEquipmentInsurancePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment Insurance Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_images(Request $request, $id)
    {
        if($request->path){
            $chargingEquipmentImages = ChargingEquipmentImages::where('path', $request->path)->where('charging_equipment_id', $id)->first();
            $this->deleteFile($chargingEquipmentImages->path);
            ChargingEquipmentImages::destroy($chargingEquipmentImages->id);
        }else{
            $chargingEquipmentImages = ChargingEquipmentImages::findOrFail($id);
            $this->deleteFile($chargingEquipmentImages->path);
            ChargingEquipmentImages::destroy($id);
            if($request->ajax()){
                return response()->json([
                    'mode' => true,
                    'message' => 'ChargingEquipment Images deleted!',
                    'errors' => ''
                ], 200);
            }
        }
        return true;
    }
}
