<?php

namespace App\Http\Controllers\Admin\Assets;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Assets\ChargingStation;
use App\Models\Vendors\ChargingStation as Dealer;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Vendors\VendorCategory;
use App\Models\Vendors\VendorOem;
use App\Models\Location;
use App\Models\Master\ProductType;
use App\Models\Master\PropertyType;
use App\Models\Master\MaintenanceType;
use App\Models\Master\InsuranceType;
use App\Models\Assets\ChargingStationParts;
use App\Models\Assets\ChargingStationImages;
use App\Models\Assets\ChargingStationServicePlan;
use App\Models\Assets\ChargingStationInsurancePlan;
use App\Models\Master\Duration;


class ChargingStationController extends AppController
{
    public function __construct()
    {
        $productTypeList = ProductType::whereNull('deleted_at')->get();
        $propertyTypeList = PropertyType::whereNull('deleted_at')->get();
        $MaintenanceTypeList = MaintenanceType::whereNull('deleted_at')->get();
        $insuranceTypeList = InsuranceType::whereNull('deleted_at')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $dealerList = Dealer::whereNull('deleted_at')->get();
        $vendorOemList = VendorOem::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        View::share([
            'productTypeList' => $productTypeList, 
            'propertyTypeList' => $propertyTypeList, 
            'MaintenanceTypeList' => $MaintenanceTypeList, 
            'insuranceTypeList' => $insuranceTypeList, 
            'dealerList' => $dealerList, 
            'locationList' => $locationList, 
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'vendorOemList' => $vendorOemList, 
            'durationList' => $durationList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $chargingStationList = ChargingStation::whereNull('deleted_at')->get();
        return view('admin.assets.charging_station.index', compact('chargingStationList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $chargingStationList = ((new ChargingStation())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ChargingStation())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($chargingStationList->isEmpty()) {
            
        }else{
            foreach($chargingStationList as $chargingStation){
                $data['data'][] = [
                    'id' => $chargingStation->id,
                    'product_id' => isset($chargingStation->product) ? $chargingStation->product->product_type :'',
                    'property_id' => isset($chargingStation->property) ? $chargingStation->property->property_type :'',
                //    'charging_station_type' => $chargingStation->charging_station_type,
                    'model_name' => $chargingStation->model_name,
                    'vin_number' => $chargingStation->vin_number,
                    'oem_id' => isset($chargingStation->vendorOem) ? $chargingStation->vendorOem->vendor_oem :'',
                    'charging_station_dealer_id' => isset($chargingStation->chargingStationDealer) ? $chargingStation->chargingStationDealer->battery_dealer :'',
                    'purchased_invoice_number' => $chargingStation->purchased_invoice_number,
                    'parts' => isset($chargingStation->parts) ? '<a href="#" id="' . $chargingStation->id . '" class="view_asset_parts_qr">'. count($chargingStation->parts) .'</a>' : '',
                    'location_id' => isset($chargingStation->location) ? $chargingStation->location->location :'',
                    'service_plan' => isset($chargingStation->servicePlan) ? count($chargingStation->servicePlan) : '',
                    'insurance_plan' => isset($chargingStation->insurancePlan) ? count($chargingStation->insurancePlan) : '',
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($chargingStation->created_at)) ,
                    'created_by' => isset($chargingStation->createdUser) ? $chargingStation->createdUser->name :'',
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($chargingStation->updated_at)) ,
                    'updated_by' => isset($chargingStation->updatedUser) ? $chargingStation->updatedUser->name :'',
                    'action' => '
                    <a href="'. route('asset.charging-station.show', ['charging_station' => $chargingStation->id]) . '"><i class="mdi mdi-eye font-size-16 text-success me-1"></i></a>
                    <a href="'. route('asset.charging-station.edit', ['charging_station' => $chargingStation->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('asset.charging-station.destroy', ['charging_station' => $chargingStation->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if($request->id){
            $validate = Validator::make($request->all(), [
                'vin_number' => [
                    'required',
                    Rule::unique('a_charging_station')->ignore($request->all()['id']),
                ],
                'product_id' => 'required',
                'oem_id' => 'required',
                'charging_station_dealer_id' => 'required',
                'location_id' => 'required',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
                'purchased_invoice_number' => 'required',
                'purchased_date' => 'required',
                'model_name' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'vin_number' => 'required|unique:a_charging_station,vin_number',
                'product_id' => 'required',
                'oem_id' => 'required',
                'charging_station_dealer_id' => 'required',
                'location_id' => 'required',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
                'purchased_invoice_number' => 'required',
                'purchased_date' => 'required',
                'model_name' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $chargingStation = new ChargingStation();
        return view('admin.assets.charging_station.edit', compact('chargingStation'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $this->save_data($request);

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Station Created!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/charging-station')->with('flash_message', 'ChargingStation Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $chargingStation = ChargingStation::findOrFail($id);
        return view('admin.assets.charging_station.show', compact('chargingStation'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $chargingStation = ChargingStation::findOrFail($id);
        
        return view('admin.assets.charging_station.edit', compact('chargingStation'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $this->save_data($request);

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Station updated!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/charging-station')->with('flash_message', 'Charging Station updated!');
    }
    public function save_data($request){
        
        $requestData = $request->all();

        $chargingStation = [];
        if($request->id){
            $chargingStation = ChargingStation::findOrFail($request->id);
        }
      
        if($chargingStation){
            $chargingStation->update($requestData);
        }else{
            $chargingStation = ChargingStation::create($requestData);

        }
        $requestData['purchased_date'] =  $requestData['purchased_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['purchased_date'] )) : $chargingStation->purchased_date;
        $chargingStation->update($requestData);
        if(isset($requestData['asset_image'])){
            foreach($requestData['asset_image'] as $image){
                $file = $image;
                $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                //$filePath = $file->storeAs('uploads/assets/charging-station/'.$chargingStation->id, $savedAs, 'public');
                $path = '/uploads/assets/charging-station/'.$chargingStation->id. '/' . $savedAs;
                $filePath = $this->uploadFile($path, $file);
                
                $assetImageData = [
                    'charging_station_id' => $chargingStation->id,
                    'name' => $file->getClientOriginalName(),
                    'path' => $path,
                    'saved_as' => $savedAs,
                ];
                $assetImage = ChargingStationImages::create($assetImageData);
            }
        }
        foreach($requestData['asset-parts'] as $assetParts){
            $assetPartsData = [
                'charging_station_id' => $chargingStation->id,
                'product_id' => $assetParts['asset_part'],
                'part_id' => $assetParts['part_id'],
                //'qr_code' => $assetParts['field_name'],
            ];
            
            if(isset($assetParts['asset_part_id'])){
                if($assetParts['asset_part_id'] != ''){
                    $assetPart =  ChargingStationParts::findOrFail($assetParts['asset_part_id']);
                    $assetPart->update($assetPartsData);
                }else{
                    $assetPart = ChargingStationParts::create($assetPartsData);
                }
            }else{
                $assetPart = ChargingStationParts::create($assetPartsData);
            }
        }
        if(isset($requestData['asset-maintenance'])){
            foreach($requestData['asset-maintenance'] as $servicePlanField){
                if($servicePlanField['maintenance_type_id']){
                    $servicePlanData = [
                    'charging_station_id' => $chargingStation->id,
                    'maintenance_type_id' => $servicePlanField['maintenance_type_id'],
                    'maintenance_duration' => $servicePlanField['maintenance_duration'],
                    'maintenance_duration_date' => ($servicePlanField['maintenance_duration_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['maintenance_duration_date'] )) : null,
                    'maintenance_cost' => $servicePlanField['maintenance_cost'],
                    'service_reminder' => $servicePlanField['service_reminder'],
                    'service_reminder_date' => ($servicePlanField['service_reminder_date']) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['service_reminder_date'] )) : null,
                    ];
                    if(isset($servicePlanField['asset_service_id'])){
                        if($servicePlanField['asset_service_id'] != ''){
                            $servicePlan =  ChargingStationServicePlan::findOrFail($servicePlanField['asset_service_id']);
                            $servicePlan->update($servicePlanData);
                        }else{
                            $servicePlan = ChargingStationServicePlan::create($servicePlanData);
                        }
                    }else{
                        $servicePlan = ChargingStationServicePlan::create($servicePlanData);
                    }
                }
            }
        }

        if(isset($requestData['asset-insurance'])){
            foreach($requestData['asset-insurance'] as $insurancePlanField){
                if($insurancePlanField['insurance_type_id']){
                    $insurancePlannData = [
                    'charging_station_id' => $chargingStation->id,
                    'insurance_type_id' => $insurancePlanField['insurance_type_id'],
                    'insurance_duration' => isset($insurancePlanField['insurance_duration']) ? $insurancePlanField['insurance_duration'] : '',
                    'insurance_duration_date' => ($insurancePlanField['insurance_duration_date']) ? date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_duration_date'] )) : null,
                    'maintenance_cost' => isset($insurancePlanField['maintenance_cost']) ? $insurancePlanField['maintenance_cost'] : '',
                    'service_reminder' => $insurancePlanField['insurance_service_reminder'],
                    'service_reminder_date' => ($insurancePlanField['insurance_service_reminder_date']) ?  date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_service_reminder_date'] )) : null,
                ];
                
                    if(isset($insurancePlanField['asset_insurance_id'])){
                        if($insurancePlanField['asset_insurance_id'] != ''){
                            $insurancePlan =  ChargingStationInsurancePlan::findOrFail($insurancePlanField['asset_insurance_id']);
                            $insurancePlan->update($insurancePlannData);
                        }else{
                            $insurancePlan = ChargingStationInsurancePlan::create($insurancePlannData);
                        }
                    }else{
                        $insurancePlan = ChargingStationInsurancePlan::create($insurancePlannData);
                    }
                }
            }
        }
        return true;
    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        ChargingStation::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Station deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/charging-station')->with('flash_message', 'Charging Station deleted!');
    }
    public function destroy_parts(Request $request, $id)
    {
        ChargingStationParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Station Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_service_plan(Request $request, $id)
    {
        ChargingStationServicePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Station Service Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_insurance_plan(Request $request, $id)
    {
        ChargingStationInsurancePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Station Insurance Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function list_by_type(Request $request)
    {
        if(!isset($request->product_id)){
            $request->product_id = $request->asset_type_id;
        }
        $chargingStationList = ChargingStation::whereNull('deleted_at')->where('product_id', $request->product_id)->get();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Station list',
                'errors' => '',
                'data' => $chargingStationList
            ], 200);
        }
    }
    public function destroy_images(Request $request, $id)
    {
        if($request->path){
            $chargingStationImages = ChargingStationImages::where('path', $request->path)->where('charging_station_id', $id)->first();
            $this->deleteFile($chargingStationImages->path);
            ChargingStationImages::destroy($chargingStationImages->id);
        }else{
            $chargingStationImages = ChargingStationImages::findOrFail($id);
            $this->deleteFile($chargingStationImages->path);
            ChargingStationImages::destroy($id);
            if($request->ajax()){
                return response()->json([
                    'mode' => true,
                    'message' => 'Charging Station Images deleted!',
                    'errors' => ''
                ], 200);
            }
        }
        return true;
    }
}
