<?php

namespace App\Http\Controllers\Admin\Assets;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Assets\Vehicle;
use App\Models\VehicleOem;
use App\Models\Assets\vendoroem_model;
use App\Models\Vendors\Vehicle as Dealer;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Vendors\VendorCategory;
use App\Models\Vendors\VendorOem;
use App\Models\Location;
use App\Models\Master\ProductType;
use App\Models\Master\MaintenanceType;
use App\Models\Master\InsuranceType;
use App\Models\Assets\VehicleParts;
use App\Models\Assets\VehicleImages;
use App\Models\Assets\VehicleServicePlan;
use App\Models\Assets\VehicleInsurancePlan;
use App\Models\Master\Duration;


class VehiclesController extends AppController
{
    public function __construct()
    {
        $productTypeList = ProductType::whereNull('deleted_at')->get();
        $MaintenanceTypeList = MaintenanceType::whereNull('deleted_at')->get();
        $insuranceTypeList = InsuranceType::whereNull('deleted_at')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $dealerList = Dealer::whereNull('deleted_at')->get();
        $vendorOemList = VendorOem::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        $vehicleOemList =VehicleOem::get();

        View::share([
            'productTypeList' => $productTypeList, 
            'MaintenanceTypeList' => $MaintenanceTypeList, 
            'insuranceTypeList' => $insuranceTypeList, 
            'dealerList' => $dealerList, 
            'locationList' => $locationList, 
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'vendorOemList' => $vendorOemList, 
            'durationList' => $durationList, 
            'vehicleOemList' => $vehicleOemList, 

        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        
        $vehicleList = Vehicle::whereNull('deleted_at')->get();
        return view('admin.assets.vehicles.index', compact('vehicleList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $vehicle = ((new Vehicle())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Vehicle())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($vehicle->isEmpty()) {
            
        }else{
            foreach($vehicle as $vehicle){
                $data['data'][] = [
                    'id' => $vehicle->id,
                    'product_id' => isset($vehicle->product) ? $vehicle->product->product_type :'',
                //    'vehicle_type' => $vehicle->vehicle_type,
                    'vehicle_name' => $vehicle->vendorOeems->Vehicle_OEM ?? null,
                    'model_name' => $vehicle->vendorOeemsmodel->vehicle_oem_model ?? null,
                    'registeration_number' => $vehicle->registeration_number,
                    'vin_number' => $vehicle->vin_number,
                    'qr_code' => '<a href="#" id="' . $vehicle->id . '" class="view_asset_qr">View</a>',
                    'oem_id' => isset($vehicle->vendorOem) ? $vehicle->vendorOem->vendor_oem :'',
                    'vehicle_dealer_id' => isset($vehicle->vehicleDealer) ? $vehicle->vehicleDealer->vehicle_dealer :'',
                    'purchased_invoice_number' => $vehicle->purchased_invoice_number,
                    'purchased_date' => $vehicle->purchased_date,
                    'location_id' => isset($vehicle->location) ? $vehicle->location->location :'',
                    'parts' => isset($vehicle->parts) ? '<a href="#" id="' . $vehicle->id . '" class="view_asset_parts_qr">'. count($vehicle->parts) .'</a>' : '',                  
                    'service_plan' => isset($vehicle->servicePlan) ? count($vehicle->servicePlan) : '',
                    'insurance_plan' => isset($vehicle->insurancePlan) ? count($vehicle->insurancePlan) : '',
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($vehicle->created_at)) ,
                    'created_by' => isset($vehicle->createdUser) ? $vehicle->createdUser->name :'',
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($vehicle->updated_at)) ,
                    'updated_by' => isset($vehicle->updatedUser) ? $vehicle->updatedUser->name :'',
                    'action' => '
                    <a href="'. route('asset.vehicles.show', ['vehicle' => $vehicle->id]) . '"><i class="mdi mdi-eye font-size-16 text-success me-1"></i></a>
                    <a href="'. route('asset.vehicles.edit', ['vehicle' => $vehicle->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('asset.vehicles.destroy', ['vehicle' => $vehicle->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>                    
                    <a href="'. route('asset.vehicle.copy', ['id' => $vehicle->id]) . '"><i class="bx bx-copy-alt"></i></a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    public function asset_qr($id)
    {
        $vehicle = Vehicle::findOrFail($id);
        return view('admin.assets.vehicles.asset_qr', compact('vehicle'));
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request) 
    {
        $requiredData = [
            'product_id' => 'required',
            'oem_id' => 'required',
            'vehicle_dealer_id' => 'required',
            'location_id' => 'required',
            'city_id' => 'required',
            'district_id' => 'required',
            'state_id' => 'required',
            'zone_id' => 'required',
            'purchased_invoice_number' => 'required',
            'purchased_date' => 'required',
           // 'model_name' => 'required',
        ];

        if(isset($request->all()['id'])){
            $requiredData['vin_number'] = [
                'required',
                Rule::unique('a_vehicle')->ignore($request->all()['id']),
            ];
            if($request->registeration_number){
                $requiredData['registeration_number'] = [
                    Rule::unique('a_vehicle')->ignore($request->all()['id']),
                ];
            }

            $validate = Validator::make($request->all(),$requiredData);
        }else{

            $requiredData['vin_number'] = 'required|unique:a_vehicle,vin_number';
            
            if($request->registeration_number){
                $requiredData['registeration_number'] = 'unique:a_vehicle,registeration_number';
            }
            $validate = Validator::make($request->all(),$requiredData);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        
       // dd('hi');
        $vehicle = new Vehicle();
        //dd($vehicle);
        
        return view('admin.assets.vehicles.edit', compact('vehicle'));
    }

    public function asset()
    {
      $id = $_POST['id'];
      $products = vendoroem_model::where('business_category_id', $id)->select('business_model','id')->get();
       return response()->json($products);
    }

    public function dealeroem(Request $request)
    {
      //$id = $_POST['id'];
      $id = $request->input('id');
      $products = Dealer::where('oem_id', $id)->get();
     // dd($products);
       return response()->json($products);
    }

    public function vehiclemodelregister(Request $request)
    {
      //$id = $_POST['id'];
      $id = $request->input('id');
      $products = Vehicle::where('oem_id', $id)->get();
     // dd($products);
       return response()->json($products);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $this->save_data($request);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle updated!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/vehicles')->with('flash_message', 'Vehicle Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $vehicle = Vehicle::findOrFail($id);
        return view('admin.assets.vehicles.show', compact('vehicle'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $vehicle = Vehicle::findOrFail($id);
        
        return view('admin.assets.vehicles.edit', compact('vehicle'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $this->save_data($request);

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle updated!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/vehicles')->with('flash_message', 'Vehicle updated!');
    }
    
    public function save_data($request){

        $requestData = $request->all();
        // print_r($requestData); exit;
        $vehicle = [];
        if($request->id){
            $vehicle = Vehicle::findOrFail($request->id);
        }
      
        if($vehicle){
            
            $requestData['purchased_date'] =  $requestData['purchased_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['purchased_date'] )) : $vehicle->purchased_date;

            $vehicle->update($requestData);
        }else{
            
            $requestData['purchased_date'] =  $requestData['purchased_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['purchased_date'] )) : null;

            $vehicle = Vehicle::create($requestData);
        }  
        

        if(isset($requestData['rc_book'])){
            $file = $requestData['rc_book'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            //$filePath = $file->storeAs('uploads/assets/vehicles/'.$vehicle->id, $savedAs, 'public');
            $path = '/uploads/assets/vehicles/'.$vehicle->id. '/rc-book/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $requestData['rc_book'] = $path;        
        }else{
            $requestData['rc_book'] = $vehicle->rc_book;        
        }

        $vehicle->update($requestData);
        foreach($requestData['asset-parts'] as $assetParts){
            $assetPartsData = [
                'vehicle_id' => $vehicle->id,
                'product_id' => $assetParts['asset_part'],
                'part_id' => $assetParts['part_id'],
                //'qr_code' => $assetParts['field_name'],
            ];
            
            if(isset($assetParts['asset_part_id'])){
                if($assetParts['asset_part_id'] != ''){
                    $assetPart =  VehicleParts::findOrFail($assetParts['asset_part_id']);
                    $assetPart->update($assetPartsData);
                }else{
                    $assetPart = VehicleParts::create($assetPartsData);
                }
            }else{
                $assetPart = VehicleParts::create($assetPartsData);
            }
        }

        if(isset($requestData['asset-maintenance'])){
            foreach($requestData['asset-maintenance'] as $servicePlanField){
                if($servicePlanField['maintenance_type_id']){

                    $servicePlanData = [
                        'asset_id' => $vehicle->id,
                        'maintenance_type_id' => $servicePlanField['maintenance_type_id'],
                        'maintenance_duration' => $servicePlanField['maintenance_duration'],
                        'maintenance_duration_date' => ($servicePlanField['maintenance_duration_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['maintenance_duration_date'] )) : null,
                        'maintenance_cost' => $servicePlanField['maintenance_cost'],
                        'service_reminder' => $servicePlanField['service_reminder'],
                        'service_reminder_date' => ($servicePlanField['service_reminder_date']) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['service_reminder_date'] )) : null,
                    ];
                    if(isset($servicePlanField['asset_service_id'])){
                        if($servicePlanField['asset_service_id'] != ''){
                            $servicePlan =  VehicleServicePlan::findOrFail($servicePlanField['asset_service_id']);
                            $servicePlan->update($servicePlanData);
                        }else{
                            $servicePlan = VehicleServicePlan::create($servicePlanData);
                        }
                    }else{
                        $servicePlan = VehicleServicePlan::create($servicePlanData);
                    }
                }
            }
        }

        if(isset($requestData['asset-insurance'])){
            foreach($requestData['asset-insurance'] as $insurancePlanField){
                if($insurancePlanField['insurance_type_id']){

                    $insurancePlannData = [
                    'asset_id' => $vehicle->id,
                    'insurance_type_id' => $insurancePlanField['insurance_type_id'],
                    'insurance_duration' => isset($insurancePlanField['insurance_duration']) ? $insurancePlanField['insurance_duration'] : '',
                    'insurance_duration_date' => ($insurancePlanField['insurance_duration_date']) ? date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_duration_date'] )) : null,
                    'maintenance_cost' => isset($insurancePlanField['maintenance_cost']) ? $insurancePlanField['maintenance_cost'] : '',
                    'service_reminder' => $insurancePlanField['insurance_service_reminder'],
                    'service_reminder_date' => ($insurancePlanField['insurance_service_reminder_date']) ?  date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_service_reminder_date'] )) : null,
                    ];
                    
                    if(isset($insurancePlanField['asset_insurance_id'])){
                        if($insurancePlanField['asset_insurance_id'] != ''){
                            $insurancePlan =  VehicleInsurancePlan::findOrFail($insurancePlanField['asset_insurance_id']);
                            $insurancePlan->update($insurancePlannData);
                        }else{
                            $insurancePlan = VehicleInsurancePlan::create($insurancePlannData);
                        }
                    }else{
                        $insurancePlan = VehicleInsurancePlan::create($insurancePlannData);
                    }
                }
            }
        }
        if(isset($requestData['asset_image'])){
            foreach($requestData['asset_image'] as $image){
                $file = $image;
                $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                //$filePath = $file->storeAs('uploads/assets/vehicles/'.$vehicle->id, $savedAs, 'public');
                $path = '/uploads/assets/vehicles/'.$vehicle->id. '/' . $savedAs;
                $filePath = $this->uploadFile($path, $file);
                
                $assetImageData = [
                    'asset_id' => $vehicle->id,
                    'name' => $file->getClientOriginalName(),
                    'path' => $path,
                    'saved_as' => $savedAs,
                ];
                $assetImage = VehicleImages::create($assetImageData);
            }
        }

    }

    public function copy_model($id){

        $asset = Vehicle::findOrFail($id);

        $vehicleData = $asset->toArray();
        $vehicleData['id'] = null;
        $vehicleData['registeration_number'] = null;
        $vehicleData['vin_number'] = null;
        $vehicleData['purchased_invoice_number'] = null;
        $vehicleData['rc_book'] = null;
        $vehicle = Vehicle::create($vehicleData);

        if($asset->parts->count() > 0){
            foreach($asset->parts as $assetParts){
                $assetPartsData = [
                    'vehicle_id' => $vehicle->id,
                    'product_id' => $assetParts['product_id'],
                    'part_id' => $assetParts['part_id'],
                ];
                $assetPart = VehicleParts::create($assetPartsData);
            }
        }

        if($asset->servicePlan->count() > 0){
            foreach($asset->servicePlan as $servicePlanField){
                $servicePlanData = [
                    'asset_id' => $vehicle->id,
                    'maintenance_type_id' => $servicePlanField['maintenance_type_id'],
                    'maintenance_duration' => $servicePlanField['maintenance_duration'],
                    'maintenance_duration_date' => ($servicePlanField['maintenance_duration_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['maintenance_duration_date'] )) : null,
                    'maintenance_cost' => $servicePlanField['maintenance_cost'],
                    'service_reminder' => $servicePlanField['service_reminder'],
                    'service_reminder_date' => ($servicePlanField['service_reminder_date']) ? date($this->siteSettings['timestamp_format'], strtotime($servicePlanField['service_reminder_date'] )) : null,
                ];
                $servicePlan = VehicleServicePlan::create($servicePlanData);
            
            }
        }

        if($asset->insurancePlan->count() > 0){
            foreach($asset->insurancePlan as $insurancePlanField){
                
                $insurancePlannData = [
                'asset_id' => $vehicle->id,
                'insurance_type_id' => $insurancePlanField['insurance_type_id'],
                'insurance_duration' => isset($insurancePlanField['insurance_duration']) ? $insurancePlanField['insurance_duration'] : '',
                'insurance_duration_date' => ($insurancePlanField['insurance_duration_date']) ? date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['insurance_duration_date'] )) : null,
                'maintenance_cost' => isset($insurancePlanField['maintenance_cost']) ? $insurancePlanField['maintenance_cost'] : '',
                'service_reminder' => $insurancePlanField['service_reminder'],
                'service_reminder_date' => ($insurancePlanField['service_reminder_date']) ?  date($this->siteSettings['timestamp_format'], strtotime($insurancePlanField['service_reminder_date'] )) : null,
                ];
                
                $insurancePlan = VehicleInsurancePlan::create($insurancePlannData);
            }
        }
        return redirect( route('asset.vehicles.edit', ['vehicle' => $vehicle->id]))->with('flash_message', 'Vehicle Copied!');
        
    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Vehicle::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/vehicles')->with('flash_message', 'Vehicle deleted!');
    }
    public function destroy_parts(Request $request, $id)
    {
        VehicleParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_service_plan(Request $request, $id)
    {
        VehicleServicePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle Service Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_insurance_plan(Request $request, $id)
    {
        VehicleInsurancePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle Insurance Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function asset_vehicle_list(Request $request){
        $vehicleList = Vehicle::whereNull('deleted_at')->where('model_name', $request->model_name)->get();
        $data = [];
        if( $request->with == 'parts'){
            foreach($vehicleList as $vehicle){
                if($vehicle->parts){
                    foreach($vehicle->parts as $parts){
                        if($parts){
                            //$productType = ProductType::whereNull('deleted_at')->where('id', $parts->product_id)->first();
                            $data[$parts->id] = $parts?->product?->product_type . ' ' . $parts->part_id;
                        }
                    }
                }
            }
        }
        return response()->json([
            'mode' => true,
            'message' => 'Vehicle Insurance Plan deleted!',
            'errors' => '',
            'data' => $data
        ], 200);
    }
    public function list_by_type(Request $request)
    {
        if(!isset($request->product_id)){
            $request->product_id = $request->asset_type_id;
        }
        $vehicleList = Vehicle::whereNull('deleted_at')->where('product_id', $request->product_id)->groupBy('model_name')->get();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle list',
                'errors' => '',
                'data' => $vehicleList
            ], 200);
        }
    }
    public function list_by_model(Request $request)
    {
        if(!isset($request->product_id)){
            $request->product_id = $request->asset_type_id;
        }
        $vehicleList = Vehicle::whereNull('deleted_at')->where('model_name', $request->model_name)->get();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle list',
                'errors' => '',
                'data' => $vehicleList
            ], 200);
        }
    }
    public function part_list_by_asset(Request $request)
    {
        if(!isset($request->id)){
            $request->id = $request->asset_id;
        }
        $vehicleList = Vehicle::whereNull('deleted_at')->where('id', $request->id)->first();
        foreach($vehicleList->parts as $parts){

            $vehicleList->parts->product = $parts->product;
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle list',
                'errors' => '',
                'data' => $vehicleList->parts
            ], 200);
        }
    }
    public function destroyAssetImage(Request $request, $id){
        $vehicleImage = VehicleImages::findOrFail($id);
        $this->deleteFile($vehicleImage->path);
        VehicleImages::destroy($id);

        return true;
    }
    public function delete_rc_book(Request $request, $id){
        $vehicle = Vehicle::findOrFail($id);
        $this->deleteFile($vehicle->rc_book);
        $vehicle->rc_book = '';
        $vehicle->update();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle RC deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/asset/vehicles')->with('flash_message', 'Vehicle RC  deleted!');
    }
    public function destroy_images(Request $request, $id)
    {
        if($request->path){
            $vehicleImages = VehicleImages::where('path', $request->path)->where('asset_id', $id)->first();
            $this->deleteFile($vehicleImages->path);
            VehicleImages::destroy($vehicleImages->id);
        }else{
            $vehicleImages = VehicleImages::findOrFail($id);
            $this->deleteFile($vehicle->path);
            VehicleImages::destroy($id);
            if($request->ajax()){
                return response()->json([
                    'mode' => true,
                    'message' => 'Vehicle Images deleted!',
                    'errors' => ''
                ], 200);
            }
        }
        return true;
    }

    public function vehiclemodelwise()
    {
      $id = $_POST['id'];
      $products = vendoroem_model::where('vehicle_oem_id', $id)->get();
       return response()->json($products);
    }

// Controller method


}
