<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Master\Duration;
use App\Models\CMS\Announcement;
use App\Models\CMS\AnnouncementLocation;


class AnnouncementController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $announcementList = Announcement::whereNull('deleted_at')->get();
        return view('admin.cms.announcement.index', compact('announcementList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $announcement = ((new Announcement())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Announcement())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($announcement->isEmpty()) {
            
        }else{
            foreach($announcement as $announcement){
                $data['data'][] = [
                    'id' => $announcement->id,
                    'announcement_name' => $announcement->announcement_name,
                    'mobile_user' => $announcement->mobile_user,
                    'location' => $announcement->location,
                    'updated_by' => ($announcement->updatedUser)? $announcement->updatedUser->name : '' ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($announcement->created_at)) ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($announcement->created_at)) ,
                    'action' => '
                    <a href="'. route('cms.announcement.edit', ['announcement' => $announcement->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.announcement.destroy', ['announcement' => $announcement->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'announcement_name' => [
                    'required',
                    Rule::unique('cms_announcement')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'announcement_name' => 'required|unique:cms_announcement,announcement_name',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.announcement.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $announcement = Announcement::create($requestData);
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/cms/announcement/'.$announcement->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $data = [
                'image' =>  $path
            ];
            $announcement->update($data);
        }
        if($requestData['location'] == 'Selected Location'){
            $locationData = [
                'announcement_id' => $announcement['id'],
                'city_id' => $requestData['city_id'],
                'district_id' => $requestData['district_id'],
                'state_id' => $requestData['state_id'],
                'zone_id' => $requestData['zone_id'],
            ];
            $location = AnnouncementLocation::create($locationData);
        }
        return redirect('admin/cms/announcement')->with('flash_message', 'Announcement added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $announcement = Announcement::findOrFail($id);
        return view('admin.cms.announcement.show', compact('announcement'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        //$announcement = Announcement::with(['location'])->findOrFail($id);
        $announcement = Announcement::with(['announcementLocation'])->where('id', '=', $id)->first();
        
        return view('admin.cms.announcement.edit', compact('announcement'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $announcement = Announcement::findOrFail($id);
        
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/cms/announcement/'.$announcement->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $requestData['image'] = $path;
        }else{
            $requestData['image'] = $announcement->image;
        }
        if($requestData['location'] == 'Selected Location'){
            $announcementLocation = AnnouncementLocation::where('announcement_id', $announcement->id)->first();

            $locationData = [
                'announcement_id' => $announcement['id'],
                'city_id' => $requestData['city_id'],
                'district_id' => $requestData['district_id'],
                'state_id' => $requestData['state_id'],
                'zone_id' => $requestData['zone_id'],
            ];
            if(isset($announcementLocation->id)){
                $announcementLocation =  $announcementLocation->update($locationData);
                }else{
                $announcementLocation = AnnouncementLocation::create($locationData);
            }
        }
        $announcement->update($requestData);
        return redirect('admin/cms/announcement')->with('flash_message', 'Announcement updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Announcement::destroy($id);
        $announcementLocation = AnnouncementLocation::where('announcement_id', $id);
        if($announcementLocation){
            $this->destroy_Location($announcementLocation->id);
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Announcement deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/announcement')->with('flash_message', 'Announcement deleted!');
    }
   // public function destroy_Location(Request $request, $id)
    public function destroy_Location($id)
    {
        AnnouncementParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Announcement Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
}
