<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Master\Duration;
use App\Models\CMS\Banner;
use App\Models\CMS\BannerLocation;


class BannerController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $bannerList = Banner::whereNull('deleted_at')->get();
        return view('admin.cms.banner.index', compact('bannerList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $banner = ((new Banner())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Banner())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($banner->isEmpty()) {
            
        }else{
            foreach($banner as $banner){
                $data['data'][] = [
                    'id' => $banner->id,
                    'banner_name' => $banner->banner_name,
                    'mobile_user' => $banner->mobile_user,
                    'location' => $banner->location,
                    'updated_by' => ($banner->updatedUser)? $banner->updatedUser->name : '' ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($banner->created_at)) ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($banner->created_at)) ,
                    'action' => '
                    <a href="'. route('cms.banner.edit', ['banner' => $banner->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.banner.destroy', ['banner' => $banner->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'banner_name' => [
                    'required',
                    Rule::unique('cms_banner')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'banner_name' => 'required|unique:cms_banner,banner_name',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.banner.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $banner = Banner::create($requestData);
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/cms/banner/'.$banner->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $data = [
                'image' =>  $path
            ];
            $banner->update($data);
        }
        if($requestData['location'] == 'Selected Location'){
            $locationData = [
                'banner_id' => $banner['id'],
                'city_id' => $requestData['city_id'],
                'district_id' => $requestData['district_id'],
                'state_id' => $requestData['state_id'],
                'zone_id' => $requestData['zone_id'],
            ];
            $location = BannerLocation::create($locationData);
        }
        return redirect('admin/cms/banner')->with('flash_message', 'Banner added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $banner = Banner::findOrFail($id);
        return view('admin.cms.banner.show', compact('banner'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $banner = Banner::findOrFail($id);
        
        return view('admin.cms.banner.edit', compact('banner'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $banner = Banner::findOrFail($id);
        
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/cms/banner/'.$banner->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $requestData['image'] = $path;
        }else{
            $requestData['image'] = $banner->image;
        }
        if($requestData['location'] == 'Selected Location'){
            $bannerLocation = BannerLocation::where('banner_id', $banner->id)->first();

            $locationData = [
                'banner_id' => $banner['id'],
                'city_id' => $requestData['city_id'],
                'district_id' => $requestData['district_id'],
                'state_id' => $requestData['state_id'],
                'zone_id' => $requestData['zone_id'],
            ];
            if($bannerLocation){
                $bannerLocation =  $bannerLocation->update($locationData);
                }else{
                $bannerLocation = BannerLocation::create($locationData);
            }
        }
        $banner->update($requestData);
        return redirect('admin/cms/banner')->with('flash_message', 'Banner updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Banner::destroy($id);
        $bannerLocation = BannerLocation::where('banner_id', $id);
        if($bannerLocation){
            $this->destroy_Location($bannerLocation->id);
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Banner deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/banner')->with('flash_message', 'Banner deleted!');
    }
   // public function destroy_Location(Request $request, $id)
    public function destroy_Location($id)
    {
        BannerParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Banner Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
}
