<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\CMS\EmergencyService;
use App\Models\CMS\Faq;
use App\Models\Master\EmergencyService as masterEmrgencyService;


class EmergencyServiceController extends AppController
{
    public function __construct()
    {
        $masterEmergencyServiceList = masterEmrgencyService::whereNull('deleted_at')->get();
        View::share([
            'masterEmergencyServiceList' => $masterEmergencyServiceList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $emergencyServiceList = EmergencyService::whereNull('deleted_at')->get();
        return view('admin.cms.emergency_service.index', compact('emergencyServiceList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $emergencyServiceList = ((new EmergencyService())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new EmergencyService())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($emergencyServiceList->isEmpty()) {
            
        }else{
            foreach($emergencyServiceList as $emergencyService){
                $updateStatus = ($emergencyService->created_at == $emergencyService->updated_at) ? 'New' : 'Edited';
                $data['data'][] = [
                    'id' => $emergencyService->id,
                    'emergency_service_id' => $emergencyService?->emergencyService?->emergency_service,
                    'mobile_user' => $emergencyService->mobile_user,                   
                    'update_status' => $updateStatus,
                    'created_by' => ($emergencyService->createdUser)? $emergencyService->createdUser->name : '' ,
                    'updated_by' => ($emergencyService->updatedUser)? $emergencyService->updatedUser->name : '' ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($emergencyService->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($emergencyService->updated_at)) ,
                    'action' => '
                    <a href="'. route('cms.emergency-service.edit', ['emergency_service' => $emergencyService->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.emergency-service.destroy', ['emergency_service' => $emergencyService->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
        if(isset($request->all()['id'])){
            // $validate = Validator::make($request->all(), [
            //     'emergency_service_id' => [
            //         'required',
            //         Rule::unique('cms_emergency_services')->ignore($request->all()['id']),
            //     ],
            // ]);
        }else{
            // $validate = Validator::make($request->all(), [
            //     'emergency_service_id' => 'required|unique:cms_emergency_services,emergency_service_id',
            // ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.emergency_service.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $emergencyService = EmergencyService::create($requestData);
       
        return redirect('admin/cms/emergency-service')->with('flash_message', 'Emergency Service added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $emergencyService = EmergencyService::findOrFail($id);
        return view('admin.cms.emergency_service.show', compact('emergencyService'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $emergencyService = EmergencyService::findOrFail($id);
        
        return view('admin.cms.emergency_service.edit', compact('emergencyService'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $emergencyService = EmergencyService::findOrFail($id);
        
        $emergencyService->update($requestData);
        
        return redirect('admin/cms/emergency-service')->with('flash_message', 'Emergency Service updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        EmergencyService::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'EmergencyService deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/emergency-service')->with('flash_message', 'Emergency Service deleted!');
    }
}
