<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\CMS\FaqCategory;
use App\Models\CMS\Faq;


class FaqCategoryController extends AppController
{
    public function __construct()
    {
        //$zones = Zone::whereNull('deleted_at')->get();
        View::share([
            //'zones' => $zones, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $faqCategoryList = FaqCategory::whereNull('deleted_at')->get();
        return view('admin.cms.faq.index', compact('faqCategoryList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $faqCategoryList = ((new FaqCategory())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new FaqCategory())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($faqCategoryList->isEmpty()) {
            
        }else{
            foreach($faqCategoryList as $faqCategory){
                $data['data'][] = [
                    'id' => $faqCategory->id,
                    'faq_category' => $faqCategory->faq_category,
                    'mobile_user' => $faqCategory->mobile_user,
                    'created_by' => ($faqCategory->createdUser)? $faqCategory->createdUser->name : '' ,
                    'updated_by' => ($faqCategory->updatedUser)? $faqCategory->updatedUser->name : '' ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($faqCategory->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($faqCategory->updated_at)) ,
                    'action' => '
                    <a href="'. route('cms.faq.edit', ['faq' => $faqCategory->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.faq.destroy', ['faq' => $faqCategory->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'faq_category' => [
                    'required',
                    Rule::unique('cms_faq_category')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'faq_category' => 'required|unique:cms_faq_category,faq_category',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.faq.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $faqCategory = FaqCategory::create($requestData);
        if(isset($requestData['faq-questions'])){
            foreach($requestData['faq-questions'] as $faqCategoryQuestions){
                if($faqCategoryQuestions['question'] != ''){

                    $faqCategoryQuestionData = [
                        'faq_category_id' => $faqCategory->id,
                        'question_priority' => $faqCategoryQuestions['question_priority'],
                        'question' => $faqCategoryQuestions['question'],
                        'search_tag' => $faqCategoryQuestions['search_tag'],
                        'search_answer' => $faqCategoryQuestions['search_answer'],
                    ];
                    $faqCategoryQuestion = Faq::create($faqCategoryQuestionData);
                }

            }
        }
        return redirect('admin/cms/faq')->with('flash_message', 'Faq added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $faqCategory = FaqCategory::findOrFail($id);
        return view('admin.cms.faq.show', compact('faqCategory'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $faqCategory = FaqCategory::findOrFail($id);
        
        return view('admin.cms.faq.edit', compact('faqCategory'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $faqCategory = FaqCategory::findOrFail($id);
        
        $faqCategory->update($requestData);
        
        if(isset($requestData['faq-questions'])){
            foreach($requestData['faq-questions'] as $faqCategoryQuestions){
                if($faqCategoryQuestions['question'] != ''){

                    $faqCategoryQuestionData = [
                        'faq_category_id' => $faqCategory->id,
                        'question_priority' => $faqCategoryQuestions['question_priority'],
                        'question' => $faqCategoryQuestions['question'],
                        'search_tag' => $faqCategoryQuestions['search_tag'],
                        'search_answer' => $faqCategoryQuestions['search_answer'],
                    ];
                    if(isset($faqCategoryQuestions['faq_id']) &&  $faqCategoryQuestions['faq_id'] !=''){
                        $faq = Faq::findOrFail($faqCategoryQuestions['faq_id']);
                        $faq->update($faqCategoryQuestionData);

                    }else{
                        $faqCategoryQuestion = Faq::create($faqCategoryQuestionData);

                    }
                }

            }
        }
        return redirect('admin/cms/faq')->with('flash_message', 'Faq updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        FaqCategory::destroy($id);
        $faqCategoryLocation = Faq::where('faq_category_id', $id);
        if($faqCategoryLocation){
            $this->destroy_faqs($faqCategoryLocation->id);
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'FaqCategory deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/faq')->with('flash_message', 'FaqCategory deleted!');
    }
    public function destroy_faqs(Request $request, $id)
    {
        Faq::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Faq Category  deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function priority_list(Request $request){
        $faqCategoryList = Faq::select('question_priority')->get()->toArray();
        $number = range(1,20);
        
        return response()->json([
            'mode' => true,
            'message' => 'Priority List',
            'data' => $number
        ], 200);
    }
}
