<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\CMS\FeedbackRating;
use App\Models\CMS\FeedbackRatingImpression;


class FeedbackRatingController extends AppController
{
    public function __construct()
    {
        //$zones = Zone::whereNull('deleted_at')->get();
        View::share([
            //'zones' => $zones, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $feedbackRatingList = FeedbackRating::whereNull('deleted_at')->get();
        return view('admin.cms.feedback_rating.index', compact('feedbackRatingList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $feedbackRatingList = ((new FeedbackRating())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new FeedbackRating())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($feedbackRatingList->isEmpty()) {
            
        }else{
            foreach($feedbackRatingList as $feedbackRating){
                $data['data'][] = [
                    'id' => $feedbackRating->id,
                    'feedback_rating_for' => $feedbackRating->feedback_rating_for,
                    'mobile_user' => $feedbackRating->mobile_user,
                    'created_by' => ($feedbackRating->createdUser)? $feedbackRating->createdUser->name : '' ,
                    'updated_by' => ($feedbackRating->updatedUser)? $feedbackRating->updatedUser->name : '' ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($feedbackRating->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($feedbackRating->updated_at)) ,
                    'action' => '
                    <a href="'. route('cms.feedback-rating.edit', ['feedback_rating' => $feedbackRating->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.feedback-rating.destroy', ['feedback_rating' => $feedbackRating->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'feedback_rating_for' => [
                    'required',
                    Rule::unique('cms_feedback_rating')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'feedback_rating_for' => 'required|unique:cms_feedback_rating,feedback_rating_for',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.feedback_rating.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $feedbackRating = FeedbackRating::create($requestData);
        if(isset($requestData['impression-points'])){
            foreach($requestData['impression-points'] as $ratingImpressionPoints){
                if($ratingImpressionPoints['impression_points'] != ''){
                    $ratingImpressionPointsData = [
                        'feedback_rating_id' => $feedbackRating->id,
                        'impression_points' => $ratingImpressionPoints['impression_points']
                    ];
                    $ratingImpressionPoint = FeedbackRatingImpression::create($ratingImpressionPointsData);
                }

            }
        }
        return redirect('admin/cms/feedback-rating')->with('flash_message', 'Feedback Rating added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $feedbackRating = FeedbackRating::findOrFail($id);
        return view('admin.cms.feedback_rating.show', compact('feedbackRating'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $feedbackRating = FeedbackRating::findOrFail($id);
        
        return view('admin.cms.feedback_rating.edit', compact('feedbackRating'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $feedbackRating = FeedbackRating::findOrFail($id);
        
        $feedbackRating->update($requestData);
        
        if(isset($requestData['impression-points'])){
            foreach($requestData['impression-points'] as $ratingImpressionPoints){
                if($ratingImpressionPoints['impression_points'] != ''){

                    $ratingImpressionPointsData = [
                        'feedback_rating_id' => $feedbackRating->id,
                        'impression_points' => $ratingImpressionPoints['impression_points']
                    ];
                    if(isset($ratingImpressionPoints['impression_id']) &&  $ratingImpressionPoints['impression_id'] !=''){
                        $ratingImpressionPoint = FeedbackRatingImpression::findOrFail($ratingImpressionPoints['impression_id']);
                        $ratingImpressionPoint->update($ratingImpressionPointsData);

                    }else{
                        $ratingImpressionPoint = FeedbackRatingImpression::create($ratingImpressionPointsData);

                    }
                }

            }
        }
        return redirect('admin/cms/feedback-rating')->with('flash_message', 'Faq updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        FeedbackRating::destroy($id);
        $feedbackRatingImpression = FeedbackRatingImpression::where('feedback_rating_for_id', $id);
        if($feedbackRatingImpression){
            $this->destroy_feedback_rating_impression($feedbackRatingImpression->id);
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'FeedbackRating deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/feedback-rating')->with('flash_message', 'FeedbackRating deleted!');
    }
    public function destroy_feedback_rating_impression(Request $request, $id)
    {
        FeedbackRatingImpression::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'FeedbackRating   deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    
}
