<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Foundation\Validation\ValidatesRequests;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\CMS\Forms;
use App\Models\CMS\FormButtons;
use App\Models\CMS\FormFields;
use App\Http\Controllers\AppController;
use App\Models\Master\FormFieldType;
use App\Models\Master\FormFieldGroup;
use App\Models\CMS\FormFieldCondition;
use View;
use Illuminate\Validation\Rule;
use Illuminate\Support\Arr;

class FormsController extends AppController
{
    
    public function __construct()
    {
        $formFieldTypes = FormFieldType::whereNull('deleted_at')->get();
        $formFieldGroups = FormFieldGroup::whereNull('deleted_at')->get();
        View::share([
            'formFieldTypes' => $formFieldTypes, 
            'formFieldGroups' => $formFieldGroups, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $formList = Forms::get();
        return view('admin.cms.forms.index', compact('formList'));
    }
    
    public function order_tab_index(Request $request){
        $requestData = $request->all();
        $form = Forms::findOrFail($requestData['id']);
        $form->priority = $requestData['position'];
        $form->save();
        return true;
    }
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $formsList = ((new Forms())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Forms())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($formsList->isEmpty()) {
            
        }else{
            foreach($formsList as $forms){
                $data['data'][] = [
                    'id' => $forms->id,
                   // 'priority' => '<a href="#" id="inline-username" data-type="text" data-pk="1" data-title="Enter username" class="editable editable-click" style="">superuser</a>',
                    'slug' => $forms->slug,
                    'title' => $forms->title,
                    'updated_by' => ($forms->updatedUser)? $forms->updatedUser->name : '' ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($forms->created_at)) ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($forms->created_at)) ,
                    'action' => '
                    <a href="'. route('cms.forms.edit', ['form' => $forms->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.forms.destroy', ['form' => $forms->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    ',
                    'DT_RowId' =>  $forms->id,

                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'slug' => [
                    'required',
                    Rule::unique('cms_forms')->ignore($request->all()['id']),
                ],
                'title' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'slug' => 'required|unique:cms_forms,slug',
                'title' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
        //return $form->validate($request);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.forms.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        
        $requestData['is_before_login'] =isset($requestData['is_before_login']) ? $requestData['is_before_login'] : '0';
        $requestData['is_back_button'] =isset($requestData['is_back_button']) ? $requestData['is_back_button'] : '0';
        $requestData['have_section'] =isset($requestData['have_section']) ? $requestData['have_section'] : '0';
        $requestData['fields_have_values'] =isset($requestData['fields_have_values']) ? $requestData['fields_have_values'] : '0';
        
        $filePath ='';
        $form = Forms::create($requestData);
        $path='';
        if(isset($request->file()['image'])){
            $file = $request->file()['image'];
            $savedAs = $requestData['slug'] .'.'.$file->extension();
            //$filePath = $file->storeAs('uploads/mobile-form/'.$form->id, $savedAs, 'public');
            $path = '/uploads/cms/forms/'.$form->id .'/image/' .  $savedAs;
            $filePath = $this->uploadFile($path, $file);
        }
        $bottomPath = '';
        if(isset($request->file()['bottom_image'])){
            $file = $request->file()['bottom_image'];
            $savedAs = $requestData['slug'] .'.'.$file->extension();
            //$filePath = $file->storeAs('uploads/mobile-form/'.$form->id, $savedAs, 'public');
            $bottomPath = '/uploads/cms/forms/'.$form->id .'/bottom_image/' .  $savedAs;
            $filePath = $this->uploadFile($bottomPath, $file);
        }
        $formData = [
            'image' => $path,
            'bottom_image' => $bottomPath,
        ];
        $form->update($formData);
        if(isset($requestData['form-fields'])){

            foreach($requestData['form-fields'] as $formFields){
                $formFieldsData = [
                'form_id' => $form['id'],
                    'group_id' => $formFields['group_id'],
                    'type_id' => $formFields['type_id'],
                    'name' => $formFields['field_name'],
                    'title' => $formFields['field_title'],
                    'place_holder' => $formFields['place_holder'], 
                    'option' =>  $formFields['option'], 
                    'priority' =>  $formFields['priority'], 
                    'have_condition' =>  isset($formFields['have_condition']) ? $formFields['have_condition'] : 'No', 
                ];
                $formField = FormFields::create($formFieldsData);
                if($formField->have_condition == 'Yes'){
                    $conditionField = FormFields::where('name', $formFields['condition_field_name'])->first();
                    $conditionData = [
                        'field_id' => $formField->id,
                        'condition_field_id' => $conditionField->id,
                        'equal_value' => $formFields['equal_value'],
                        'field_id_type' => $formFields['field_id_type'],
                        'equal_value_type' => $formFields['equal_value_type'],
                    ];
                    
                    $conditionField = FormFieldCondition::create($conditionData);
                }
            }
        }
        if(isset($requestData['form-buttons'])){
            //exit;
            foreach($requestData['form-buttons'] as $buttonFields){
                
                if(isset($buttonFields['name'])){
                    $formButtonData = [
                        'form_id' => $form['id'],
                        'attributes' => json_encode($buttonFields)
                    ];
                    $formButton = FormButtons::create($formButtonData);
                }
            }
        }

        return redirect('admin/cms/forms')->with('flash_message', 'Forms added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $form = Forms::findOrFail($id);
        $formFields = FormFields::where('form_id', $id)->get();
        $formButtons = FormButtons::where('form_id', $id)->get();
        return view('admin.cms.forms.show', compact('form', 'formFields', 'formButtons'));

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $form = Forms::findOrFail($id);
        $formFields = FormFields::with('FormCondition')->where('form_id', $id)->get();
        $formButtons = FormButtons::where('form_id', $id)->get();
        //print_r($formFields); exit;
        return view('admin.cms.forms.edit', compact('form', 'formFields', 'formButtons'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
       // print_r($requestData); exit;
        $form = Forms::findOrFail($id);
        
        $path = $form->image;
        //print_r($file); exit;
        if(isset($request->file()['image'])){
            $file = $request->file()['image'];
            $savedAs = $requestData['slug'] .'.'.$file->extension();
            //$filePath = $file->storeAs('uploads/mobile-form/'.$id, $savedAs, 'public');
            $path = '/uploads/cms/forms/'.$form->id . '/image/' .  $savedAs;
            $filePath = $this->uploadFile($path, $file);
        }else{
            $path = $form->image;
        }
        $requestData['image'] = $path;
        if(isset($request->file()['bottom_image'])){
            $file = $request->file()['bottom_image'];
            $savedAs = $requestData['slug'] .'.'.$file->extension();
            //$filePath = $file->storeAs('uploads/mobile-form/'.$id, $savedAs, 'public');
            $path = '/uploads/cms/forms/'.$form->id . '/bottom_image/' .  $savedAs;
            $filePath = $this->uploadFile($path, $file);
        }else{
            $path = $form->bottom_image;
        }
        $requestData['bottom_image'] = $path;
        $requestData['is_before_login'] =isset($requestData['is_before_login']) ? $requestData['is_before_login'] : '0';
        $requestData['is_back_button'] =isset($requestData['is_back_button']) ? $requestData['is_back_button'] : '0';
        $requestData['have_section'] =isset($requestData['have_section']) ? $requestData['have_section'] : '0';
        $requestData['fields_have_values'] =isset($requestData['fields_have_values']) ? $requestData['fields_have_values'] : '0';
        $form->update($requestData);
        //$formFields = FormFields::where('form_id', $id)->get();
        // foreach($formFields as $formField){
        //     if($formField->formCondition){
        //         $this->destroyFieldCondition($formField->formCondition->id);
        //     }
        //     $this->destroyFormField($formField->id);
            
        // } 
        foreach($requestData['form-fields'] as $formFields){
            if($formFields['field_name']){
                $formFieldsData = [
                'form_id' => $form->id,
                    'group_id' => $formFields['group_id'],
                    'type_id' => $formFields['type_id'],
                    'name' => $formFields['field_name'],
                    'title' => $formFields['field_title'],
                    'place_holder' => $formFields['place_holder'], 
                    'option' =>  $formFields['option'], 
                    'priority' =>  $formFields['priority'], 
                    'have_condition' => isset($formFields['have_condition']) ? $formFields['have_condition'] : 'No',
                ];
                
                if(isset($formFields['form_field_id'])){
                    if($formFields['form_field_id'] != ''){
                        $formField =  FormFields::findOrFail($formFields['form_field_id']);
                        $formField->update($formFieldsData);
                    }else{
                        $formField = FormFields::create($formFieldsData);
                    }
                }else{
                    $formField = FormFields::create($formFieldsData);
                }
                //$formField = FormFields::create($formFieldsData);
                if($formField->have_condition == 'Yes'){
                    $conditionField = FormFields::where('form_id', $id)->where('name', $formFields['condition_field_name'])->first();
                    if($conditionField){
                        $conditionData = [
                            'field_id' => $formField->id,
                            'condition_field_id' => $conditionField->id,
                            'equal_value' => $formFields['equal_value'],
                            'field_id_type' => $formFields['field_id_type'],
                            'equal_value_type' => $formFields['equal_value_type'],
                        ];
                        if($formField->formCondition){
                            $conditionFormField = $formField->formCondition->update($conditionData);
                        }else{
                            $conditionFormField = FormFieldCondition::create($conditionData);
                        }
                    }
                }
            }
        }
        // $formButtons = FormButtons::where('form_id', $id)->get()->toArray();
        // foreach($formButtons as $formButton){
        //     $this->destroyFormButton($formButton['id']);
        // }
        foreach($requestData['form-buttons'] as $buttonFields){
           // print_r($buttonFields); exit;
            if(isset($buttonFields['name'])){
                $formButtonData = [
                    'form_id' => $form['id'],
                    'attributes' => json_encode($buttonFields)
                ];
                if(isset($buttonFields['button_id'])){
                    $formButton = FormButtons::findOrFail($buttonFields['button_id']);
                }else{
                   $formButton = [];
                }
                if(isset($formButton->id)){
                    $formButton->update($formButtonData);
                }else{
                    $formButton = FormButtons::create($formButtonData);
                }
            }
        }
        return redirect(route('cms.forms.edit', ['form' => $id]))->with('flash_message', 'Forms updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        Forms::destroy($id);
        $formFields = FormFields::where('form_id', $id)->get()->toArray();
        foreach($formFields as $formField){
            $this->destroyFormField($formField['id']);
        } 
        $formButtons = FormButtons::where('form_id', $id)->get()->toArray();
        foreach($formButtons as $formButton){
            $this->destroyFormButton($formButton['id']);
        }
        return redirect('admin/cms/forms')->with('flash_message', 'Forms  deleted!');
    }
    public function destroyFormField($id){
        if(FormFields::destroy($id)){
            return true;
        }
    }
    public function destroyFieldCondition($id){
        if(FormFieldCondition::destroy($id)){
            return true;
        }
    }
    public function destroyFormButton($id){
        if(FormButtons::destroy($id)){
            return true;
        }
    }
    public function destroyFormImage(Request $request, $id, $field){
        $form = Forms::findOrFail($id);
        $this->deleteFile($form->$field);
        $form->$field = '';
        $form->update();
        return true;
    }
}
