<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Master\Duration;
use App\Models\CMS\IncidentalInfo;
use App\Models\CMS\IncidentalInfoLocation;


class IncidentalInfoController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $incidentalInfoList = IncidentalInfo::whereNull('deleted_at')->get();
        return view('admin.cms.incidental_info.index', compact('incidentalInfoList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $incidentalInfo = ((new IncidentalInfo())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new IncidentalInfo())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($incidentalInfo->isEmpty()) {
            
        }else{
            foreach($incidentalInfo as $incidentalInfo){
                $data['data'][] = [
                    'id' => $incidentalInfo->id,
                    'incidental_name' => $incidentalInfo->incidental_name,
                    'incidental_title' => $incidentalInfo->incidental_title,
                    'mobile_user' => $incidentalInfo->mobile_user,
                    'location' => $incidentalInfo->location,
                    'updated_by' => ($incidentalInfo->updatedUser)? $incidentalInfo->updatedUser->name : '' ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($incidentalInfo->created_at)) ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($incidentalInfo->created_at)) ,
                    'action' => '
                    <a href="'. route('cms.incidental-info.edit', ['incidental_info' => $incidentalInfo->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.incidental-info.destroy', ['incidental_info' => $incidentalInfo->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'incidental_name' => [
                    'required',
                    Rule::unique('cms_incidental_info')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'incidental_name' => 'required|unique:cms_incidental_info,incidental_name',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.incidental_info.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $incidentalInfo = IncidentalInfo::create($requestData);
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/cms/incidental-info/'.$incidentalInfo->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $data = [
                'image' =>  $path
            ];
            $incidentalInfo->update($data);
        }
        if($requestData['location'] == 'Selected Location'){
            foreach($requestData['location-field-list'] as $locationDields){
                $locationData = [
                    'incidental_id' => $incidentalInfo['id'],
                    'city_id' => $locationDields['city_id'],
                    'district_id' => $locationDields['district_id'],
                    'state_id' => $locationDields['state_id'],
                    'zone_id' => $locationDields['zone_id'],
                ];
                $location = IncidentalInfoLocation::create($locationData);

            }
        }
        return redirect('admin/cms/incidental-info')->with('flash_message', 'IncidentalInfo added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $incidentalInfo = IncidentalInfo::findOrFail($id);
        return view('admin.cms.incidental_info.show', compact('incidentalInfo'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        //$incidentalInfo = IncidentalInfo::with(['location'])->findOrFail($id);
        $incidentalInfo = IncidentalInfo::with(['incidentalInfoLocation'])->where('id', '=', $id)->first();
        
        return view('admin.cms.incidental_info.edit', compact('incidentalInfo'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $incidentalInfo = IncidentalInfo::findOrFail($id);
        
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/cms/incidental-info/'.$incidentalInfo->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $requestData['image'] = $path;
        }else{
            $requestData['image'] = $incidentalInfo->image;
        }
        if($requestData['location'] == 'Selected Location'){
            foreach($requestData['location-field-list'] as $locationDields){

                $incidentalInfoLocation = IncidentalInfo::findOrFail($locationDields['location_id']);
                $locationData = [
                    'incidental_id' => $incidentalInfo['id'],
                    'city_id' => $locationDields['city_id'],
                    'district_id' => $locationDields['district_id'],
                    'state_id' => $locationDields['state_id'],
                    'zone_id' => $locationDields['zone_id'],
                ];
                if(isset($incidentalInfoLocation->id)){
                    $incidentalInfoLocation =  $incidentalInfoLocation->update($locationData);
                    }else{
                    $incidentalInfoLocation = IncidentalInfoLocation::create($locationData);
                }

            }
            
        }
        $incidentalInfo->update($requestData);
        return redirect('admin/cms/incidental-info')->with('flash_message', 'IncidentalInfo updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        IncidentalInfo::destroy($id);
        $incidentalInfoLocationList = IncidentalInfoLocation::where('incidental_id', $id);
        foreach($incidentalInfoLocationList as $incidentalInfoLocation){
            if($incidentalInfoLocation){
                $this->destroy_Location($incidentalInfoLocation->id);
            }
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'IncidentalInfo deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/incidental-info')->with('flash_message', 'IncidentalInfo deleted!');
    }
   // public function destroy_Location(Request $request, $id)
    public function destroy_Location($id)
    {
        IncidentalInfoParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'IncidentalInfo Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
}
