<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\CMS\Forms;
use App\Models\CMS\FormButtons;
use App\Models\CMS\FormFields;
use App\Models\CMS\InputAttribute;


class InputAttributeController extends AppController
{
    public function __construct()
    {
        $forms = Forms::get();
        View::share([
            'forms' => $forms,
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $inputAttributeList = InputAttribute::whereNull('deleted_at')->get();
        return view('admin.cms.input_attribute.index', compact('inputAttributeList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $inputAttribute = ((new InputAttribute())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new InputAttribute())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($inputAttribute->isEmpty()) {
            
        }else{
            foreach($inputAttribute as $inputAttribute){
                $data['data'][] = [
                    'id' => $inputAttribute->id,
                    'form_id' => $inputAttribute?->form?->slug,
                    'form_field_id' => $inputAttribute?->formField?->name,
                    'type' => $inputAttribute->type,
                    'key' => $inputAttribute->key,
                    'value' => $inputAttribute->value,
                    'action' => '
                    <a href="'. route('cms.input-attribute.edit', ['input_attribute' => $inputAttribute->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.input-attribute.destroy', ['input_attribute' => $inputAttribute->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    public function form_fields_by_form(Request $request)
    {
        $requestData = $request->all();
        $formField = FormFields::where('form_id', $requestData['form_id'])->get();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $formField
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.input_attribute.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $inputAttribute = InputAttribute::create($requestData);
        return redirect('admin/cms/input-attribute')->with('flash_message', 'Input Attribute added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $inputAttribute = InputAttribute::findOrFail($id);
        return view('admin.cms.input_attribute.show', compact('inputAttribute'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $inputAttribute = InputAttribute::findOrFail($id);
        
        return view('admin.cms.input_attribute.edit', compact('inputAttribute'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $inputAttribute = InputAttribute::findOrFail($id);
        
        $inputAttribute->update($requestData);
        return redirect('admin/cms/input-attribute')->with('flash_message', 'Input Attribute updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        InputAttribute::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'InputAttribute deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/input-attribute')->with('flash_message', 'InputAttribute deleted!');
    }
}
