<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Master\Duration;
use App\Models\CMS\Menu;
use App\Models\CMS\MenuLocation;
use App\Models\Users\UserData;
use App\Models\Master\BusinessModels;
use App\Models\Master\BusinessCategory;


class MenuController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $businessCategoryList = BusinessCategory::whereNull('deleted_at')->get();
        $businessModelsList = BusinessModels::whereNull('deleted_at')->get();
       // dd($businessModelsList);
        View::share([
            'businessModelsList' => $businessModelsList, 
            'businessCategoryList' => $businessCategoryList,
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $menuList = Menu::whereNull('deleted_at')->get();
        return view('admin.cms.menu.index', compact('menuList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $menu = ((new Menu())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Menu())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($menu->isEmpty()) {
            
        }else{
            foreach($menu as $menu){
                $data['data'][] = [
                    'id' => $menu->id,
                    'title' => $menu->title,
                    'mobile_user' => $menu->mobile_user,
                    'priority' => $menu->priority,
                    'updated_by' => ($menu->updatedUser)? $menu->updatedUser->name : '' ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($menu->created_at)) ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($menu->created_at)) ,
                    'action' => '
                    <a href="'. route('cms.menu.edit', ['menu' => $menu->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.menu.destroy', ['menu' => $menu->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'title' => [
                    'required',
                    Rule::unique('cms_menu')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'title' => 'required|unique:cms_menu,title',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        
        return view('admin.cms.menu.create');
    }


    public function businessmodelmenuwise()
    {
      $id = $_POST['id'];
      $products = BusinessModels::where('business_category_id', $id)->get();
       return response()->json($products);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $menu = Menu::create($requestData);
        return Redirect::to('/cms/menu')->with('flash_message', 'Menu added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $menu = Menu::findOrFail($id);
        return view('admin.cms.menu.show', compact('menu'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $menu = Menu::findOrFail($id);
        
        return view('admin.cms.menu.edit', compact('menu'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $menu = Menu::findOrFail($id);
        $menu->update($requestData);
        return redirect('admin/cms/menu')->with('flash_message', 'Menu updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Menu::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Menu deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/menu')->with('flash_message', 'Menu deleted!');
    }
    public function priority_list(Request $request){
        $menuList = Menu::get()->pluck('priority')->toArray();
        $number = range(1,20);
        if($menuList){
            $number = array_diff($number, $menuList);
        }
        return response()->json([
            'mode' => true,
            'message' => 'Priority List',
            'data' => $number
        ], 200);
    }
}
