<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use View;
use App\Models\CMS\Onboard;
use App\Models\CMS\OnboardList;
use App\Models\CMS\OnboardPermission;
use App\Models\CMS\PermissionDescription;


class OnboardController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $onboardList = Onboard::whereNull('deleted_at')->get();
        return view('admin.onboard.index', compact('onboardList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $onboard = ((new Onboard())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Onboard())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($onboard->isEmpty()) {
            
        }else{
            foreach($onboard as $onboard){
                $data['data'][] = [
                    'id' => $onboard->id,
                    'app_name' => $onboard->app_name,
                    'app_icon' => $onboard->app_icon,
                    'splash_image' => $onboard->splash_image,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($onboard->created_at)) ,
                    'action' => '<a href="'. route('onboard.edit', ['onboard' => $onboard->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('onboard.destroy', ['onboard' => $onboard->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'app_name' => [
                    'required',
                    Rule::unique('cms_onboard')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'app_name' => 'required|unique:cms_onboard,app_name',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.onboard.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {        
        $requestData = $request->all();
        $onboardData = [
            'app_name' => $requestData['app_name'],
        ];
        $onboard = Onboard::create($onboardData);
        
        foreach($requestData['onboard-list'] as $buttonFields){
            $onboardListData = [
                'onboard_id' => $onboard->id,
                'title' => $buttonFields['title'],
                'description' => $buttonFields['description']
            ];
            $onboardList = OnboardList::create($onboardListData);
        }
        foreach($requestData['onboard-permission-list'] as $buttonFields){
            $onboardpermissionListData = [
                'onboard_id' => $onboard->id,
                'title' => $buttonFields['title'],
                'request' => $buttonFields['request'],
            ];
            $onboardPermissionList = OnboardPermission::create($onboardpermissionListData);
        }
        return redirect(route('onboard.edit', ['onboard' => $onboard->id]))->with('flash_message', 'Onboard added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $onboard = Onboard::findOrFail($id);
        return view('admin.onboard.show', compact('onboard'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $onboard = Onboard::findOrFail($id);
        
        $onboardList = OnboardList::where('onboard_id', $id)->get();
        $onboardPermissionList = OnboardPermission::where('onboard_id', $id)->get();
        $permissionDescriptionList = PermissionDescription::with('onboardPermission')->where('onboard_id', $id)->get();

        return view('admin.onboard.edit', compact('onboard', 'onboardList', 'onboardPermissionList', 'permissionDescriptionList'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $onboard = Onboard::findOrFail($id);
        $onboardData = [
            'app_name' => $requestData['app_name'],
        ];
        if(isset($requestData['app_icon'])){
            
            $file = $requestData['app_icon'];
            $savedAs = $onboard->id .'_app_icon.'.$file->extension();
            //$filePath = $file->storeAs('uploads/onboard/'.$onboard->id, $savedAs, 'public');
            $path = '/uploads/onboard/'.$onboard->id . '/' .  $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $onboardData['app_icon'] = $path;
        }
        if(isset($requestData['splash_image'])){
            
            $file = $requestData['splash_image'];
            $savedAs = $onboard->id .'_splash_image.'.$file->extension();
            //$filePath = $file->storeAs('uploads/onboard/'.$onboard->id, $savedAs, 'public');
            $path = '/uploads/onboard/'.$onboard->id . '/' .  $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $onboardData['splash_image'] = $path;
        }
        $onboard->update($onboardData);
        
        $onboardList = OnboardList::where('onboard_id', $id)->get();
        // foreach($onboardList as $onboardData){
        //     $this->destroyOnboardList($onboardData->id);
        // }
        foreach($requestData['onboard-list'] as $onboardFields){
            $onboardListData = [
                'onboard_id' => $onboard->id,
                'title' => $onboardFields['title'],
                'description' => $onboardFields['description']
            ];
            if(isset($onboardFields['onboard_list_id'])){
                if($onboardFields['onboard_list_id'] != ''){
                    $onboardList =  OnboardList::findOrFail($onboardFields['onboard_list_id']);
                    $onboardList->update($onboardListData);
                }else{
                    $onboardList = OnboardList::create($onboardListData);
                }
            }else{
                $onboardList = OnboardList::create($onboardListData);
            }
            
            if(isset($onboardFields['image'])){
                $file = $onboardFields['image'];
                $savedAs = $onboardList->id .'.'.$file->extension();
                //$filePath = $file->storeAs('uploads/onboard/'.$onboard->id.'/list', $savedAs, 'public');
                $path = '/uploads/onboard/'.$onboard->id. '/list/' .  $savedAs;
                $filePath = $this->uploadFile($path, $file);
                $onboardListData = [
                    'image' => $path,
                ];
                $onboardList->update($onboardListData);
            }
        }
        $onboardPermissionList = OnboardPermission::where('onboard_id', $id)->get();
        // foreach($onboardPermissionList as $onboardPermission){
        //     $this->destroyOnboardPermissionList($onboardPermission->id);
        // }
        foreach($requestData['onboard-permission-list'] as $permissionFields){
            $onboardpermissionListData = [
                'onboard_id' => $onboard->id,
                'title' => $permissionFields['title'],
                'request' => $permissionFields['request'],
            ];
            if(isset($permissionFields['permission_id'])){
                if($permissionFields['permission_id'] != ''){
                    $onboardPermissionList =  OnboardPermission::findOrFail($permissionFields['permission_id']);
                    $onboardPermissionList->update($onboardpermissionListData);
                }else{
                    $onboardPermissionList = OnboardPermission::create($onboardpermissionListData);
                }
            }else{
                $onboardPermissionList = OnboardPermission::create($onboardpermissionListData);
            }
            
            if(isset($permissionFields['image'])){
                $file = $permissionFields['image'];
                $savedAs = $onboardPermissionList->id .'.'.$file->extension();
                //$filePath = $file->storeAs('uploads/onboard/'.$onboard->id.'/permission', $savedAs, 'public');
                $path = '/uploads/onboard/'.$onboard->id. '/permission/' .  $savedAs;
                $filePath = $this->uploadFile($path, $file);
                $onboardpermissionListData = [
                    'image' => $path,
                ];
                $onboardPermissionList->update($onboardpermissionListData);
            }
        }
        //return redirect('admin/onboard')->with('flash_message', 'Onboard updated!');
        return redirect(route('onboard.edit', ['onboard' => $onboard->id]))->with('flash_message', 'Onboard Updated!');
    }
    public function save_description(Request $request){
        $requestData = $request->all();
        if(isset($requestData['id'])){
            if($requestData['id']){
                $id = $requestData['id'];
                $permissionDesc = PermissionDescription::findOrFail($id);
                $onboardPermission = OnboardPermission::findOrFail($permissionDesc->permission_id);
                $onboard = Onboard::findOrFail($onboardPermission->onboard_id);
                if(isset($requestData['action']) && $requestData['action'] == 'get'){
                    return response()->json([
                        'mode' => true,
                        'message' => 'sucess',
                        'data' => $permissionDesc,
                        'errors' => ''
                    ], 200);
                }else{
                    $permissionDesc->title = $requestData['title'];
                    if(isset($request->file()['description_image'])){
                        $file = $request->file()['description_image'];
                        $savedAs = $permissionDesc->id .'_description_image.'.$file->extension();
                        //$filePath = $file->storeAs('uploads/onboard/'.$onboard->id.'/permission-description', $savedAs, 'public');
                        $path = '/uploads/onboard/'.$onboard->id. '/permission-description/' .  $savedAs;
                        $filePath = $this->uploadFile($path, $file);
                        $permissionDesc->image = $path;
                    }
                    $permissionDesc->update();
                    return response()->json([
                        'mode' => true,
                        'message' => 'sucess',
                        'errors' => ''
                    ], 200);
                }
            }
        }else{
            $onboardPermission = OnboardPermission::findOrFail($requestData['permission_id']);
            $onboard = Onboard::findOrFail($onboardPermission->onboard_id);
            $requestData['onboard_id'] = $onboard->id;
            $permissionDesc = PermissionDescription::create($requestData);
            $filePath='';
            if(isset($request->file()['description_image'])){
                $file = $request->file()['description_image'];
                $savedAs = $permissionDesc->id .'_description_image.'.$file->extension();
                //$filePath = $file->storeAs('uploads/onboard/'.$onboard->id.'/permission-description', $savedAs, 'public');
                $path = '/uploads/onboard/'.$onboard->id. '/permission-description/' .  $savedAs;
                $filePath = $this->uploadFile($path, $file);
            }
            $permissionDescData = [
                'image' => $path,
            ];
            $permissionDesc->update($permissionDescData);
            return response()->json([
                'mode' => true,
                'message' => 'sucess',
                'errors' => ''
            ], 200);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Onboard::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Onboard deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/onboard')->with('flash_message', 'Onboard deleted!');
    }
    public function delete_onboard_list(Request $request, $id){
        if(OnboardList::destroy($id)){
            if($request->ajax()){
                return response()->json([
                    'mode' => true,
                    'message' => 'Onboard List deleted!',
                    'errors' => ''
                ], 200);
            }
            return true;
        }
    }
    public function delete_onboard_permission(Request $request, $id){
        $onboardPermission = OnboardPermission::findOrFail($id);
        foreach($onboardPermission->permissionDescription as $permissionDescription){
            $this->delete_onboard_permission_description($request, $permissionDescription->id);
        }
        if(OnboardPermission::destroy($id)){
            if($request->ajax()){
                return response()->json([
                    'mode' => true,
                    'message' => 'Permission deleted!',
                    'errors' => ''
                ], 200);
            }
            return true;
        }
    }
    public function delete_onboard_permission_description(Request $request, $id){
        if(PermissionDescription::destroy($id)){
            
            if($request->ajax()){
                return response()->json([
                    'mode' => true,
                    'message' => 'Permission Description deleted!',
                    'errors' => ''
                ], 200);
            }
            return true;
        }
    }
}
