<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\CMS\Forms;
use App\Models\CMS\FormButtons;
use App\Models\CMS\FormFields;
use App\Models\CMS\TabMenu;


class TabMenuController extends AppController
{
    public function __construct()
    {
        $forms = Forms::get();
        View::share([
            'forms' => $forms,
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $tabMenuList = TabMenu::whereNull('deleted_at')->get();
        return view('admin.cms.tab_menu.index', compact('tabMenuList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $tabMenu = ((new TabMenu())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new TabMenu())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($tabMenu->isEmpty()) {
            
        }else{
            foreach($tabMenu as $tabMenu){
                $data['data'][] = [
                    'id' => $tabMenu->id,
                    'form_id' => $tabMenu->form->slug,
                    'form_field_id' => $tabMenu->formField->name,
                    'menu' => $tabMenu->menu,
                    'action' => '
                    <a href="'. route('cms.tab-menu.edit', ['tab_menu' => $tabMenu->form_field_id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.tab-menu.destroy', ['tab_menu' => $tabMenu->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    public function form_fields_by_form(Request $request)
    {
        $requestData = $request->all();
        $formField = FormFields::where('form_id', $requestData['form_id'])->get();
        return $this->success_response('success', $formField);
    }
    public function tab_menu_by_form_field(Request $request)
    {
        $requestData = $request->all();
        $tabMenu = TabMenu::where('form_field_id', $requestData['form_field_id'])->get();
        return $this->success_response('success', $tabMenu);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.tab_menu.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $tabMenu = TabMenu::create($requestData);
        
        if(isset($requestData['menu-list'])){
            foreach($requestData['menu-list'] as $menuList){
                if($menuList['menu'] != ''){
                    $menuData = [
                        'form_id' => $requestData['form_id'],
                        'form_field_id' => $requestData['form_field_id'],
                        'menu' => $menuList['menu'],
                    ];
                    $tabMenu = TabMenu::create($menuData);
                }

            }
        }

        return redirect('admin/cms/tab-menu')->with('flash_message', 'Input Attribute added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $tabMenu = TabMenu::findOrFail($id);
        return view('admin.cms.tab_menu.show', compact('tabMenu'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $formField = FormFields::findOrFail($id);
        $tabMenuList = TabMenu::where('form_field_id', $id)->get();
        
        return view('admin.cms.tab_menu.edit', compact('formField', 'tabMenuList'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $formField = FormFields::findOrFail($id);
        
        if(isset($requestData['menu-list'])){
            foreach($requestData['menu-list'] as $menuList){
                if($menuList['menu'] != ''){
                    $menuData = [
                        'form_id' => $requestData['form_id'],
                        'form_field_id' => $requestData['form_field_id'],
                        'menu' => $menuList['menu'],
                    ];
                    
                    if($menuList['menu'] != '' &&  $menuList['menu_id'] !=''){
                        $tabMenu = TabMenu::findOrFail($menuList['menu_id']);
                        $tabMenu->update($menuData);
                    }else{
                        $tabMenu = TabMenu::create($menuData);

                    }

                }

            }
        }

        $tabMenu->update($requestData);
        return redirect('admin/cms/tab-menu')->with('flash_message', 'Input Attribute updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        TabMenu::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'TabMenu deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/tab-menu')->with('flash_message', 'TabMenu deleted!');
    }
}
