<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\CMS\Forms;
use App\Models\CMS\TabMenuInputCondition;
use App\Models\CMS\FormFields;
use App\Models\CMS\TabMenu;
use App\Models\CMS\TabMenuInput;
use App\Models\Master\FormFieldType;


class TabMenuInputController extends AppController
{
    public function __construct()
    {
        $forms = Forms::get();
        $formFieldTypes = FormFieldType::whereNull('deleted_at')->get();
        $tabMenuList = TabMenu::whereNull('deleted_at')->get();
        View::share([
            'forms' => $forms,
            'tabMenuList' => $tabMenuList,
            'formFieldTypes' => $formFieldTypes,
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $tabMenuInputList = TabMenuInput::whereNull('deleted_at')->get();
        return view('admin.cms.tab_menu_input.index', compact('tabMenuInputList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $tabMenuInput = ((new TabMenuInput())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new TabMenuInput())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($tabMenuInput->isEmpty()) {
            
        }else{
            foreach($tabMenuInput as $tabMenuInput){
                $data['data'][] = [
                    'id' => $tabMenuInput->id,
                    'form_id' => $tabMenuInput->formFieldTabMenu->form->slug,
                    'form_field_id' => $tabMenuInput->formFieldTabMenu->formField->name,
                    'menu' => $tabMenuInput->formFieldTabMenu->menu,
                    'action' => '
                    <a href="'. route('cms.tab-menu-input.edit', ['tab_menu_input' => $tabMenuInput->formFieldTabMenu->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.tab-menu-input.destroy', ['tab_menu_input' => $tabMenuInput->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    public function form_fields_by_form(Request $request)
    {
        $requestData = $request->all();
        $formField = FormFields::where('form_id', $requestData['form_id'])->get();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $formField
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.tab_menu_input.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        
        foreach($requestData['input-list'] as $tabMenuInputs){
            if($tabMenuInputs['field_name'] != ''){
                $tabMenuInputsData = [
                    'tab_menu_id' => $requestData['tab_menu_id'],
                    'type_id' => $tabMenuInputs['type_id'],
                    'name' => $tabMenuInputs['field_name'],
                    'title' => $tabMenuInputs['field_title'],
                    'place_holder' => $tabMenuInputs['place_holder'], 
                    'option' =>  $tabMenuInputs['option'], 
                    'priority' =>  $tabMenuInputs['priority'], 
                    'have_condition' =>  isset($tabMenuInputs['have_condition']) ? $tabMenuInputs['have_condition'] : 'No', 
                ];
                $tabMenuInput = TabMenuInput::create($tabMenuInputsData);
                if($tabMenuInput->have_condition == 'Yes' && $tabMenuInputs['condition_field_name']){
                    $conditionInputField = TabMenuInput::where('name', $tabMenuInputs['condition_field_name'])->first();
                    $conditionData = [
                        'tab_menu_input_id' => $conditionInputField->id,
                        'condition_field_id' => $conditionField->id,
                        'equal_value' => $tabMenuInputs['equal_value'],
                        'field_id_type' => $tabMenuInputs['field_id_type'],
                        'equal_value_type' => $tabMenuInputs['equal_value_type'],
                    ];
                    
                    $conditionField = TabMenuInputCondition::create($conditionData);
                }
            }
        }
        return redirect('admin/cms/tab-menu-input')->with('flash_message', 'Input Attribute added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $tabMenuInput = TabMenuInput::findOrFail($id);
        return view('admin.cms.tab_menu_input.show', compact('tabMenuInput'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $tabMenu = TabMenu::findOrFail($id);
        return view('admin.cms.tab_menu_input.edit', compact('tabMenu'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $tabMenu = TabMenu::findOrFail($id);
        foreach($requestData['input-list'] as $tabMenuInputs){
            if($tabMenuInputs['field_name']){
                $tabMenuInputsData = [
                    'tab_menu_id' => $requestData['tab_menu_id'],
                    'type_id' => $tabMenuInputs['type_id'],
                    'name' => $tabMenuInputs['field_name'],
                    'title' => $tabMenuInputs['field_title'],
                    'place_holder' => $tabMenuInputs['place_holder'], 
                    'option' =>  $tabMenuInputs['option'], 
                    'priority' =>  $tabMenuInputs['priority'], 
                    'have_condition' =>  isset($tabMenuInputs['have_condition']) ? $tabMenuInputs['have_condition'] : 'No', 
                ];
                
                if(isset($tabMenuInputs['tab_input_id'])){
                    if($tabMenuInputs['tab_input_id'] != ''){
                        $tabMenuInput =  TabMenuInput::findOrFail($tabMenuInputs['tab_input_id']);
                        $tabMenuInput->update($tabMenuInputsData);
                    }else{
                        $tabMenuInput = TabMenuInput::create($tabMenuInputsData);
                    }
                }else{
                    $tabMenuInput = TabMenuInput::create($tabMenuInputsData);
                }
                if($tabMenuInput->have_condition == 'Yes'){
                    $conditionInputField = TabMenuInput::where('name', $tabMenuInputs['condition_field_name'])->first();
                    $conditionData = [
                        'field_id' => $tabMenuInput->id,
                        'condition_field_id' => $conditionInputField->id,
                        'equal_value' => $tabMenuInputs['equal_value'],
                        'field_id_type' => $tabMenuInputs['field_id_type'],
                        'equal_value_type' => $tabMenuInputs['equal_value_type'],
                    ];
                    if($tabMenuInput->formCondition){
                        $conditionField = $tabMenuInput->formCondition->update($conditionData);
                    }else{
                        $conditionField = TabMenuInputCondition::create($conditionData);
                    }
                }
            }
        }

        return redirect('admin/cms/tab-menu-input')->with('flash_message', 'Input Attribute updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        TabMenuInput::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'TabMenuInput deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/tab-menu-input')->with('flash_message', 'Tab Menu Input deleted!');
    }
}
