<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\CMS\TermsCondition;


class TermsConditionController extends AppController
{
    public function __construct()
    {
       // $zones = Zone::whereNull('deleted_at')->get();
        View::share([
           // 'cities' => $city, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $termsConditionList = TermsCondition::whereNull('deleted_at')->get();
        return view('admin.cms.terms_condition.index', compact('termsConditionList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $termsConditionList = ((new TermsCondition())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new TermsCondition())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($termsConditionList->isEmpty()) {
            
        }else{

            foreach($termsConditionList as $termsCondition){
                $updateStatus = ($termsCondition->created_at == $termsCondition->updated_at) ? 'New' : 'Edited';
                $data['data'][] = [
                    'id' => $termsCondition->id,
                    'terms_condition_title' => $termsCondition->terms_condition_title,
                    'mobile_user' => $termsCondition->mobile_user,
                    'update_status' => $updateStatus,
                    'created_by' => ($termsCondition->createdUser)? $termsCondition->createdUser->name : '' ,
                    'updated_by' => ($termsCondition->updatedUser)? $termsCondition->updatedUser->name : '' ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($termsCondition->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($termsCondition->updated_at)) ,
                    'action' => '
                    <a href="'. route('cms.terms-condition.edit', ['terms_condition' => $termsCondition->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.terms-condition.destroy', ['terms_condition' => $termsCondition->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'terms_condition_title' => [
                    'required',
                    Rule::unique('cms_terms_condition')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'terms_condition_title' => 'required|unique:cms_terms_condition,terms_condition_title',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.terms_condition.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $termsCondition = TermsCondition::create($requestData);
        if(isset($requestData['terms_condition_doc'])){
            $file = $requestData['terms_condition_doc'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/cms/terms_condition/'.$termsCondition->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $data = [
                'terms_condition_doc' =>  $path
            ];
            $termsCondition->update($data);
        }
        return redirect('admin/cms/terms-condition')->with('flash_message', 'TermsCondition added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $termsCondition = TermsCondition::findOrFail($id);
        return view('admin.cms.terms_condition.show', compact('termsCondition'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $termsCondition = TermsCondition::findOrFail($id);
        
        return view('admin.cms.terms_condition.edit', compact('termsCondition'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $termsCondition = TermsCondition::findOrFail($id);
        
        if(isset($requestData['terms_condition_doc'])){
            $file = $requestData['terms_condition_doc'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/cms/terms_condition/'.$termsCondition->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $requestData['terms_condition_doc'] = $path;
        }else{
            $requestData['terms_condition_doc'] = $termsCondition->terms_condition_doc;
        }
        $termsCondition->update($requestData);
        return redirect('admin/cms/terms-condition')->with('flash_message', 'TermsCondition updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        TermsCondition::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'TermsCondition deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/terms-condition')->with('flash_message', 'TermsCondition deleted!');
    }
   // public function destroy_Location(Request $request, $id)
    public function destroy_Location($id)
    {
        TermsConditionParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'TermsCondition Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
}
