<?php

namespace App\Http\Controllers\Admin\CMS;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\CMS\WalkaroundChecklist;
use App\Models\CMS\WalkaroundQuestion;
use App\Models\CMS\WalkaroundCategory;
use App\Models\Master\ProductType;
use App\Models\Assets\Vehicle;
use App\Models\SubscriptionPlan\Vehicle as SubscriptionPlan;


class WalkaroundChecklistController extends AppController
{
    public function __construct()
    {
        $productTypeList = ProductType::whereNull('deleted_at')->get();
        $assetList = Vehicle::whereNull('deleted_at')->groupBy('model_name')->get();
        $subscriptionPolicyList = SubscriptionPlan::whereNull('deleted_at')->get();
        $categoryList = WalkaroundCategory::whereNull('deleted_at')->get();

        View::share([
            'productTypeList' => $productTypeList, 
            'assetList' => $assetList, 
            'subscriptionPolicyList' => $subscriptionPolicyList, 
            'categoryList' => $categoryList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $walkaroundChecklistData = WalkaroundChecklist::whereNull('deleted_at')->get();
        return view('admin.cms.walkaround_checklist.index', compact('walkaroundChecklistData'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $walkaroundChecklistData = ((new WalkaroundChecklist())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new WalkaroundChecklist())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($walkaroundChecklistData->isEmpty()) {
            
        }else{
            foreach($walkaroundChecklistData as $walkaroundChecklist){
                $data['data'][] = [
                    'id' => $walkaroundChecklist->id,
                    'product_type' => $walkaroundChecklist?->productType?->product_type,
                    'product_model' => $walkaroundChecklist->product_model,
                    'subscription_plan_id' => $walkaroundChecklist?->vehiclePlan?->plan_name,
                    'mobile_user' => $walkaroundChecklist->mobile_user,
                    'created_by' => ($walkaroundChecklist->createdUser)? $walkaroundChecklist->createdUser->name : '' ,
                    'updated_by' => ($walkaroundChecklist->updatedUser)? $walkaroundChecklist->updatedUser->name : '' ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($walkaroundChecklist->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($walkaroundChecklist->updated_at)) ,
                    'action' => '
                    <a href="'. route('cms.walkaround-checklist.edit', ['walkaround_checklist' => $walkaroundChecklist->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('cms.walkaround-checklist.destroy', ['walkaround_checklist' => $walkaroundChecklist->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        // if(isset($request->all()['id'])){
        //     $validate = Validator::make($request->all(), [
        //         'faq_category' => [
        //             'required',
        //             Rule::unique('cms_faq_category')->ignore($request->all()['id']),
        //         ],
        //     ]);
        // }else{
        //     $validate = Validator::make($request->all(), [
        //         'faq_category' => 'required|unique:cms_faq_category,faq_category',
        //     ]);
        // }
        $validate = Validator::make($request->all(), [
            'product_type_id' => 'required',
            'product_model' => 'required',
            'subscription_plan_id' => 'required',
        ]);
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.cms.walkaround_checklist.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $walkaroundChecklist = WalkaroundChecklist::create($requestData);
        
        return redirect(route('cms.walkaround-checklist.edit', ['walkaround_checklist' => $walkaroundChecklist->id]))->with('flash_message', 'Walkaround Checklist updated!');
        
    }
    public function create_category(Request $request)
    {
        $requestData = $request->all();
        $validate = Validator::make($request->all(), [
            'category_name' => 'required|unique:cms_walkaround_categories,category_name',
        ]);
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }

        $walkaroundChecklist = WalkaroundCategory::create($requestData);
        
        return response()->json([
            'mode' => true,
            'message' => 'Category added',
            'data' => $walkaroundChecklist
        ], 200);
        
    }
    public function add_nistruction_checklist(Request $request)
    {
        $requestData = $request->all();
        $walkaroundChecklist = WalkaroundCategory::create($requestData);
        
        return response()->json([
            'mode' => true,
            'message' => 'Category added',
            'data' => $walkaroundChecklist
        ], 200);
        
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $walkaroundChecklist = WalkaroundChecklist::findOrFail($id);
        return view('admin.cms.walkaround_checklist.show', compact('walkaroundChecklist'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $walkaroundChecklist = WalkaroundChecklist::findOrFail($id);
        $categoryList = WalkaroundCategory::whereNull('deleted_at')->where('walkaround_checklis_id', $walkaroundChecklist->id)->get();
        return view('admin.cms.walkaround_checklist.edit', compact('walkaroundChecklist', 'categoryList'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $requestData = $request->all();
        //print_r($requestData); exit;
        $walkaroundChecklist = WalkaroundChecklist::findOrFail($id);
        
        $walkaroundChecklist->update($requestData);
        
        if(isset($requestData['checklist-item'])){
            foreach($requestData['checklist-item'] as $checklistItem){
                if($checklistItem['question'] != ''){
                    $checklistItemData = [
                        'walkaround_checklis_id' => $walkaroundChecklist->id,
                        'walkaround_category_id' => $checklistItem['walkaround_category_id'],
                        'question' => $checklistItem['question'],
                        'instructions' => $checklistItem['instructions'] ?? $checklistItem['instruction'] ?? null
                    ];
                    if(isset($checklistItem['question_id']) &&  $checklistItem['question_id'] !=''){
                        $walkaroundQuestion = WalkaroundQuestion::findOrFail($checklistItem['question_id']);
                        $walkaroundQuestion->update($checklistItemData);

                    }else{
                        $walkaroundQuestion = WalkaroundQuestion::create($checklistItemData);

                    }
                    $mediaPath =[];
                    if($walkaroundQuestion && isset($checklistItem['media'])){
                        foreach($checklistItem['media'] as $image){
                            $file = $image;
                            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                            
                            $path = '/uploads/cms/checklist/'.$walkaroundChecklist->id. '/question/'.$walkaroundQuestion->id . $savedAs;
                            $filePath = $this->uploadFile($path, $file);
                            $mediaPath[] = $path;
                        }
                        $walkaroundQuestion->media = json_encode($mediaPath);
    
                        $walkaroundQuestion->update();
                    }
                }

            }
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Walkaround Checklist updated!',
                'errors' => ''
            ], 200);
        }

        return redirect(route('cms.walkaround-checklist.edit', ['walkaround_checklist' => $walkaroundChecklist->id]))->with('flash_message', 'Walkaround Checklist updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        WalkaroundChecklist::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Walkaround Checklist deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cms/faq')->with('flash_message', 'Walkaround Checklist deleted!');
    }
    public function delete_media_file(Request $request)
    {
        $walkaroundQuestion = WalkaroundQuestion::findOrFail($request->question_id);
        $media = json_decode($walkaroundQuestion->media);
        $newMedia = array_diff($media, [$request->path] ) ;
        $walkaroundQuestion->media = $newMedia;
        $walkaroundQuestion->update();
        $this->deleteFile($request->path);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Walkaround ChecklistCategory  deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function priority_list(Request $request){
        $faqCategoryList = Faq::select('question_priority')->get()->toArray();
        $number = range(1,20);
        
        return response()->json([
            'mode' => true,
            'message' => 'Priority List',
            'data' => $number
        ], 200);
    }
}
