<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\User;
use App\Models\MailTemplate;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use App\Mail\DynamicMail;


class EmailController extends AppController
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $mailTemplates = MailTemplate::whereNull('deleted_at')->get();
        return view('admin.mail_templates.index', compact('mailTemplates'));
    }
    
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        $validate = Validator::make($request->all(), [
            'template_key' => 'required|unique:mail_templates,template_key',
            'subject' => 'required',
        ]);
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.mail_templates.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        
        $requestData['created_by'] = Auth::id();
        MailTemplate::create($requestData);

        return redirect('admin/email-templates')->with('flash_message', 'Assets added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $mailTemplate = MailTemplate::findOrFail($id);

        return view('admin.mail_templates.show', compact('mailTemplate'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $mailTemplate = MailTemplate::findOrFail($id);
        $user = User::with(['UserData'])->where('id', '=', 1)->first();
        
        return view('admin.mail_templates.edit', compact('mailTemplate'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $mailTemplate = MailTemplate::findOrFail($id);
        $mailTemplate->update($requestData);

        return redirect('admin/email-templates')->with('flash_message', 'Assets updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        MailTemplate::destroy($id);

        return redirect('admin/email-templates')->with('flash_message', 'Assets deleted!');
    }

    public function sendMail($mailData)
    {
        try
        {
            Mail::to('rosy.dev96@gmail.com')->send(new DynamicMail($mailData));
            return redirect()->back()->with('success', 'Test email sent successfully');
        }
        catch(\Exception $e)
        {
           print_r($e->getMessage()); exit;
        }
    }
}
