<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Location;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Master\LocationClassification;
use App\Models\Master\PropertyType;


class LocationController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $locationClassification = LocationClassification::whereNull('deleted_at')->get();
        $propertyTypeList = PropertyType::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'locationClassification' => $locationClassification, 
            'propertyTypeList' => $propertyTypeList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $locationList = Location::whereNull('deleted_at')->get();
        return view('admin.location.index', compact('locationList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $location = ((new Location())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Location())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($location->isEmpty()) {
            
        }else{
            foreach($location as $location){
                $data['data'][] = [
                    'id' => $location->id,
                    'zone_id' => $location->zone->zone ?? '',
                    'state_id' => $location->state->state ?? '',
                    'district_id' => $location->district->district ?? '',
                    'city_id' => $location->city->city ?? '',
                    'location' => $location->location ?? '',
                    'location_classification_id' => $location->locationClassification->location_classification ?? '',
                    'property_type_id' => $location->propertyType->property_type ?? '',
                    'address' => $location->address,
                    'postal_code' => $location->postal_code,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($location->created_at)) ,
                    'created_by' => isset($location->createdUser) ? $location->createdUser->name :'',
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($location->updated_at)) ,
                    'updated_by' => isset($location->updatedUser) ? $location->updatedUser->name :'',
                    'action' => '<a href="'. route('location.edit', ['location' => $location->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('location.destroy', ['location' => $location->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'location' => [
                    'required',
                    Rule::unique('location')->ignore($request->all()['id']),
                ],
                'location_classification_id' => 'required',
                'property_type_id' => 'required',
                'postal_code' => 'required',
                'address' => 'required',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'location' => 'required|unique:location,location',
                'location_classification_id' => 'required',
                'property_type_id' => 'required',
                'postal_code' => 'required',
                'address' => 'required',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.location.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $location = Location::create($requestData);
        return redirect('admin/location')->with('flash_message', 'Location added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $location = Location::findOrFail($id);
        return view('admin.location.show', compact('location'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $location = Location::findOrFail($id);
        
        return view('admin.location.edit', compact('location'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $location = Location::findOrFail($id);
        $location->update($requestData);

        return redirect('admin/location')->with('flash_message', 'Location updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Location::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Location deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/location')->with('flash_message', 'Location deleted!');
    }
}
