<?php

namespace App\Http\Controllers\Admin\Marketing;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Master\Duration;
use App\Models\Marketing\Cashback;
use App\Models\Master\BusinessCategory;



class CashbackController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        $businessCategoryList = BusinessCategory::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'durationList' => $durationList, 
            'businessCategoryList' => $businessCategoryList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $cashbackList = Cashback::whereNull('deleted_at')->get();
        return view('admin.marketing.cashback.index', compact('cashbackList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $cashback = ((new Cashback())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Cashback())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($cashback->isEmpty()) {
            
        }else{
            foreach($cashback as $cashback){
                $data['data'][] = [
                    'id' => $cashback->id,
                    'cashback_condition' => $cashback->cashback_condition,
                    'business_category_id' => isset($cashback->businessCategory) ? $cashback->businessCategory->business_category :'',
                    'city_id' => isset($cashback->city) ? $cashback->city->city :'',
                    'district_id' => isset($cashback->district) ? $cashback->district->district :'',
                    'state_id' => isset($cashback->state) ? $cashback->state->state :'',
                    'zone_id' => isset($cashback->zone) ? $cashback->zone->zone :'',
                    'subscription_plan_id' => $cashback->subscription_plan_id,
                    'minimum_order_cost' => $cashback->minimum_order_cost,
                    'cashback' => $cashback->cashback,
                    'add_cashback_to' => $cashback->add_cashback_to,
                    'expiry_date' => date($this->siteSettings['timestamp_format'], strtotime($cashback->expiry_date)) ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($cashback->created_at)) ,
                    'action' => '
                    <a href="'. route('marketing.cashback.edit', ['cashback' => $cashback->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('marketing.cashback.destroy', ['cashback' => $cashback->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'cashback_condition' => [
                    'required',
                    Rule::unique('mr_cashback')->ignore($request->all()['id']),
                ],
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'cashback_condition' => 'required|unique:mr_cashback,cashback_condition',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.marketing.cashback.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $requestData['expiry_date'] = ($requestData['expiry_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($requestData['expiry_date'] )) : null ;
        $cashback = Cashback::create($requestData);
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/marketing/cashback/'.$cashback->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $data = [
                'image' =>  $path
            ];
            $cashback->update($data);
        }
        return redirect('admin/marketing/cashback')->with('flash_message', 'Cashback Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $cashback = Cashback::findOrFail($id);
        return view('admin.marketing.cashback.show', compact('cashback'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $cashback = Cashback::findOrFail($id);
        
        return view('admin.marketing.cashback.edit', compact('cashback'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $cashback = Cashback::findOrFail($id);
        $requestData['expiry_date'] = ($requestData['expiry_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($requestData['expiry_date'] )) : $cashback->expiry_date ;
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/marketing/cashback/'.$cashback->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $requestData['image'] =  $path;
        }
        $cashback->update($requestData);
        return redirect('admin/marketing/cashback')->with('flash_message', 'Cashback updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Cashback::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Cashback deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/marketing/cashback')->with('flash_message', 'Cashback deleted!');
    }
    public function destroy_parts(Request $request, $id)
    {
        CashbackParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Cashback Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_service_plan(Request $request, $id)
    {
        CashbackServicePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Cashback Service Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_insurance_plan(Request $request, $id)
    {
        CashbackInsurancePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Cashback Insurance Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
}
