<?php

namespace App\Http\Controllers\Admin\Marketing;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Master\Duration;
use App\Models\Marketing\Discount;
use App\Models\Master\BusinessCategory;



class DiscountController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        $businessCategoryList = BusinessCategory::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'durationList' => $durationList, 
            'businessCategoryList' => $businessCategoryList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $discountList = Discount::whereNull('deleted_at')->get();
        return view('admin.marketing.discount.index', compact('discountList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $discount = ((new Discount())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Discount())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($discount->isEmpty()) {
            
        }else{
            foreach($discount as $discount){
                $data['data'][] = [
                    'id' => $discount->id,
                    'discount_code' => $discount->discount_code,
                    'business_category_id' => isset($discount->businessCategory) ? $discount->businessCategory->business_category :'',
                    'city_id' => isset($discount->city) ? $discount->city->city :'',
                    'district_id' => isset($discount->district) ? $discount->district->district :'',
                    'state_id' => isset($discount->state) ? $discount->state->state :'',
                    'zone_id' => isset($discount->zone) ? $discount->zone->zone :'',
                    'subscription_plan_id' => $discount->subscription_plan_id,
                    'minimum_order_cost' => $discount->minimum_order_cost,
                    'discount' => $discount->discount,
                    'up_to_cost' => $discount->up_to_cost,
                    'expiry_date' => date($this->siteSettings['timestamp_format'], strtotime($discount->expiry_date)) ,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($discount->created_at)) ,
                    'action' => '
                    <a href="'. route('marketing.discount.edit', ['discount' => $discount->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('marketing.discount.destroy', ['discount' => $discount->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'discount_code' => [
                    'required',
                    Rule::unique('mr_discount')->ignore($request->all()['id']),
                ],
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'discount_code' => 'required|unique:mr_discount,discount_code',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.marketing.discount.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $requestData['expiry_date'] = ($requestData['expiry_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($requestData['expiry_date'] )) : null ;
        $discount = Discount::create($requestData);
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/marketing/discount/'.$discount->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $data = [
                'image' =>  $path
            ];
            $discount->update($data);
        }
        return redirect('admin/marketing/discount')->with('flash_message', 'Discount Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $discount = Discount::findOrFail($id);
        return view('admin.marketing.discount.show', compact('discount'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $discount = Discount::findOrFail($id);
        
        return view('admin.marketing.discount.edit', compact('discount'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $discount = Discount::findOrFail($id);
        $requestData['expiry_date'] = ($requestData['expiry_date'] ) ? date($this->siteSettings['timestamp_format'], strtotime($requestData['expiry_date'] )) : $discount->expiry_date ;
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/marketing/discount/'.$discount->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $requestData['image'] =  $path;
        }
        $discount->update($requestData);
        return redirect('admin/marketing/discount')->with('flash_message', 'Discount updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Discount::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Discount deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/marketing/discount')->with('flash_message', 'Discount deleted!');
    }
    public function destroy_parts(Request $request, $id)
    {
        DiscountParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Discount Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_service_plan(Request $request, $id)
    {
        DiscountServicePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Discount Service Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_insurance_plan(Request $request, $id)
    {
        DiscountInsurancePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Discount Insurance Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
}
