<?php

namespace App\Http\Controllers\Admin\Marketing;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Master\Duration;
use App\Models\Marketing\Reward;
use App\Models\Master\BusinessCategory;



class RewardController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        $businessCategoryList = BusinessCategory::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'durationList' => $durationList, 
            'businessCategoryList' => $businessCategoryList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $rewardList = Reward::whereNull('deleted_at')->get();
        return view('admin.marketing.reward.index', compact('rewardList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $reward = ((new Reward())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Reward())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($reward->isEmpty()) {
            
        }else{
            foreach($reward as $reward){
                $data['data'][] = [
                    'id' => $reward->id,
                    'reward_name' => $reward->reward_name,
                    'business_category_id' => isset($reward->businessCategory) ? $reward->businessCategory->business_category :'',
                    'city_id' => isset($reward->city) ? $reward->city->city :'',
                    'district_id' => isset($reward->district) ? $reward->district->district :'',
                    'state_id' => isset($reward->state) ? $reward->state->state :'',
                    'zone_id' => isset($reward->zone) ? $reward->zone->zone :'',
                    'reward_point' => $reward->reward_point,
                    'redemption_cost' => $reward->redemption_cost,
                    'redemption_duration' => isset($reward->redemptionDuration) ? $reward->redemptionDuration->days . ' Days' :'',
                    'redemption_validity' => isset($reward->redemptionValidity) ? $reward->redemptionValidity->days . ' Days' :'',
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($reward->created_at)) ,
                    'action' => '
                    <a href="'. route('marketing.reward.edit', ['reward' => $reward->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('marketing.reward.destroy', ['reward' => $reward->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'reward_name' => [
                    'required',
                    Rule::unique('mr_reward')->ignore($request->all()['id']),
                ],
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'reward_name' => 'required|unique:mr_reward,reward_name',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.marketing.reward.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        
        $reward = Reward::create($requestData);
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/marketing/reward/'.$reward->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $data = [
                'image' =>  $path
            ];
            $reward->update($data);
        }
        return redirect('admin/marketing/reward')->with('flash_message', 'Reward Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $reward = Reward::findOrFail($id);
        return view('admin.marketing.reward.show', compact('reward'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $reward = Reward::findOrFail($id);
        
        return view('admin.marketing.reward.edit', compact('reward'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $reward = Reward::findOrFail($id);
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
            $path = '/uploads/marketing/reward/'.$reward->id. '/' . $savedAs;
            $filePath = $this->uploadFile($path, $file);
            $requestData['image'] =  $path;
        }
        $reward->update($requestData);
        return redirect('admin/marketing/reward')->with('flash_message', 'Reward updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Reward::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Reward deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/marketing/reward')->with('flash_message', 'Reward deleted!');
    }
    public function destroy_parts(Request $request, $id)
    {
        RewardParts::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Reward Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_service_plan(Request $request, $id)
    {
        RewardServicePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Reward Service Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_insurance_plan(Request $request, $id)
    {
        RewardInsurancePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Reward Insurance Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
}
