<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\ActivityStatus;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class ActivityStatusController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $activityStatusList = ActivityStatus::whereNull('deleted_at')->get();
        return view('admin.master.activity_status.index', compact('activityStatusList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $activityStatus = ((new ActivityStatus())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ActivityStatus())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($activityStatus->isEmpty()) {
            
        }else{
            foreach($activityStatus as $activityStatus){
                $data['data'][] = [
                    'id' => $activityStatus->id,
                    'activity_status' => $activityStatus->activity_status,
                   // 'type' => $activityStatus->type,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($activityStatus->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($activityStatus->updated_at)) ,
                    'action' => '<a href="'. route('activity-status.edit', ['activity_status' => $activityStatus->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('activity-status.destroy', ['activity_status' => $activityStatus->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'activity_status' => [
                    'required',
                    Rule::unique('master_activity_status')->ignore($request->all()['id']),
                ],
                //'type' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'activity_status' => 'required|unique:master_activity_status,activity_status',
               // 'type' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.activity_status.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $activityStatus = ActivityStatus::create($requestData);
        return redirect('admin/activity-status')->with('flash_message', 'Activity Status added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $activityStatus = ActivityStatus::findOrFail($id);
        return view('admin.master.activity_status.show', compact('activityStatus'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $activityStatus = ActivityStatus::findOrFail($id);
        
        return view('admin.master.activity_status.edit', compact('activityStatus'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $activityStatus = ActivityStatus::findOrFail($id);
        $activityStatus->update($requestData);

        return redirect('admin/activity-status')->with('flash_message', 'Activity Status updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        ActivityStatus::destroy($id);
        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Activity Status deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/activity-status')->with('flash_message', 'Activity Status deleted!');
    }
}
