<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\AngelService;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class AngelServiceController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $angelServiceList = AngelService::whereNull('deleted_at')->get();
        return view('admin.master.angel_service.index', compact('angelServiceList'));
    }
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $angelServiceList = ((new AngelService())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new AngelService())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($angelServiceList->isEmpty()) {
            
        }else{
            foreach($angelServiceList as $angelService){
                $data['data'][] = [
                    'id' => $angelService->id,
                    'service_type' => $angelService->service_type ?? '',                    
                    'image' => $angelService->image ? '<img src="/storage'.$angelService->image.'" style="width: 60px;"/>': '',                    
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($angelService->created_at)),
                    'created_by' => isset($angelService->createdUser) ? $angelService->createdUser->name :'',
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($angelService->updated_at)),
                    'updated_by' => isset($angelService->updatedUser) ? $angelService->updatedUser->name :'',
                    'action' => '<a href="'. route('master.angel-service.edit', ['angel_service' => $angelService->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('master.angel-service.destroy', ['angel_service' => $angelService->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if($request->id){
            $validate = Validator::make($request->all(), [
                'service_type' => [
                    'required',
                    Rule::unique('master_angel_services')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'service_type' => 'required|unique:master_angel_services,service_type',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $angelService = new AngelService();
        
        return view('admin.master.angel_service.edit', compact('angelService'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $this->save_data($request);
        return redirect('admin/angel-service')->with('flash_message', 'Service Type added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $angelService = AngelService::findOrFail($id);
        return view('admin.master.angel_service.show', compact('angelService'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $angelService = AngelService::findOrFail($id);
        
        return view('admin.master.angel_service.edit', compact('angelService'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $this->save_data($request);

        return redirect('admin/angel-service')->with('flash_message', 'Service Type updated!');
    }

    public function save_data($request){

        $requestData = $request->all();
        //print_r($requestData); exit;
        $angelService = [];
        if($request->id){
            $angelService = AngelService::findOrFail($request->id);
        }
      
        if($angelService){
            $angelService->update($requestData);
        }else{
            $angelService = AngelService::create($requestData);

        }
        
        if(isset($requestData['image'])){
            $file = $requestData['image'];
            if($file){
                $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                $path = '/uploads/master/angel_service/'.$angelService->id. '/' . $savedAs;
                $filePath = $this->uploadFile($path, $file);
                $angelService->image = $path;
                $angelService->update();
            }
        }

    }
        
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        AngelService::destroy($id);

        return redirect('admin/angel-service')->with('flash_message', 'Service Type deleted!');
    }
    public function destroy_service_type_image(Request $request, $id)
    {
        $angelService = AngelService::findOrFail($id);

        $this->deleteFile($angelService->image);
        $angelService->image = '';
        $angelService->update();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'AngelService Service Image deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect(route('master.angel-service.edit', ['angel_service' => $angelService->id]))->with('flash_message', 'AngelService Service Image deleted!');
    }
}
