<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\BillingType;

use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class BillingTypeController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $billingTypes = BillingType::whereNull('deleted_at')->get();
        return view('admin.master.billing_types.index', compact('billingTypes'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $billingTypes = ((new BillingType())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new BillingType())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($billingTypes->isEmpty()) {
            
        }else{
            foreach($billingTypes as $billingType){
                $data['data'][] = [
                    'id' => $billingType->id,
                    'billing_type' => $billingType->billing_type,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($billingType->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($billingType->updated_at)) ,
                    'action' => '<a href="'. route('billing-types.edit', ['billing_type' => $billingType->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('billing-types.destroy', ['billing_type' => $billingType->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'billing_type' => [
                    'required',
                    Rule::unique('master_billing_types')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'billing_type' => 'required|unique:master_billing_types,billing_type',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.billing_types.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $billingType = BillingType::create($requestData);
        return redirect('admin/billing-types')->with('flash_message', 'Billing Type added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $billingType = BillingType::findOrFail($id);
        return view('admin.master.billing_types.show', compact('billingType'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $billingType = BillingType::findOrFail($id);
        
        return view('admin.master.billing_types.edit', compact('billingType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $billingType = BillingType::findOrFail($id);
        $billingType->update($requestData);

        return redirect('admin/billing-types')->with('flash_message', 'Billing Type updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        BillingType::destroy($id);
        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Billing Type deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/billing-types')->with('flash_message', 'Billing Type deleted!');
    }
}
