<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\BusinessCategory;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class BusinessCategoryController extends AppController
{
    public function __construct()
    {
        $businessCategory = BusinessCategory::whereNull('deleted_at')->get();
       // $businessModelsList = BusinessCategory::whereNull('deleted_at')->get();
        View::share([
            'businessCategory' => $businessCategory, 
         //   'businessModelsList' => $businessModelsList
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $businessCategoryList = BusinessCategory::whereNull('deleted_at')->get();
        return view('admin.master.business_category.index', compact('businessCategoryList'));
    }
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $businessCategoryList = ((new BusinessCategory())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new BusinessCategory())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($businessCategoryList->isEmpty()) {
            
        }else{
            foreach($businessCategoryList as $businessCategory){
                $data['data'][] = [
                    'id' => $businessCategory->id,
                    'business_category' => $businessCategory->business_category,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($businessCategory->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($businessCategory->updated_at)) ,
                    'action' => '<a href="'. route('business-categories.edit', ['business_category' => $businessCategory->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('business-categories.destroy', ['business_category' => $businessCategory->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'business_category' => [
                    'required',
                    Rule::unique('master_business_category')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'business_category' => 'required|unique:master_business_category,business_category',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.business_category.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $businessCategory = BusinessCategory::create($requestData);
        return redirect('admin/business-categories')->with('flash_message', 'Business Category added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $businessCategory = BusinessCategory::findOrFail($id);
        return view('admin.master.business_category.show', compact('businessCategory'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $businessCategory = BusinessCategory::findOrFail($id);
        
        return view('admin.master.business_category.edit', compact('businessCategory'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $businessCategory = BusinessCategory::findOrFail($id);
        $businessCategory->update($requestData);

        return redirect('admin/business-categories')->with('flash_message', 'Business Category updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        BusinessCategory::destroy($id);

        
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Business Category deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/business-categories')->with('flash_message', 'Business Category deleted!');
    }
}
