<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\BusinessCategory;
use App\Models\Master\BusinessModels;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class BusinessController extends AppController
{
    public function __construct()
    {
        $businessCategory = BusinessCategory::whereNull('deleted_at')->get();
       // $businessModelsList = BusinessModels::whereNull('deleted_at')->get();
        View::share([
            'businessCategory' => $businessCategory, 
         //   'businessModelsList' => $businessModelsList
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $businessModels = BusinessModels::whereNull('deleted_at')->get();
        return view('admin.master.business_models.index', compact('businessModels'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $businessModelList = ((new BusinessModels())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new BusinessModels())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($businessModelList->isEmpty()) {
            
        }else{
            foreach($businessModelList as $businessModel){
                $data['data'][] = [
                    'id' => $businessModel->id,
                    'business_category' => (isset($businessModel->businessCategory)) ? $businessModel->businessCategory->business_category : '',
                    'business_model' => $businessModel->business_model,
                    'asset_types' => $businessModel->asset_types,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($businessModel->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($businessModel->updated_at)) ,
                    'action' => '<a href="'. route('business-models.edit', ['business_model' => $businessModel->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('business-models.destroy', ['business_model' => $businessModel->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'business_category_id' => 'required',
                'business_model' => [
                    'required',
                    // Rule::unique('master_business_models')->ignore($request->all()['id']),
                ],
                'asset_types' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'business_category_id' => 'required',
                'business_model' => 'required',
                'asset_types' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.business_models.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $requestData['asset_types'] = implode(',', $requestData['asset_types']);
        $businessModel = BusinessModels::create($requestData);
        return redirect('admin/business-models')->with('flash_message', 'Business Model added!');
    }

    public function businesscategorywise()
    {
      $id = $_POST['id'];
      $products = BusinessModels::where('business_category_id', $id)->select('business_model','id')->get();
       return response()->json($products);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $businessModel = BusinessModels::findOrFail($id);
        return view('admin.master.business_models.show', compact('businessModel'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $businessModel = BusinessModels::findOrFail($id);
        
        return view('admin.master.business_models.edit', compact('businessModel'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $requestData['asset_types'] = implode(',', $requestData['asset_types']);
        $businessModel = BusinessModels::findOrFail($id);
        $businessModel->update($requestData);

        return redirect('admin/business-models')->with('flash_message', 'Business Model updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        BusinessModels::destroy($id);
        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Business Model deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/business-models')->with('flash_message', 'Business Model deleted!');
    }
}
