<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\DeliveryType;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class DeliveryTypeController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $deliveryTypeList = DeliveryType::whereNull('deleted_at')->get();
        return view('admin.master.delivery_types.index', compact('deliveryTypeList'));
    }
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $deliveryTypeList = ((new DeliveryType())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new DeliveryType())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($deliveryTypeList->isEmpty()) {
            
        }else{
            foreach($deliveryTypeList as $deliveryType){
                $data['data'][] = [
                    'id' => $deliveryType->id,
                    'delivery_type' => $deliveryType->delivery_type,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($deliveryType->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($deliveryType->updated_at)) ,
                    'action' => '<a href="'. route('delivery-types.edit', ['delivery_type' => $deliveryType->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('delivery-types.destroy', ['delivery_type' => $deliveryType->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'delivery_type' => [
                    'required',
                    Rule::unique('master_delivery_types')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'delivery_type' => 'required|unique:master_delivery_types,delivery_type',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.delivery_types.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $deliveryType = DeliveryType::create($requestData);
        return redirect('admin/delivery-types')->with('flash_message', 'Devivery Type added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $deliveryType = DeliveryType::findOrFail($id);
        return view('admin.master.delivery_types.show', compact('deliveryType'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $deliveryType = DeliveryType::findOrFail($id);
        
        return view('admin.master.delivery_types.edit', compact('deliveryType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $deliveryType = DeliveryType::findOrFail($id);
        $validate = Validator::make($request->all(), [
            'delivery_type' => [
                'required',
                Rule::unique('delivery_types')->ignore($deliveryType->id),
            ]
            
        
        ]);
        $deliveryType->update($requestData);

        return redirect('admin/delivery-types')->with('flash_message', 'Devivery Type updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        DeliveryType::destroy($id);

        return redirect('admin/delivery-types')->with('flash_message', 'Devivery Type deleted!');
    }
}
