<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\Duration;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class DurationController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $durationList = Duration::whereNull('deleted_at')->get();
        return view('admin.master.duration.index', compact('durationList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $duration = ((new Duration())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Duration())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($duration->isEmpty()) {
            
        }else{
            foreach($duration as $duration){
                $data['data'][] = [
                    'id' => $duration->id,
                    'duration' => $duration->duration,
                    'days' => $duration->days,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($duration->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($duration->updated_at)) ,
                    'action' => '<a href="'. route('duration.edit', ['duration' => $duration->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('duration.destroy', ['duration' => $duration->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'duration' => [
                    'required',
                    Rule::unique('master_duration')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'duration' => 'required|unique:master_duration,duration',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.duration.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $duration = Duration::create($requestData);
        return redirect('admin/duration')->with('flash_message', 'Duration added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $duration = Duration::findOrFail($id);
        return view('admin.master.duration.show', compact('duration'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $duration = Duration::findOrFail($id);
        
        return view('admin.master.duration.edit', compact('duration'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $duration = Duration::findOrFail($id);
        $duration->update($requestData);

        return redirect('admin/duration')->with('flash_message', 'Duration updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Duration::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Duration deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/duration')->with('flash_message', 'Duration deleted!');
    }
}
