<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\FormFieldGroup;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class FormFieldGroupController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $formFieldGroupList = FormFieldGroup::whereNull('deleted_at')->get();
        return view('admin.master.form_field_group.index', compact('formFieldGroupList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $formFieldGroup = ((new FormFieldGroup())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new FormFieldGroup())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($formFieldGroup->isEmpty()) {
            
        }else{
            foreach($formFieldGroup as $formFieldGroup){
                $data['data'][] = [
                    'id' => $formFieldGroup->id,
                    'field_group' => $formFieldGroup->field_group,
                    'title' => $formFieldGroup->title,
                    'sub_title' => $formFieldGroup->sub_title,
                    'priority' => $formFieldGroup->priority,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($formFieldGroup->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($formFieldGroup->updated_at)) ,
                    'action' => '<a href="'. route('form-field-group.edit', ['form_field_group' => $formFieldGroup->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('form-field-group.destroy', ['form_field_group' => $formFieldGroup->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'field_group' => [
                    'required',
                    Rule::unique('master_form_field_group')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'field_group' => 'required|unique:master_form_field_group,field_group',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.form_field_group.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $formFieldGroup = FormFieldGroup::create($requestData);
        return redirect('admin/form-field-group')->with('flash_message', 'FormFieldGroup added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $formFieldGroup = FormFieldGroup::findOrFail($id);
        return view('admin.master.form_field_group.show', compact('formFieldGroup'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $formFieldGroup = FormFieldGroup::findOrFail($id);
        
        return view('admin.master.form_field_group.edit', compact('formFieldGroup'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $formFieldGroup = FormFieldGroup::findOrFail($id);
        $formFieldGroup->update($requestData);

        return redirect('admin/form-field-group')->with('flash_message', 'FormFieldGroup updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        FormFieldGroup::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'FormFieldGroup deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/form-field-group')->with('flash_message', 'FormFieldGroup deleted!');
    }
}
