<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\FormFieldType;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class FormFieldTypeController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $formFieldTypeList = FormFieldType::whereNull('deleted_at')->get();
        return view('admin.master.form_field_type.index', compact('formFieldTypeList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $formFieldType = ((new FormFieldType())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new FormFieldType())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($formFieldType->isEmpty()) {
            
        }else{
            foreach($formFieldType as $formFieldType){
                $data['data'][] = [
                    'id' => $formFieldType->id,
                    'field_type' => $formFieldType->field_type,
                    'add_option' => $formFieldType->add_option,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($formFieldType->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($formFieldType->updated_at)) ,
                    'action' => '<a href="'. route('form-field-type.edit', ['form_field_type' => $formFieldType->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('form-field-type.destroy', ['form_field_type' => $formFieldType->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'field_type' => [
                    'required',
                    Rule::unique('master_form_field_type')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'field_type' => 'required|unique:master_form_field_type,field_type',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.form_field_type.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $formFieldType = FormFieldType::create($requestData);
        return redirect('admin/form-field-type')->with('flash_message', 'FormFieldType added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $formFieldType = FormFieldType::findOrFail($id);
        return view('admin.master.form_field_type.show', compact('formFieldType'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $formFieldType = FormFieldType::findOrFail($id);
        
        return view('admin.master.form_field_type.edit', compact('formFieldType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $formFieldType = FormFieldType::findOrFail($id);
        $formFieldType->update($requestData);

        return redirect('admin/form-field-type')->with('flash_message', 'FormFieldType updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        FormFieldType::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'FormFieldType deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/form-field-type')->with('flash_message', 'FormFieldType deleted!');
    }
}
