<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\InsuranceDuration;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class InsuranceDurationController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $insuranceDurations = InsuranceDuration::whereNull('deleted_at')->get();
        return view('admin.master.insurance_durations.index', compact('insuranceDurations'));
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'insurance_duration' => [
                    'required',
                    Rule::unique('master_s_insurance_duration')->ignore($request->all()['id']),
                ],
                'duration_by_days' => 'required',
            ]);

        }else{
            $validate = Validator::make($request->all(), [
                'insurance_duration' => 'required|unique:master_s_insurance_duration,insurance_duration',
                'duration_by_days' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.insurance_durations.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $insuranceDuration = InsuranceDuration::create($requestData);
        return redirect('admin/insurance-durations')->with('flash_message', 'Insurance Duration added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $insuranceDuration = InsuranceDuration::findOrFail($id);
        return view('admin.master.insurance_durations.show', compact('insuranceDuration'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $insuranceDuration = InsuranceDuration::findOrFail($id);
        
        return view('admin.master.insurance_durations.edit', compact('insuranceDuration'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $requestData = $request->all();
        $insuranceDuration = InsuranceDuration::findOrFail($id);
        $insuranceDuration->update($requestData);

        return redirect('admin/insurance-durations')->with('flash_message', 'Insurance Duration updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        InsuranceDuration::destroy($id);

        return redirect('admin/insurance-durations')->with('flash_message', 'Insurance Duration deleted!');
    }
}
