<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\InsuranceType;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class InsuranceTypeController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $insuranceTypeList = InsuranceType::whereNull('deleted_at')->get();
        return view('admin.master.insurance_types.index', compact('insuranceTypeList'));
    }
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $insuranceTypeList = ((new InsuranceType())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new InsuranceType())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($insuranceTypeList->isEmpty()) {
            
        }else{
            foreach($insuranceTypeList as $insuranceType){
                $data['data'][] = [
                    'id' => $insuranceType->id,
                    'insurance_type' => $insuranceType->insurance_type ?? '',
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($insuranceType->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($insuranceType->updated_at)) ,
                    'action' => '<a href="'. route('insurance-types.edit', ['insurance_type' => $insuranceType->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('insurance-types.destroy', ['insurance_type' => $insuranceType->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        $validate = Validator::make($request->all(), [
            'insurance_type' => 'required|unique:master_s_insurance_type,insurance_type',
        ]);
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.insurance_types.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $insuranceType = InsuranceType::create($requestData);
        return redirect('admin/insurance-types')->with('flash_message', 'Insurance Type added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $insuranceType = InsuranceType::findOrFail($id);
        return view('admin.master.insurance_types.show', compact('insuranceType'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $insuranceType = InsuranceType::findOrFail($id);
        
        return view('admin.master.insurance_types.edit', compact('insuranceType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $insuranceType = InsuranceType::findOrFail($id);
        $insuranceType->update($requestData);

        return redirect('admin/insurance-types')->with('flash_message', 'Insurance Type updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        InsuranceType::destroy($id);

        return redirect('admin/insurance-types')->with('flash_message', 'Insurance Type deleted!');
    }
}
