<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\LocationClassification;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class LocationClassificationController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $locationClassificationList = LocationClassification::whereNull('deleted_at')->get();
        return view('admin.master.location_classifications.index', compact('locationClassificationList'));
    }
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $locationClassificationList = ((new LocationClassification())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new LocationClassification())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($locationClassificationList->isEmpty()) {
            
        }else{
            foreach($locationClassificationList as $locationClassification){
                $data['data'][] = [
                    'id' => $locationClassification->id,
                    'location_classification' => $locationClassification->location_classification ?? '',
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($locationClassification->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($locationClassification->updated_at)) ,
                    'action' => '<a href="'. route('location-classifications.edit', ['location_classification' => $locationClassification->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('location-classifications.destroy', ['location_classification' => $locationClassification->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'location_classification' => [
                    'required',
                    Rule::unique('master_location_classification')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'location_classification' => 'required|unique:master_location_classification,location_classification',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.location_classifications.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $locationClassification = LocationClassification::create($requestData);
        return redirect('admin/location-classifications')->with('flash_message', 'Location Classification added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $locationClassification = LocationClassification::findOrFail($id);
        return view('admin.master.location_classifications.show', compact('locationClassification'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $locationClassification = LocationClassification::findOrFail($id);
        
        return view('admin.master.location_classifications.edit', compact('locationClassification'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $locationClassification = LocationClassification::findOrFail($id);
        $locationClassification->update($requestData);

        return redirect('admin/location-classifications')->with('flash_message', 'Location Classification updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        LocationClassification::destroy($id);

        return redirect('admin/location-classifications')->with('flash_message', 'Location Classification deleted!');
    }
}
