<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\MaintenanceType;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;



class MaintentanceTypeController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $maintenanceTypeList = MaintenanceType::whereNull('deleted_at')->get();
        return view('admin.master.maintenance_types.index', compact('maintenanceTypeList'));
    }
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $maintenanceTypeList = ((new MaintenanceType())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new MaintenanceType())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($maintenanceTypeList->isEmpty()) {
            
        }else{
            foreach($maintenanceTypeList as $maintenanceType){
                $data['data'][] = [
                    'id' => $maintenanceType->id,
                    'maintenance_type' => $maintenanceType->maintenance_type ?? '',
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($maintenanceType->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($maintenanceType->updated_at)) ,
                    'action' => '<a href="'. route('maintenance-types.edit', ['maintenance_type' => $maintenanceType->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('maintenance-types.destroy', ['maintenance_type' => $maintenanceType->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'maintenance_type' => [
                    'required',
                    Rule::unique('master_s_maintenance_type')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'maintenance_type' => 'required|unique:master_s_maintenance_type,maintenance_type',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.maintenance_types.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $maintenanceType = MaintenanceType::create($requestData);
        return redirect('admin/maintenance-types')->with('flash_message', 'Maintenance Type added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $maintenanceType = MaintenanceType::findOrFail($id);
        return view('admin.master.maintenance_types.show', compact('maintenanceType'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $maintenanceType = MaintenanceType::findOrFail($id);
        
        return view('admin.master.maintenance_types.edit', compact('maintenanceType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $maintenanceType = MaintenanceType::findOrFail($id);
        $maintenanceType->update($requestData);

        return redirect('admin/maintenance-types')->with('flash_message', 'Maintenance Type updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        MaintenanceType::destroy($id);

        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Maintenance Type deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/maintenance-types')->with('flash_message', 'Maintenance Type deleted!');
    }
}
