<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\PaymentType;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class PaymentTypeController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $paymentTypes = PaymentType::whereNull('deleted_at')->get();
        return view('admin.master.payment_types.index', compact('paymentTypes'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $paymentTypes = ((new PaymentType())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new PaymentType())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($paymentTypes->isEmpty()) {
            
        }else{
            foreach($paymentTypes as $paymentType){
                $data['data'][] = [
                    'id' => $paymentType->id,
                    'payment_type' => $paymentType->payment_type,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($paymentType->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($paymentType->updated_at)) ,
                    'action' => '<a href="'. route('payment-types.edit', ['payment_type' => $paymentType->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('payment-types.destroy', ['payment_type' => $paymentType->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'payment_type' => [
                    'required',
                    Rule::unique('master_payment_types')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'payment_type' => 'required|unique:master_payment_types,payment_type',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.payment_types.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $paymentType = PaymentType::create($requestData);
        return redirect('admin/payment-types')->with('flash_message', 'Payment Type added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $paymentType = PaymentType::findOrFail($id);
        return view('admin.master.payment_types.show', compact('paymentType'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $paymentType = PaymentType::findOrFail($id);
        
        return view('admin.master.payment_types.edit', compact('paymentType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $paymentType = PaymentType::findOrFail($id);
        $paymentType->update($requestData);

        return redirect('admin/payment-types')->with('flash_message', 'Payment Type updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        PaymentType::destroy($id);
        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Payment Type deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/payment-types')->with('flash_message', 'Payment Type deleted!');
    }
}
