<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Users\Permission;

class PermissionController extends AppController
{
    public function __construct()
    {
        $parentList = Permission::parentList;
        View::share([
            'parentList' => $parentList, 
        ]);
        
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $permissionList = Permission::get();
        return view('admin.master.permissions.index', compact('permissionList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $permission = ((new Permission())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Permission())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($permission->isEmpty()) {
            
        }else{
            foreach($permission as $permission){
                $data['data'][] = [
                    'id' => $permission->id,
                    'name' => $permission->name,
                    'days' => $permission->days,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($permission->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($permission->updated_at)) ,
                    'action' => '<a href="'. route('permissions.edit', ['permission' => $permission->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('permissions.destroy', ['permission' => $permission->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if($request->id){
            $validate = Validator::make($request->all(), [
                'name' => [
                    'required',
                    Rule::unique('permissions')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'name' => 'required|unique:permissions,name',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $permission = new Permission();
        return view('admin.master.permissions.edit', compact('permission'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $permission = Permission::create($requestData);
        return redirect('admin/permissions')->with('flash_message', 'Permission added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $permission = Permission::findOrFail($id);
        return view('admin.master.permissions.show', compact('permission'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $permission = Permission::findOrFail($id);
        
        return view('admin.master.permissions.edit', compact('permission'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        //print_r($requestData); exit;
        $permission = Permission::findOrFail($id);
        $permission->update($requestData);

        return redirect('admin/permissions')->with('flash_message', 'Permission updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Permission::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Permission deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/permissions')->with('flash_message', 'Permission deleted!');
    }
}
