<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\ProductType;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class ProductTypesController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $productTypes = ProductType::whereNull('deleted_at')->get();
        if(\Request::ajax()){
            return response()->json([
                'status' => true,
                'message' => 'sucess',
                'data' => $productTypes
            ], 200);
        }
        return view('admin.master.product_types.index', compact('productTypes'));
    }
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $ProductTypeList = ((new ProductType())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ProductType())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($ProductTypeList->isEmpty()) {
            
        }else{
            foreach($ProductTypeList as $ProductType){
                $data['data'][] = [
                    'id' => $ProductType->id,
                    'product_type' => $ProductType->product_type,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($ProductType->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($ProductType->updated_at)) ,
                    'action' => '<a href="'. route('product-types.edit', ['product_type' => $ProductType->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('product-types.destroy', ['product_type' => $ProductType->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'product_type' => [
                    'required',
                    Rule::unique('master_product_types')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'product_type' => 'required|unique:master_product_types,product_type',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    public function products(){
        
        $requestData = $request->all();
        $products = '';
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $products
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.product_types.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $productType = ProductType::create($requestData);
        return redirect('admin/product-types')->with('flash_message', 'Product Type added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $productType = ProductType::findOrFail($id);
        return view('admin.master.product_types.show', compact('ProductType'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $productType = ProductType::findOrFail($id);
        
        return view('admin.master.product_types.edit', compact('productType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $productType = ProductType::findOrFail($id);
        
        $validate = Validator::make($request->all(), [
            'product_type' => [
                'required',
                Rule::unique('product_types')->ignore($productType->id),
            ]
        ]);
        $productType->update($requestData);

        return redirect('admin/product-types')->with('flash_message', 'Product Type updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        ProductType::destroy($id);

        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Product Type deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/product-types')->with('flash_message', 'Product Type deleted!');
    }
}
