<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\PropertyType;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class PropertyTypesController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $propertyTypelist = PropertyType::whereNull('deleted_at')->get();
        return view('admin.master.property_types.index', compact('propertyTypelist'));
    }
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $propertyTypelist = ((new PropertyType())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new PropertyType())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($propertyTypelist->isEmpty()) {
            
        }else{
            foreach($propertyTypelist as $propertyType){
                $data['data'][] = [
                    'id' => $propertyType->id,
                    'property_type' => $propertyType->property_type ?? '',
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($propertyType->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($propertyType->updated_at)) ,
                    'action' => '<a href="'. route('property-types.edit', ['property_type' => $propertyType->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('property-types.destroy', ['property_type' => $propertyType->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'property_type' => [
                    'required',
                    Rule::unique('master_property_types')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'property_type' => 'required|unique:master_property_types,property_type',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.property_types.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $propertyType = PropertyType::create($requestData);
        return redirect('admin/property-types')->with('flash_message', 'Property Type added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $propertyType = PropertyType::findOrFail($id);
        return view('admin.master.property_types.show', compact('propertyType'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $propertyType = PropertyType::findOrFail($id);
        
        return view('admin.master.property_types.edit', compact('propertyType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $propertyType = PropertyType::findOrFail($id);
        
        $validate = Validator::make($request->all(), [
            'property_type' => [
                'required',
                Rule::unique('property_types')->ignore($propertyType->id),
            ]
        ]);
        $propertyType->update($requestData);

        return redirect('admin/property-types')->with('flash_message', 'Property Type updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        PropertyType::destroy($id);

        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Property Type deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/property-types')->with('flash_message', 'Property Type deleted!');
    }
}
