<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\PurchasedService;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class PurchasedServiceController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $purchasedServices = PurchasedService::whereNull('deleted_at')->get();
        return view('admin.master.purchased_services.index', compact('purchasedServices'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $purchasedServices = ((new PurchasedService())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new PurchasedService())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($purchasedServices->isEmpty()) {
            
        }else{
            foreach($purchasedServices as $purchasedService){
                $data['data'][] = [
                    'id' => $purchasedService->id,
                    'purchased_service' => $purchasedService->purchased_service,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($purchasedService->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($purchasedService->updated_at)) ,
                    'action' => '<a href="'. route('purchased-services.edit', ['purchased_service' => $purchasedService->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('purchased-services.destroy', ['purchased_service' => $purchasedService->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'purchased_service' => [
                    'required',
                    Rule::unique('master_purchased_services')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'purchased_service' => 'required|unique:master_purchased_services,purchased_service',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.purchased_services.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $purchasedService = PurchasedService::create($requestData);
        return redirect('admin/purchased-services')->with('flash_message', 'Purchased Service added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $purchasedService = PurchasedService::findOrFail($id);
        return view('admin.master.purchased_services.show', compact('purchasedService'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $purchasedService = PurchasedService::findOrFail($id);
        
        return view('admin.master.purchased_services.edit', compact('purchasedService'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $purchasedService = PurchasedService::findOrFail($id);
        $purchasedService->update($requestData);

        return redirect('admin/purchased-services')->with('flash_message', 'Purchased Service updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        PurchasedService::destroy($id);
        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Purchased Service deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/purchased-services')->with('flash_message', 'Purchased Service deleted!');
    }
}
