<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Users\Role;
use App\Models\Users\Permission;

class RoleController extends AppController
{
   
    public function __construct()
    {
        $permissionList = Permission::get();
        View::share([
            'permissionList' => $permissionList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $roleList = Role::get();
        return view('admin.master.roles.index', compact('roleList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $role = ((new Role())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Role())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($role->isEmpty()) {
            
        }else{
            foreach($role as $role){
                $data['data'][] = [
                    'id' => $role->id,
                    'name' => $role->name,
                    'days' => $role->days,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($role->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($role->updated_at)) ,
                    'action' => '<a href="'. route('roles.edit', ['role' => $role->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('roles.destroy', ['role' => $role->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if($request->id){
            $validate = Validator::make($request->all(), [
                'name' => [
                    'required',
                    Rule::unique('roles')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'name' => 'required|unique:roles,name',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $role = new Role();
        return view('admin.master.roles.edit', compact('role'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $this->save_data($request);

        return redirect('admin/roles')->with('flash_message', 'Role added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $role = Role::findOrFail($id);
        return view('admin.master.roles.show', compact('role'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $role = Role::findOrFail($id);
        
        return view('admin.master.roles.edit', compact('role'));
    }

    public function save_data($request){

        $requestData = $request->all();
        //print_r($requestData); exit;
        $role = [];
        if($request->id){
            $role = Role::findOrFail($request->id);
        }
      
        if($role){
            $role->update($requestData);
        }else{
            $role = Role::create($requestData);
        }
        
        

        if(isset($requestData['permission'])){
            $hasPermissions = $role->permissions->pluck('name');
            foreach($hasPermissions as $permissions){
                if(!in_array($permissions, $requestData['permission'])){
                    $role->revokePermissionTo($permissions);
                }
            }
            foreach($requestData['permission'] as $permission){
                $role->givePermissionTo($permission);
            }
        }
        return true;
    }
    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $this->save_data($request);

        return redirect('admin/roles')->with('flash_message', 'Role updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Role::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Role deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/roles')->with('flash_message', 'Role deleted!');
    }
}
