<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\SopCategory;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class SopCategoryController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $sopCategorys = SopCategory::whereNull('deleted_at')->get();
        return view('admin.master.sop_categories.index', compact('sopCategorys'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $sopCategorys = ((new SopCategory())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new SopCategory())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($sopCategorys->isEmpty()) {
            
        }else{
            foreach($sopCategorys as $sopCategory){
                $data['data'][] = [
                    'id' => $sopCategory->id,
                    'sop_category' => $sopCategory->sop_category,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($sopCategory->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($sopCategory->updated_at)) ,
                    'action' => '<a href="'. route('sop-categories.edit', ['sop_category' => $sopCategory->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('sop-categories.destroy', ['sop_category' => $sopCategory->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'sop_category' => [
                    'required',
                    Rule::unique('master_sop_category')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'sop_category' => 'required|unique:master_sop_category,sop_category',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.sop_categories.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $sopCategory = SopCategory::create($requestData);
        return redirect('admin/sop-categories')->with('flash_message', 'SOP Category added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $sopCategory = SopCategory::findOrFail($id);
        return view('admin.master.sop_categories.show', compact('sopCategory'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $sopCategory = SopCategory::findOrFail($id);
        
        return view('admin.master.sop_categories.edit', compact('sopCategory'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $sopCategory = SopCategory::findOrFail($id);
        $sopCategory->update($requestData);

        return redirect('admin/sop-categories')->with('flash_message', 'SOP Category updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        SopCategory::destroy($id);
        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'SOP Category deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/sop-categories')->with('flash_message', 'SOP Category deleted!');
    }
}
