<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\Taxationprofile;
use App\Models\Master\TaxPercentage;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class TaxPercentageController extends AppController
{
    public function __construct()
    { 
        $taxProfileList = Taxationprofile::whereNull('deleted_at')->get();
        View::share([
            'taxProfileList' => $taxProfileList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $taxPercentageList = TaxPercentage::whereNull('deleted_at')->get();
        return view('admin.master.tax_percentage.index', compact('taxPercentageList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $taxPercentageList = ((new TaxPercentage())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new TaxPercentage())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($taxPercentageList->isEmpty()) {
            
        }else{
            foreach($taxPercentageList as $taxPercentage){
                $data['data'][] = [
                    'id' => $taxPercentage->id,
                    'taxation_profile_id' => $taxPercentage->taxationProfile->taxation_profile,
                    'tax_name' => $taxPercentage->tax_name,
                    'percentage' => $taxPercentage->percentage,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($taxPercentage->created_at)),
                    'created_by' => $taxPercentage?->createdUser?->name,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($taxPercentage->updated_at)) ,
                    'updated_by' => $taxPercentage?->updatedUser?->name,
                    'action' => '<a href="'. route('tax-percentage.edit', ['tax_percentage' => $taxPercentage->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('tax-percentage.destroy', ['tax_percentage' => $taxPercentage->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        $validate = Validator::make($request->all(), [
            'taxation_profile_id' => 'required',
        ],[
            'taxation_profile_id.required' => 'The taxation profile field is required ',
        ]);
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.tax_percentage.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {        
        $requestData = $request->all();
        $error = false;
        $taxName = [];
        foreach($requestData['tax-list'] as $taxList){
            $taxPercentage = TaxPercentage::where('tax_name', $taxList['tax_name'])->first();
            if($taxPercentage || in_array($taxList['tax_name'], $taxName)){
                $error = $error . ' ' . $taxList['tax_name'];
            }
            
            $taxName[] = $taxList['tax_name'];
        }
        if($error){
            return redirect()->back()->with('error', $error . ' Tax Name already taken'); 
        }
        
        foreach($requestData['tax-list'] as $taxList){
            if($taxList['tax_name']){
                $taxListData = [
                    'taxation_profile_id' => $requestData['taxation_profile_id'],
                    'tax_name' => $taxList['tax_name'],
                    'percentage' => $taxList['percentage']
                ];
                
                $taxPercentage = TaxPercentage::create($taxListData);
                
            }
        }
        
        return redirect('admin/tax-percentage')->with('flash_message', 'Tax Percentage created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $emergencyService = TaxPercentage::findOrFail($id);
        return view('admin.master.tax_percentage.show', compact('emergencyService'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $taxPercentage = TaxPercentage::findOrFail($id);
        $profileId = $taxPercentage->taxationProfile->id;
        $taxProfile = Taxationprofile::with('taxPercentage')->where('id',  $profileId)->first();
        
        return view('admin.master.tax_percentage.edit', compact('taxPercentage', 'taxProfile'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        
        $error = false;
        $taxName = [];
        foreach($requestData['tax-list'] as $taxList){
            $query = TaxPercentage::where('tax_name', $taxList['tax_name']);
            if($taxList['tax_id']){
                $query->where('id', '!=' , $taxList['tax_id']);
            }
            $taxPercentage = $query->first();

            if($taxPercentage || in_array($taxList['tax_name'], $taxName)){
                $error = $error . ' ' . $taxList['tax_name'];
            }
            
            $taxName[] = $taxList['tax_name'];
        }
        if($error){
            return redirect()->back()->with('error', $error . ' Tax Name already taken'); 
        }
        
        foreach($requestData['tax-list'] as $taxList){
            if($taxList['tax_name']){
                $taxListData = [
                    'taxation_profile_id' => $requestData['taxation_profile_id'],
                    'tax_name' => $taxList['tax_name'],
                    'percentage' => $taxList['percentage']
                ];
                if($taxList['tax_id']){
                    $taxPercentage = TaxPercentage::findOrFail($taxList['tax_id']);
                    $taxPercentage->update($taxListData);
                }else{
                    $taxPercentage = TaxPercentage::create($taxListData);
                }
                
            }
        }

        return redirect('admin/tax-percentage')->with('flash_message', 'Tax Percentage updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        TaxPercentage::destroy($id);
        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Tax Percentage deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/taxation-profile')->with('flash_message', 'Tax Percentage deleted!');
    }
}
