<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\Taxationprofile;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class TaxationprofileController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $emergencyServices = Taxationprofile::whereNull('deleted_at')->get();
        return view('admin.master.taxation_profile.index', compact('emergencyServices'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $emergencyServices = ((new Taxationprofile())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Taxationprofile())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($emergencyServices->isEmpty()) {
            
        }else{
            foreach($emergencyServices as $emergencyService){
                $data['data'][] = [
                    'id' => $emergencyService->id,
                    'taxation_profile' => $emergencyService->taxation_profile,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($emergencyService->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($emergencyService->updated_at)) ,
                    'action' => '<a href="'. route('taxation-profile.edit', ['taxation_profile' => $emergencyService->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('taxation-profile.destroy', ['taxation_profile' => $emergencyService->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'taxation_profile' => [
                    'required',
                    Rule::unique('master_taxation_profile')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'taxation_profile' => 'required|unique:master_taxation_profile,taxation_profile',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.taxation_profile.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $emergencyService = Taxationprofile::create($requestData);
        return redirect('admin/taxation-profile')->with('flash_message', 'Taxation Profile added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $emergencyService = Taxationprofile::findOrFail($id);
        return view('admin.master.taxation_profile.show', compact('emergencyService'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $emergencyService = Taxationprofile::findOrFail($id);
        
        return view('admin.master.taxation_profile.edit', compact('emergencyService'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $emergencyService = Taxationprofile::findOrFail($id);
        $emergencyService->update($requestData);

        return redirect('admin/taxation-profile')->with('flash_message', 'Taxation Profile updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Taxationprofile::destroy($id);
        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Taxation Profile deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/taxation-profile')->with('flash_message', 'Taxation Profile deleted!');
    }
}
