<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\VAServiceType;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class VAServiceTypeController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $vaServiceTypeList = VAServiceType::whereNull('deleted_at')->get();
        return view('admin.master.va_service_types.index', compact('vaServiceTypeList'));
    }
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $vaServiceTypeList = ((new VAServiceType())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new VAServiceType())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($vaServiceTypeList->isEmpty()) {
            
        }else{
            foreach($vaServiceTypeList as $vaServiceType){
                $data['data'][] = [
                    'id' => $vaServiceType->id,
                    'va_service_type' => $vaServiceType->va_service_type,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($vaServiceType->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($vaServiceType->updated_at)) ,
                    'action' => '<a href="'. route('va-service-types.edit', ['va_service_type' => $vaServiceType->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('va-service-types.destroy', ['va_service_type' => $vaServiceType->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'va_service_type' => [
                    'required',
                    Rule::unique('master_va_service_types')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'va_service_type' => 'required|unique:master_va_service_types,va_service_type',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.va_service_types.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $vaServiceType = VAServiceType::create($requestData);
        return redirect('admin/va-service-types')->with('flash_message', 'Service Type added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $vaServiceType = VAServiceType::findOrFail($id);
        return view('admin.master.va_service_types.show', compact('vaServiceType'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $vaServiceType = VAServiceType::findOrFail($id);
        
        return view('admin.master.va_service_types.edit', compact('vaServiceType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $vaServiceType = VAServiceType::findOrFail($id);
        $validate = Validator::make($request->all(), [
            'va_service_type' => [
                'required',
                Rule::unique('va_service_types')->ignore($vaServiceType->id),
            ]
            
        
        ]);
        $vaServiceType->update($requestData);

        return redirect('admin/va-service-types')->with('flash_message', 'Service Type updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        VAServiceType::destroy($id);

        return redirect('admin/va-service-types')->with('flash_message', 'Service Type deleted!');
    }
}
