<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\VerificationType;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Users\Role;

class VerficationTypeController extends AppController
{
    public function __construct()
    {
        
        $roles = Role::get();
        View::share([
            'roles' => $roles, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $verificationTypes = VerificationType::whereNull('deleted_at')->get();
        return view('admin.master.verification_types.index', compact('verificationTypes'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $verificationTypes = ((new VerificationType())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new VerificationType())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($verificationTypes->isEmpty()) {
            
        }else{
            foreach($verificationTypes as $verificationType){
                $data['data'][] = [
                    'id' => $verificationType->id,
                    'verification_parameter' => $verificationType->verification_parameter ?? '',
                    'oblication' => $verificationType->oblication,
                    'proof_required' => $verificationType->proof_required,
                    'user_role' => $verificationType?->role?->name,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($verificationType->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($verificationType->updated_at)) ,
                    'action' => '<a href="'. route('verification-types.edit', ['verification_type' => $verificationType->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('verification-types.destroy', ['verification_type' => $verificationType->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'verification_parameter' => [
                    'required',
                    Rule::unique('master_verification_types')->ignore($request->all()['id']),
                ],
                'proof_required' => 'required',
                'oblication' => 'required',
                'user_role' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'verification_parameter' => 'required|unique:master_verification_types,verification_parameter',
                'proof_required' => 'required',
                'oblication' => 'required',
                'user_role' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.verification_types.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $verificationType = VerificationType::create($requestData);
        return redirect('admin/verification-types')->with('flash_message', 'Verification Type added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $verificationType = VerificationType::findOrFail($id);
        return view('admin.master.verification_types.show', compact('verificationType'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $verificationType = VerificationType::findOrFail($id);
        
        return view('admin.master.verification_types.edit', compact('verificationType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $verificationType = VerificationType::findOrFail($id);
        $verificationType->update($requestData);

        return redirect('admin/verification-types')->with('flash_message', 'Verification Type updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        VerificationType::destroy($id);
        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'Verification Type deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/verification-types')->with('flash_message', 'Verification Type deleted!');
    }
}
