<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\VerificationMode;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class VerificationModeController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $verificationModeList = VerificationMode::whereNull('deleted_at')->get();
        return view('admin.master.verification_mode.index', compact('verificationModeList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $verificationMode = ((new VerificationMode())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new VerificationMode())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($verificationMode->isEmpty()) {
            
        }else{
            foreach($verificationMode as $verificationMode){
                $data['data'][] = [
                    'id' => $verificationMode->id,
                    'verification_mode' => $verificationMode->verification_mode,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($verificationMode->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($verificationMode->updated_at)) ,
                    'action' => '<a href="'. route('verification-mode.edit', ['verification_mode' => $verificationMode->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('verification-mode.destroy', ['verification_mode' => $verificationMode->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'verification_mode' => [
                    'required',
                    Rule::unique('master_verification_mode')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'verification_mode' => 'required|unique:master_verification_mode,verification_mode',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.verification_mode.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $verificationMode = VerificationMode::create($requestData);
        return redirect('admin/verification-mode')->with('flash_message', 'Verification Mode added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $verificationMode = VerificationMode::findOrFail($id);
        return view('admin.master.verification_mode.show', compact('verificationMode'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $verificationMode = VerificationMode::findOrFail($id);
        
        return view('admin.master.verification_mode.edit', compact('verificationMode'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $verificationMode = VerificationMode::findOrFail($id);
        $verificationMode->update($requestData);

        return redirect('admin/verification-mode')->with('flash_message', 'Verification Mode updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        VerificationMode::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Verification Mode deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/verification-mode')->with('flash_message', 'Verification Mode deleted!');
    }
}
