<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use App\Http\Resources\ZoneState as ZoneStateResource; 

use Illuminate\Database\Eloquent\Builder;


class ZoneCityController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $citys = ZoneCity::with(['zone', 'state', 'district'])->whereNull('deleted_at');
        return view('admin.master.zone_city.index', compact('citys'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $citys = ((new ZoneCity())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ZoneCity())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($citys->isEmpty()) {
            
        }else{
            foreach($citys as $city){
                $data['data'][] = [
                    'id' => $city->id,
                    'zone' => (isset($city->zone)) ? $city->zone->zone : '',
                    'state' => (isset($city->state)) ? $city->state->state : '',
                    'district' => (isset($city->district)) ? $city->district->district : '',
                    'city' => $city->city,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($city->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($city->updated_at)) ,
                    'action' => '
                        <a href="'. route('cities.edit', ['city' => $city->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                        <a  href="#" class="delete" data-url="'.  route('cities.destroy', ['city' => $city->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    public function cities_by_state(Request $request)
    {
        $requestData = $request->all();
        $districtByState = ((new ZoneCity())->districts_by_state($requestData['state_id']))->toArray();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $districtByState
        ], 200);
    }
    public function cities_by_zone(Request $request)
    {
        $requestData = $request->all();
        $districtByZone = ((new ZoneCity())->districts_by_zone($requestData['zone_id']))->toArray();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $districtByZone
        ], 200);
    }
    public function cities_by_district(Request $request)
    {
        $requestData = $request->all();
        $districtByZone = ((new ZoneCity())->districts_by_zone($requestData['zone_id']))->toArray();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $districtByZone
        ], 200);
    }
    public function city(Request $request)
    {
        $requestData = $request->all();
        if(!isset($requestData['with'])){
            $requestData['with'] = '';
        }
        $districtByZone = ((new ZoneCity())->city($requestData['city_id'], $requestData['with']))->toArray();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $districtByZone
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        $validate = Validator::make($request->all(), [
            'zone_id' => 'required',
            'state_id' => 'required',
            'district_id' => 'required',
            'city' => 'required',
        ]);
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.zone_city.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $city = ZoneCity::create($requestData);
        return redirect('admin/cities')->with('flash_message', 'City added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $city = ZoneCity::findOrFail($id);
        return view('admin.master.zone_city.show', compact('state'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $city = ZoneCity::findOrFail($id);
        
        return view('admin.master.zone_city.edit', compact('city'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $city = ZoneCity::findOrFail($id);
        $city->update($requestData);

        return redirect('admin/cities')->with('flash_message', 'City updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        ZoneCity::destroy($id);
        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'City deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/cities')->with('flash_message', 'City deleted!');
    }
}
