<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\Zone;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use App\Http\Resources\ZoneState as ZoneStateResource; 
use Illuminate\Validation\Rule;

use Illuminate\Database\Eloquent\Builder;


class ZoneDistrictController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $districts = ZoneDistrict::with(['zone', 'state'])->whereNull('deleted_at');
        return view('admin.master.zone_district.index', compact('districts'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $districts = ((new ZoneDistrict())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ZoneDistrict())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($districts->isEmpty()) {
            
        }else{
            foreach($districts as $district){
                $data['data'][] = [
                    'id' => $district->id,
                    'zone' => (isset($district->zone)) ? $district->zone->zone : '',
                    'state' => (isset($district->state)) ? $district->state->state : '',
                    'district' => $district->district,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($district->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($district->updated_at)) ,
                    'action' => '<a href="'. route('districts.edit', ['district' => $district->id]) . '"><i
                            class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                            <a  href="#" class="delete" data-url="'.  route('districts.destroy', ['district' => $district->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    public function districts_by_state(Request $request)
    {
        $requestData = $request->all();
        $districtByState = ((new ZoneDistrict())->districts_by_state($requestData['state_id']))->toArray();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $districtByState
        ], 200);
    }
    public function districts_by_zone(Request $request)
    {
        $requestData = $request->all();
        $districtByZone = ((new ZoneDistrict())->districts_by_zone($requestData['zone_id']))->toArray();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $districtByZone
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'district' => [
                    'required',
                    Rule::unique('master_zone_district')->ignore($request->all()['id']),
                ],
                'zone_id' => 'required',
                'state_id' => 'required',
            ]);
        }else{
            
            $validate = Validator::make($request->all(), [
                'zone_id' => 'required',
                'state_id' => 'required',
             //   'district' => 'required',
                'district' => 'required|unique:master_zone_district,district',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.zone_district.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $district = ZoneDistrict::create($requestData);
        return redirect('admin/districts')->with('flash_message', 'District added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $district = ZoneDistrict::findOrFail($id);
        return view('admin.master.zone_district.show', compact('district'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $district = ZoneDistrict::findOrFail($id);
        return view('admin.master.zone_district.edit', compact('district'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $district = ZoneDistrict::findOrFail($id);
        $district->update($requestData);

        return redirect('admin/districts')->with('flash_message', 'District updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        ZoneDistrict::destroy($id);

        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'District deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/districts')->with('flash_message', 'District deleted!');
    }
}
