<?php

namespace App\Http\Controllers\Admin\Master;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Master\ZoneState;
use App\Models\Master\Zone;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class ZoneStateController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $states = ZoneState::whereNull('deleted_at')->get();
        return view('admin.master.zone_state.index', compact('states'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $states = ((new ZoneState())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ZoneState())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($states->isEmpty()) {
            
        }else{
            foreach($states as $state){
                $data['data'][] = [
                    'id' => $state->id,
                    'zone' => (isset($state->zone)) ? $state->zone->zone : '',
                    'state' => $state->state,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($state->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($state->updated_at)) ,
                    'action' => '<a href="'. route('states.edit', ['state' => $state->id]) . '"><i
                            class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                            
                            <a  href="#" class="delete" data-url="'.  route('states.destroy', ['state' => $state->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    public function states_by_zone(Request $request)
    {
        
        $requestData = $request->all();
        $statesByZone = ((new ZoneState())->states_by_zone($requestData['zone_id']))->toArray();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $statesByZone
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'zone_id' => 'required',
                'state' => [
                    'required',
                    Rule::unique('master_zone_state')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'zone_id' => 'required',
                'state' => 'required|unique:master_zone_state,state',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.master.zone_state.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $state = ZoneState::create($requestData);
        return redirect('admin/states')->with('flash_message', 'State added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $state = ZoneState::findOrFail($id);
        return view('admin.master.zone_state.show', compact('state'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $state = ZoneState::findOrFail($id);
        
        return view('admin.master.zone_state.edit', compact('state'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $state = ZoneState::findOrFail($id);
        $state->update($requestData);

        return redirect('admin/states')->with('flash_message', 'State updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        ZoneState::destroy($id);

        return redirect('admin/states')->with('flash_message', 'State deleted!');
    }
}
