<?php

namespace App\Http\Controllers\Admin\Order;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Order;
use App\Models\Orders\OrderAngelService;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use App\Models\Master\ServiceType;
use App\Models\Master\ActivityStatus;
use App\Models\Master\PaymentType;


class AngelServiceController extends AppController
{
    public function __construct()
    {
        $serviceType = ServiceType::whereNull('deleted_at')->get();
        $activityStatusList = ActivityStatus::whereNull('deleted_at')->get();
        $paymentTypeList = PaymentType::whereNull('deleted_at')->get();
        $vehicleOrderList = Order::whereNull('deleted_at')->get();
        View::share([
            'serviceTypeList' => $serviceType, 
            'activityStatusList' => $activityStatusList, 
            'paymentTypeList' => $paymentTypeList, 
            'vehicleOrderList' => $vehicleOrderList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $orderList = OrderAngelService::whereNull('deleted_at')->get();
        return view('admin.orders.angel_service.index', compact('orderList'));
    }
    
    public function tab_index(Request $request){

        $requestData = $request->all();

        $orderList = ((new OrderAngelService())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new OrderAngelService())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        $asetType = [
            'Vehicle' => 'Rent an EV',
            'battery' => 'Battery Swap',
            'angel-service' => 'Charging Station ',
        ];
        if ($orderList->isEmpty()) {
            
        }else{
            foreach($orderList as $order){
                
                $data['data'][] = [
                    'id' => $order->id,
                    'order_number' => $order->order_number,
                    'status' => '
                    <select class="form-select order_status '.$order->id.'" id="'. $order->id .'">
                        <option value="0" "class="'. $order->id .'" '. ((strtoupper($order->status) == '0') ? 'selected' : '' ).'>BOOKED</option>
                        <option value="1" "class="'. $order->id .'" '. ((strtoupper($order->status) == '1') ? 'selected' : '' ).'>PAYMENT COMPLETE</option>
                        <option value="2" "class="'. $order->id .'" '. ((strtoupper($order->status) == '2') ? 'selected' : '' ).'>INPROGRESS</option>
                        <option value="3" "class="'. $order->id .'" '. ((strtoupper($order->status) == '3') ? 'selected' : '' ).'>COMPLETED</option>
                    </select>
                    ',
                    'payment_status' => '
                    <select class="form-select payment_status '.$order->id.'" id="'. $order->id .'">
                        <option value="" id="df" '. ((strtolower($order->payment_status) == '') ? 'selected' : '') .'>Select</option>
                        <option value="Pending" id="" '. ((strtolower($order->payment_status) == 'pending') ? 'selected' : '') .'>Pending</option>
                        <option value="Complete" id="df" '. ((strtolower($order->payment_status) == 'complete') ? 'selected' : '') .'>Complete</option>
                    </select>
                    ',
                    'payment_type' => $order->payment_type,
                    'order_type' => 'Battery Swap',
                    'cost' => $order->cost,
                    'convenience_fee' => $order->convenience_fee,
                    'delivery_charge' => $order->delivery_charge,
                    'order_sub_total' => $order->order_sub_total,
                    'delivery_type' => $order->delivery_type,
                    'model_name' => $order->model_name,
                    'subscription_id' => $order->subscription_id,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($order->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($order->updated_at)) ,
                    'action' => ' 
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        
        $validate = Validator::make($request->all(), []);
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        $order = OrderAngelService::findOrFail($id);
        if($order->asset_type == 'vehicle'){
            if( $order->vehicleAsset){
                $order->vehicleAsset->status = 0;
                $order->vehicleAsset->update();
            }
        }
        OrderAngelService::destroy($id);

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Orders deleted!',
                'errors' => '',
            ]);
        }
        return redirect('admin/orders')->with('flash_message', 'Orders deleted!');
    }
    public function change_angel_service_order_status(Request $request)
    {
        $order = OrderAngelService::findOrFail($request->id);

            $order->status = $request->status;
            $order->update();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Orders status changed',
                'errors' => '',
            ]);
        }
        return redirect('admin/orders')->with('flash_message', 'Orders status changed');

    }
    public function battery_payment_status_change(Request $request)
    {
        $order = Order::findOrFail($request->id);
        $order->payment_status = $request->status;
        $order->update();

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Orders status changed',
                'errors' => '',
            ]);
        }
        return redirect('admin/orders')->with('flash_message', 'Orders status changed');

    }
}
