<?php

namespace App\Http\Controllers\Admin\Order;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Order;
use App\Models\Orders\OrderBattery;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use App\Models\Master\ServiceType;
use App\Models\Master\ActivityStatus;
use App\Models\Master\PaymentType;


class OrderController extends AppController
{
    public function __construct()
    {
        $serviceType = ServiceType::whereNull('deleted_at')->get();
        $activityStatusList = ActivityStatus::whereNull('deleted_at')->get();
        $paymentTypeList = PaymentType::whereNull('deleted_at')->get();
        View::share([
            'serviceTypeList' => $serviceType, 
            'activityStatusList' => $activityStatusList, 
            'paymentTypeList' => $paymentTypeList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $orders = Order::whereNull('deleted_at')->get();
        return view('admin.orders.vehicle.index', compact('orders'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $orderList = ((new Order())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Order())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        $asetType = [
            'Vehicle' => 'Rent an EV',
            'battery' => 'Battery Swap',
            'charging-station' => 'Charging Station ',
        ];
        if ($orderList->isEmpty()) {
            
        }else{
            foreach($orderList as $order){
                
                $subscriptioPlan = [
                    'vehicle' => $order->vehicleSubscription->plan_name ?? null,
                    'battery' => $order?->batterySubscription?->plan_name ?? null,
                    'charging-station' => 'Charging Station ',
                ];
                $data['data'][] = [
                    'id' => $order->id,
                    'order_number' => $order->order_number,
                    'status' => '
                    <select class="form-select order_status '.$order->id.'" id="'. $order->id .'">
                        <option value="PENDING" id="df" '. ((strtoupper($order->status) == 'PENDING') ? 'selected' : '') .'>PENDING</option>
                        <option value="INPROGRESS" "class="'. $order->id .'" '. ((strtoupper($order->status) == 'INPROGRESS') ? 'selected' : '' ).'>INPROGRESS</option>
                        <option value="BOOKING COMPLETED" '. ((strtoupper($order->status) == 'BOOKING COMPLETED') ? 'selected' : '') .'>BOOKING COMPLETED</option>                        
                        <option value="PAYMENT COMPLETED"  '. ((strtoupper($order->status) == 'PAYMENT COMPLETED') ? 'selected' : '') .'>PAYMENT COMPLETED</option>
                        <option value="VEHICLE UNLOCKED"  '. ((strtoupper($order->status) == 'VEHICLE UNLOCKED') ? 'selected' : '') .'>VEHICLE UNLOCKED</option>
                        <option value="WALKAROUND DONE"  '. ((strtoupper($order->status) == 'WALKAROUND DONE') ? 'selected' : '') .'>WALKAROUND DONE</option>
                        <option value="USAGE INPROGRESS"  '. ((strtoupper($order->status) == 'USAGE INPROGRESS') ? 'selected' : '') .'>USAGE INPROGRESS</option>
                        <option value="BATTERY SWAP"  '. ((strtoupper($order->status) == 'BATTERY SWAP') ? 'selected' : '') .'>BATTERY SWAP</option>
                        <option value="ORDER COMPLETED"  '. ((strtoupper($order->status) == 'ORDER COMPLETED') ? 'selected' : '') .'>ORDER COMPLETED</option>
                        <option value="CANCELLED"  '. ((strtoupper($order->status) == 'CANCELLED') ? 'selected' : '') .'>CANCELLED</option>
                    </select>
                    ',
                    'payment_status' => '
                    <select class="form-select payment_status '.$order->id.'" id="'. $order->id .'">
                        <option value="" id="df" '. ((strtolower($order->payment_status) == '') ? 'selected' : '') .'>Select</option>
                        <option value="Pending" id="" '. ((strtolower($order->payment_status) == 'pending') ? 'selected' : '') .'>Pending</option>
                        <option value="Complete" id="df" '. ((strtolower($order->payment_status) == 'complete') ? 'selected' : '') .'>Complete</option>
                    </select>
                    ',
                    'payment_type' => $order->payment_type,
                    //'business_type' => $order->business_type,
                    'customer_name' => $order->customer_name,
                    'customer_email' => $order->customer_email,
                    'customer_phone' => $order->customer_phone,
                    'order_type' => $order->order_type,
                    'cost' => $order->cost,
                    'convenience_fee' => $order->convenience_fee,
                    'delivery_charge' => $order->delivery_charge,
                    'order_sub_total' => $order->order_sub_total,
                    'delivery_type' => $order->delivery_type,
                    'model_name' => $order->model_name,
                    'subscription_id' => $subscriptioPlan[$order->asset_type],
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($order->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($order->updated_at)) ,
                    'action' => ' <a href="'. route('orders.vehicle.edit', ['vehicle' => $order->id]) . '"><i
                            class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                            
                            <a  href="#" class="delete" data-url="'.   route('orders.vehicle.destroy', ['vehicle' => $order->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                            <a  href="'.   route('order.battery_index', ['order_id' => $order->id]) .'">  battery-swaps </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }

    public function battery_index(Request $request, $order_id){
        $order = Order::findOrFail($order_id);

        return view('admin.orders.vehicle.order_battery', compact('order'));
    }
    public function tab_battery_index(Request $request, $order_id){
        
        $requestData = $request->all();
        $requestData['order_id'] = $order_id;

        $orderList = ((new OrderBattery())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new OrderBattery())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        $asetType = [
            'Vehicle' => 'Rent an EV',
            'battery' => 'Battery Swap',
            'charging-station' => 'Charging Station ',
        ];
        if ($orderList->isEmpty()) {
            
        }else{
            foreach($orderList as $order){
                
                $data['data'][] = [
                    'id' => $order->id,
                    'order_number' => $order->order_number,
                    'status' => '
                    <select class="form-select order_status '.$order->id.'" id="'. $order->id .'">
                        <option value="PENDING" id="df" '. ((strtoupper($order->status) == 'PENDING') ? 'selected' : '') .'>PENDING</option>
                        <option value="0" "class="'. $order->id .'" '. ((strtoupper($order->status) == '0') ? 'selected' : '' ).'>To SWAP</option>
                        <option value="1" "class="'. $order->id .'" '. ((strtoupper($order->status) == '1') ? 'selected' : '' ).'>IN PROGRESS</option>
                        <option value="2" "class="'. $order->id .'" '. ((strtoupper($order->status) == '2') ? 'selected' : '' ).'>DRIED</option>
                    </select>
                    ',
                    'payment_status' => '
                    <select class="form-select payment_status '.$order->id.'" id="'. $order->id .'">
                        <option value="" id="df" '. ((strtolower($order->payment_status) == '') ? 'selected' : '') .'>Select</option>
                        <option value="Pending" id="" '. ((strtolower($order->payment_status) == 'pending') ? 'selected' : '') .'>Pending</option>
                        <option value="Complete" id="df" '. ((strtolower($order->payment_status) == 'complete') ? 'selected' : '') .'>Complete</option>
                    </select>
                    ',
                    'payment_type' => $order->payment_type,
                    'order_type' => 'Battery Swap',
                    'cost' => $order->cost,
                    'convenience_fee' => $order->convenience_fee,
                    'delivery_charge' => $order->delivery_charge,
                    'order_sub_total' => $order->order_sub_total,
                    'delivery_type' => $order->delivery_type,
                    'model_name' => $order->model_name,
                    'subscription_id' => $order->subscription_id,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($order->created_at)) ,
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($order->updated_at)) ,
                    'action' => ' 
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        
        $validate = Validator::make($request->all(), [
            'service_type' => 'required',
            'order_date' => 'required',
            'start_date' => 'required',
            'end_date' => 'required',
            'user_type' => 'required',
            'customer_phone' => 'required',
            'customer_name' => 'required',
            'customer_email' => 'required',
            'order_sub_total' => 'required',
            'deliver_type' => 'required',
            'status' => 'required',
        ]);
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $order = new Order();
        
        return view('admin.orders.vehicle.edit', compact('order'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $order = Order::create($requestData);
        return redirect('admin/orders')->with('flash_message', 'Orders added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $order = Order::findOrFail($id);
        return view('admin.orders.vehicle.show', compact('order',  'assetDocuments'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $order = Order::findOrFail($id);
        
        return view('admin.orders.vehicle.edit', compact('order'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $order = Order::findOrFail($id);
        $order->update($requestData);

        return redirect('admin/orders')->with('flash_message', 'Orders updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        $order = Order::findOrFail($id);
        if($order->asset_type == 'vehicle'){
            if( $order->vehicleAsset){
                $order->vehicleAsset->status = 0;
                $order->vehicleAsset->update();
            }
        }
        Order::destroy($id);

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Orders deleted!',
                'errors' => '',
            ]);
        }
        return redirect('admin/orders')->with('flash_message', 'Orders deleted!');
    }
    public function change_order_status(Request $request)
    {
        $order = Order::findOrFail($request->id);

        if($order->asset_type == 'vehicle' && ($request->status == 'ORDER COMPLETED' || $request->status == 'CANCELLED')){
            if($order->vehicleAsset){
                $order->vehicleAsset->status = 0;
                $order->vehicleAsset->update();
            }
        }elseif($order->asset_type == 'vehicle'){
            if($order->vehicleAsset){
                $order->vehicleAsset->status = 1;
                $order->vehicleAsset->update();
            }
        }
        $order->status = $request->status;
        $order->update();

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Orders status changed',
                'errors' => '',
            ]);
        }
        return redirect('admin/orders')->with('flash_message', 'Orders status changed');

    }
    public function payment_status_change(Request $request)
    {
        $order = Order::findOrFail($request->id);
        $order->payment_status = $request->status;
        $order->update();

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Orders status changed',
                'errors' => '',
            ]);
        }
        return redirect('admin/orders')->with('flash_message', 'Orders status changed');

    }
    public function change_battery_order_status(Request $request)
    {
        $order = OrderBattery::findOrFail($request->id);

        if($order->battery_id){
            $order->status = $request->status;
            $order->update();
        }else{
            return response()->json([
                'mode' => true,
                'message' => 'Orders status changed',
                'errors' => '',
            ]);
        }
        if($request->ajax()){
            return response()->json([
                'mode' => false,
                'message' => 'No battery assigned',
            ], 400);
        }
        return redirect('admin/orders')->with('flash_message', 'Orders status changed');

    }
    public function battery_payment_status_change(Request $request)
    {
        $order = Order::findOrFail($request->id);
        $order->payment_status = $request->status;
        $order->update();

        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Orders status changed',
                'errors' => '',
            ]);
        }
        return redirect('admin/orders')->with('flash_message', 'Orders status changed');

    }
}
