<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Order;
use App\Models\Asset;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use App\Models\Master\ServiceType;


class OrderController extends AppController
{
    public function __construct()
    {
        $serviceType = ServiceType::whereNull('deleted_at')->get();
        View::share([
            'serviceTypeList' => $serviceType, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $orders = Asset::whereNull('deleted_at')->get();
        return view('admin.orders.index', compact('orders'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $orders = ((new Order())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Order())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($orders->isEmpty()) {
            
        }else{
            foreach($orders as $order){
                $data['data'][] = [
                    'id' => $order->id,
                    'name' => $order->name,
                    'category' => (isset($order->category)) ? $order->category->category_name : '',
                    'asset_type' => $order->asset_type,
                    'oem' => $order->oem,
                    'model_name' => $order->model_name,
                    'model_number' => $order->model_number,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($order->created_at)) ,
                    'action' => ' <a href="'. route('orders.edit', ['order' => $order->id]) . '"><i
                            class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                            <a href="'. route('orders.destroy', ['order' => $order->id]).'"><i class="mdi mdi-eye font-size-16  text-info me-1"></i></a>
                            <a href="'. route('orders.show', ['order' => $order->id]).'"><i
                                class="mdi mdi-trash-can font-size-16 text-danger me-1"></i></a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        
        $validate = Validator::make($request->all(), [
            'service_type' => 'required',
            'order_date' => 'required',
            'start_date' => 'required',
            'end_date' => 'required',
            'user_type' => 'required',
            'customer_phone' => 'required',
            'customer_name' => 'required',
            'customer_email' => 'required',
            'order_sub_total' => 'required',
            'deliver_type' => 'required',
            'status' => 'required',
        ]);
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.orders.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $requestData['category_id'] = $requestData['category'];
        $order = Asset::create($requestData);
        if($files = $request->file('file')){
            foreach($files as $file){
             (new AssetDocuments())->uploadFile($file, $order);
            }
         }
        return redirect('admin/orders')->with('flash_message', 'Assets added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $order = Asset::findOrFail($id);
        $assetDocuments = AssetDocuments::where('asset_id', $id)->get()->toArray();
        return view('admin.orders.show', compact('order',  'assetDocuments'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $order = Asset::findOrFail($id);
        
        return view('admin.orders.edit', compact('order'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $requestData['category_id'] = $requestData['category'];
        $order = Asset::findOrFail($id);
        $order->update($requestData);

        return redirect('admin/orders')->with('flash_message', 'Assets updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy($id)
    {
        Asset::destroy($id);

        return redirect('admin/orders')->with('flash_message', 'Assets deleted!');
    }
}
