<?php

namespace App\Http\Controllers\Admin\PurchasedService;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\PrchasedService\ChargingStation;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Master\PurchasedService;
use App\Models\Master\ProductType;
use App\Models\Location;
use App\Models\Vendors\ServiceWorkshop;
use App\Models\Assets\ChargingStation as Asset;


class ChargingStationController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $purchasedServiceList = PurchasedService::whereNull('deleted_at')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $serviceWorkshopList = ServiceWorkshop::whereNull('deleted_at')->get();
        $assetTypeList = ProductType::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'purchasedServiceList' => $purchasedServiceList, 
            'locationList' => $locationList, 
            'serviceWorkshopList' => $serviceWorkshopList, 
            'assetTypeList' => $assetTypeList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $chargingStationList = ChargingStation::whereNull('deleted_at')->get();
        return view('admin.purchased_service.charging_station.index', compact('chargingStationList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $chargingStation = ((new ChargingStation())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ChargingStation())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($chargingStation->isEmpty()) {
            
        }else{
            foreach($chargingStation as $chargingStation){
                $data['data'][] = [
                    'id' => $chargingStation->id,
                    'purchased_service_id' => $chargingStation->purchasedService->purchased_service,
                    'location_id' => $chargingStation->location->location,
                    'vendor_workshop_id' => $chargingStation->serviceWorkshop->service_workshop,
                    'asset_type_id' => isset($chargingStation->assetType) ? $chargingStation->assetType->product_type : '',
                    'asset_id' => $chargingStation->asset->model_name,
                    'bill_number' => $chargingStation->bill_number,
                    'service_cost' => $chargingStation->service_cost,
                    'start_date' => date($this->siteSettings['timestamp_format'], strtotime($chargingStation->start_date)),
                    'estimated_delivery_date' => date($this->siteSettings['timestamp_format'], strtotime($chargingStation->estimated_delivery_date)),
                    'actual_delivery_date' => date($this->siteSettings['timestamp_format'], strtotime($chargingStation->actual_delivery_date)),
                    'remarks' => $chargingStation->remarks,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($chargingStation->created_at)) ,
                    'action' => '<a href="'. route('purchased-service.charging-station.edit', ['charging_station' => $chargingStation->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('purchased-service.charging-station.destroy', ['charging_station' => $chargingStation->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'purchased_service_id' => [
                    'required',
                    Rule::unique('ps_charging_station')->ignore($request->all()['id']),
                ],
                'location_id' => 'required',
                'vendor_workshop_id' => 'required',
                'asset_id' => 'required',
                'service_cost' => 'required',
                'start_date' => 'required',
                'estimated_delivery_date' => 'required',
                'actual_delivery_date' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'purchased_service_id' => 'required|unique:ps_charging_station,purchased_service_id',
                'location_id' => 'required',
                'vendor_workshop_id' => 'required',
                'asset_id' => 'required',
                'service_cost' => 'required',
                'start_date' => 'required',
                'estimated_delivery_date' => 'required',
                'actual_delivery_date' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.purchased_service.charging_station.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $requestData['start_date'] = $requestData['start_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['start_date'] )) : null ;

        $requestData['estimated_delivery_date'] = $requestData['estimated_delivery_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['estimated_delivery_date'] )) : null ;

        $requestData['actual_delivery_date'] = $requestData['actual_delivery_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['actual_delivery_date'] )) : null ;

        $chargingStation = ChargingStation::create($requestData);
        return redirect('admin/purchased-service/charging-station')->with('flash_message', 'Purchased Service added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $chargingStation = ChargingStation::findOrFail($id);
        return view('admin.purchased_service.charging_station.show', compact('charging-station'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $chargingStation = ChargingStation::findOrFail($id);
        
        return view('admin.purchased_service.charging_station.edit', compact('chargingStation'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();

        $requestData['start_date'] = $requestData['start_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['start_date'] )) : null ;

        $requestData['estimated_delivery_date'] = $requestData['estimated_delivery_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['estimated_delivery_date'] )) : null ;

        $requestData['actual_delivery_date'] = $requestData['actual_delivery_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['actual_delivery_date'] )) : null ;

        $chargingStation = ChargingStation::findOrFail($id);
        $chargingStation->update($requestData);

        return redirect('admin/purchased-service/charging-station')->with('flash_message', 'Purchased Service updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        ChargingStation::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingStation deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/purchased-service/charging-station')->with('flash_message', 'Purchased Service deleted!');
    }
}
