<?php

namespace App\Http\Controllers\Admin\PurchasedService;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\PrchasedService\Manpower;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Master\Designation;
use App\Models\Master\Duration;
use App\Models\Master\PurchasedService;
use App\Models\Location;
use App\Models\Vendors\Manpower as Vendor;


class ManpowerController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $purchasedServiceList = PurchasedService::whereNull('deleted_at')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $manpowerList = Vendor::whereNull('deleted_at')->get();
        $designationList = Designation::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'purchasedServiceList' => $purchasedServiceList, 
            'locationList' => $locationList, 
            'manpowerList' => $manpowerList, 
            'designationList' => $designationList, 
            'durationList' => $durationList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $manpowerList = Manpower::whereNull('deleted_at')->get();
        return view('admin.purchased_service.manpower.index', compact('manpowerList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $manpowerList = ((new Manpower())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Manpower())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($manpowerList->isEmpty()) {
            
        }else{
            foreach($manpowerList as $manpower){
                $data['data'][] = [
                    'id' => $manpower->id,
                    'purchased_service_id' => $manpower->purchasedService->purchased_service,
                    'location_id' => isset($manpower->location) ? $manpower->location->location : '',
                    'vendor_manpower_id' => isset($manpower->vendorManpower) ? $manpower->vendorManpower->organisation_name : '',
                    'resource_name' => $manpower->resource_name,
                    'designation' => isset($manpower->designation) ? $manpower->designation->designation : '', 
                    'gozap_id' => $manpower->gozap_id,
                    'duration' => isset($manpower->duration) ? $manpower->duration->duration : '', 
                    'bill_number' => $manpower->bill_number,
                    'service_cost' => $manpower->service_cost,
                    'start_date' => date($this->siteSettings['timestamp_format'], strtotime($manpower->start_date)),
                    'end_date' => date($this->siteSettings['timestamp_format'], strtotime($manpower->end_date)),
                    'remarks' => $manpower->remarks,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($manpower->created_at)) ,
                    'action' => '<a href="'. route('purchased-service.manpower.edit', ['manpower' => $manpower->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('purchased-service.manpower.destroy', ['manpower' => $manpower->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'purchased_service_id' => [
                    'required',
                    Rule::unique('ps_manpower')->ignore($request->all()['id']),
                ],
                'location_id' => 'required',
                'vendor_manpower_id' => 'required',
                'resource_name' => 'required',
                'work_call' => 'required',
                'designation_id' => 'required',
                'gozap_prefix' => 'required',
                'gozap_number' => 'required',
                'service_cost' => 'required',
                'start_date' => 'required',
                'end_date' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'purchased_service_id' => 'required|unique:ps_manpower,purchased_service_id',
                'location_id' => 'required',
                'vendor_manpower_id' => 'required',
                'resource_name' => 'required',
                'work_call' => 'required',
                'designation_id' => 'required',
                'gozap_prefix' => 'required',
                'gozap_number' => 'required',
                'service_cost' => 'required',
                'start_date' => 'required',
                'end_date' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.purchased_service.manpower.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $requestData['start_date'] = $requestData['start_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['start_date'] )) : null ;

        $requestData['end_date'] = $requestData['end_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['end_date'] )) : null ;

        $requestData['gozap_id'] = $requestData['gozap_prefix'] . $requestData['gozap_number'];

        $manpower = Manpower::create($requestData);
        return redirect('admin/purchased-service/manpower')->with('flash_message', 'Purchased Service added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $manpower = Manpower::findOrFail($id);
        return view('admin.purchased_service.manpower.show', compact('manpower'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $manpower = Manpower::findOrFail($id);
        
        return view('admin.purchased_service.manpower.edit', compact('manpower'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();

        $requestData['start_date'] = $requestData['start_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['start_date'] )) : null ;

        $requestData['end_date'] = $requestData['end_date'] ? date($this->siteSettings['timestamp_format'], strtotime($requestData['end_date'] )) : null ;

        $requestData['gozap_id'] = $requestData['gozap_prefix'] . $requestData['gozap_number'];

        $manpower = Manpower::findOrFail($id);
        $manpower->update($requestData);

        return redirect('admin/purchased-service/manpower')->with('flash_message', 'Purchased Service updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Manpower::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Manpower deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/purchased-service/manpower')->with('flash_message', 'Purchased Service deleted!');
    }
}
