<?php

namespace App\Http\Controllers\Admin\SubscriptionPlan;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Location;
use App\Models\Master\AngelService as ServiceType;
use App\Models\Master\VAServiceType;
use App\Models\SubscriptionPlan\AngelService;
use App\Models\SubscriptionPlan\AngelServiceLocation;
use App\Models\SubscriptionPlan\AngelServiceTermsCondition;
use App\Models\SubscriptionPlan\AngelServiceAssetVAService;

use App\Models\Master\Duration;
use App\Models\Master\BusinessCategory;
use App\Models\Master\BusinessModels;
use App\Models\Master\Taxationprofile;


class AngelServiceController extends AppController
{
    public function __construct()
    {
        $serviceTypeList = ServiceType::whereNull('deleted_at')->get();
        $vAServiceTypeList = VAServiceType::whereNull('deleted_at')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        
        $durationList = Duration::whereNull('deleted_at')->get();
        $businessCategoryList = BusinessCategory::whereNull('deleted_at')->get();
        $businessModelsList = BusinessModels::whereNull('deleted_at')->get();
        $taxationProfileListData = Taxationprofile::whereNull('deleted_at')->get();
        $taxationProfileList = [];
        foreach($taxationProfileListData as $taxationProfile){
            $taxationProfileListItem['id'] =  $taxationProfile->id;
            $taxationProfileListItem['taxation_profile'] =  $taxationProfile->taxation_profile;
            $taxPercentageList = '';
            foreach($taxationProfile->taxPercentage as $taxPercentage){
                $taxPercentageList = $taxPercentageList . ' ' . $taxPercentage->tax_name . ' - ' . $taxPercentage->percentage .'%';
            }
            $taxationProfileListItem['tax-percentage'] = '';

            if(!empty($taxPercentageList)){
                $taxationProfileListItem['tax-percentage'] = $taxPercentageList;
            }
            $taxationProfileList[] = $taxationProfileListItem;
        }
        
        View::share([
            'serviceTypeList' => $serviceTypeList, 
            'vAServiceTypeList' => $vAServiceTypeList, 
            'locationList' => $locationList,
            'durationList' => $durationList, 
            'businessCategoryList' => $businessCategoryList,
            'businessModelsList' => $businessModelsList,
            'taxationProfileList' => $taxationProfileList,
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $angelServiceList = AngelService::whereNull('deleted_at')->get();
        return view('admin.subscription_plan.angel_service.index', compact('angelServiceList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $angelServiceList = ((new AngelService())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new AngelService())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($angelServiceList->isEmpty()) {
            
        }else{
            foreach($angelServiceList as $angelService){
                $data['data'][] = [
                    'id' => $angelService->id,
                    'plan_name' => $angelService->plan_name,
                    'business_category_id' => isset($angelService->businessCategory) ? $angelService->businessCategory->business_category : '',
                    'business_model_id' => isset($angelService->businessModel) ? $angelService->businessModel->business_model : '',
                    'service_type_id' => $angelService?->serviceType?->service_type,
                    'fixed_price' => $angelService->fixed_price,
                    'base_plan' => $angelService->base_plan,
                    'location' => count($angelService->location),
                    'terms' => count($angelService->terms),
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($angelService->created_at)),
                    'created_by' => isset($angelService->createdUser) ? $angelService->createdUser->name :'',
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($angelService->updated_at)),
                    'updated_by' => isset($angelService->updatedUser) ? $angelService->updatedUser->name :'',
                    'action' => '
                    <!--<a href="'. route('subscription-plan.angel-service.show', ['angel_service' => $angelService->id]) . '"><i class="mdi mdi-eye font-size-16 text-success me-1"></i></a>-->
                    <a href="'. route('subscription-plan.angel-service.edit', ['angel_service' => $angelService->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('subscription-plan.angel-service.destroy', ['angel_service' => $angelService->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'plan_name' => [
                    'required',
                    Rule::unique('subs_angel_service')->ignore($request->all()['id']),
                ],
                'business_category_id' => 'required',
                'business_model_id' => 'required',
                'product_overview' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'plan_name' => 'required|unique:subs_angel_service,plan_name',
                'business_category_id' => 'required',
                'business_model_id' => 'required',
                'product_overview' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $angelService = new AngelService();
        
        return view('admin.subscription_plan.angel_service.edit', compact('angelService'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $this->save_data($request);
        
        return redirect('admin/subscription-plan/angel-service')->with('flash_message', 'AngelService Asset added!');
    }
    

    public function save_data($request){

        $requestData = $request->all();
        //print_r($requestData); exit;
        $angelService = [];
        if($request->id){
            $angelService = AngelService::findOrFail($request->id);
        }
      
        if($angelService){
            $angelService->update($requestData);
        }else{
            $angelService = AngelService::create($requestData);

        }
        
        if(isset($requestData['location_regions_list'])){
            foreach($requestData['location_regions_list'] as $locationRegions){
                if(isset($locationRegions['base_price'])){
                    $angelServiceLocationData = [
                            'plan_id' => $angelService->id,
                            'location_id' => $locationRegions['location_id'],
                            'base_price' => $locationRegions['base_price'],
                            'base_price_taxation_profile_id' => $locationRegions['base_price_taxation_profile_id'],
                            'convenience_fee' => $locationRegions['convenience_fee'],
                            'convenience_fee_taxation_profile_id' => $locationRegions['convenience_fee_taxation_profile_id'],
                            'delivery_fee' => $locationRegions['delivery_fee'],
                            'delivery_fee_taxation_profile_id' => $locationRegions['delivery_fee_taxation_profile_id'],
                    ];
                    if(isset($locationRegions['angel_service_location_id'])){  
                        
                        $angelServiceLocation = AngelServiceLocation::findOrFail($locationRegions['angel_service_location_id']);

                        if($angelServiceLocation){
                                $angelServiceLocation->update($angelServiceLocationData);
                        }else{
                            $angelServiceLocation = AngelServiceLocation::create($angelServiceLocationData);
                        }
                    }else{
                        $angelServiceLocation = AngelServiceLocation::create($angelServiceLocationData);
                    }
                }
            }
            
        }
        if(isset($requestData['terms_condition_list'])){
            foreach($requestData['terms_condition_list'] as $termsConditions){
                $termsConditionsData = [
                    'plan_id' => $angelService->id,
                    'terms_condition' => $termsConditions['terms_condition'],
                ];
                if(isset($termsConditions['terms_conditionn_id'])){    
                    $angelServiceTermsCondition = AngelServiceTermsCondition::findOrFail($termsConditions['terms_conditionn_id']);

                    if($angelServiceTermsCondition){
                            $angelServiceTermsCondition->update($termsConditionsData);
                    }else{
                        $angelServiceTermsCondition = AngelServiceTermsCondition::create($termsConditionsData);
                    }
                }else{
                    $angelServiceTermsCondition = AngelServiceTermsCondition::create($termsConditionsData);
                }

                if(isset($termsConditions['image'])){
                    $file = $termsConditions['image'];
                    if($file){
                        $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                        $path = '/uploads/subscription_plan/angel_service/'.$angelService->id. '/' . $savedAs;
                        $filePath = $this->uploadFile($path, $file);
                        $angelServiceTermsCondition->image = $path;
                        $angelServiceTermsCondition->update();
                    }
                }
            }
        }
        return true;
    }
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $angelService = AngelService::findOrFail($id);
        return view('admin.subscription_plan.angel_service.show', compact('angelService'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $angelService = AngelService::findOrFail($id);
        
        return view('admin.subscription_plan.angel_service.edit', compact('angelService'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $this->save_data($request);

        return redirect('admin/subscription-plan/angel-service')->with('flash_message', 'AngelService updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        AngelService::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'AngelService deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/subscription-plan/battery')->with('flash_message', 'AngelService deleted!');
    }
    public function destroy_asset_parts(Request $request, $id)
    {
        AngelServiceAssetPart ::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'AngelService Asset Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_base_plan(Request $request, $id)
    {
        AngelServiceBasePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'AngelService Base Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_locatoin_region(Request $request, $id)
    {
        AngelServiceLocation::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'AngelService Location Region deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_terms_condition(Request $request, $id)
    { 
        $angelServiceTermsCondition = AngelServiceTermsCondition::findOrFail($id);

        $this->deleteFile($angelServiceTermsCondition->image);
        AngelServiceTermsCondition::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'AngelService Terms & Condition deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_terms_condition_image(Request $request, $id)
    {
        $angelServiceTermsCondition = AngelServiceTermsCondition::findOrFail($id);

        $this->deleteFile($angelServiceTermsCondition->image);
        $angelServiceTermsCondition->image = '';
        $angelServiceTermsCondition->update();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'AngelService Terms & Condition Image deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function battery_plan(Request $request)
    {
        if(!isset($request->id)){
            $request->id = $request->subscription_plan_id;
        }
        $angelServiceList = AngelService::whereNull('deleted_at')->where('id', $request->id)->first();
        $angelServiceList->basePlan;

        if(isset($angelServiceList->basePlan)){
            $angelServiceList->basePlan->duration;
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'AngelService list',
                'errors' => '',
                'data' => $angelServiceList
            ], 200);
        }
    }
}
