<?php

namespace App\Http\Controllers\Admin\SubscriptionPlan;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Location;
use App\Models\Master\ProductType;
use App\Models\Master\VAServiceType;
use App\Models\SubscriptionPlan\Battery;
use App\Models\SubscriptionPlan\BatteryAssetPart;
use App\Models\SubscriptionPlan\BatteryLocation;
use App\Models\SubscriptionPlan\BatteryTermsCondition;
use App\Models\SubscriptionPlan\BatteryAssetVAService;
use App\Models\Assets\Battery as Asset;
use App\Models\Vendors\Battery as Dealer;
use App\Models\Master\Duration;
use App\Models\Master\BusinessCategory;
use App\Models\Master\BusinessModels;
use App\Models\Master\Taxationprofile;


class BatteryController extends AppController
{
    public function __construct()
    {
        $productTypeList = ProductType::whereNull('deleted_at')->get();
        $vAServiceTypeList = VAServiceType::whereNull('deleted_at')->get();
        $assetList = Asset::whereNull('deleted_at')->groupBy('model_name')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $dealerList = Dealer::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        $businessCategoryList = BusinessCategory::whereNull('deleted_at')->get();
        $businessModelsList = BusinessModels::whereNull('deleted_at')->get();
        $taxationProfileListData = Taxationprofile::whereNull('deleted_at')->get();
        $taxationProfileList = [];
        foreach($taxationProfileListData as $taxationProfile){
            $taxationProfileListItem['id'] =  $taxationProfile->id;
            $taxationProfileListItem['taxation_profile'] =  $taxationProfile->taxation_profile;
            $taxPercentageList = '';
            foreach($taxationProfile->taxPercentage as $taxPercentage){
                $taxPercentageList = $taxPercentageList . ' ' . $taxPercentage->tax_name . ' - ' . $taxPercentage->percentage .'%';
            }
            $taxationProfileListItem['tax-percentage'] = '';

            if(!empty($taxPercentageList)){
                $taxationProfileListItem['tax-percentage'] = $taxPercentageList;
            }
            $taxationProfileList[] = $taxationProfileListItem;
        }
        
        View::share([
            'productTypeList' => $productTypeList, 
            'vAServiceTypeList' => $vAServiceTypeList, 
            'assetList' => $assetList, 
            'dealerList' => $dealerList, 
            'locationList' => $locationList,
            'durationList' => $durationList, 
            'businessCategoryList' => $businessCategoryList,
            'businessModelsList' => $businessModelsList,
            'taxationProfileList' => $taxationProfileList,
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $batteryList = Battery::whereNull('deleted_at')->get();
        return view('admin.subscription_plan.battery.index', compact('batteryList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $batteryList = ((new Battery())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Battery())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($batteryList->isEmpty()) {
            
        }else{
            foreach($batteryList as $battery){
                $data['data'][] = [
                    'id' => $battery->id,
                    'plan_name' => $battery->plan_name,
                    'business_category_id' => isset($battery->businessCategory) ? $battery->businessCategory->business_category : '',
                    'business_model_id' => isset($battery->businessModel) ? $battery->businessModel->business_model : '',
                    'battery_type' => $battery->battery_type,
                    'model_name' =>$battery->model_name,
                    'kwh_units' =>$battery->kwh_units,
                    'asset_type_id' => $battery?->assetType?->product_type,
                    'fixed_price' => $battery->fixed_price,
                    'base_plan' => $battery->base_plan,
                    'location' => count($battery->location),
                    'terms' => count($battery->terms),
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($battery->created_at)),
                    'created_by' => isset($battery->createdUser) ? $battery->createdUser->name :'',
                    'updated_at' => date($this->siteSettings['timestamp_format'], strtotime($battery->updated_at)),
                    'updated_by' => isset($battery->updatedUser) ? $battery->updatedUser->name :'',
                    'action' => '
                    <!--<a href="'. route('subscription-plan.battery.show', ['battery' => $battery->id]) . '"><i class="mdi mdi-eye font-size-16 text-success me-1"></i></a>-->
                    <a href="'. route('subscription-plan.battery.edit', ['battery' => $battery->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('subscription-plan.battery.destroy', ['battery' => $battery->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if($request->id){
            $validate = Validator::make($request->all(), [
                'plan_name' => [
                    'required',
                    Rule::unique('subs_battery')->ignore($request->all()['id']),
                ],
                'business_category_id' => 'required',
                'business_model_id' => 'required',
                'asset_type_id' => 'required',
                'oem_id' => 'required',
                'model_name' => 'required',
                'product_overview' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'plan_name' => 'required|unique:subs_battery,plan_name',
                'business_category_id' => 'required',
                'business_model_id' => 'required',
                'asset_type_id' => 'required',
                'oem_id' => 'required',
                'model_name' => 'required',
                'product_overview' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $battery = new Battery();
        
        return view('admin.subscription_plan.battery.edit', compact('battery'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $this->save_data($request);

        return redirect('admin/subscription-plan/battery')->with('flash_message', 'Battery Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $battery = Battery::findOrFail($id);
        return view('admin.subscription_plan.battery.show', compact('battery'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $battery = Battery::findOrFail($id);
        
        return view('admin.subscription_plan.battery.edit', compact('battery'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $this->save_data($request);

        return redirect('admin/subscription-plan/battery')->with('flash_message', 'Battery updated!');
    }

    public function save_data($request){

        $requestData = $request->all();
        //print_r($requestData); exit;
        $battery = [];
        if($request->id){
            $battery = Battery::findOrFail($request->id);
        }
      
        if($battery){
            $battery->update($requestData);
        }else{
            $battery = Battery::create($requestData);
        }
        
        if(isset($requestData ['base_plan'])){
            $requestData ['billing_period_id'] = '';
            $requestData ['grace_time_hr'] = '';
            $requestData ['grace_time'] = '';
            $requestData ['lock_bike'] = '';

            if($requestData ['base_plan'] == 'Freemium'){
                $requestData ['billing_period_id'] = $requestData ['freemium_free_usages_id'] ?? '';
                $requestData ['grace_time_hr'] = $requestData ['freemium_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['freemium_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['freemium_lock_bike'] ?? '';
            }elseif($requestData ['base_plan'] == 'Re-Subscribe'){
                $requestData ['grace_time_hr'] = $requestData ['re_subscribe_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['re_subscribe_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['re_subscribe_lock_bike'] ?? '';
            }elseif($requestData ['base_plan'] == 'Auto Renewing'){
                $requestData ['billing_period_id'] = $requestData ['auto_renewing_billing_period_id'] ?? '';
                $requestData ['grace_time'] = $requestData ['auto_renewing_grace_time'] ?? '';
            }elseif($requestData ['base_plan'] == 'Prepaid'){
                $requestData ['billing_period_id'] = $requestData ['prepaid_billing_cycle_id'] ?? '';
                $requestData ['grace_time_hr'] = $requestData ['prepaid_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['prepaid_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['prepaid_lock_bike'] ?? '';
            }

        }

        $battery->update($requestData);
        
        if(isset($requestData['part_id'])){
            foreach($requestData['part_id'] as $part_id){
                $batteryAssetPartData = [
                    'plan_id' => $battery->id,
                   // 'asset_id' => $batteryAsset->id,
                    'part_id' => $part_id,
                ];
                
                $batteryAssetPart = BatteryAssetPart::where('plan_id', $battery->id)->where('part_id', $part_id)->first();
                
                if($batteryAssetPart){
                        $batteryAssetPart->update($batteryAssetPartData);
                }else{
                    $batteryAssetPart = BatteryAssetPart::create($batteryAssetPartData);
                }
            }
        }

        if(isset($requestData['va_service_type_id'])){
            foreach($requestData['va_service_type_id'] as $va_service_type_id){
                $batteryAssetVAServiceData = [
                    'plan_id' => $battery->id,
                    //'asset_id' => $batteryAsset->id,
                    'va_service_type_id' => $va_service_type_id,
                ];
                $batteryAssetVAService = BatteryAssetVAService::where('plan_id', $battery->id)->where('va_service_type_id', $va_service_type_id)->first();
                
                if($batteryAssetVAService){
                        $batteryAssetVAService->update($batteryAssetVAServiceData);
                }else{
                    $batteryAssetVAService = BatteryAssetPart::create($batteryAssetVAServiceData);
                }
            }
        }
        if(isset($requestData['location_regions_list'])){
            foreach($requestData['location_regions_list'] as $locationRegions){
                $batteryLocationData = [
                    'plan_id' => $battery->id,
                    'location_id' => $locationRegions['location_id'],
                    'base_price' => $locationRegions['base_price'],
                    'base_price_taxation_profile_id' => $locationRegions['base_price_taxation_profile_id'],
                    'convenience_fee' => $locationRegions['convenience_fee'],
                    'convenience_fee_taxation_profile_id' => $locationRegions['convenience_fee_taxation_profile_id'],
                    'delivery_fee' => $locationRegions['delivery_fee'],
                    'delivery_fee_taxation_profile_id' => $locationRegions['delivery_fee_taxation_profile_id'],
                ];
                if(isset($locationRegions['battery_location_id'])){  
                    
                    $batteryLocation = BatteryLocation::findOrFail($locationRegions['battery_location_id']);

                    if($batteryLocation){
                            $batteryLocation->update($batteryLocationData);
                    }else{
                        $batteryLocation = BatteryLocation::create($batteryLocationData);
                    }
                }else{
                    $batteryLocation = BatteryLocation::create($batteryLocationData);
                }
            }
        }
        if(isset($requestData['terms_condition_list'])){
            foreach($requestData['terms_condition_list'] as $termsConditions){
                if($termsConditions['terms_condition']){
                    $termsConditionsData = [
                        'plan_id' => $battery->id,
                        'terms_condition' => $termsConditions['terms_condition'],
                    ];
                    if(isset($termsConditions['terms_conditionn_id'])){    
                        $batteryTermsCondition = BatteryTermsCondition::findOrFail($termsConditions['terms_conditionn_id']);

                        if($batteryTermsCondition){
                                $batteryTermsCondition->update($termsConditionsData);
                        }else{
                            $batteryTermsCondition = BatteryTermsCondition::create($termsConditionsData);
                        }
                    }else{
                        $batteryTermsCondition = BatteryTermsCondition::create($termsConditionsData);
                    }
                }

            }
            if(isset($termsConditions['image'])){
                $file = $termsConditions['image'];
                if($file){
                    $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                    $path = '/uploads/subscription_plan/battery/'.$battery->id. '/' . $savedAs;
                    $filePath = $this->uploadFile($path, $file);
                    $batteryTermsCondition->image = $path;
                    $batteryTermsCondition->update();
                }
            }
        }

    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Battery::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/subscription-plan/battery')->with('flash_message', 'Battery deleted!');
    }
    public function destroy_asset_parts(Request $request, $id)
    {
        BatteryAssetPart ::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery Asset Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_base_plan(Request $request, $id)
    {
        BatteryBasePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery Base Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_locatoin_region(Request $request, $id)
    {
        BatteryLocation::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery Location Region deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_terms_condition(Request $request, $id)
    { 
        $batteryTermsCondition = BatteryTermsCondition::findOrFail($id);

        $this->deleteFile($batteryTermsCondition->image);
        BatteryTermsCondition::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery Terms & Condition deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_terms_condition_image(Request $request, $id)
    {
        $batteryTermsCondition = BatteryTermsCondition::findOrFail($id);

        $this->deleteFile($batteryTermsCondition->image);
        $batteryTermsCondition->image = '';
        $batteryTermsCondition->update();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery Terms & Condition Image deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function battery_plan(Request $request)
    {
        if(!isset($request->id)){
            $request->id = $request->subscription_plan_id;
        }
        $batteryList = Battery::whereNull('deleted_at')->where('id', $request->id)->first();
        $batteryList->basePlan;

        if(isset($batteryList->basePlan)){
            $batteryList->basePlan->duration;
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery list',
                'errors' => '',
                'data' => $batteryList
            ], 200);
        }
    }
}
