<?php

namespace App\Http\Controllers\Admin\SubscriptionPlan;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Location;
use App\Models\Master\ProductType;
use App\Models\Master\VAServiceType;
use App\Models\SubscriptionPlan\ChargingEquipment;
use App\Models\SubscriptionPlan\ChargingEquipmentAssetPart;
use App\Models\SubscriptionPlan\ChargingEquipmentLocation;
use App\Models\SubscriptionPlan\ChargingEquipmentTermsCondition;
use App\Models\SubscriptionPlan\ChargingEquipmentAssetVAService;
use App\Models\Assets\ChargingEquipment as Asset;
use App\Models\Vendors\ChargingStation as Dealer;
use App\Models\Master\Duration;
use App\Models\Master\BusinessCategory;
use App\Models\Master\BusinessModels;
use App\Models\Master\Taxationprofile;


class ChargingEquipmentController extends AppController
{
    public function __construct()
    {
        $productTypeList = ProductType::whereNull('deleted_at')->get();
        $vAServiceTypeList = VAServiceType::whereNull('deleted_at')->get();
        $assetList = Asset::whereNull('deleted_at')->groupBy('model_name')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $dealerList = Dealer::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        $businessCategoryList = BusinessCategory::whereNull('deleted_at')->get();
        $businessModelsList = BusinessModels::whereNull('deleted_at')->get();
        $taxationProfileListData = Taxationprofile::whereNull('deleted_at')->get();
        $taxationProfileList = [];
        foreach($taxationProfileListData as $taxationProfile){
            $taxationProfileListItem['id'] =  $taxationProfile->id;
            $taxationProfileListItem['taxation_profile'] =  $taxationProfile->taxation_profile;
            $taxPercentageList = '';
            foreach($taxationProfile->taxPercentage as $taxPercentage){
                $taxPercentageList = $taxPercentageList . ' ' . $taxPercentage->tax_name . ' - ' . $taxPercentage->percentage .'%';
            }
            $taxationProfileListItem['tax-percentage'] = '';

            if(!empty($taxPercentageList)){
                $taxationProfileListItem['tax-percentage'] = $taxPercentageList;
            }
            $taxationProfileList[] = $taxationProfileListItem;
        }
        
        View::share([
            'productTypeList' => $productTypeList, 
            'vAServiceTypeList' => $vAServiceTypeList, 
            'assetList' => $assetList, 
            'dealerList' => $dealerList, 
            'locationList' => $locationList,
            'durationList' => $durationList, 
            'businessCategoryList' => $businessCategoryList,
            'businessModelsList' => $businessModelsList,
            'taxationProfileList' => $taxationProfileList,
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $chargingEquipmentList = ChargingEquipment::whereNull('deleted_at')->get();

        return view('admin.subscription_plan.charging-equipment.index', compact('chargingEquipmentList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $chargingEquipmentList = ((new ChargingEquipment())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ChargingEquipment())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($chargingEquipmentList->isEmpty()) {
            
        }else{
            foreach($chargingEquipmentList as $chargingEquipment){
                $data['data'][] = [
                    'id' => $chargingEquipment->id,
                    'plan_name' => $chargingEquipment->plan_name,
                    'business_category_id' => isset($chargingEquipment->businessCategory) ? $chargingEquipment->businessCategory->business_category : '',
                    'business_model_id' => isset($chargingEquipment->businessModel) ? $chargingEquipment->businessModel->business_model : '',
                    'asset_type_id' => $chargingEquipment?->assetType?->product_type,
                    'charger_name' => $chargingEquipment?->assetType?->charger_name,
                    'charger_type' => $chargingEquipment?->assetType?->charger_type,
                    'charger_model' => $chargingEquipment?->assetType?->charger_model,
                    'fixed_price' => $chargingEquipment->fixed_price,
                    'base_plan' => $chargingEquipment->base_plan,
                    'location' => count($chargingEquipment->location),
                    'terms' => count($chargingEquipment->terms),
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($chargingEquipment->created_at)),
                    'action' => '
                    <!--<a href="'. route('subscription-plan.charging-equipment.show', ['charging_equipment' => $chargingEquipment->id]) . '"><i class="mdi mdi-eye font-size-16 text-success me-1"></i></a>-->
                    <a href="'. route('subscription-plan.charging-equipment.edit', ['charging_equipment' => $chargingEquipment->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('subscription-plan.charging-equipment.destroy', ['charging_equipment' => $chargingEquipment->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if($request->id){
            $validate = Validator::make($request->all(), [
                'plan_name' => [
                    'required',
                    Rule::unique('subs_charging_equipment')->ignore($request->all()['id']),
                ],
                'business_category_id' => 'required',
                'business_model_id' => 'required',
                'asset_type_id' => 'required',
                'oem_id' => 'required',
                'model_name' => 'required',
                'base_plan' => 'required',
                'fixed_price' => 'required|numeric',
                'product_overview' => 'required',
                'part_id' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'plan_name' => 'required|unique:subs_charging_equipment,plan_name',
                'business_category_id' => 'required',
                'business_model_id' => 'required',
                'asset_type_id' => 'required',
                'oem_id' => 'required',
                'oem_id' => 'required',
                'model_name' => 'required',
                'base_plan' => 'required',
                'fixed_price' => 'required|numeric',
                'product_overview' => 'required',
                'part_id' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }

        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $chargingEquipment = new ChargingEquipment();
        
        return view('admin.subscription_plan.charging-equipment.edit', compact('chargingEquipment'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $this->save_data($request);

        return redirect('admin/subscription-plan/charging-equipment')->with('flash_message', 'ChargingEquipment Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $chargingEquipment = ChargingEquipment::findOrFail($id);
        return view('admin.subscription_plan.charging-equipment.show', compact('chargingEquipment'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $chargingEquipment = ChargingEquipment::findOrFail($id);
        
        return view('admin.subscription_plan.charging-equipment.edit', compact('chargingEquipment'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $requestData = $request->all();
        $this->save_data($request);
        return redirect('admin/subscription-plan/charging-equipment')->with('flash_message', 'ChargingEquipment updated!');
    }

    public function save_data($request){

        $requestData = $request->all();
       // print_r($requestData); exit;
        $chargingEquipment = [];
        if($request->id){
            $chargingEquipment = ChargingEquipment::findOrFail($request->id);
        }
      
        if($chargingEquipment){
            $chargingEquipment->update($requestData);
        }else{
            $chargingEquipment = ChargingEquipment::create($requestData);

        }
        if(isset($requestData['part_id'])){
            foreach($requestData['part_id'] as $part_id){
                $chargingEquipmentAssetPartData = [
                    'plan_id' => $chargingEquipment->id,
                   // 'asset_id' => $chargingEquipmentAsset->id,
                    'part_id' => $part_id,
                ];
                
                $chargingEquipmentAssetPart = ChargingEquipmentAssetPart::where('plan_id', $chargingEquipment->id)->where('part_id', $part_id)->first();
                
                if($chargingEquipmentAssetPart){
                        $chargingEquipmentAssetPart->update($chargingEquipmentAssetPartData);
                }else{
                    $chargingEquipmentAssetPart = ChargingEquipmentAssetPart::create($chargingEquipmentAssetPartData);
                }
            }
        }

        if(isset($requestData['va_service_type_id'])){
            foreach($requestData['va_service_type_id'] as $va_service_type_id){
                $chargingEquipmentAssetVAServiceData = [
                    'plan_id' => $chargingEquipment->id,
                    //'asset_id' => $chargingEquipmentAsset->id,
                    'va_service_type_id' => $va_service_type_id,
                ];
                $chargingEquipmentAssetVAService = ChargingEquipmentAssetVAService::where('plan_id', $chargingEquipment->id)->where('va_service_type_id', $va_service_type_id)->first();
                
                if($chargingEquipmentAssetVAService){
                        $chargingEquipmentAssetVAService->update($chargingEquipmentAssetVAServiceData);
                }else{
                    $chargingEquipmentAssetVAService = ChargingEquipmentAssetPart::create($chargingEquipmentAssetVAServiceData);
                }
            }
        }
        if(isset($requestData['location_regions_list'])){
            foreach($requestData['location_regions_list'] as $locationRegions){
                if(isset($locationRegions['base_price'])){
                    $chargingEquipmentLocationData = [
                            'plan_id' => $chargingEquipment->id,
                            'location_id' => $locationRegions['location_id'],
                            'base_price' => $locationRegions['base_price'],
                            'base_price_taxation_profile_id' => $locationRegions['base_price_taxation_profile_id'],
                            'convenience_fee' => $locationRegions['convenience_fee'],
                            'convenience_fee_taxation_profile_id' => $locationRegions['convenience_fee_taxation_profile_id'],
                            'delivery_fee' => $locationRegions['delivery_fee'],
                            'delivery_fee_taxation_profile_id' => $locationRegions['delivery_fee_taxation_profile_id'],
                    ];
                    if(isset($locationRegions['charging_equipment_location_id'])){  
                        
                        $chargingEquipmentLocation = ChargingEquipmentLocation::findOrFail($locationRegions['charging_equipment_location_id']);

                        if($chargingEquipmentLocation){
                                $chargingEquipmentLocation->update($chargingEquipmentLocationData);
                        }else{
                            $chargingEquipmentLocation = ChargingEquipmentLocation::create($chargingEquipmentLocationData);
                        }
                    }else{
                        $chargingEquipmentLocation = ChargingEquipmentLocation::create($chargingEquipmentLocationData);
                    }
                }
            }
            
        }
        if(isset($requestData['terms_condition_list'])){
            foreach($requestData['terms_condition_list'] as $termsConditions){
                $termsConditionsData = [
                    'plan_id' => $chargingEquipment->id,
                    'terms_condition' => $termsConditions['terms_condition'],
                ];
                if(isset($termsConditions['terms_conditionn_id'])){    
                    $chargingEquipmentTermsCondition = ChargingEquipmentTermsCondition::findOrFail($termsConditions['terms_conditionn_id']);

                    if($chargingEquipmentTermsCondition){
                            $chargingEquipmentTermsCondition->update($termsConditionsData);
                    }else{
                        $chargingEquipmentTermsCondition = ChargingEquipmentTermsCondition::create($termsConditionsData);
                    }
                }else{
                    $chargingEquipmentTermsCondition = ChargingEquipmentTermsCondition::create($termsConditionsData);
                }

                if(isset($termsConditions['image'])){
                    $file = $termsConditions['image'];
                    if($file){
                        $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                        $path = '/uploads/subscription_plan/charging_equipment'.$chargingEquipment->id. '/' . $savedAs;
                        $filePath = $this->uploadFile($path, $file);
                        $chargingEquipmentTermsCondition->image = $path;
                        $chargingEquipmentTermsCondition->update();
                    }
                }
            }
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        ChargingEquipment::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/subscription-plan/ChargingEquipment')->with('flash_message', 'ChargingEquipment deleted!');
    }
    public function destroy_asset_parts(Request $request, $id)
    {
        ChargingEquipmentAssetPart ::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment Asset Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_base_plan(Request $request, $id)
    {
        ChargingEquipmentBasePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment Base Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_locatoin_region(Request $request, $id)
    {
        ChargingEquipmentLocation::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment Location Region deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_terms_condition(Request $request, $id)
    { 
        $chargingEquipmentTermsCondition = ChargingEquipmentTermsCondition::findOrFail($id);

        $this->deleteFile($chargingEquipmentTermsCondition->image);
        ChargingEquipmentTermsCondition::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment Terms & Condition deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_terms_condition_image(Request $request, $id)
    {
        $chargingEquipmentTermsCondition = ChargingEquipmentTermsCondition::findOrFail($id);

        $this->deleteFile($chargingEquipmentTermsCondition->image);
        $chargingEquipmentTermsCondition->image = '';
        $chargingEquipmentTermsCondition->update();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment Terms & Condition Image deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function charging_equipment_plan(Request $request)
    {
        if(!isset($request->id)){
            $request->id = $request->subscription_plan_id;
        }
        $chargingEquipmentList = ChargingEquipment::whereNull('deleted_at')->where('id', $request->id)->first();
        $chargingEquipmentList->basePlan;

        if(isset($chargingEquipmentList->basePlan)){
            $chargingEquipmentList->basePlan->duration;
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ChargingEquipment list',
                'errors' => '',
                'data' => $chargingEquipmentList
            ], 200);
        }
    }
}
