<?php

namespace App\Http\Controllers\Admin\SubscriptionPlan;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Location;
use App\Models\Master\ProductType;
use App\Models\Master\VAServiceType;
use App\Models\SubscriptionPlan\Vehicle;
use App\Models\SubscriptionPlan\VehicleAssetPart;
use App\Models\SubscriptionPlan\VehicleLocation;
use App\Models\SubscriptionPlan\VehicleTermsCondition;
use App\Models\SubscriptionPlan\VehicleAssetVAService;
use App\Models\Assets\Vehicle as Asset;
use App\Models\Vendors\Vehicle as Dealer;
use App\Models\Master\Duration;
use App\Models\Master\BusinessCategory;
use App\Models\Master\BusinessModels;
use App\Models\Master\TaxationProfile;


class ChargingStationController extends AppController
{
    public function __construct()
    {
        $productTypeList = ProductType::whereNull('deleted_at')->get();
        $vAServiceTypeList = VAServiceType::whereNull('deleted_at')->get();
        $assetList = Asset::whereNull('deleted_at')->groupBy('model_name')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $dealerList = Dealer::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        $businessCategoryList = BusinessCategory::whereNull('deleted_at')->get();
        $businessModelsList = BusinessModels::whereNull('deleted_at')->get();
        $taxationProfileListData = TaxationProfile::whereNull('deleted_at')->get();
        $taxationProfileList = [];
        foreach($taxationProfileListData as $taxationProfile){
            $taxationProfileListItem['id'] =  $taxationProfile->id;
            $taxationProfileListItem['taxation_profile'] =  $taxationProfile->taxation_profile;
            $taxPercentageList = '';
            foreach($taxationProfile->taxPercentage as $taxPercentage){
                $taxPercentageList = $taxPercentageList . ' ' . $taxPercentage->tax_name . ' - ' . $taxPercentage->percentage .'%';
            }
            $taxationProfileListItem['tax-percentage'] = '';

            if(!empty($taxPercentageList)){
                $taxationProfileListItem['tax-percentage'] = $taxPercentageList;
            }
            $taxationProfileList[] = $taxationProfileListItem;
        }
        
        View::share([
            'productTypeList' => $productTypeList, 
            'vAServiceTypeList' => $vAServiceTypeList, 
            'assetList' => $assetList, 
            'dealerList' => $dealerList, 
            'locationList' => $locationList,
            'durationList' => $durationList, 
            'businessCategoryList' => $businessCategoryList,
            'businessModelsList' => $businessModelsList,
            'taxationProfileList' => $taxationProfileList,
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $vehicleList = Vehicle::whereNull('deleted_at')->get();
        return view('admin.subscription_plan.vehicles.index', compact('vehicleList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $vehicleList = ((new Vehicle())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Vehicle())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($vehicleList->isEmpty()) {
            
        }else{
            foreach($vehicleList as $vehicle){
                $data['data'][] = [
                    'id' => $vehicle->id,
                    'plan_name' => $vehicle->plan_name,
                    'business_category_id' => isset($vehicle->businessCategory) ? $vehicle->businessCategory->business_category : '',
                    'business_model_id' => isset($vehicle->businessModel) ? $vehicle->businessModel->business_model : '',
                    'asset_type_id' => $vehicle?->assetType?->product_type,
                    'fixed_price' => $vehicle->fixed_price,
                    'base_plan' => $vehicle->base_plan,
                    'location' => count($vehicle->location),
                    'terms' => count($vehicle->terms),
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($vehicle->created_at)),
                    'action' => '
                    <!--<a href="'. route('subscription-plan.vehicles.show', ['vehicle' => $vehicle->id]) . '"><i class="mdi mdi-eye font-size-16 text-success me-1"></i></a>-->
                    <a href="'. route('subscription-plan.vehicles.edit', ['vehicle' => $vehicle->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('subscription-plan.vehicles.destroy', ['vehicle' => $vehicle->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'plan_name' => [
                    'required',
                    Rule::unique('subs_vehicle')->ignore($request->all()['id']),
                ],
                'business_category_id' => 'required',
                'business_model_id' => 'required',
                'asset_type_id' => 'required',
                'oem_id' => 'required',
                'model_name' => 'required',
                'product_overview' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'plan_name' => 'required|unique:subs_vehicle,plan_name',
                'business_category_id' => 'required',
                'business_model_id' => 'required',
                'asset_type_id' => 'required',
                'oem_id' => 'required',
                'model_name' => 'required',
                'product_overview' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.subscription_plan.vehicles.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        //print_r($requestData); exit;
        
        if(isset($requestData ['base_plan'])){
            $requestData ['billing_period_id'] = '';
            $requestData ['grace_time_hr'] = '';
            $requestData ['grace_time'] = '';
            $requestData ['lock_bike'] = '';

            if($requestData ['base_plan'] == 'Freemium'){
                $requestData ['billing_period_id'] = $requestData ['freemium_free_usages_id'] ?? '';
                $requestData ['grace_time_hr'] = $requestData ['freemium_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['freemium_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['freemium_lock_bike'] ?? '';
            }elseif($requestData ['base_plan'] == 'Re-Subscribe'){
                $requestData ['grace_time_hr'] = $requestData ['re_subscribe_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['re_subscribe_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['re_subscribe_lock_bike'] ?? '';
            }elseif($requestData ['base_plan'] == 'Auto Renewing'){
                $requestData ['billing_period_id'] = $requestData ['auto_renewing_billing_period_id'] ?? '';
                $requestData ['grace_time'] = $requestData ['auto_renewing_grace_time'] ?? '';
            }elseif($requestData ['base_plan'] == 'Prepaid'){
                $requestData ['billing_period_id'] = $requestData ['prepaid_billing_cycle_id'] ?? '';
                $requestData ['grace_time_hr'] = $requestData ['prepaid_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['prepaid_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['prepaid_lock_bike'] ?? '';
            }

        }

        $vehicleData = [
            'plan_name' => $requestData ['plan_name'],
            'business_category_id' => $requestData ['business_category_id'],
            'business_model_id' => $requestData ['business_model_id'],
            'asset_type_id' => $requestData ['asset_type_id'],
            'oem_id' => $requestData ['oem_id'],
            'model_name' => $requestData ['model_name'],
            'product_overview' => $requestData ['product_overview'],
            'fixed_price' => $requestData ['fixed_price'],
            'base_plan' => $requestData ['base_plan'],
            'have_convenience_price' => $requestData ['have_convenience_price'],
            'have_delivery_charge' => $requestData ['have_delivery_charge'],
            'convenience_price' => $requestData ['convenience_price'],
            'delivery_charge' => $requestData ['delivery_charge'],
            'billing_period_id' => $requestData ['billing_period_id'],
            'grace_time_hr' => $requestData ['grace_time_hr'],
            'grace_time' => $requestData ['grace_time'],
            'lock_bike' => $requestData ['lock_bike'],
        ];
        $vehicle = Vehicle::create($vehicleData);
        
        if(isset($requestData['part_id'])){
            foreach($requestData['part_id'] as $part_id){
                $vehicleAssetPartData = [
                    'plan_id' => $vehicle->id,
                    //'asset_id' => $vehicleAsset->id,
                    'part_id' => $part_id,
                ];
                $vehicleAssetPart = VehicleAssetPart::create($vehicleAssetPartData);
            }
        } 
        if(isset($requestData['va_service_type_id'])){
            foreach($requestData['va_service_type_id'] as $va_service_type_id){
                $vehicleAssetVAServiceData = [
                    'plan_id' => $vehicle->id,
                    //'asset_id' => $vehicleAsset->id,
                    'va_service_type_id' => $va_service_type_id,
                ];
                $vehicleAssetVAService = VehicleAssetVAService::create($vehicleAssetVAServiceData);
            }
        }
        if(isset($requestData['location_regions_list'])){
            foreach($requestData['location_regions_list'] as $locationRegions){
                $vehicleLocationData = [
                    'plan_id' => $vehicle->id,
                    'location_id' => $locationRegions['location_id'],
                    'base_price' => $locationRegions['base_price'],
                    'taxation_profile_id' => $locationRegions['taxation_profile_id'],
                    'delivery_fee' => $locationRegions['delivery_fee'],
                    'convenience_fee' => $locationRegions['convenience_fee'],
                ];
                $vehicleLocation = VehicleLocation::create($vehicleLocationData);
            }
        }
        if(isset($requestData['terms_condition_list'])){

            foreach($requestData['terms_condition_list'] as $ltermsConditions){
                
                $path = '';
                if(isset($ltermsConditions['image'])){
                    $file = $ltermsConditions['image'];
                    if($file){
                        $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                        $path = '/uploads/subscription_plan/vehicles/'.$vehicle->id. '/' . $savedAs;
                        $filePath = $this->uploadFile($path, $file);
                    }
                }
                $ltermsConditionsData = [
                    'plan_id' => $vehicle->id,
                    'image' => $path,
                    'terms_condition' => $ltermsConditions['terms_condition'],
                ];
                $vehicleTermsCondition = VehicleTermsCondition::create($ltermsConditionsData);
            }
        }
        
        return redirect('admin/subscription-plan/vehicles')->with('flash_message', 'Vehicle Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $vehicle = Vehicle::findOrFail($id);
        return view('admin.subscription_plan.vehicles.show', compact('vehicle'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $vehicle = Vehicle::findOrFail($id);
        
        return view('admin.subscription_plan.vehicles.edit', compact('vehicle'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $requestData = $request->all();
        $vehicle = Vehicle::findOrFail($id);
        
        if(isset($requestData ['base_plan'])){
            $requestData ['billing_period_id'] = '';
            $requestData ['grace_time_hr'] = '';
            $requestData ['grace_time'] = '';
            $requestData ['lock_bike'] = '';

            if($requestData ['base_plan'] == 'Freemium'){
                $requestData ['billing_period_id'] = $requestData ['freemium_free_usages_id'] ?? '';
                $requestData ['grace_time_hr'] = $requestData ['freemium_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['freemium_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['freemium_lock_bike'] ?? '';
            }elseif($requestData ['base_plan'] == 'Re-Subscribe'){
                $requestData ['grace_time_hr'] = $requestData ['re_subscribe_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['re_subscribe_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['re_subscribe_lock_bike'] ?? '';
            }elseif($requestData ['base_plan'] == 'Auto Renewing'){
                $requestData ['billing_period_id'] = $requestData ['auto_renewing_billing_period_id'] ?? '';
                $requestData ['grace_time'] = $requestData ['auto_renewing_grace_time'] ?? '';
            }elseif($requestData ['base_plan'] == 'Prepaid'){
                $requestData ['billing_period_id'] = $requestData ['prepaid_billing_cycle_id'] ?? '';
                $requestData ['grace_time_hr'] = $requestData ['prepaid_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['prepaid_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['prepaid_lock_bike'] ?? '';
            }

        }

        $vehicleData = [
            'plan_name' => $requestData ['plan_name'],
            'business_category_id' => $requestData ['business_category_id'],
            'business_model_id' => $requestData ['business_model_id'],
            'asset_type_id' => $requestData ['asset_type_id'],
            'oem_id' => $requestData ['oem_id'],
            'model_name' => $requestData ['model_name'],
            'product_overview' => $requestData ['product_overview'],
            'fixed_price' => $requestData ['fixed_price'],
            'base_plan' => $requestData ['base_plan'],
            'have_convenience_price' => $requestData ['have_convenience_price'],
            'have_delivery_charge' => $requestData ['have_delivery_charge'],
            'convenience_price' => $requestData ['convenience_price'],
            'delivery_charge' => $requestData ['delivery_charge'],
            'billing_period_id' => $requestData ['billing_period_id'],
            'grace_time_hr' => $requestData ['grace_time_hr'],
            'grace_time' => $requestData ['grace_time'],
            'lock_bike' => $requestData ['lock_bike'],
        ];
        $vehicle->update($vehicleData);
        
        if(isset($requestData['part_id'])){
            foreach($requestData['part_id'] as $part_id){
                $vehicleAssetPartData = [
                    'plan_id' => $vehicle->id,
                   // 'asset_id' => $vehicleAsset->id,
                    'part_id' => $part_id,
                ];
                
                $vehicleAssetPart = VehicleAssetPart::where('plan_id', $vehicle->id)->where('part_id', $part_id)->first();
                
                if($vehicleAssetPart){
                        $vehicleAssetPart->update($vehicleAssetPartData);
                }else{
                    $vehicleAssetPart = VehicleAssetPart::create($vehicleAssetPartData);
                }
            }
        }

        if(isset($requestData['va_service_type_id'])){
            foreach($requestData['va_service_type_id'] as $va_service_type_id){
                $vehicleAssetVAServiceData = [
                    'plan_id' => $vehicle->id,
                    //'asset_id' => $vehicleAsset->id,
                    'va_service_type_id' => $va_service_type_id,
                ];
                $vehicleAssetVAService = VehicleAssetVAService::where('plan_id', $vehicle->id)->where('va_service_type_id', $va_service_type_id)->first();
                
                if($vehicleAssetVAService){
                        $vehicleAssetVAService->update($vehicleAssetVAServiceData);
                }else{
                    $vehicleAssetVAService = VehicleAssetPart::create($vehicleAssetVAServiceData);
                }
            }
        }
        if(isset($requestData['location_regions_list'])){
            foreach($requestData['location_regions_list'] as $locationRegions){
                $vehicleLocationData = [
                    'plan_id' => $vehicle->id,
                    'location_id' => $locationRegions['location_id'],
                    'base_price' => $locationRegions['base_price'],
                    'taxation_profile_id' => $locationRegions['taxation_profile_id'],
                    'delivery_fee' => $locationRegions['delivery_fee'],
                    'convenience_fee' => $locationRegions['convenience_fee'],
                ];
                if(isset($locationRegions['vehicle_location_id'])){  
                    
                    $vehicleLocation = VehicleLocation::findOrFail($locationRegions['vehicle_location_id']);

                    if($vehicleLocation){
                            $vehicleLocation->update($vehicleLocationData);
                    }else{
                        $vehicleLocation = VehicleLocation::create($vehicleLocationData);
                    }
                }else{
                    $vehicleLocation = VehicleLocation::create($vehicleLocationData);
                }
            }
        }
        if(isset($requestData['terms_condition_list'])){

            foreach($requestData['terms_condition_list'] as $ltermsConditions){
                
                $termsConditionsData = [
                    'plan_id' => $vehicle->id,
                    'terms_condition' => $ltermsConditions['terms_condition'],
                ];
                if(isset($ltermsConditions['terms_conditionn_id'])){    
                    $vehicleTermsCondition = VehicleTermsCondition::findOrFail($ltermsConditions['terms_conditionn_id']);

                    if($vehicleTermsCondition){
                            $vehicleTermsCondition->update($termsConditionsData);
                    }else{
                        $vehicleTermsCondition = VehicleTermsCondition::create($termsConditionsData);
                    }
                }else{
                    $vehicleTermsCondition = VehicleTermsCondition::create($termsConditionsData);
                }

            }
            if(isset($ltermsConditions['image'])){
                $file = $ltermsConditions['image'];
                if($file){
                    $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                    $path = '/uploads/subscription_plan/vehicles/'.$vehicle->id. '/' . $savedAs;
                    $filePath = $this->uploadFile($path, $file);
                    $vehicleTermsCondition->image = $path;
                    $vehicleTermsCondition->update();
                }
            }
        }
        return redirect('admin/subscription-plan/vehicles')->with('flash_message', 'Vehicle updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Vehicle::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/subscription-plan/vehicles')->with('flash_message', 'Vehicle deleted!');
    }
    public function destroy_asset_parts(Request $request, $id)
    {
        VehicleAssetPart ::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle Asset Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_base_plan(Request $request, $id)
    {
        VehicleBasePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle Base Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_locatoin_region(Request $request, $id)
    {
        VehicleLocation::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle Location Region deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_terms_condition(Request $request, $id)
    { 
        $vehicleTermsCondition = VehicleTermsCondition::findOrFail($id);

        $this->deleteFile($vehicleTermsCondition->image);
        VehicleTermsCondition::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle Terms & Condition deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_terms_condition_image(Request $request, $id)
    {
        $vehicleTermsCondition = VehicleTermsCondition::findOrFail($id);

        $this->deleteFile($vehicleTermsCondition->image);
        $vehicleTermsCondition->image = '';
        $vehicleTermsCondition->update();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle Terms & Condition Image deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function vehicle_plan(Request $request)
    {
        if(!isset($request->id)){
            $request->id = $request->subscription_plan_id;
        }
        $vehicleList = Vehicle::whereNull('deleted_at')->where('id', $request->id)->first();
        $vehicleList->basePlan;

        if(isset($vehicleList->basePlan)){
            $vehicleList->basePlan->duration;
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Vehicle list',
                'errors' => '',
                'data' => $vehicleList
            ], 200);
        }
    }
}
