<?php

namespace App\Http\Controllers\Admin\SubscriptionPlan;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Location;
use App\Models\Master\VAServiceType;
use App\Models\SubscriptionPlan\ValueAddedService;
use App\Models\SubscriptionPlan\ValueAddedServiceLocation;
use App\Models\SubscriptionPlan\ValueAddedServiceTermsCondition;
use App\Models\Master\Duration;
use App\Models\Master\BusinessCategory;
use App\Models\Master\BusinessModels;
use App\Models\Master\Taxationprofile;


class ValueAddedServiceController extends AppController
{
    public function __construct()
    {
        
        $vAServiceTypeList = VAServiceType::whereNull('deleted_at')->get();
        $locationList = Location::whereNull('deleted_at')->get();
        $durationList = Duration::whereNull('deleted_at')->get();
        $businessCategoryList = BusinessCategory::whereNull('deleted_at')->get();
        $businessModelsList = BusinessModels::whereNull('deleted_at')->get();
        $taxationProfileListData = Taxationprofile::whereNull('deleted_at')->get();
        $taxationProfileList = [];
        foreach($taxationProfileListData as $taxationProfile){
            $taxationProfileListItem['id'] =  $taxationProfile->id;
            $taxationProfileListItem['taxation_profile'] =  $taxationProfile->taxation_profile;
            $taxPercentageList = '';
            foreach($taxationProfile->taxPercentage as $taxPercentage){
                $taxPercentageList = $taxPercentageList . ' ' . $taxPercentage->tax_name . ' - ' . $taxPercentage->percentage .'%';
            }
            $taxationProfileListItem['tax-percentage'] = '';

            if(!empty($taxPercentageList)){
                $taxationProfileListItem['tax-percentage'] = $taxPercentageList;
            }
            $taxationProfileList[] = $taxationProfileListItem;
        }
        
        View::share([
            
            'vAServiceTypeList' => $vAServiceTypeList,
            'locationList' => $locationList,
            'durationList' => $durationList, 
            'businessCategoryList' => $businessCategoryList,
            'businessModelsList' => $businessModelsList,
            'taxationProfileList' => $taxationProfileList,
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $valueAddedServiceList = ValueAddedService::whereNull('deleted_at')->get();
        return view('admin.subscription_plan.value_added_service.index', compact('valueAddedServiceList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $valueAddedServiceList = ((new ValueAddedService())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ValueAddedService())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($valueAddedServiceList->isEmpty()) {
            
        }else{
            foreach($valueAddedServiceList as $valueAddedService){
                $data['data'][] = [
                    'id' => $valueAddedService->id,
                    'plan_name' => $valueAddedService->plan_name,
                    'business_category_id' => isset($valueAddedService->businessCategory) ? $valueAddedService->businessCategory->business_category : '',
                    'business_model_id' => isset($valueAddedService->businessModel) ? $valueAddedService->businessModel->business_model : '',
                    'va_service_id' => isset($valueAddedService->vaService) ? $valueAddedService->vaService->va_service_type : '',
                    'fixed_price' => $valueAddedService->fixed_price,
                    'base_plan' => $valueAddedService->base_plan,
                    'location' => $valueAddedService->location->count(),
                    'terms' => count($valueAddedService->terms),
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($valueAddedService->created_at)),
                    'action' => '
                    <!--<a href="'. route('subscription-plan.value-added-service.show', ['value_added_service' => $valueAddedService->id]) . '"><i class="mdi mdi-eye font-size-16 text-success me-1"></i></a>-->
                    <a href="'. route('subscription-plan.value-added-service.edit', ['value_added_service' => $valueAddedService->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('subscription-plan.value-added-service.destroy', ['value_added_service' => $valueAddedService->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        $validateData = [
            'business_category_id' => 'required',
            'business_model_id' => 'required',
            'va_service_id' => 'required',
            'base_plan' => 'required',
            'fixed_price' => 'required|numeric',
            'product_overview' => 'required',
            'have_convenience_price' => 'required',
            'have_delivery_charge' => 'required',
        ];
        if($request->id){
            $validateData['plan_name'] = [
                    'required',
                    Rule::unique('subs_value_added_service')->ignore($request->all()['id']),                
            ];

        }else{
            $validateData['plan_name'] = 'required|unique:subs_value_added_service,plan_name';
            
        }
        $validate = Validator::make($request->all(), $validateData);
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $valueAddedService = new ValueAddedService();
        
        return view('admin.subscription_plan.value_added_service.edit', compact('valueAddedService'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $this->save_data($request);

        return redirect('admin/subscription-plan/value-added-service')->with('flash_message', 'ValueAddedService Asset added!');
    }
    

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $valueAddedService = ValueAddedService::findOrFail($id);
        return view('admin.subscription_plan.value_added_service.show', compact('valueAddedService'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $valueAddedService = ValueAddedService::findOrFail($id);
        
        return view('admin.subscription_plan.value_added_service.edit', compact('valueAddedService'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        $this->save_data($request);

        return redirect('admin/subscription-plan/value-added-service')->with('flash_message', 'ValueAddedService updated!');
    }
    public function save_data($request){

        $requestData = $request->all();
        //print_r($requestData); exit;
        $valueAddedService = [];
        if($request->id){
            $valueAddedService = ValueAddedService::findOrFail($request->id);
        }
      
        if($valueAddedService){
            $valueAddedService->update($requestData);
        }else{
            $valueAddedService = ValueAddedService::create($requestData);
        }        
        
        if(isset($requestData ['base_plan'])){
            $requestData ['billing_period_id'] = '';
            $requestData ['grace_time_hr'] = '';
            $requestData ['grace_time'] = '';
            $requestData ['lock_bike'] = '';

            if($requestData ['base_plan'] == 'Freemium'){
                $requestData ['billing_period_id'] = $requestData ['freemium_free_usages_id'] ?? '';
                $requestData ['grace_time_hr'] = $requestData ['freemium_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['freemium_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['freemium_lock_bike'] ?? '';
            }elseif($requestData ['base_plan'] == 'Prepaid'){
                $requestData ['billing_period_id'] = $requestData ['prepaid_billing_cycle_id'] ?? '';
                $requestData ['grace_time_hr'] = $requestData ['prepaid_grace_time_hr'] ?? '';
                $requestData ['grace_time'] = $requestData ['prepaid_grace_time'] ?? '';
                $requestData ['lock_bike'] = $requestData ['prepaid_lock_bike'] ?? '';
            }

        }

        $valueAddedServiceData = [
            'billing_period_id' => $requestData ['billing_period_id'],
            'grace_time_hr' => $requestData ['grace_time_hr'],
            'grace_time' => $requestData ['grace_time'],
            'lock_bike' => $requestData ['lock_bike'],
        ];

        $valueAddedService->update($valueAddedServiceData);
        
        if(isset($requestData['location_regions_list'])){
            foreach($requestData['location_regions_list'] as $locationRegions){
                if($locationRegions['location_id']){
                    $valueAddedServiceLocationData = [
                        'plan_id' => $valueAddedService->id,
                        'location_id' => $locationRegions['location_id'],
                        'base_price' => $locationRegions['base_price'],
                        'base_price_taxation_profile_id' => $locationRegions['base_price_taxation_profile_id'],
                        'convenience_fee' => $locationRegions['convenience_fee'],
                        'convenience_fee_taxation_profile_id' => $locationRegions['convenience_fee_taxation_profile_id'],
                        'delivery_fee' => $locationRegions['delivery_fee'],
                        'delivery_fee_taxation_profile_id' => $locationRegions['delivery_fee_taxation_profile_id'],
                    ];
                    if(isset($locationRegions['value_added_service_location_id'])){
                        $valueAddedServiceLocation = [] ;
                        
                        if($locationRegions['value_added_service_location_id']){
                            $valueAddedServiceLocation = ValueAddedServiceLocation::findOrFail($locationRegions['value_added_service_location_id']);
                        }
                        if($valueAddedServiceLocation){
                                $valueAddedServiceLocation->update($valueAddedServiceLocationData);
                        }else{
                            $valueAddedServiceLocation = ValueAddedServiceLocation::create($valueAddedServiceLocationData);
                        }
                    }else{
                        $valueAddedServiceLocation = ValueAddedServiceLocation::create($valueAddedServiceLocationData);
                    }
                }
            }
        }
        if(isset($requestData['terms_condition_list'])){

            foreach($requestData['terms_condition_list'] as $ltermsConditions){
                if($ltermsConditions['terms_condition']){
                
                    $termsConditionsData = [
                        'plan_id' => $valueAddedService->id,
                        'terms_condition' => $ltermsConditions['terms_condition'],
                    ];
                    if(isset($ltermsConditions['terms_conditionn_id'])){  
                        $valueAddedServiceTermsCondition = [] ;
                        if($ltermsConditions['terms_conditionn_id']){  
                            $valueAddedServiceTermsCondition = ValueAddedServiceTermsCondition::findOrFail($ltermsConditions['terms_conditionn_id']);
                        }
                        if($valueAddedServiceTermsCondition){
                                $valueAddedServiceTermsCondition->update($termsConditionsData);
                        }else{
                            $valueAddedServiceTermsCondition = ValueAddedServiceTermsCondition::create($termsConditionsData);
                        }
                    }else{
                        $valueAddedServiceTermsCondition = ValueAddedServiceTermsCondition::create($termsConditionsData);
                    }
                }

            }
            if(isset($ltermsConditions['image'])){
                $file = $ltermsConditions['image'];
                if($file){
                    $savedAs = rand('111', '999'). '_'. time() .'.'.$file->extension();
                    $path = '/uploads/subscription_plan/vehicles/'.$valueAddedService->id. '/' . $savedAs;
                    $filePath = $this->uploadFile($path, $file);
                    $valueAddedServiceTermsCondition->image = $path;
                    $valueAddedServiceTermsCondition->update();
                }
            }
        }

    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        ValueAddedService::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ValueAddedService deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/subscription-plan/vehicles')->with('flash_message', 'ValueAddedService deleted!');
    }
    public function destroy_asset_parts(Request $request, $id)
    {
        ValueAddedServiceAssetPart ::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ValueAddedService Asset Parts deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_base_plan(Request $request, $id)
    {
        ValueAddedServiceBasePlan::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ValueAddedService Base Plan deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_locatoin_region(Request $request, $id)
    {
        ValueAddedServiceLocation::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ValueAddedService Location Region deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_terms_condition(Request $request, $id)
    { 
        $valueAddedServiceTermsCondition = ValueAddedServiceTermsCondition::findOrFail($id);

        $this->deleteFile($valueAddedServiceTermsCondition->image);
        ValueAddedServiceTermsCondition::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ValueAddedService Terms & Condition deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function destroy_terms_condition_image(Request $request, $id)
    {
        $valueAddedServiceTermsCondition = ValueAddedServiceTermsCondition::findOrFail($id);

        $this->deleteFile($valueAddedServiceTermsCondition->image);
        $valueAddedServiceTermsCondition->image = '';
        $valueAddedServiceTermsCondition->update();
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ValueAddedService Terms & Condition Image deleted!',
                'errors' => ''
            ], 200);
        }
        return true;
    }
    public function  value_added_service_plan(Request $request)
    {
        if(!isset($request->id)){
            $request->id = $request->subscription_plan_id;
        }
        $valueAddedServiceList = ValueAddedService::whereNull('deleted_at')->where('id', $request->id)->first();
        $valueAddedServiceList->basePlan;

        if(isset($valueAddedServiceList->basePlan)){
            $valueAddedServiceList->basePlan->duration;
        }
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'ValueAddedService list',
                'errors' => '',
                'data' => $valueAddedServiceList
            ], 200);
        }
    }
}
