<?php

namespace App\Http\Controllers\Admin\Vendors;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Vendors\Battery;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Vendors\VendorCategory;
use App\Models\Vendors\VendorOem;
use App\Models\VehicleOem;



class BatteryController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $vendorCategoryList = VendorCategory::whereNull('deleted_at')->get();
        $vendorOemList = VendorOem::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'vendorCategoryList' => $vendorCategoryList, 
            'vendorOemList' => $vendorOemList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $batteryList = Battery::whereNull('deleted_at')->get();
        return view('admin.vendors.battery.index', compact('batteryList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $battery = ((new Battery())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new Battery())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($battery->isEmpty()) {
            
        }else{
            foreach($battery as $battery){
                $data['data'][] = [
                    'id' => $battery->id,
                    'oem_id' => $battery->vendorOemss->Vehicle_OEM ?? null,
                    'battery_dealer' => $battery->battery_dealer,
                    'phone_number' => $battery->phone_number,
                    'email' => $battery->email,
                    'address' => $battery->address,
                    'postal_code' => $battery->postal_code,
                    'city_id' => $battery?->city?->city,
                    'district_id' => $battery?->district?->district,
                    'state_id' => $battery?->state?->state,
                    'zone_id' => $battery?->zone?->zone,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($battery->created_at)) ,
                    'action' => '<a href="'. route('battery.edit', ['battery' => $battery->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('battery.destroy', ['battery' => $battery->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'battery_dealer' => [
                    'required',
                    Rule::unique('v_battery')->ignore($request->all()['id']),
                ],
                'oem_id' => 'required',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'battery_dealer' => 'required|unique:v_battery,battery_dealer',
                'oem_id' => 'required',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        $vehicleList = VehicleOem::get();

        return view('admin.vendors.battery.create',compact('vehicleList'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $battery = Battery::create($requestData);
        return redirect('/vendor/battery')->with('flash_message', 'Battery Dealer added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $battery = Battery::findOrFail($id);
        return view('admin.vendors.battery.show', compact('battery'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $battery = Battery::findOrFail($id);
        
        return view('admin.vendors.battery.edit', compact('battery'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $battery = Battery::findOrFail($id);
        $battery->update($requestData);

        return redirect('admin/vendor/battery')->with('flash_message', 'Battery updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        Battery::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Battery deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/vendor/battery')->with('flash_message', 'Battery deleted!');
    }
}
