<?php

namespace App\Http\Controllers\Admin\Vendors;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Vendors\ChargingStation;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Vendors\VendorCategory;
use App\Models\Vendors\VendorOem;


class ChargingStationController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $vendorCategoryList = VendorCategory::whereNull('deleted_at')->get();
        $vendorOemList = VendorOem::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'vendorCategoryList' => $vendorCategoryList, 
            'vendorOemList' => $vendorOemList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $chargingStationList = ChargingStation::whereNull('deleted_at')->get();
        return view('admin.vendors.charging_station.index', compact('chargingStationList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $chargingStation = ((new ChargingStation())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ChargingStation())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($chargingStation->isEmpty()) {
            
        }else{
            foreach($chargingStation as $chargingStation){
                $data['data'][] = [
                    'id' => $chargingStation->id,
                    'oem_id' => $chargingStation?->vendorOem?->vendor_oem,
                    'station_dealer' => $chargingStation->station_dealer,
                    'phone_number' => $chargingStation->phone_number,
                    'email' => $chargingStation->email,
                    'address' => $chargingStation->address,
                    'postal_code' => $chargingStation->postal_code,
                    'city_id' => $chargingStation?->city?->city,
                    'district_id' => $chargingStation?->district?->district,
                    'state_id' => $chargingStation?->state?->state,
                    'zone_id' => $chargingStation?->zone?->zone,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($chargingStation->created_at)) ,
                    'action' => '<a href="'. route('charging-station.edit', ['charging_station' => $chargingStation->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('charging-station.destroy', ['charging_station' => $chargingStation->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'station_dealer' => [
                    'required',
                    Rule::unique('v_charging_station')->ignore($request->all()['id']),
                ],
                'oem_id' => 'required',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'station_dealer' => 'required|unique:v_charging_station,station_dealer',
                'oem_id' => 'required',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.vendors.charging_station.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $chargingStation = ChargingStation::create($requestData);
        return redirect('admin/vendor/charging-station')->with('flash_message', 'Charging Station Dealer added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $chargingStation = ChargingStation::findOrFail($id);
        return view('admin.vendors.charging_station.show', compact('chargingStation'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $chargingStation = ChargingStation::findOrFail($id);
        
        return view('admin.vendors.charging_station.edit', compact('chargingStation'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $chargingStation = ChargingStation::findOrFail($id);
        $chargingStation->update($requestData);

        return redirect('admin/vendor/charging-station')->with('flash_message', 'Charging Station Dealer updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        ChargingStation::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Charging Station Dealer  deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/vendor/charging-station')->with('flash_message', 'Charging Station Dealer  deleted!');
    }
}
