<?php

namespace App\Http\Controllers\Admin\Vendors;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Vendors\ServiceWorkshop;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;
use App\Models\Master\ZoneState;
use App\Models\Master\ZoneDistrict;
use App\Models\Master\ZoneCity;
use App\Models\Master\Zone;
use App\Models\Vendors\VendorCategory;
use App\Models\Vendors\VendorOem;


class ServiceWorkshopController extends AppController
{
    public function __construct()
    {
        $zones = Zone::whereNull('deleted_at')->get();
        $states = ZoneState::whereNull('deleted_at')->get();
        $districts = ZoneDistrict::whereNull('deleted_at')->get();
        $city = ZoneCity::whereNull('deleted_at')->get();
        $vendorCategoryList = VendorCategory::whereNull('deleted_at')->get();
        $vendorOemList = VendorOem::whereNull('deleted_at')->get();
        View::share([
            'zones' => $zones, 
            'states' => $states, 
            'districts' => $districts, 
            'cities' => $city, 
            'vendorCategoryList' => $vendorCategoryList, 
            'vendorOemList' => $vendorOemList, 
        ]);
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        $serviceWorkshopList = ServiceWorkshop::whereNull('deleted_at')->get();
        return view('admin.vendors.service_workshop.index', compact('serviceWorkshopList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $serviceWorkshop = ((new ServiceWorkshop())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new ServiceWorkshop())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($serviceWorkshop->isEmpty()) {
            
        }else{
            foreach($serviceWorkshop as $serviceWorkshop){
                $data['data'][] = [
                    'id' => $serviceWorkshop->id,
                    'service_workshop' => $serviceWorkshop->service_workshop,
                    'phone_number' => $serviceWorkshop->phone_number,
                    'email' => $serviceWorkshop->email,
                    'address' => $serviceWorkshop->address,
                    'postal_code' => $serviceWorkshop->postal_code,
                    'city_id' => $serviceWorkshop?->city?->city,
                    'district_id' => $serviceWorkshop?->district?->district,
                    'state_id' => $serviceWorkshop?->state?->state,
                    'zone_id' => $serviceWorkshop?->zone?->zone,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($serviceWorkshop->created_at)) ,
                    'action' => '<a href="'. route('service-workshop.edit', ['service_workshop' => $serviceWorkshop->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('service-workshop.destroy', ['service_workshop' => $serviceWorkshop->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'service_workshop' => [
                    'required',
                    Rule::unique('v_service_workshop')->ignore($request->all()['id']),
                ],
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'service_workshop' => 'required|unique:v_service_workshop,service_workshop',
                'city_id' => 'required',
                'district_id' => 'required',
                'state_id' => 'required',
                'zone_id' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.vendors.service_workshop.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $serviceWorkshop = ServiceWorkshop::create($requestData);
        return redirect('admin/vendor/service-workshop')->with('flash_message', 'Service Workshop Dealer added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $serviceWorkshop = ServiceWorkshop::findOrFail($id);
        return view('admin.vendors.service_workshop.show', compact('serviceWorkshop'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $serviceWorkshop = ServiceWorkshop::findOrFail($id);
        
        return view('admin.vendors.service_workshop.edit', compact('serviceWorkshop'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $serviceWorkshop = ServiceWorkshop::findOrFail($id);
        $serviceWorkshop->update($requestData);

        return redirect('admin/vendor/service-workshop')->with('flash_message', 'Service Workshop updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        ServiceWorkshop::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'Service Workshop deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/vendor/service-workshop')->with('flash_message', 'Service Workshop deleted!');
    }
}
