<?php

namespace App\Http\Controllers\Admin\Vendors;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Vendors\VendorCategory;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class VendorCategoryController extends AppController
{
    public function __construct()
    {
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
       
        $vendorCategoryList = VendorCategory::whereNull('deleted_at')->get();
        return view('admin.vendor_category.index', compact('vendorCategoryList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $vendorCategory = ((new VendorCategory())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new VendorCategory())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($vendorCategory->isEmpty()) {
            
        }else{
            foreach($vendorCategory as $vendorCategory){
                $data['data'][] = [
                    'id' => $vendorCategory->id,
                    'vendor_category' => $vendorCategory->vendor_category,
                    'add_oem' => $vendorCategory->add_oem,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($vendorCategory->created_at)) ,
                    'action' => '<a href="'. route('vendor-category.edit', ['vendor_category' => $vendorCategory->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('vendor-category.destroy', ['vendor_category' => $vendorCategory->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'vendor_category' => [
                    'required',
                    Rule::unique('vendor_category')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'vendor_category' => 'required|unique:vendor_category,vendor_category',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.vendor_category.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $vendorCategory = VendorCategory::create($requestData);
        return redirect('admin/vendor-category')->with('flash_message', 'VendorCategory added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $vendorCategory = VendorCategory::findOrFail($id);
        return view('admin.vendor_category.show', compact('vendorCategory'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $vendorCategory = VendorCategory::findOrFail($id);
        
        return view('admin.vendor_category.edit', compact('vendorCategory'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $vendorCategory = VendorCategory::findOrFail($id);
        $vendorCategory->update($requestData);

        return redirect('admin/vendor-category')->with('flash_message', 'VendorCategory updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        VendorCategory::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'VendorCategory deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/vendor-category')->with('flash_message', 'VendorCategory deleted!');
    }
}
