<?php

namespace App\Http\Controllers\Admin\Vendors;

use Illuminate\Routing\Controller as BaseController;
use Illuminate\Http\Request;
use Hash;
use Session;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use App\Models\Vendors\VendorOem;
use App\Models\Assets\vendoroem_model;
use App\Models\VehicleOem;

use App\Models\Vendors\VendorCategory;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\AppController;
use View;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Validation\Rule;


class VendorOemController extends AppController
{
    public function __construct()
    {
        
        $vendorCategory = VendorCategory::whereNull('deleted_at')->get();
        $vehicle_oem = VehicleOem::get();

        View::share([
        'vendorCategoryList' => $vendorCategory, 
        'vehicle_oemList' => $vehicle_oem] );
        parent::__construct();
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {

       // dd('hi');
       
        $vendorOemList = VendorOem::whereNull('deleted_at')->get();
        return view('admin.vendor_oem.index', compact('vendorOemList'));
    }
    
    public function tab_index(Request $request){
        $requestData = $request->all();
        
        $vendorOem = ((new VendorOem())->createQuery($request))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new VendorOem())->createQuery($request))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($vendorOem->isEmpty()) {
            
        }else{
            foreach($vendorOem as $vendorOem){
                $data['data'][] = [
                    'id' => $vendorOem->id,
                    'vendor_category_id' => $vendorOem->vendorCategory->vendor_category,
                    'vendor_oem' => $vendorOem->vehicleOem->Vehicle_OEM ?? null,
                    'vendor_oem_model' => $vendorOem->vehicleOemmodel->vehicle_oem_model ?? null,
                    'created_at' => date($this->siteSettings['timestamp_format'], strtotime($vendorOem->created_at)) ,
                    'action' => '<a href="'. route('vendor-oem.edit', ['vendor_oem' => $vendorOem->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('vendor-oem.destroy', ['vendor_oem' => $vendorOem->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>
                    
                    '
                ];
            }
        }
        return response()->json($data, 200);
    }
    
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function validate(Request $request)
    {
        if(isset($request->all()['id'])){
            $validate = Validator::make($request->all(), [
                'vendor_category_id' =>  'required',
                'vendor_oem' => [
                    'required',
                    Rule::unique('vendor_oem')->ignore($request->all()['id']),
                ],
            ]);
        }else{
            $validate = Validator::make($request->all(), [
                'vendor_category_id' => 'required',
            ]);
        }
        if($validate->fails()){
            return response()->json([
                'mode' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        return response()->json([
            'mode' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.vendor_oem.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
        
        $requestData = $request->all();
        $vendorOem = VendorOem::create($requestData);
        return redirect('admin/vendor-oem')->with('flash_message', 'VendorOem added!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function show($id)
    {
        $vendorOem = VendorOem::findOrFail($id);
        return view('admin.vendor_oem.show', compact('vendorOem'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     *
     * @return \Illuminate\View\View
     */
    public function edit($id)
    {
        $vendorOem = VendorOem::findOrFail($id);
        
        return view('admin.vendor_oem.edit', compact('vendorOem'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id)
    {
        
        $requestData = $request->all();
        $vendorOem = VendorOem::findOrFail($id);
        $vendorOem->update($requestData);

        return redirect('admin/vendor-oem')->with('flash_message', 'VendorOem updated!');
    }

    public function oems(Request $request)
    {

      // dd('hi');
    //  $id = $_POST['id'];
      $id = $request->input('id');

      $oemmodel = vendoroem_model::where('vehicle_oem_id', $id)->get();
     // dd($oemmodel);
      return response()->json($oemmodel);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     *
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function destroy(Request $request, $id)
    {
        VendorOem::destroy($id);
        if($request->ajax()){
            return response()->json([
                'mode' => true,
                'message' => 'VendorOem deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/vendor-oem')->with('flash_message', 'VendorOem deleted!');
    }
    
    public function vendor_oem_by_category(Request $request)
    {
        $requestData = $request->all();
        $oemByCategory = ((new VendorOem())->vendor_oem_by_category($requestData['vendor_category_id']))->toArray();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $oemByCategory
        ], 200);
    }

    public function oem(Request $request)
    {
        $requestData = $request->all();
       // print_r($requestData ); exit;
        if(!isset($requestData['with'])){
            $requestData['with'] = '';
        }
        //dealers or oem
        $oem = ((new VendorOem())->oemList($requestData['oem_id'], $requestData['with']))->toArray();
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'data' => $oem
        ], 200);
    }
}
