<?php

namespace App\Http\Controllers\Api\v1;

use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Foundation\Validation\ValidatesRequests;
use Illuminate\Routing\Controller as BaseController;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use App\Models\Settings;
use View;
use Config;
use Storage;
use App\Models\Auth\PasswordReset;
use App\Models\User;
use App\Models\Users\UserDevices;
use Notification;
use App\Notifications\SendPushNotification;
use App\Notifications\SMSNotification;
use App\Models\Users\UserNotification;
use App\Models\Location;
use AuthHelper;


class AppController extends BaseController
{
    public $siteSettings ;
    public function __construct()
    {
        $settings = Settings::get()->keyBy('key');
        $siteSettings[] = $settings->map(function($settings, $key) {
            return $siteSettings[] = $settings->value;
            });
        $this->siteSettings = $siteSettings[0];
        \Log::info('app.requests.header', [json_encode(request()->header())]);
        View::share('settings',$this->siteSettings);
        $user = auth('api')->user();
        $this->createUserDevice();


    }

    public function createUserDevice(){
        $user = auth('api')->user();

        $fcmToken =  request()->header('token');
        $deviceId =  request()->header('deviceId');
        $createDevice = false;
        $userDevice = [];
        if($deviceId){
            $userDevice = UserDevices::where('device_id', $deviceId)->first();
            if(empty($userDevice)){
                $createDevice = true;
            }else{
                if($fcmToken && $userDevice->fcm_token != $fcmToken){
                    $userDevice->fcm_token = $fcmToken;
                    $userDevice->user_id = $user->id ?? $userDevice->user_id;
                    $userDevice->update();
                }
            }
        }
        if($createDevice == true){
            $userDevice = UserDevices::create([
                'user_id' => $user->id ?? null,
                'device_id' => $deviceId,
                'fcm_token' => $fcmToken,
                'device_type' => request()->header('platform') ?? null,
                'version' => request()->header('version') ?? null,
                'model_name' => request()->header('modelname') ?? null,
                'manufacturer' => request()->header('manufacturer') ?? null,
                'is_physical_device' => request()->header('isphysicaldevice') == true ? 1 : 0,
                'screen_resolution' => request()->header('screenresolution') ?? null,
                'last_vesited_date' => request()->header('visitedat') ? date('Y-m-d H:i:s', strtotime(request()->header('visitedat'))) : null, // It shoud get updated for each request
                'last_vesited_page' => request()->header('pageurl') ?? null, // It shoud get updated for each request
            ]);
        }
        return $userDevice;
    }
    public function checkredirect(){
        if (Auth::check()) {

        }
    }
    public function getAuthPwUser($request){
        //user before set new password or trying to change password
        $token = $request->bearerToken();
        $passwordRest = PasswordReset::where('token', '=', $token)->first();
        $user = '';
        if(empty($passwordRest)){
            return false;
        }
        $user = User::with(['UserData'])->where('phone_number', '=', $passwordRest->phone_number)->first();
        if(empty($user)){
            $user = User::with(['UserData'])->where('email', '=', $passwordRest->email)->first();
        }

        return $user;
    }
    public function uploadFile($path, $file){
        if($this->siteSettings['file_disk'] == 'local'){
            $filePath = Storage::disk('public')->put($path, $file);
            $filePath = Storage::disk('public')->url($path);
        }else{
            $filePath = Storage::disk('s3')->put($path, $file);
            $filePath = Storage::disk('s3')->url($path);
        }
        return $filePath;
    }
    public function deleteFile($file){
        if($this->siteSettings['file_disk'] == 'local'){
            $filePath = Storage::disk('public')->delete($file);
        }else{
            $filePath = Storage::disk('s3')->delete($file);
        }
        return $filePath;
        Storage::disk('s3')->delete('folder_path/file_name.jpg');
    }
    public function updateExistingFile($existingFile, $newFile){

        if($existingFile != $newFile){
            $image_path = public_path().'/storage'. $existingFile;
            if(\File::exists($image_path)) {
                \File::delete($image_path);
                return true;
            }
        }
        return true;

    }

    public function user_not_found(){
        $msg = "User Not found";
        return response()->json([
            'status' => false,
            'message' => $msg,
            'redirect_type' => ''
        ], 404);
    }
    public function unauthenticated(){
        return response()->json([
            'status' => false,
            'message' => 'Unauthenticated'
        ], 401);
    }
    public function not_found(){
        return response()->json([
            'status' => false,
            'message' => 'Not Found'
        ], 404);
    }
    public function validation_fail($errors){
        $msg = "User Not found";
        return response()->json([
            'status' => false,
            'message' => 'validation error',
            'errors' => $errors
        ], 400);
    }
    public function fail_response($msg){
        return response()->json([
            'status' => false,
            'message' => $msg,
        ], 400);
    }
    public function throw_catch_error($e){
        return response()->json([
            'status' => false,
            'message' => $e->getMessage()
        ], 500);
    }
    public function success_response($data, $msg ='', $redirectUrl =''){
        $response =  [
            'status' => true,
        ];
        if($msg){
            $response['message'] = $msg;
        }
        $response['data'] = $data;
        if($redirectUrl){
            $response['redirect_url'] = $redirectUrl;
            $response['redirect_type'] = 'page';
        }
        return response()->json($response, 200);

    }
    public function mapCall( $url){
        $url = $url . '&key=' .$this->siteSettings['google_map_api_id'];
        $headers = array(
            "Cache-Control: no-cache",
            "Content-Type: application/json",
            );
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_PROXYPORT, 3128);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
            $response = curl_exec($ch);
            curl_close($ch);

            return $response;
    }

    public function notification($request, $title, $message){

        $deviceId =  request()->header('deviceId');
        $user_id = null;
        $user = $request->user('api');
        if(empty($user)){
            $user = $this->getAuthPwUser($request);
        }
        if($user){
            $user_id = $user->id;
            $fcmTokens = $user->devices->pluck('fcm_token')->toArray();
        }elseif($deviceId){
            $fcmTokens = UserDevices::where('device_id', $deviceId)->pluck('fcm_token')->toArray();
        }
        try{
            //auth()->user()->notify(new SendPushNotification($title,$message,$fcmTokens));
            Notification::send(null,new SendPushNotification($title,$message,$fcmTokens));

            $UserNotification = UserNotification::create([
                'user_id' => $user_id,
                'title' => $title,
                'message' => $message,
                'readed' => 0,
            ]);

        }catch(\Exception $e){
            report($e);
            return redirect()->back()->with('error','Something goes wrong while sending notification.');
        }

        return true;
    }

    public function sendLoginOtp($user_id){
        $user = User::with(['userData'])->where('id', '=', $user_id)->first();
        if($user){
            $smsNotification = new SMSNotification();
            $text = 'Dear '. $user->name .', Your one time password is '. $user->userData->otp .' for login. Cygnusa';
            $smsNotification->sendSms($user->phone_number, $text, 'login');
        }
        return true;
    }
    public function sendRegisterOtp($user_id){
        $user = User::with(['userData'])->where('id', '=', $user_id)->first();
        if($user){
            $smsNotification = new SMSNotification();
            $text = 'Dear '. $user->name .', Your one time password is '. $user->userData->otp .' for registration. Cygnusa';
            $smsNotification->sendSms($user->phone_number, $text, 'register');
        }
        return true;
    }

    //Need to add tax for all price
    // public function calculate_price($plan, $locationIds){

    //     $price = 0;
    //     $convenience_price = 0;
    //     $delivery_charge = 0;
    //     if($plan->location->count() > 0){
    //         foreach($plan->location as $location){
    //             foreach($locationIds as $locationId){
    //                 if($location->location_id == $locationId){
    //                     if($location->base_price > 0){
    //                         $price = $location->base_price;
    //                         if($plan->have_convenience_price == 'Yes'){
    //                             $convenience_price = $location->convenience_fee;
    //                             // $convenience_taxProfile = $location->convenience_fee_taxation_profile_id;
    //                         }
    //                         if($plan->have_delivery_charge == 'Yes'){
    //                             $delivery_charge = $location->delivery_fee;
    //                         }
    //                     }
    //                 }
    //             }
    //         }
    //     }
    //     if($price == 0){
    //         $price = $plan->fixed_price;
    //         $convenience_price = $plan->convenience_price;
    //         $delivery_charge = $plan->delivery_charge;
    //     }

    //     return [
    //         'price' => $price,
    //         'convenience_price' => $convenience_price,
    //         'delivery_charge' => $delivery_charge,
    //     ];

    // }
    
    public function calculate_price($plan, $locationIds){
        $price = 0;
        $convenience_price = 0;
        $delivery_charge = 0;
        if($plan->location->count() > 0){
            foreach($plan->location as $location){
                foreach($locationIds as $locationId){
                    if($location->location_id == $locationId){
                        
                        if($location->base_price > 0){
                            $price = $location->base_price;
                            $basePriceTax = 0;
                            $basePriceTaxationProfile = $location->basePriceTaxationProfile;
                            
                            if($basePriceTaxationProfile){
                                $taxes = $basePriceTaxationProfile->taxPercentage;
                                if($taxes->count() > 0){
                                    foreach($taxes as $taxPercentages){
                                        $taxPercentage = $taxPercentages->percentage;
                                        if($taxPercentage > 0){
                                            $basePriceTax = $basePriceTax + ($price * ($taxPercentage/100));
                                        }

                                    }
                                }
                            }
                            $price = $price + $basePriceTax;
                            if($plan->have_convenience_price == 'Yes'){
                                $convenience_price = $location->convenience_fee;
                                
                                $conveniencePriceTax = 0;
                                $convenienceFeeTaxationProfile = $location->convenienceFeeTaxationProfile;
                                
                                if($convenienceFeeTaxationProfile){
                                    $taxes = $convenienceFeeTaxationProfile->taxPercentage;
                                    if($taxes->count() > 0){
                                        foreach($taxes as $taxPercentages){
                                            $taxPercentage = $taxPercentages->percentage;
                                            if($taxPercentage > 0){
                                                $conveniencePriceTax = $conveniencePriceTax + ($convenience_price * ($taxPercentage/100));
                                            }

                                        }
                                    }
                                }
                                $convenience_price = $convenience_price + $conveniencePriceTax;
                                
                            }
                            if($plan->have_delivery_charge == 'Yes'){
                                $delivery_charge = $location->delivery_fee;
                                $deliveryPriceTax = 0;
                                $deliveryFeeTaxationProfile = $location->deliveryFeeTaxationProfile;
                                
                                if($deliveryFeeTaxationProfile){
                                    $taxes = $deliveryFeeTaxationProfile->taxPercentage;
                                    if($taxes->count() > 0){
                                        foreach($taxes as $taxPercentages){
                                            $taxPercentage = $taxPercentages->percentage;
                                            if($taxPercentage > 0){
                                                $deliveryPriceTax = $deliveryPriceTax + ($delivery_charge * ($taxPercentage/100));
                                            }

                                        }
                                    }
                                }
                                $delivery_charge = $delivery_charge + $deliveryPriceTax;
                                
                            }
                        }
                    }
                }
            }
        }
        if($price == 0){
            $price = $plan->fixed_price;
            $priceTax = 0;

            $fixedPriceTaxationProfile = $plan->fixedPriceTaxationProfile;
            
            if($fixedPriceTaxationProfile){
                $taxes = $fixedPriceTaxationProfile->taxPercentage;
                if($taxes->count() > 0){
                    foreach($taxes as $taxPercentages){
                        $taxPercentage = $taxPercentages->percentage;
                        if($taxPercentage > 0){
                            $priceTax = $priceTax + ($price * ($taxPercentage/100));
                        }

                    }
                }
            }
            $price = $price + $priceTax;

            $convenience_price = $plan->convenience_price;
            $conveniencePriceTax = 0;

            $conveniencePriceTaxationProfile = $plan->conveniencePriceTaxationProfile;
            
            if($conveniencePriceTaxationProfile){
                $taxes = $conveniencePriceTaxationProfile->taxPercentage;
                if($taxes->count() > 0){
                    foreach($taxes as $taxPercentages){
                        $taxPercentage = $taxPercentages->percentage;
                        if($taxPercentage > 0){
                            $conveniencePriceTax = $conveniencePriceTax + ($price * ($taxPercentage/100));
                        }

                    }
                }
            }
            $convenience_price = $convenience_price + $conveniencePriceTax;

            $delivery_charge = $plan->delivery_charge;
            $deliveryPriceTax = 0;
            $deliveryChargeTaxationProfile = $plan->deliveryChargeTaxationProfile;
            
            if($deliveryChargeTaxationProfile){
                $taxes = $deliveryChargeTaxationProfile->taxPercentage;
                if($taxes->count() > 0){
                    foreach($taxes as $taxPercentages){
                        $taxPercentage = $taxPercentages->percentage;
                        if($taxPercentage > 0){
                            $deliveryPriceTax = $deliveryPriceTax + ($delivery_charge * ($taxPercentage/100));
                        }

                    }
                }
            }
            $delivery_charge = $delivery_charge + $deliveryPriceTax;
        }

        return [
            'price' => intval($price),
            'convenience_price' => intval($convenience_price),
            'delivery_charge' => intval($delivery_charge),
        ];

    }

    public function getLocationId($address){

        $addressGeocodeUrl = "https://maps.googleapis.com/maps/api/geocode/json?address=". urlencode($address) ;
        $addressGeocodeResponse = $this->mapCall($addressGeocodeUrl);
        $addressGeocodeResponse = json_decode($addressGeocodeResponse, true);
        // dd($addressGeocodeResponse);
        if($addressGeocodeResponse){
            $latitide = $addressGeocodeResponse['results'][0]['geometry']['location']['lat'] ?? null;
            $longitude = $addressGeocodeResponse['results'][0]['geometry']['location']['lng'];
            $placeId = $addressGeocodeResponse['results'][0]['place_id'];
            foreach($addressGeocodeResponse['results'][0]['address_components'] as $addressComp){
                if($addressComp['types'][0] == 'postal_code'){
                    $pincode = $addressComp['long_name'];
                }
            }
        }
        $locationIds = [];
        if($pincode ?? null){
            $locations = Location::whereNull('deleted_at')->where('postal_code', $pincode)->get();
            if($locations->count() > 0){
                foreach($locations as $location){
                    $locationIds[] = $location->id;
                }
            }
        }
        return  $locationIds;

    }
}
