<?php

namespace App\Http\Controllers\Api\v1;

use App\Http\Controllers\Api\v1\AppController;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\User;
use Illuminate\Validation\Rule;
use App\Models\Assets\ChargingStation;
use App\Http\Resources\Assets\ChargingStationCollection;
use App\Models\Assets\Vehicle;
use App\Models\SubscriptionPlan\Vehicle as VehicleSubscription;
use App\Http\Resources\Assets\VehicleCollection;
use App\Http\Resources\SubscriptionPlan\VehicleCollection as VehicleSubscriptionCollection;
use App\Models\Assets\Battery;
use App\Models\SubscriptionPlan\Battery as BatterySubscription;
use App\Http\Resources\Assets\BatteryCollection;
use App\Http\Resources\SubscriptionPlan\BatteryCollection as BatterySubscriptionCollection;
use App\Models\Order;
use App\Models\OrderBattery;
use App\Http\Resources\Order as OrderResource;
use App\Http\Resources\Orders\OrderBattery as OrderBatteryResource;
use App\Models\SubscriptionPlan\ChargingEquipment as ChargingEquipmentSubscription;
use App\Http\Resources\SubscriptionPlan\ChargingEquipmentCollection as ChargingEquipmentSubscriptionCollection;
use App\Models\SubscriptionPlan\AngelService as AngelServiceSubscription;
use App\Http\Resources\SubscriptionPlan\AngelServiceCollection as AngelServiceSubscriptionCollection;

class AssetController extends AppController
{
    /**
     * @param Request $request
     * @return JsonResponse
     */
    public function asset_list(Request $request, $slug)
    {
        $requestData = $request->all();
        
        $i = 0;
        $data['tabs'] = [];
        try {
            //Validated
            $validate = Validator::make($request->all(), 
            [
                'address' => 'required',
            ]);

            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
            $user = $request->user('api');
            $busenessCategory = 'b2c';
            if($user){
                if($user->user_type == 'Corporate Rider'){
                    $busenessCategory = 'b2b'; 
                }
            }

            $data = [];

            if($slug == 'charging-station'){
                $assetList = ChargingStation::whereNull('deleted_at')
                ->get()
                ->groupBy('product.product_type');
                foreach($assetList as $key => $asset){
                    $data['tabs'][] = [
                        'tab_id' => ++$i,
                        'title' => $key,
                        'data' => new ChargingStationCollection($asset)
                    ];
                }
            
                $data['tabs'][] = [
                    "tab_id" => ++$i,
                    "title" => '3 Wheeler',
                    'data' => []
                ];
                if($user){
                    $this->notification($request, 'GOZAP-Vehicles', 'Find an best EV for you ride');
                }
            }elseif($slug == 'vehicles'){
                $subscriptionList = VehicleSubscription::whereNull('deleted_at')
                ->whereRelation('businessCategory', 'business_category_key', $busenessCategory)
                ->get()
                ->groupBy('assetType.product_type');
                foreach($subscriptionList as $key => $subscription){
                    $data['tabs'][] = [
                        'tab_id' => ++$i,
                        'title' => $key,
                        'data' => new VehicleSubscriptionCollection($subscription)
                    ];
                }
            
                $data['tabs'][] = [
                    "tab_id" => ++$i,
                    "title" => '3 Wheeler',
                    'data' => []
                ];
                if($user){
                    $this->notification($request, 'GOZAP-Vehicles', 'Find an best EV for you ride');
                }
            }elseif($slug == 'battery'){
                $assetsList = BatterySubscription::whereNull('deleted_at')
                ->whereRelation('businessCategory', 'business_category_key', $busenessCategory)
                ->get()
                ->groupBy('assetType.product_type');
                foreach($assetsList as $key => $assets){
                    $data['tabs'][] = [
                        'tab_id' => ++$i,
                        'title' => $key,
                        'data' => new BatterySubscriptionCollection($assets)
                    ];
                }
            
                $data['tabs'][] = [
                    "tab_id" => ++$i,
                    "title" => '3 Wheeler',
                    'data' => []
                ];
            }elseif($slug == 'angel-service'){
                $assetsList = AngelServiceSubscription::whereNull('deleted_at')
                ->whereRelation('businessCategory', 'business_category_key', $busenessCategory)
                ->get();
                $data['angel-service'] = new AngelServiceSubscriptionCollection($assetsList);
                
                if($user){
                    $order = Order::where('user_id', $user->id)->where('status', '!=', 'CANCELLED')->where('status', '!=', 'ORDER COMPLETED')->first();
                    $data['order_data'] = new OrderResource($order);   
                }   
            }

            $msg = "List of " . $slug;
            return $this->success_response($data, $msg);
        

        } catch (\Throwable $e) {
            return $this->throw_catch_error($e);
        }
    }
    public function asset_list_old(Request $request, $slug)
    {
        $requestData = $request->all();
        
        $i = 0;
        $data['tabs'] = [];
        try {
            //Validated
            $validate = Validator::make($request->all(), 
            [
                'address' => 'required',
            ]);

            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
            $user = $request->user('api');

            $data = [];

            if($slug == 'charging-station'){
                $assetsList = ChargingStation::whereNull('deleted_at')->get()->groupBy('property.property_type');
                foreach($assetsList as $key => $assets){
                    $data['tabs'][] = [
                        'tab_id' => ++$i,
                        'title' => $key,
                        'data' => new ChargingStationCollection($assets)
                    ];
                }
            }elseif($slug == 'vehicles'){
                $assetsList = Vehicle::whereNull('deleted_at')->get()->groupBy('product.product_type');
                foreach($assetsList as $key => $assets){
                    $data['tabs'][] = [
                        'tab_id' => ++$i,
                        'title' => $key,
                        'data' => new VehicleCollection($assets)
                    ];
                }

            }elseif($slug == 'battery'){
                $assetsList = Battery::whereNull('deleted_at')->get()->groupBy('product.product_type');
                foreach($assetsList as $key => $assets){
                    $data['tabs'][] = [
                        'tab_id' => ++$i,
                        'title' => $key,
                        'data' => new BatteryCollection($assets)
                    ];
                }
            }
            $msg = "List of " . $slug;
            return $this->success_response($data, $msg);
        

        } catch (\Throwable $e) {
            return $this->throw_catch_error($e);
        }
    }
    
    
    public function scan(Request $request){
        $user = $request->user('api');
        
            //Validated
            $validate = Validator::make($request->all(), 
            [
                'scan_data' => 'required',
            ]);

            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
        if($request->scan_data){
            $scanData = explode(',', $request->scan_data);
            $assetType = $scanData[0]  ?? '';
            $vendor_oem = $scanData[1]  ?? '';
            $model_name = $scanData[2]  ?? '';
            $registeration_number = $scanData[3]  ?? '';
            $vin_number = $scanData[4] ?? '';
            
                    
            $busenessCategory = 'b2c';
            if($user){
                if($user->user_type == 'Corporate Rider'){
                    $busenessCategory = 'b2b'; 
                }
            }
            if($assetType){
                $order =[];
                if($user){
                    $order = Order::where('user_id', $user->id)->where('status', '!=', 'CANCELLED')->where('status', '!=', 'ORDER COMPLETED')->first();
                }
                if($order){
                    $response['order_data'] = new OrderResource($order);                   
                    if($assetType == 'vehicle'){
                        
                        $query = VehicleSubscription::whereNull('deleted_at')
                        ->whereRelation('businessCategory', 'business_category_key', $busenessCategory);
                        if($model_name){
                            $query->where('model_name', $model_name);
                        }
                        $subscriptionList = $query->get();
                        $response['subscription_data'] = new VehicleSubscriptionCollection($subscriptionList);

                        if($order->asset_id){
                            if($order->model_name == $model_name && $order->vehicleAsset->registeration_number == $registeration_number && $order->vehicleAsset->vin_number == $vin_number){
                                if($order->status == 'VEHICLE UNLOCKED' || $order->status == 'WALKAROUND DONE' || $order->status == 'USAGE INPROGRESS' || $order->status == 'BATTERY SWAP'){
                                    $response['message'] = "Your Vehicle already Unlocked"; 
                                }else{
                                    $order->status = 'VEHICLE UNLOCKED';
                                    $order->update();
                                    $response['message'] = "Vehicle Unlocked Successfully";   
                                }  

                                return $this->success_response($response, 'Vehicle Unlocked Successfully');
                            }else{

                                $response['message'] = "Your Scan doesn't match to your existing order !";   
                                return $this->success_response($response, "Your Scan doesn't match to your existing order !");
                            }
                        }else{
                            $response['message'] = "Your Scan doesn't match to your existing order !";   
                            return $this->success_response($response, "Your Scan doesn't match to your existing order !");
                        }
                    }elseif($assetType == 'battery'){
                        $scanData = explode(',', $request->scan_data);
                        $assetType = $scanData[0]  ?? '';
                        $model_name = $scanData[1]  ?? '';
                        $model_number = $scanData[2]  ?? '';
                        
                        $query = BatterySubscription::whereNull('deleted_at')
                        ->whereRelation('businessCategory', 'business_category_key', $busenessCategory);
                        if($model_name){
                            $query->where('model_name', $model_name);
                        }
                        $subscriptionList = $query->get();
                        $response['subscription_data'] = new BatterySubscriptionCollection($subscriptionList);

                        foreach($order->orderBattery as $orderBattery){
                            $response['order_data']= new OrderBatteryResource($orderBattery); 
                            if($orderBattery->status == 0){
                                $response['message'] = "Your Scan doesn't match to your order";                
                                return $this->success_response($response, "Your Scan doesn't match to your order");
                            }elseif($orderBattery->status == 1){
                                if(strtolower($orderBattery->batteryAsset->model_name) == strtolower($model_name) && $orderBattery->batteryAsset->model_number == $model_number){
                                    $response['message'] = "Your Scan match to your orde";    
                                    return $this->success_response($response, 'Your Scan match to your order');
                                }else{
                                    $response['message'] = "Your Scan doesn't match to your order !";    

                                    return $this->success_response($response, "Your Scan doesn't match to your order !");

                                }
                            }else{
                                    $response['message'] = "Your Scan doesn't match to your order !";    
                                    return $this->success_response($response, "Battery List");
                            }
                        }
                    }
                }else{
                    if($assetType == 'vehicle'){
                        $query = VehicleSubscription::whereNull('deleted_at')
                        ->whereRelation('businessCategory', 'business_category_key', $busenessCategory);
                        if($model_name){
                            $query->where('model_name', $model_name);
                        }
                        $subscriptionList = $query->get();
                        $response['subscription_data'] = new VehicleSubscriptionCollection($subscriptionList);
                        $response['message'] = "There are no bookings related to this scan. What would you like to do?";
                        return $this->success_response($response, "Vehicle List");
                    }elseif($assetType == 'battery'){
                        
                        $assetType = $scanData[0]  ?? '';
                        $model_name = $scanData[1]  ?? '';
                        $model_number = $scanData[2]  ?? '';
                        $query = BatterySubscription::whereNull('deleted_at')
                        ->whereRelation('businessCategory', 'business_category_key', $busenessCategory);
                        if($model_name){
                            $query->where('model_name', $model_name);
                        }
                        $subscriptionList = $query->get();
                        $response['message'] = "There are no bookings related to this scan. What would you like to do?";
                        $response['subscription_data'] = new BatterySubscriptionCollection($subscriptionList);
                        return $this->success_response($response, "Battery List");
                    }
                }
            }else{
                return $this->success_response([], 'There are no bookings related to this scan. What would you like to do?');
            }

        }
        
    }

}
