<?php

namespace App\Http\Controllers\Api\v1;

use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Foundation\Validation\ValidatesRequests;
use Illuminate\Routing\Controller as BaseController;
use App\Http\Controllers\Api\v1\AppController;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\User;
use App\Models\Users\UserData;
use App\Models\Users\UserLocation;
use App\Models\Users\UserDocuments;
use App\Models\PLAttendance;
use App\Http\Resources\User as UserResource;
use App\Models\MailTemplate;
use Illuminate\Validation\Rule;
use App\Notifications\SMSNotification;
use App\Models\Master\VerificationType;
use App\Notifications\SendPushNotification;
use App\Models\Users\UserDevices;
use App\Http\Resources\Users\UserDevices as UserDevicesResource;


class LoginController extends AppController
{
    /**
     * @param Request $request
     * @return JsonResponse
     */
    public function register(Request $request){

        try {
            //Validated
            $required =  [
                'user_type' => 'required',
                'phone_number' =>  'required|unique:users,phone_number|numeric',
            ];
            if($request->user_type == 'Corporate Rider'){
                $required['employee_id'] = 'required';
            }
            $validate = Validator::make($request->all(),$required);

            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
            $user = User::where('phone_number', '=', $request->phone_number)->first();
            if(empty($user)){
                $user = User::create([
                    'phone_number' => $request->phone_number,
                    'user_type' => $request->user_type,
                    'employee_id' => $request->emplyee_id ?? null
                ]);

                $userDataUpdate = [
                    'user_id' => $user->id,
                    'phone_number' => $request->phone_number,
                    'referral_code' => rand (111111, 999999),
                    'otp' => rand (1111, 9999),
                ];
                $userData = UserData::create($userDataUpdate);
                $user = User::with(['userData'])->where('id', '=', $user->id)->first();
                if($user->userData->otp){

                    $this->sendRegisterOtp($user->id);      

                    $msg = 'Please check your sms to verify';

                    $token = $user->createPasswordResetToken();  //TMP  Token

                    return response()->json([
                        'status' => true,
                        'message' => $msg,
                        'token' => $token,
                        'redirect_url' => $request->redirect_url ?? '',
                        'redirect_type' => 'page'
                    ], 200);
                    
                }
            }else{
                return $this->fail_response('This User already registered Please login');                
            }            

        } catch (\Throwable $e) {
            return response()->json([
                'status' => false,
                'message' => $e->getMessage()
            ], 500);
        }
    }
    public function register_old(Request $request){

        try {
            //Validated
            $required =  [
                'user_type' => 'required',
                'user_name' => 'required',
            ];
            if($request->user_type == 'Corporate Rider'){
                $required['employee_id'] = 'required';
            }
            $validate = Validator::make($request->all(),$required);

            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
            $user = User::where('phone_number', '=', $request->user_name)->first();
            if(empty($user)){
                $user = User::where('email', '=', $request->user_name)->first();
                if(empty($user)){
                    $phoneNumber = NULL;
                    $email = NULL;
                    if(filter_var($request->user_name, FILTER_VALIDATE_EMAIL)) {
                        $email = $request->user_name;
                    } else {
                        $phoneNumber = $request->user_name;
                    }
                    $user = User::create([
                        'phone_number' => $phoneNumber,
                        'email' => $email,
                        'user_type' => $request->user_type,
                        'employee_id' => (isset($request->emplyee_id) ? $request->emplyee_id :'') 
                    ]);
                    
                    $userDataUpdate = [
                        'user_id' => $user->id,
                        'phone_number' => $phoneNumber,
                    ];
                    $userData = UserData::create($userDataUpdate);
                }
            }
            if($user){
                $user = User::with(['userData'])->where('id', '=', $user->id)->first();
                if(is_null($user->email_verified_at) || is_null($user->password)){
                    $user->userData->otp = rand (1111, 9999);
                    $user->userData->referral_code = rand (111111, 999999);
                    if($user->userData->update()){

                        if(!empty($user->phone_number)){
                            $smsNotification = new SMSNotification();
                            $text = 'Dear '. $user->name .', Your one time password is '. $user->userData->otp .' for registration. Cygnusa';
                            $smsNotification->sendSms($user->phone_number, $text, 'register');
                            $msg = 'Please check your sms to verify';
                        }else{
                            $mailTemplate = MailTemplate::where('template_key', '=', 'send-otp-new-user')->first();
                            $mailData = [
                                        'template' => $mailTemplate,
                                        'data' => [
                                        'user' => $user,
                                        'data' => $user->userData
                                    ]
                                ];
                            $mailTemplate->sendEmail($mailData, $user);
                            $msg = 'Please check your Email to verify';
                        }
                        $token = $user->createPasswordResetToken();
                        return response()->json([
                            'status' => true,
                            'message' => $msg,
                            'token' => $token,
                            'redirect_url' => $request->redirect_url,
                            'redirect_type' => 'page'
                        ], 200);
                    }
                }else{
                    return $this->fail_response('This User already registered Please login');
                }
            }

        } catch (\Throwable $e) {
            return response()->json([
                'status' => false,
                'message' => $e->getMessage()
            ], 500);
        }
    }
    public function verify_user(Request $request){       
        
        $user = $this->getAuthPwUser($request);

        try {
            //Validated
            $validate = Validator::make($request->all(), 
            [
                'otp' => 'required',
            ]);

            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
            if($user){
                $user = User::with(['UserData'])->where('id', '=', $user->id)->first();
                $tokenName = $user->phone_number ?? $user->email ?? '';
                if($request->otp == $user->userData->otp){
                    $userUpdate = [
                        'phone_verified_at' => date('Y-m-d H:i:s'),
                    ];
                    $user->update($userUpdate);
                    $userDataUpdate = [
                        'otp_verify' => 'Yes',
                        'otp' => null,
                    ];
                    $userData = $user->userData->update($userDataUpdate);
                    $token = $user->createToken("Gozap-". $user->phone_number, ['*']);
                    
                    $currentUserDevice = $this->createUserDevice();
                    if($currentUserDevice){
                        $currentUserDevice->login_token_id = $token->accessToken->id;
                        $currentUserDevice->user_id = $user->id;
                        $currentUserDevice->update();
                    }

                    $this->notification($request, 'GOZAP', 'Welcome to GOZAP');

                    return response()->json([
                        'status' => true,
                        'message' => 'User Verified Successfully',
                        'token' => $token->plainTextToken,
                        'expired_at' => $token->accessToken->expires_at,
                        'redirect_url' => $request->redirect_url,
                        'redirect_type' => 'page'
                    ], 200);

                }else{
                    return response()->json([
                        'status' => false,
                        'message' => 'Authenticaion Failed'
                    ], 401);
                }
            }else{
                return $this->fail_response('Invalid user'); //Wrong Token
            }
            
        } catch (\Throwable $e) {
            return response()->json([
                'status' => false,
                'message' => $e->getMessage()
            ], 500);
        }
    }
    public function re_send_otp(Request $request){
        
        $user = $this->getAuthPwUser($request);  // user by TMP Token

        if($user){
            $user = User::with(['UserData'])->where('id', '=', $user->id)->first();
            $userDataUpdate = [
                'otp' =>  rand (1111, 9999),
                'otp_verify' => 'No',
            ];
            $userData = $user->userData->update($userDataUpdate);

            $this->sendLoginOtp($user->id);

            return response()->json([
                'status' => true,
                'message' => 'Please check your SMS to verify',
                'redirect_url' => $request->redirect_url,
                'redirect_type' => 'page'
            ], 200);
        }else{
            $this->user_not_found();
        }
    }
    //to change password for existing user
    public function send_otp(Request $request){
        $user = $request->user('api');
        if($user){
            $user = User::with(['UserData'])->where('id', '=', $user->id)->first();
            $userDataUpdate = [
                'otp' =>  rand (1111, 9999),
                'otp_verify' => 'No',
            ];
            $userData = $user->userData->update($userDataUpdate);
            if(!empty($user->phone_number)){
                $smsNotification = new SMSNotification();
                $text = 'Dear '. $user->name .', Your one time password is '. $user->userData->otp .' for login. Cygnusa';
                $smsNotification->sendSms($user->phone_number, $text, 'login');
                $msg = 'Please check your sms to verify';
            }else{
                $mailTemplate = MailTemplate::where('template_key', '=', 'send-otp-new-user')->first();
                $mailData = [
                            'template' => $mailTemplate,
                            'data' => [
                            'user' => $user,
                            'data' => $user->userData
                        ]
                    ];
                $mailTemplate->sendEmail($mailData, $user);
                $msg = 'Please check your Email to verify';
            }
            return response()->json([
                'status' => true,
                'message' => $msg,
                'redirect_url' => $request->redirect_url,
                'redirect_type' => 'page'
            ], 200);
        }else{
            $this->user_not_found();
        }
    }
    public function forgot_password(Request $request){

        $user = User::with(['UserData'])->where('phone_number', '=', trim($request->phone_number))->first();
        if($user){
            $userDataUpdate = [
                'otp' =>  rand (1111, 9999),
                'otp_verify' => 'No',
            ];
            $userData = $user->userData->update($userDataUpdate);
            if(!empty($user->phone_number)){
                $smsNotification = new SMSNotification();
                $text = 'Dear '. $user->name .', Your one time password is '. $user->userData->otp .' for login. Cygnusa';
                $smsNotification->sendSms($user->phone_number, $text, 'login');
                $msg = 'Please check your sms to verify';
            }else{
                $mailTemplate = MailTemplate::where('template_key', '=', 'send-otp-new-user')->first();
                $mailData = [
                            'template' => $mailTemplate,
                            'data' => [
                            'user' => $user,
                            'data' => $user->userData
                        ]
                    ];
                $mailTemplate->sendEmail($mailData, $user);
                $msg = 'Please check your Email to verify';
            }
            
            return response()->json([
                'status' => true,
                'message' => $msg,
                'token' => $user->createPasswordResetToken(),
                'redirect_url' => $request->redirect_url,
                'redirect_type' => 'page'
            ], 200);
        }else{
            return $this->user_not_found();
        }
    }
    /**
     * Customer login
     */
    public function login(Request $request){
        $credientialError = false;
        try {
            $response =[];
            $validate = Validator::make($request->all(), [
                'phone_number' => 'required',
            ]);
            
            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
            $user = User::where('phone_number', $request->phone_number)->first();
           
            if($user){
                
                $userDataUpdate = [
                    'otp' =>  rand (1111, 9999),
                    'otp_verify' => 'No',
                ];
                $userData = $user->userData->update($userDataUpdate);
                $this->sendLoginOtp($user->id);

                $token = $user->createPasswordResetToken();  //TMP  Token

                return response()->json([
                    'status' => true,
                    'message' => 'Please check your SMS to verify',
                    'token' => $token,
                    'redirect_url' => $request->redirect_url ?? '',
                    'redirect_type' => 'page'
                ], 200);
            }else{
                return response()->json([
                    'status' => false,
                    'message' => "Invalid Credientials"
                ], 401);
                
            }
        } catch (\Throwable $e) {
            return response()->json([
                'status' => false,
                'message' => $e->getMessage()
            ], 500);
        }
    }
    public function user_details(Request $request){
        $user = $request->user('api');
        $UserDetails = UserData::where('user_id', $user["id"])->get();


        $checkoutPreCheck=PLAttendance::where('user_id', $user["id"])->whereNull('checkout')->get()->first();
        if($checkoutPreCheck==null){
            $user->checked_in=false;
        }else{
            $user->checked_in=true;
        }
        $user->vehicle_no=null;//get data from subscription plan
        return response()->json([
            'status' => true,
            'message' => 'User Details',
            'data' => new UserResource($user),
        ], 200);
    }
    public function kyc(Request $request)
    {
        $requestData = $request->all();
    
        $user = $request->user('api');
    
        if (!$user) {
            return response()->json(['error' => 'User not authenticated'], 401);
        }
    
        $verificationParams = VerificationType::whereNull('deleted_at')->get();
    
        foreach ($verificationParams as $verificationParam) {
            if ($verificationParam->role->name == $user->user_type) {
    
                $verification_parameter = strtolower($verificationParam->verification_parameter);
                $verification_parameter = str_replace(' ', '_', $verification_parameter);
                $docName = $verificationParam->verification_parameter;
    
                // Existing user documents
                $userDocument = UserDocuments::where('user_id', $user->id)->where('doc_name', $docName)->first();
    
                $file = isset($requestData[$verification_parameter . "_doc_front_page"]) ? $requestData[$verification_parameter . "_doc_front_page"] : '';
                $doc_front_page = isset($userDocument->doc_front_page) ? $userDocument->doc_front_page : '';
                $doc_back_page = isset($userDocument->doc_back_page) ? $userDocument->doc_back_page : '';
    
                // Handle file operations...
    
            }
        }
    
        // Update user information
        $userUpdate = [
            'name' => $requestData['name'] ?? $user->name,
            'email' => $requestData['email'] ?? $user->email,
            'phone_number' => $requestData['phone_number'] ?? $user->phone_number,
        ];
    
        $user->update($userUpdate);
    
        // Handle address update if postal code exists...
    
        // Handle image update...
    
        // Finalize user data update...
        
        $user->userData->update(); // Assuming this is correct based on your logic
    
        $userDocuments = new UserResource($user); // Assuming UserResource handles user data correctly
    
        return $this->success_response($userDocuments, 'success', $request->redirect_url);
    }
    

    public function register_verified_user(Request $request){
        $user = $request->user('api');

        $requestData = $request->all();
        //$user = $this->getAuthPwUser($request);  // TMP User
        if($user){
            $user = User::with(['userData'])->where('id', '=', $user->id)->first();

            $validate = Validator::make($request->all(), [
              //  'password' => 'required',
                'email' => [
                    'required',
                    Rule::unique('users')->ignore($user->id),
                ],
            ]);
            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
            if($user->user_type == 'Corporate Rider'){
                $validate = Validator::make($request->all(), [
                    'employee_id' => 'required',
                ]);
                if($validate->fails()){
                    return $this->validation_fail($validate->errors());
                }
            }
            $userUpdate = [
                //'name' => $requestData['first_name'] .' ' . $requestData['last_name'],
                'name' => $requestData['name'],
                'email' => $requestData['email'],
                //'phone_number' => $requestData['phone_number'],
                //'user_type' => isset($requestData['user_type']) ? $requestData['user_type'] : $user->user_type,
            ];
            $token = '';
            if(isset($requestData['password'])){
                if($requestData['password']){
                    $userUpdate['password'] =  Hash::make($requestData['password']);
                }
            }
            $user->update($userUpdate);
            $userData = UserData::where('user_id', $user['id'])->first();
            $userDataUpdate = [
                'user_id' => $user['id'],
                'first_name' => isset($requestData['first_name']) ? $requestData['first_name'] : '',
                'last_name' => isset($requestData['last_name']) ? $requestData['last_name'] : '',
                'user_country_code' => isset($requestData['user_country_code']) ? $requestData['user_country_code'] :  $this->siteSettings['country_code'],
                //'phone_number' => isset($requestData['phone_number']) ? $requestData['phone_number'] : '',
                'employee_id' =>  isset($requestData['employee_id']) ? $requestData['employee_id'] : $user->employee_id,
            ];
            if($userData){
                $userData = $userData->update($userDataUpdate);
            }else{
                $userData = UserData::create($userDataUpdate);
            }
            return response()->json([
                'status' => true,
                'message' => 'User Updated Successfully',
                'user' => new UserResource($user),
                'redirect_url' => $request->redirect_url,
            ], 200);
        }else{
            return $this->user_not_found();
            
        }
    }

    public function set_password(Request $request){
        $requestData = $request->all();
        
        $user = $this->getAuthPwUser($request);

        if($user){
            $validate = Validator::make($request->all(), [
                'new_password' => 'required',
                'confirm_password' => 'required',
                // 'confirm_password' => [
                //     'required',
                //     Rule::in(['gte', 'new_password']),
                // ],
            ]);
            if($validate->fails()){
                return $this->validation_fail($validate->errors()); 
            }
            if($request->new_password === $request->confirm_password){
                $user->password = Hash::make($requestData['confirm_password']);
                $user->update();
                //return $this->success_response($user, 'Password changed successfully', $request->redirect_url);

                return response()->json([
                    'status' => true,
                    'message' => 'Password changed successfully',
                    'token' => $user->createToken($user->phone_number)->plainTextToken,
                    'redirect_url' => $request->redirect_url,
                    'redirect_type' => 'page'
                ], 200);
            }else{
                return $this->validation_fail('Password did not match'); 
            }
        }else{
            return $this->user_not_found();
        }
    
    } 
    public function verify_change_password_otp(Request $request){       
        
        $user = $request->user('api');

        try {
            //Validated
            $validate = Validator::make($request->all(), 
            [
                'otp' => 'required',
            ]);

            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
            if($user){
                $user = User::with(['UserData'])->where('id', '=', $user->id)->first();
                $tokenName = $user->phone_number ?? $user->email ?? '';
                if($request->otp == $user->userData->otp){
                    $userUpdate = [
                        'email_verified_at' => date('Y-m-d H:i:s'),
                    ];
                    $user->update($userUpdate);
                    $userDataUpdate = [
                        'otp_verify' => 'Yes',
                        'otp' => '',
                    ];
                    $userData = $user->userData->update($userDataUpdate);
                    return response()->json([
                        'status' => true,
                        'message' => 'User Verified',
                        'redirect_url' => $request->redirect_url,
                        'redirect_type' => 'page',
                    ], 200);
                }else{
                    return response()->json([
                        'status' => false,
                        'message' => 'Authenticaion Failed'
                    ], 401);
                }
            }else{
                return $this->fail_response('Invalid user'); //Wrong Token
            }
            
        } catch (\Throwable $e) {
            return response()->json([
                'status' => false,
                'message' => $e->getMessage()
            ], 500);
        }
    }
    public function change_existing_password(Request $request){
        ini_set('memory_limit', '1024M');
        $requestData = $request->all();
        $user = $request->user('api');
        
        if($user){
            $validate = Validator::make($request->all(), [
                'new_password' => 'required',
                'confirm_password' => 'required',
            ]);
            if($validate->fails()){
                return $this->validation_fail($validate->errors()); 
            }
            
            if($request->new_password === $request->confirm_password){
                $user->password = Hash::make($requestData['confirm_password']);
                $user->update();
                //return $this->success_response($user, 'Password changed successfully', $request->redirect_url);
                $user->tokens()->delete();
                return response()->json([
                    'status' => true,
                    'message' => 'Password changed successfully',
                    'token' => $user->createToken($user->phone_number)->plainTextToken,
                    'redirect_url' => $request->redirect_url,
                    'redirect_type' => 'page'
                ], 200);
            }else{
                return $this->validation_fail('Password did not match'); 
            }
        }else{
            return $this->user_not_found();
        }
    
    }
    public function logout_options(Request $request){
        $user = $request->user('api');
        $response = [];
        foreach($user->devices as $device){
            if($device->login_token_id > 0){
                $response['devices'][] = (new UserDevicesResource($device))->currentUserDevice($this->createUserDevice());
            }

        }
        $response['logout_all_device_url'] = 'user/logout/all';
        return $this->success_response($response, 'User Devices');
        

    } 
    public function logout(Request $request){
        $user = $request->user('api');
        $currentUserDevice = '';
        if($request->device_id == 'all'){
            $user->tokens()->delete();
            $userDevices = UserDevices::where('user_id', $user->id)->get();
            foreach($userDevices as $device){
                $device->login_token_id = '';
                $device->update();
            }
        }elseif($request->device_id){
            $currentUserDevice = UserDevices::where('id', $request->device_id)->first();
            $currentToken = $user->tokens()->where('id', $currentUserDevice->login_token_id);
        }else{
            // Revoke current user token
            $currentToken = $user->tokens()->where('id', $user->currentAccessToken()->id);
            $currentUserDevice = $this->createUserDevice();
        }
        if($currentUserDevice){
            $currentUserDevice->login_token_id = '';
            $currentUserDevice->update();
            $currentToken->delete();
        }
        return response()->json([
            'status' => true,
            'message' =>'user logged out'
        ], 200);

    } 
    
}
