<?php

namespace App\Http\Controllers\Api\v1;

use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Foundation\Validation\ValidatesRequests;
use Illuminate\Routing\Controller as BaseController;
use App\Http\Controllers\Api\v1\AppController;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\Order;
use App\Models\Orders\OrderFeedback;
use App\Models\Assets\Vehicle;
use App\Models\Assets\Battery;
use App\Models\SubscriptionPlan\Vehicle as VehicleSubscription;
use App\Http\Resources\SubscriptionPlan\Vehicle as VehicleSubscriptionResource;
use App\Http\Resources\SubscriptionPlan\Battery as BatterySubscriptionResource;
use App\Models\SubscriptionPlan\Battery as BatterySubscription;
use App\Models\SubscriptionPlan\AngelService as AngelServiceSubscription;
use App\Models\CMS\WalkaroundChecklist;
use App\Http\Resources\CMS\WalkaroundChecklist as WalkaroundChecklistResource;
use App\Http\Resources\Order as OrderResource;
use App\Http\Resources\Orders\OrderBattery as OrderBatteryResource;
use App\Models\Users\UserSubscription;
use App\Models\CMS\Forms;
use App\Http\Resources\CMS\FormButtons;
use App\Models\Orders\OrderWalkaround;
use App\Models\Orders\OrderWalkaroundCategory;
use App\Models\Orders\OrderBattery;
use App\Models\Assets\ChargingEquipmentParts;
use App\Models\Orders\OrderChargingStation;
use App\Http\Resources\Orders\OrderChargingStation as OrderChargingStationResource;
use App\Models\SubscriptionPlan\ChargingEquipment as ChargingEquipmentSubscription;
use App\Http\Resources\SubscriptionPlan\ChargingEquipment as ChargingEquipmentSubscriptionResource;
use App\Models\Orders\OrderAngelService;
use App\Http\Resources\Orders\OrderAngelService as OrderAngelServiceResource;
use App\Http\Resources\SubscriptionPlan\AngelService as AngelServiceSubscriptionResource;


class OrderController extends AppController
{
    /**
     * @param Request $request
     * @return JsonResponse
     */
    public function booking(Request $request, $slug){
        $user = $request->user('api');

        $requestData = $request->all();
        $format = 'd-m-Y H:i:s A';
        $validateFields = [];
        $errorMessages = [];
        $cost = 0;
        $days = 1;
        $userOrderList = Order::where('user_id', $user->id)->where('asset_type', $slug)->get();
        $userOrder = 0;
        $locationId = [];
        $requestData['destination_address'] = '';
        $oneDayPrice = 0;
        $subscriptionCost = 0;
        $orderType = $slug;

        foreach($userOrderList as $userOrderData){
            if(strtoupper($userOrderData->status) == 'PENDING' || $userOrderData->status == 'INPROGRESS' || $userOrderData->status == 'BOOKING COMPLETED'){
                $userOrder++;
            }
        }
        if($userOrder > 0){
            return $this->validation_fail(['erros' => 'Please complete your orders to take new order']);
        }
        if($slug == 'vehicle'){
            $orderType = 'Rent EV';
            $subscriptionPlan = VehicleSubscription::findOrFail($request->subscription_id);
        }elseif($slug == 'battery-swap'){
            $orderType = 'Battery swap';

            $subscriptionPlan = BatterySubscription::findOrFail($request->subscription_id);
            $order = Order::where('status', '!=', 'ORDER COMPLETED')->where('status', '!=', 'CANCELLED')->where('user_id', '=', $user->id)->first();
            if(empty($order)){
                return $this->validation_fail(['erros' => 'No vehicle order availabe to swap battery']);
            }
            $batterySwapCount = 0;
            if($order->orderBattery->count() > 0){
                foreach($order->orderBattery as $batterySwap){
                    if($batterySwap->status == 0){
                        $batterySwapCount++;
                    }
                }
            }
            if($batterySwapCount > 0){
                return $this->validation_fail(['erros' => 'You have already booked for battery swap']);
            }

        }elseif($slug == 'charging-station'){
            $orderType = 'Charging Station';

            if($request->charging_equipment){
                $chargingEquipmentPart = ChargingEquipmentParts::findOrFail($request->charging_equipment);
                $subscriptionPlan = $chargingEquipmentPart->subscriptionPlan;                
                $locationId[] = $chargingEquipmentPart->chargingEquipment->location_id;
                $chargingEquipment = $chargingEquipmentPart->chargingEquipment;
                $requestData['destination_address'] = $chargingEquipment?->city?->city . ',' .$chargingEquipment?->district?->district . ',' . $chargingEquipment?->district?->district . ',' . $chargingEquipment?->state?->state ;
            }

            $order = Order::where('status', '!=', 'ORDER COMPLETED')->where('status', '!=', 'CANCELLED')->where('user_id', '=', $user->id)->first();
            if(empty($order)){
                return $this->validation_fail(['erros' => 'No vehicle order availabe to Charging ']);
            }
            
            $chargingStationCount = 0;
            if($order->orderChargingStation->count() > 0){
                foreach($order->orderChargingStation as $chargingStation){
                    if($chargingStation->status == 0){
                        $chargingStationCount++;
                    }
                }
            }
            if($chargingStationCount > 0){
                return $this->validation_fail(['erros' => 'You have already booked for Charging Station']);
            }
            
            $validateFields = [
                'charging_equipment' => 'required',
                'charging_units_by' => 'required'
            ];
        }elseif($slug == 'angel-service'){
            $orderType = 'Angel Service';

            $subscriptionPlan = AngelServiceSubscription::findOrFail($request->subscription_id);
            $order = Order::where('status', '!=', 'ORDER COMPLETED')->where('status', '!=', 'CANCELLED')->where('user_id', '=', $user->id)->first();
            if(empty($order)){
                return $this->validation_fail(['erros' => 'No vehicle order availabe to Angel Service']);
            }
            $angelServiceCount = 0;
            if($order->orderBattery->count() > 0){
                foreach($order->orderAngelService as $angelService){
                    if($angelService->status == 0){
                        $angelServiceCount++;
                    }
                }
            }
            if($angelServiceCount > 0){
                return $this->validation_fail(['erros' => 'You have already booked for Angel Service']);
            }

        }
        if($slug == 'vehicle'){
            
            $asset = [];

            $totalAsset = count($subscriptionPlan->assets);
            $i = 0;
            $modelAlreadyInOrder = 0;
            foreach($subscriptionPlan->assets as $key =>  $assetData){
                if($assetData->status == 0 && empty($asset)){
                    $asset = $assetData;
                }
            }

            if(empty($asset)){
                return $this->fail_response('No assets currently available');
            }

            if(empty($requestData['delivery_date'])){
                $requestData['delivery_date'] = $requestData['duration_start'];
            }
            if($requestData['duration_start']){
                $durationStartDate = new \DateTime($requestData['duration_start'] );
                $interval = 'PT'. $durationStartDate->format('s') . 'S' ; //seconds interval to subtract 
                $durationStartDate->sub(new \DateInterval($interval));
                if($durationStartDate){
                    $requestData['duration_start'] = $durationStartDate->format('Y-m-d') ;
                    $requestData['duration_start_time'] = $durationStartDate->format('g:i A');
                }
            }
            if($requestData['duration_end']){
                $duratioEndDate = new \DateTime($requestData['duration_end'] );
                //$duratioEndDate = \DateTime::createFromFormat($format, $requestData['duration_end']);
                if($duratioEndDate){
                    $requestData['duration_end'] = $duratioEndDate->format('Y-m-d') ;
                    $requestData['duration_end_time'] = $duratioEndDate->format('g:i A');
                }
            }
            $validateFields =[
                'duration_start' => 'required',
                'duration_end' => 'required',
                'delivery_time' => 'required',
                'delivery_type' => 'required',
            ];
            
            $interval = $durationStartDate->diff($duratioEndDate);
            
            $days = $interval->format('%a');
            if($days < 1){
                return $this->validation_fail(['erros' => 'select duration atleast 1 day']);
            }
        }elseif($slug == 'battery-swap'){

            //$requestData['delivery_date'] = date("Y-m-d", strtotime($requestData['delivery_date'])) ;

            $validateFields =[
                'delivery_date' => 'required',
                'delivery_time' => 'required',
                'delivery_type' => 'required',
            ];
        }elseif($slug == 'angel-service'){

            //$requestData['delivery_date'] = date("Y-m-d", strtotime($requestData['delivery_date'])) ;

            $validateFields =[
                'delivery_date' => 'required',
                'delivery_time' => 'required',
                'delivery_type' => 'required',
            ];
        }

        if($requestData['delivery_date']){
            //$deliveryDate = \DateTime::createFromFormat($format, $requestData['delivery_date']);
            $deliveryDate = new \DateTime($requestData['delivery_date'] );
            if($deliveryDate){
                $requestData['delivery_date'] = $deliveryDate->format('Y-m-d') ;
                $requestData['delivery_time'] = $deliveryDate->format('g:i A');
            }
        }

        $requestData['delivery_charge'] = 0;
        if(trim(strtolower($requestData['delivery_type'] ?? '')) == 'i will pickup'){
            $requestData['destination_address'] = $requestData['pickup_address'];
            $requestData['delivery_type'] = 'pickup';
        }
        if(trim(strtolower($requestData['delivery_type'] ?? '')) == 'Deliver to me'){
            $requestData['destination_address'] = $requestData['derlivery_address'];
            $requestData['delivery_type'] = 'angel_delivery';
            //$requestData['delivery_charge'] = $subscriptionPlan->delivery_charge;  // need to be taken based on  location
        }

        $validateFields['destination_address'] = 'required';
        $errorMessages['destination_address.required'] = 'Pickup or Delivery Address required.';
        $validate = Validator::make($requestData, $validateFields, $errorMessages);
        if($validate->fails()){
            return $this->validation_fail($validate->errors()); 
        }
        $locationId = !empty($locationId) ? $locationId : $this->getLocationId($requestData['destination_address']);
        $calculatePrice = $this->calculate_price($subscriptionPlan, $locationId);
        $fixedPrice = $calculatePrice['price'];
        $convenience_price = $calculatePrice['convenience_price'];
        $delivery_charge = $calculatePrice['delivery_charge'];
        $subscriptionCost = $fixedPrice;
        $kwhUnits = 0;

        if($slug == 'vehicle' || $slug == 'battery-swap' || $slug == 'angel-service'){
            if($cost == 0){
                if($days > 0 ){
                    $cost = round($days * $subscriptionCost);
                }
            }
        }elseif($slug == 'charging-station'){

            if($requestData['charging_units_by'] == 'Duration'){
                $cost = $fixedPrice;  // need to calculate charging units and amount by Charging equipment API
            }elseif($requestData['charging_units_by'] == 'Cost'){
                $cost = $requestData['cost'];
                $kwhUnits = $fixedPrice > 0 ? ($requestData['cost'] / $fixedPrice ) : '';
            }elseif($requestData['charging_units_by'] == 'KWH Units'){
                $cost = $fixedPrice * $requestData['kwh_units'];
                $kwhUnits = $requestData['kwh_units'] ?? 0;
            }
        }
        
        $requestData['source_address']  = null;
        
        
        $sourcePincode = null;
        $sourceLatitide = null;
        $sourceLongtitude = null;
        $sourcePlaceId = null;


        $destinationPincode = null;
        $destinationLatitide = null;
        $destinationLongtitude = null;
        $placeId = null;

        $destinationGeocodeUrl = "https://maps.googleapis.com/maps/api/geocode/json?address=". urlencode($requestData['destination_address']) ;
        $destinationGeocodeResponse = $this->mapCall($destinationGeocodeUrl);
        $destinationGeocodeResponse = json_decode($destinationGeocodeResponse, true);
        
        if($destinationGeocodeResponse){
            $destinationLatitide = $destinationGeocodeResponse['results'][0]['geometry']['location']['lat'] ?? null;
            $destinationLongtitude = $destinationGeocodeResponse['results'][0]['geometry']['location']['lng'];
            $placeId = $destinationGeocodeResponse['results'][0]['place_id'];
            foreach($destinationGeocodeResponse['results'][0]['address_components'] as $addressComp){
                if($addressComp['types'][0] == 'postal_code'){
                    $destinationPincode = $addressComp['long_name'];
                }
            }
        }
        $estimate_distance =0;

        $orderData = [
        //    'order_number' => 'GZ' . rand(00000, 99999),
            'user_id' => $user->id,
            'customer_name' => $user->name,
            'customer_email' => $user->email,
            'customer_phone' => $user->phone_number,
            'user_type' => $user->user_type,
            'duration' => $requestData['duration'] ?? null,
            'duration_start' => $requestData['duration_start'] ?? null,
            'duration_start_time' => $requestData['duration_start_time'] ?? null,
            'duration_end' => $requestData['duration_end'] ?? null,
            'duration_end_time' => $requestData['duration_end_time'] ?? null,
            'source_latitude' => $sourceLatitide,
            'source_longitude' => $sourceLongtitude,
            'source_place_id' => $sourcePlaceId,
            'source_address' => $requestData['source_address'],
            'source_postal_code' => $sourcePincode,
            'destination_latitude' => $destinationLatitide,
            'destination_longitude' => $destinationLongtitude,
            'destination_place_id' => $placeId,
            'destination_address' => $requestData['destination_address'],
            'destination_postal_code' => $destinationPincode,
            'distance' => $estimate_distance,
            'asset_type' => $slug,
            //'asset_id' => null,
            'model_name' => $subscriptionPlan->model_name,
            'subscription_id' => $subscriptionPlan->id ?? '',
            'subscription_cost' => $subscriptionCost,
            'number_of_days_hrs' => $days,
            'cost_per_days_hrs' => $days,
            'value_added_service_id' => null,
            'delivery_date' => $requestData['delivery_date'],
            'delivery_time' => $requestData['delivery_time'],
            'delivery_type' => $requestData['delivery_type'] ?? '',
            'order_description' => $requestData['order_description'] ?? null,
            'value_added_service_amount' => null,
            'discount' => null,
            'status' => 'INPROGRESS',
            'order_type' => $orderType,
            'cost' => $cost,
            'convenience_fee' => $convenience_price,
            'delivery_charge' => $delivery_charge,
            'order_sub_total' => $cost + $convenience_price + $delivery_charge ,
            'order_grand_total' => $cost +  $convenience_price  + $delivery_charge
        ];
        
        if($slug == 'vehicle'){
            $prefixNumber = 'OEV';
            $order = Order::create($orderData);
            $response = new OrderResource($order);
            $uderSubscription = UserSubscription::create([
                'user_id' => $user->id,
                'order_id' => $order->id,
                'subscription_plan_id' => $order->subscription_id,
                'asset_type_id' => $subscriptionPlan->asset_type_id,
                'model_name' =>  $order->model_name
            ]);

        }elseif($slug == 'battery-swap'){
            $prefixNumber = 'OBS';
            $orderData['order_id'] = $order->id;
            $orderData['status'] = 0;
            $order = OrderBattery::create($orderData);   
            $response = new OrderBatteryResource($order);       
        }elseif($slug == 'charging-station'){
            $prefixNumber = 'OCE';
            $orderData['order_id'] = $order->id;
            $orderData['user_id'] = $user->id;
            $orderData['charging_station_id'] = $chargingEquipment->chargingStation->id;
            $orderData['charging_equipment_id'] = $chargingEquipment->id;
            $orderData['charging_equipment_part_id'] = $chargingEquipmentPart->id;
            $orderData['status'] = 0;
            $orderData['kwh_units'] = $kwhUnits;
            $order = OrderChargingStation::create($orderData);   
            $response = new OrderChargingStationResource($order);
        }elseif($slug == 'angel-service'){
            $prefixNumber = 'OAS';
            $orderData['order_id'] = $order->id;
            $orderData['user_id'] = $user->id;
            $orderData['status'] = 0;
            $order = OrderAngelService::create($orderData);   
            $response = new OrderAngelServiceResource($order);       
        }
        $order->order_number = $prefixNumber . date('dmY') . sprintf("%04d", $order->id);
        $order->update();
        //$asset->status = 1;
        //$asset->update();
    
        $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id : '';
        if($slug == 'battery-swap'){
            $redirectUrl = $redirectUrl ? $redirectUrl . '?order_type=battery-swap' : '';
        }
        if($slug == 'charging-station'){
            $redirectUrl = $redirectUrl ? $redirectUrl . '?order_type=charging-station' : '';
        }
        if($slug == 'angel-service'){
            $redirectUrl = $redirectUrl ? $redirectUrl . '?order_type=angel-service' : '';
        }
        return $this->success_response($response, $slug.' Booked successfully', $redirectUrl);
    }


    public function booking_summary(Request $request, $id){
        $user = $request->user('api');

        $refundAmount = 0;

        $fixedLineitems = [];
        if($request->order_type == 'battery-swap'){

            $order = OrderBattery::findOrFail($id);
            
            $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id . '?order_type=battery-swap' : '';

            $redirectUrl = $redirectUrl ? $redirectUrl . '?order_type=battery-swap' : '';
            $trackData = [
                'source_latitude' => $order->source_latitude ?? "",
                'source_longitude' => $order->source_longitude ?? "",
                'source_address' => $order->source_address ?? "",
                'source_postal_code' => $order->source_postal_code ?? "",
                'destination_latitude' => $order->destination_latitude ?? "",
                'destination_longitude' => $order->destination_longitude ?? "",
                'destination_address' => $order->destination_address ?? "",
                'destination_postal_code' => $order->destination_postal_code ?? "",
                'distance' => $order->distance ?? "",
            ];
        }if($request->order_type == 'angel-service'){

            $order = OrderAngelService::findOrFail($id);
            
            $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id . '?order_type=angel-service' : '';

            $redirectUrl = $redirectUrl ? $redirectUrl : '';
            $trackData = [
                'source_latitude' => $order->source_latitude ?? "",
                'source_longitude' => $order->source_longitude ?? "",
                'source_address' => $order->source_address ?? "",
                'source_postal_code' => $order->source_postal_code ?? "",
                'destination_latitude' => $order->destination_latitude ?? "",
                'destination_longitude' => $order->destination_longitude ?? "",
                'destination_address' => $order->destination_address ?? "",
                'destination_postal_code' => $order->destination_postal_code ?? "",
                'distance' => $order->distance ?? "",
            ];
        }elseif($request->order_type == 'charging-station'){

            $order = OrderChargingStation::findOrFail($id);
            
            $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id . '?order_type=charging-station' : '';

            $redirectUrl = $redirectUrl ? $redirectUrl . '?order_type=charging-station' : '';
            $trackData = [
                'source_latitude' => $order->source_latitude ?? "",
                'source_longitude' => $order->source_longitude ?? "",
                'source_address' => $order->source_address ?? "",
                'source_postal_code' => $order->source_postal_code ?? "",
                'destination_latitude' => $order->destination_latitude ?? "",
                'destination_longitude' => $order->destination_longitude ?? "",
                'destination_address' => $order->destination_address ?? "",
                'destination_postal_code' => $order->destination_postal_code ?? "",
                'distance' => $order->distance ?? "",
            ];
        }else{

            if($user->user_type == 'Rider'){
                $refundAmount = $this->siteSettings['rider_refund'];
            }elseif($user->user_type == 'Corporate Rider'){
                $refundAmount = $this->siteSettings['corporate_rider_refund'];
            }
    
            $order = Order::findOrFail($id);

            $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id : '';
            $trackData = [
                'duration' => $order->duration ?? "",
                'duration_start' => $order->duration_start ?? "",
                'duration_start_time' =>  $order->duration_start_time ?? "",
                'duration_end' => $order->duration_end ?? "",
                'duration_end_time' => $order->duration_end_time ?? "",
                'source_latitude' => $order->source_latitude ?? "",
                'source_longitude' => $order->source_longitude ?? "",
                'source_address' => $order->source_address ?? "",
                'source_postal_code' => $order->source_postal_code ?? "",
                'destination_latitude' => $order->destination_latitude ?? "",
                'destination_longitude' => $order->destination_longitude ?? "",
                'destination_address' => $order->destination_address ?? "",
                'destination_postal_code' => $order->destination_postal_code ?? "",
                'distance' => $order->distance ?? "",
            ];
            $fixedLineitems = [
                [
                    'id' => 4,
                    'name' => '0',
                    'title' => 'Refundable Deposit',
                    'amount' => $refundAmount,
                    'isDiscountAmount' => false,
                ]
            ];
        }
        $sectionList = [
            [
                'title' => 'Track Data',
                'data' => $trackData
            ],
            // [
            //     'title' => 'Avail Offers / Coupons', 
            //     'type' => 'link', 
            //     'redirectUrl' => 'offers', 
            // ],
            [
                'title' => 'Tip your Angel',  
                'amounts' => [
                    10,20,30,40,50
                ]
            ],
            [   
                'title' => 'Fare Breakup', 
                'data' => [
                    'lineItems' => [
                        [
                            'id' => 1,
                            'name' => 'cost',
                            'title' => 'Rental Cost',
                            'amount' => $order->cost ?? 0,
                            'isDiscountAmount' => false,
                            'subTitle' => $order->duration ,
                        ],
                        // [
                        //     'id' => 2,
                        //     'name' => 'value_added_service',
                        //     'title' => 'Value Added Service',
                        //     'amount' => $order->value_added_service_amount,
                        //     'isDiscountAmount' => false,
                        //     'subTitle' => '',
                        // ],
                        [
                            'id' => 3,
                            'name' => 'convenience_fee',
                            'title' => 'Convenience Fee',
                            'amount' => $order->convenience_fee ?? 0,
                            'isDiscountAmount' => false,
                        ],
                        [
                            'id' => 4,
                            'name' => 'delivery_fee',
                            'title' => 'Delivery Charge',
                            'amount' => $order->delivery_charge ?? 0,
                            'isDiscountAmount' => false,
                        ]
                    ],
                    'fixedLineItems' => $fixedLineitems,
                    'totalLineItemsAmountTitle' => "Total Fare",
                    'totalLineItemsAmount' => $order->order_sub_total,
                    'totalFixedLineItemsAmountTitle' => "Total Fare",
                    'totalFixedLineItemsAmount' => $refundAmount,
                    'totalAmountTitle' => "Final Fare",
                    'totalAmount' => $order->order_sub_total + $refundAmount,
                ]
            ]
        ];
        // if($order->delivery_type == 'angel_delivery'){
        //     $sectionList[3]['data']['lineItems'][] = [
        //         'id' => 4,
        //         'name' => 'delivery_fee',
        //         'title' => 'Delivery Charge',
        //         'amount' => $order->delivery_charge,
        //         'isDiscountAmount' => false,
        //     ];
        // }
        foreach($sectionList as $key  => $section){
            $id = $key + 1;
            $response['sections'][] = [
                'section_id' => $id,
                'title' => $section['title'] ?? ''
            ];
            if(isset($section['suffix'])){
                $response['sections'][$key]['suffix_title'] = $section['suffix']['title'];
            }
            if(isset($section['data'])){
                $response['sections'][$key]['data'] = $section['data'];
            }
            if(isset($section['amounts'])){
                $response['sections'][$key]['amounts'] = $section['amounts'];
            }
            if(isset($section['field'])){
                $response['sections'][$key]['field'] = $section['field'];
            }
        }
        if($request->order_type == 'battery-swap'){
            $ubscription = BatterySubscription::findOrFail($order->subscription_id);
            $subscriptionData = (new BatterySubscriptionResource($ubscription))->order($order);
        }elseif($request->order_type == 'charging-station'){
            $ubscription = ChargingEquipmentSubscription::findOrFail($order->subscription_id);
            $subscriptionData = (new ChargingEquipmentSubscriptionResource($ubscription))->order($order);
        }elseif($request->order_type == 'angel-service'){
            $ubscription = AngelServiceSubscription::findOrFail($order->subscription_id);
            $subscriptionData = (new AngelServiceSubscriptionResource($ubscription))->order($order);
        }else{
            $ubscription = VehicleSubscription::findOrFail($order->subscription_id);
            $subscriptionData = (new VehicleSubscriptionResource($ubscription))->order($order);
        }
        $response['subscriptionData'] = $subscriptionData;


        return $this->success_response($response, 'Booking Summary', $redirectUrl);

        
    }
    public function payment_options(Request $request, $id){
        $user = $request->user('api');
        $requestData = $request->all();

        $validate = Validator::make($request->all(), 
        [
            //'order_id' => 'required',
        ]);
        if($validate->fails()){
            return $this->validation_fail($validate->errors());
        }
        
        if($request->order_type == 'battery-swap'){
            $order = OrderBattery::findOrFail($id);
        }elseif($request->order_type == 'charging-station'){
            $order = OrderChargingStation::findOrFail($id);            
        }elseif($request->order_type == 'angel-service'){
            $order = OrderAngelService::findOrFail($id);            
        }else{
            $order = Order::findOrFail($id);
        }
        // $sectionList = [
        //     ['title' => $order->cost],
        //     ['title' => 'Pay From Wallet', 'value' => 'wallet', 'suffix' => ['title' => 'Add Money'], 
        //         'field' => [
        //            // 'type' => 'checkBox',
        //             'title' => $user->userdata->wallet_amount,
        //             'name' => 'payment_method',
        //             'value' => 'wallet',
        //         ],
        //     ],
        //     ['title' => 'Payment Options', 
        //         'data' => [
        //            // 'type' => 'radio',
        //             'title' => 'Payment Options',
        //             'name' => 'payment_method',
        //             'options' => [
        //                 'title' => 'COD',
        //                 'value' => 'Cash On Delivery'
        //             ]
        //         ]
        //     ]
        // ];
        $upi = [
            'title' => 'UPI', 
            'sections' => [],
        ];
        $otherPayment = [
            'title' => 'Other Payment Options', 
            'sections' => [
                [
                    'section_id' => 1,
                    'title' => 'Cash on Delivery',
                    'payment_method' => 'COD',
                    'discription' => 'Cash to be paid in person',
                    'image' => null
                ]
            ],
        ];
        $response = [
            $upi,
            $otherPayment
        ];
        $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id : '';
        if($request->order_type == 'battery-swap'){
            $redirectUrl =  $redirectUrl . '?order_type=battery-swap';
        }elseif($request->order_type == 'charging-station'){
            $redirectUrl =  $redirectUrl . '?order_type=charging-station';
        }elseif($request->order_type == 'angel-service'){
            $redirectUrl =  $redirectUrl . '?order_type=angel-service';
        }
        return $this->success_response($response, 'Payment Options', $redirectUrl);

    }
    public function walkaround_checklist(Request $request, $order_id){

        $validate = Validator::make($request->all(), 
        [
            'user' => 'required',
        ]);
        if($validate->fails()){
            return $this->validation_fail($validate->errors());
        }
        $requestData = $request->all();
        if($request->order_type == 'battery-swap'){
            $order = OrderBattery::findOrFail($order_id);
        }else{
            $order = Order::findOrFail($order_id);
        }

        $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id : '';

        if($request->order_type == 'battery-swap'){
            $redirectUrl =  $redirectUrl . '?order_type=battery-swap';
        }
        
        $walkaroundChecklistData =[];
        $walkaroundChecklist = WalkaroundChecklist::with(['walkaroundCategories', 'walkaroundQuestions'])->whereNull('deleted_at')->where('subscription_plan_id', $order->subscription_id)->where('product_model', $order->model_name)->where('mobile_user', $request->user)->first();
        if($walkaroundChecklist){
            $walkaroundChecklistData =  (new WalkaroundChecklistResource($walkaroundChecklist))->order($order);
        }

        
        return $this->success_response($walkaroundChecklistData, 'walkaround checklist', $redirectUrl ?? '');

    }
    public function walkaround_check(Request $request, $order_id){

        $requestData = $request->all();

        $order_battery_id = null;
        if($request->order_type == 'battery-swap'){
            $order = OrderBattery::findOrFail($order_id);
            $order_id = $order->order_id;
            $order_battery_id = $order->id;
        }else{
            $order = Order::findOrFail($order_id);
        }
        if($order->orderWalkaroundCategory){
            return $this->validation_fail(['errors' => 'walkaround already done']);
        }
        foreach($request->data as $requestData){
            if(isset($requestData['media'])){
                foreach($requestData['media'] as $mediaFile){
                    if($mediaFile){                    
                        $file = base64_decode($mediaFile);
                        $f = finfo_open();
                        $mime_type = finfo_buffer($f, $file, FILEINFO_MIME_TYPE);
                        $split = explode( '/', $mime_type );
                        $type = $split[1]; 
                        $savedAs = $requestData['category_name'] .'_' . rand('11', '99'). '_'. time() .'.'. $type;
                        $path = '/uploads/orders/'. $order->asset_type. '/' . $order_id . '/walkaround/' . $requestData['id'] .'/' .  $savedAs;
                        $filePath = $this->uploadFile($path, $file);
                        $doc_front_page =  $path;
                        
                    }
                    $walkaroundCategoryData = [
                        'order_id' => $order_id ,
                        'order_battery_id' => $order_battery_id,
                        'walkaround_category_id' => $requestData['id'] ?? '',
                        'category_name' => $requestData['category_name'] ?? '',
                        'media' =>  $path  ?? '',
                    ];
                    OrderWalkaroundCategory::create($walkaroundCategoryData);
                }
            }

            if(isset($requestData['walkaround_questions'])){
                foreach($requestData['walkaround_questions'] as $checklist){
                    $checklistData = [
                        'order_id' => $order_id,
                        'order_battery_id' => $order_battery_id,
                        'walkaround_category_id' => $requestData['id'] ?? '',
                        'category_name' => $requestData['category_name'] ?? '',
                        'walkaround_question' => $checklist['question'] ?? '',
                        'is_checked' => $checklist['is_checked'] ?? '',
                    ];
                    $orderWalkaround = OrderWalkaround::where('category_name', $requestData['category_name'])->where('walkaround_question', $checklist['question'])->first();
                    if($orderWalkaround){
                        $orderWalkaround->update($checklistData);
                    }else{
                        OrderWalkaround::create($checklistData);
                    }
                }
            }
        }

        $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id : '';
        if($request->order_type == 'battery-swap'){
            $redirectUrl =  $redirectUrl . '?order_type=battery-swap';
        }
        $walkaroundCheckData = OrderWalkaround::where('order_id', $order_id)->get();

        return $this->success_response($walkaroundCheckData, 'walkaround checked data', $redirectUrl ?? '');

    }
    /**
     * @param Request $request
     * @return JsonResponse
     */
    public function place_order(Request $request){
        
        $user = $request->user('api');

        $requestData = $request->all();
        
        //Validated
        $validate = Validator::make($request->all(), 
        [
            'order_id' => 'required',
            'payment_method' => 'required',
        ]);
        if($validate->fails()){
            return $this->validation_fail($validate->errors());
        }
        

        if($request->order_type == 'battery-swap'){
            $order = OrderBattery::findOrFail($request->order_id);
            
            if($requestData['payment_method'] == 'COD' || $requestData['payment_method'] == 'Cash on Delivery'){
                $order->payment_method = 'COD';
                $order->payment_status = 'Pending';
                $order->payment_type = 'Cash on Delivery';

            }
            $order->angel_tips = $requestData['angel_tip'];
            
            $msg = 'Your Order placed successfully';
            $order->update();
            $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id . '?order_type=battery-swap' : '';
            return $this->success_response($order, $msg, $redirectUrl ?? '');

        }elseif($request->order_type == 'angel-service'){
            $order = OrderAngelService::findOrFail($request->order_id);
            
            if($requestData['payment_method'] == 'COD' || $requestData['payment_method'] == 'Cash on Delivery'){
                $order->payment_method = 'COD';
                $order->payment_status = 'Pending';
                $order->payment_type = 'Cash on Delivery';

            }
            $order->angel_tips = $requestData['angel_tip'];
            
            $msg = 'Your Order placed successfully';
            $order->update();
            $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id . '?order_type=angel-service' : '';
            return $this->success_response($order, $msg, $redirectUrl ?? '');

        }elseif($request->order_type == 'charging-station'){
            $order = OrderChargingStation::findOrFail($request->order_id);
            
            if($requestData['payment_method'] == 'COD' || $requestData['payment_method'] == 'Cash on Delivery'){
                $order->payment_method = 'COD';
                $order->payment_status = 'Pending';
                $order->payment_type = 'Cash on Delivery';

            }
            $order->angel_tips = $requestData['angel_tip'];
            
            $msg = 'Your Order placed successfully';
            $order->update();
            $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id . '?order_type=charging-station' : '';
            return $this->success_response($order, $msg, $redirectUrl ?? '');

        }else{
            
            $order = Order::findOrFail($request->order_id);
            try {
                if(strtoupper($order->status) == 'PENDING' || $order->status == 'IN PROGRESS' || $order->status == 'INPROGRESS'){
                    if($requestData['payment_method'] == 'COD' || $requestData['payment_method'] == 'Cash on Delivery'){
                        $order->payment_method = 'COD';
                        $order->payment_status = 'Pending';
                        $order->payment_type = 'Cash on Delivery';
                        $order->status = 'BOOKING COMPLETED';

                    }                
                    $order->angel_tips = $requestData['angel_tip'];
                    
                    $msg = 'Your Order placed successfully';
                }else{
                    return $this->validation_fail(['erros' => 'This order already placed']);
                }
                $order->update();
                $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id : '';
                return $this->success_response($order, $msg, $redirectUrl ?? '');

            }catch (\Throwable $e) {
                return response()->json([
                    'status' => false,
                    'message' => $e->getMessage()
                ], 500);
            }
        }

    }
    public function feed_back(Request $request, $category){
       
        //Validated
        $validate = Validator::make($request->all(), 
        [
            'order_id' => 'required',
        ]);
        if($validate->fails()){
            return $this->validation_fail($validate->errors());
        }
        $requestData = $request->all();
        $order_id = $request->order_id;
        $order_battery_id = null;
        $order_charging_station_id = null;
        $order_angel_service_id = null;
        if($request->order_type == 'battery-swap'){
            $order = OrderBattery::findOrFail($order_id);
            $order_id = $order->order_id;
            $order_battery_id = $order->id;
        }elseif($request->order_type == 'angel-service'){
            $order = OrderAngelService::findOrFail($order_id);
            $order_id = $order->order_id;
            $order_angel_service_id = $order->id;
        }elseif($request->order_type == 'charging-station'){
            $order = OrderChargingStation::findOrFail($order_id);
            $order_id = $order->order_id;
            $order_charging_station_id = $order->id;
        }else{
            $order = Order::findOrFail($order_id);
        }
        if($category  == 'booking-process'){
            $category = 'Order Booking Process' ;
        }elseif($category  == 'order-complete'){
            $category = 'Order Fullfillment' ;
        }
        $points ='';
        if($request->impression_points){
            foreach($request->impression_points as $point){
                $points = ($points ? $points .',' : '') . $point;
            }
        }
        $feedbackData = [
            'order_id' => $order_id,
            'order_battery_id' => $order_battery_id,
            'feedback_category' => $category,
            'rating' => $request->rating ?? 0,
            'impression_points' => $points,
            'feedback' =>$request->feedback ?? '',
        ];
        if($request->order_type == 'battery-swap'){
            $feedBack = OrderFeedback::where('order_id', $order_id)->where('order_battery_id', $order_battery_id)->where('feedback_category', $category)->first();
        }elseif($request->order_type == 'charging-station'){
            $feedBack = OrderFeedback::where('order_id', $order_id)->where('order_charging_station_id', $order_charging_station_id)->where('feedback_category', $category)->first();
        }elseif($request->order_type == 'angel-service'){
            $feedBack = OrderFeedback::where('order_id', $order_id)->where('order_angel_service_id', $order_angel_service_id)->where('feedback_category', $category)->first();
        }else{
            $feedBack = OrderFeedback::where('order_id', $order_id)->where('feedback_category', $category)->first();
        }
        if( $feedBack ){
            $data = $feedBack->update($feedbackData);
        }else{
            $data = OrderFeedback::create($feedbackData);
        }
        
        $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id : '';
        
        if($request->order_type == 'battery-swap'){
            $redirectUrl =  $redirectUrl . '?order_type=battery-swap';
        }elseif($request->order_type == 'charging-station'){
            $redirectUrl =  $redirectUrl . '?order_type=charging-station';
        }elseif($request->order_type == 'angel-service'){
            $redirectUrl =  $redirectUrl . '?order_type=angel-service';
        }
        
        return $this->success_response($data, 'Thanks for you feedback', $redirectUrl ?? '');
    }
    public function order_history(Request $request){
            
        $user = $request->user('api');

        $requestData = $request->all();
    
        
        $i = 0;
        $data['tabs'] = [];
        try {
            $user = $request->user('api');

            $data = [];

            
            $orderList = Order::whereNull('deleted_at')->where('user_id', $user->id)->get()->groupBy('asset_type');
            foreach($orderList as $key => $orders){
                $data['tabs'][] = [
                    'tab_id' => ++$i,
                    'title' => $key,
                    'data' => OrderResource::collection($orders)
                ];                
            }
            $orderList = Order::whereNull('deleted_at')->where('user_id', $user->id)->get();
            $batteryData = [];
            foreach($orderList as $key => $order){ 
                if($order->orderBattery->count() > 0){
                    foreach($order->orderBattery as $orderBattery){
                        if($orderBattery->cost > 0){
                            $batteryData[] =   new OrderBatteryResource($orderBattery) ;
                        }
                    }
                } 
            }
            $data['tabs'][] = [
                "tab_id" => ++$i,
                "title" => 'Battery Swap',
                'data' => $batteryData      

            ];

            $chargingStationData = [];
            foreach($orderList as $key => $order){ 
                if($order->orderChargingStation->count() > 0){
                    foreach($order->orderChargingStation as $orderChargingStation){
                        if($orderChargingStation->cost > 0){
                            $chargingStationData[] =   new OrderChargingStationResource($orderChargingStation) ;
                        }
                    }
                } 
            }
            $data['tabs'][] = [
                "tab_id" => ++$i,
                "title" => 'Charging Station',
                'data' => $chargingStationData      

            ];

            $angelServiceData = [];
            foreach($orderList as $key => $order){ 
                if($order->orderAngelService->count() > 0){
                    foreach($order->orderAngelService as $orderAngelService){
                        if($orderAngelService->cost > 0){
                            $angelServiceData[] =   new OrderAngelServiceResource($orderAngelService) ;
                        }
                    }
                } 
            }
            $data['tabs'][] = [
                "tab_id" => ++$i,
                "title" => 'Angel Service',
                'data' => $angelServiceData      

            ];

            $msg = "Order History" ;
            return $this->success_response($data, $msg);
        

        } catch (\Throwable $e) {
            return $this->throw_catch_error($e);
        }
    
    }
    public function order_history_details(Request $request, $id){
            
        $user = $request->user('api');

        $requestData = $request->all();
    
        
        $i = 0;
        $data['tabs'] = [];
        try {
            $user = $request->user('api');
            $data = [];
           
            $orderData = Order::where('id', $id)->first();
            $data = new OrderResource($orderData);
            if($request->order_type == 'battery-swap'){
                $orderData = OrderBattery::where('id', $id)->first();
                $data = new OrderBatteryResource($orderData);
            }elseif($request->order_type == 'charging-station'){
                $orderData = OrderChargingStation::where('id', $id)->first();
                $data = new OrderChargingStationResource($orderData);
            }elseif($request->order_type == 'angel-service'){
                $orderData = OrderAngelService::where('id', $id)->first();
                $data = new OrderAngelServiceResource($orderData);
            }
            
            $msg = "Order Details" ;
            return $this->success_response($data, $msg);
        

        } catch (\Throwable $e) {
            return $this->throw_catch_error($e);
        }
    
    }
    public function track_order(Request $request, $order_id){
            
        $user = $request->user('api');

        $requestData = $request->all();
        
        if($request->order_type == 'battery-swap'){
            
            $order = OrderBattery::findOrFail($request->order_id);

            $response['sections'] = [];

            $redirectUrl =  isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id . '?order_type=battery-swap': '';

            $response['orderData'] = new OrderBatteryResource($order);

            return $this->success_response($response, 'Track Order', $redirectUrl ?? '');
            
        }if($request->order_type == 'angel-service'){
            
            $order = OrderAngelService::findOrFail($request->order_id);

            $response['sections'] = [];

            $redirectUrl =  isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id . '?order_type=angel-service': '';

            $response['orderData'] = new OrderAngelServiceResource($order);

            return $this->success_response($response, 'Track Order', $redirectUrl ?? '');
            
        }elseif($request->order_type == 'charging-station'){
            $order = OrderChargingStation::findOrFail($request->order_id);

            $form = Forms::where('slug', 'track-charging-station')->first();
            
            $sectionList = $form->formFields->sortBy('formFieldGroup.priority')->groupBy('formFieldGroup.field_group');
            $i =0;
            $sount = 0;

            foreach($sectionList as $key => $sectionField){
                $completeStatus = false;
                if(isset($form->formFields[$i])){
                    $formField = $form->formFields[$i];;
                    
                    if($formField->name == '1' && ($order->status == '1' || $order->status == '2' || $order->status == '3' || $order->status == '4' || $order->status == '5')){
                        $completeStatus = true;
                    }elseif($formField->name == '2' && ($order->status == '2' || $order->status == '3' || $order->status == '4' || $order->status == '5')){
                        $completeStatus = true;
                    }elseif($formField->name == '3' && ($order->status == '3'|| $order->status == '3' || $order->status == '4' || $order->status == '5')){
                        $completeStatus = true;
                    }elseif($formField->name == '4' && ($order->status == '4' || $order->status == '5')){
                        $completeStatus = true;
                    }

                }
                if($completeStatus == true){
                    $sount = ++$sount;
                }
                $i = ++$i;
                $enableButton = false;
                if(($sount > 0 && $sount < $i)){
                    $enableButton = true;
                    $sount = 0;
                }
                
                $enableButton = ($enableButton == true || $completeStatus == true) ? true : false ;

                $button = [];
                if(isset($form->formButtons[$i-1])){
                    $buttonData = $form->formButtons[$i-1];
                    $button = (new FormButtons($form->formButtons[$i-1]))->enable($enableButton);
                }
                $response['sections'][] = [
                    'section_id' => $i,
                    'slug' => $key,
                    'title' => $sectionField[0] ->formFieldGroup->title,
                    'sub_title' => $sectionField[0] ->formFieldGroup->sub_title ,
                    'complete' => $completeStatus,
                    'button' => $button,
                ];
                
            }
            $response['orderData'] = new OrderResource($order);
            
            $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id  . '?order_type=charging-station': '';
            return $this->success_response($response, 'Track Order', $redirectUrl ?? '');
        }

        $order = Order::findOrFail($request->order_id);
    
        $form = Forms::where('slug', 'track-order')->first();
        
        $sectionList = $form->formFields->sortBy('formFieldGroup.priority')->groupBy('formFieldGroup.field_group');
        $i =0;
        $sount = 0;
        foreach($sectionList as $key => $sectionField){
            $completeStatus = false;
            if(isset($form->formFields[$i])){
                $formField = $form->formFields[$i];;
                
                if($formField->name == 'PAYMENT COMPLETED' && ($order->status == 'PAYMENT COMPLETED' || $order->status == 'VEHICLE UNLOCKED' || $order->status == 'WALKAROUND DONE' || $order->status == 'USAGE INPROGRESS' || $order->status == 'BATTERY SWAP' || $order->status == 'BATTERY SWAP' || $order->status == 'ORDER COMPLETED')){
                    $completeStatus = true;
                }elseif($formField->name == 'VEHICLE UNLOCKED' && ($order->status == 'VEHICLE UNLOCKED' || $order->status == 'WALKAROUND DONE' || $order->status == 'USAGE INPROGRESS' || $order->status == 'BATTERY SWAP' || $order->status == 'BATTERY SWAP' || $order->status == 'ORDER COMPLETED')){
                    $completeStatus = true;
                }elseif($formField->name == 'WALKAROUND DONE' && ($order->status == 'WALKAROUND DONE' || $order->status == 'USAGE INPROGRESS' || $order->status == 'BATTERY SWAP' || $order->status == 'BATTERY SWAP' || $order->status == 'ORDER COMPLETED' || $order->orderWalkaroundCategory)){
                    $completeStatus = true;
                }elseif($formField->name == 'USAGE INPROGRESS' && ($order->status == 'USAGE INPROGRESS' || $order->status == 'BATTERY SWAP' || $order->status == 'BATTERY SWAP' || $order->status == 'ORDER COMPLETED')){
                    $completeStatus = true;
                }elseif($formField->name == 'BATTERY SWAP' && ($order->status == 'BATTERY SWAP' || $order->status == 'ORDER COMPLETED')){
                    $completeStatus = true;
                }elseif($formField->name == 'ORDER COMPLETED' && ($order->status == 'ORDER COMPLETED')){
                    $completeStatus = true;
                }

            }
            if($completeStatus == true){
                $sount = ++$sount;
            }
            $i = ++$i;
            $enableButton = false;
            if(($sount > 0 && $sount < $i)){
                $enableButton = true;
                $sount = 0;
            }
            
            $enableButton = ($enableButton == true || $completeStatus == true) ? true : false ;

            $button = [];
            if(isset($form->formButtons[$i-1])){
                $buttonData = $form->formButtons[$i-1];
                $button = (new FormButtons($form->formButtons[$i-1]))->enable($enableButton);
            }
            $response['sections'][] = [
                'section_id' => $i,
                'slug' => $key,
                'title' => $sectionField[0] ->formFieldGroup->title,
                'sub_title' => $sectionField[0] ->formFieldGroup->sub_title ,
                'complete' => $completeStatus,
                'button' => $button,
            ];
            
        }
        $response['orderData'] = new OrderResource($order);
        
        $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id : '';
        return $this->success_response($response, 'Track Order', $redirectUrl ?? '');
    }
    
    public function change_order_status(Request $request, $order_id)
    { 
        $redirectUrl = isset($requestData['redirect_url']) ?  $requestData['redirect_url'] . '/' . $order->id : '';

        $order_id = $request->order_id;
        $order = Order::findOrFail($order_id);

        if($order->asset_type == 'vehicle' && ($request->status == 'ORDER COMPLETED' || $request->status == 'CANCELLED')){
            if($order->vehicleAsset){
                $order->vehicleAsset->status = 0;
                $order->vehicleAsset->update();
            }
        }elseif($order->asset_type == 'vehicle'){
            if($order->vehicleAsset){
                $order->vehicleAsset->status = 1;
                $order->vehicleAsset->update();
            }
        }
        $order->status = $request->status;
        $order->update();
        $asset =[];
        if($order->vehicleAsset){
            $asset = $order->vehicleAsset;
        }
        if(empty($asset)){
            return $this->validation_fail(['error' => 'No asset assigned']);
        }
        if(isset($request->scan_data)){

            $scanData = explode(',', $request->scan_data);

            if($scanData[0] == 'vehicle' && $scanData[1] == $asset->vendorOem->vendor_oem && $scanData[2] == $asset->model_name && $scanData[3] == $asset->registeration_number && $scanData[4] == $asset->vin_number){
                if($order->status == 'VEHICLE UNLOCKED' || $order->status == 'WALKAROUND DONE' || $order->status == 'USAGE INPROGRESS' || $order->status == 'BATTERY SWAP'){
                    $response['message'] = "Your Vehicle already Unlocked";   
                }else{
                    $order->status = 'VEHICLE UNLOCKED';
                    $order->update();
                    $response['message'] = "Vehicle Unlocked Successfully";   
                }
            }else{
                $response['message'] = "Your Scan doesn't match to your existing order !";   
                return $this->success_response($response, "Your Scan doesn't match to your existing order !");
            }
        }

        $response['orderData'] = new OrderResource($order);
        
        return $this->success_response($response, 'status changed', $redirectUrl ?? '');

    }
    

}
