<?php

namespace App\Http\Controllers\Api\v1;

use App\Http\Controllers\Api\v1\AppController;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\User;
use Illuminate\Validation\Rule;
use App\Models\Users\UserVehicle;
use App\Http\Resources\UserVehicle as UserVehicleResource;
use App\Models\Users\UserNotification;
use App\Http\Resources\Users\UserNotification as UserNotificationResource;


class UserController extends AppController
{
    /**
     * @param Request $request
     * @return JsonResponse
     */
    public function add_address(Request $request)
    {
        $requestData = $request->all();
        try {
            //Validated
            $validate = Validator::make($request->all(), 
            [
                'address' => 'required',
            ]);

            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
            $user = $request->user('api');
            if($user){
                
            return $this->success_response([], 'Address Added', $request->redirect_url);

            }else{
                return $this->user_not_found();
            }

        } catch (\Throwable $e) {
            return $this->throw_catch_error($e);
        }
    }
    public function add_new_vehicle(Request $request){
        $requestData = $request->all();
        $user = $request->user('api');
        try {
            //Validated
            $validate = Validator::make($request->all(), 
            [
                'vehicle_make' => 'required',
                'model' => 'required',
                'vehicle_identification_number' => 'required|unique:user_vehicle,vehicle_identification_number',

            ]);
            if($validate->fails()){
                return $this->validation_fail($validate->errors());
            }
            $requestData['user_id'] = $user->id;
            $userVehicle = UserVehicle::create($requestData);
            if(isset($requestData['image'])){
                $image = $requestData['image'];
                $file = base64_decode($image);
                $f = finfo_open();
                $mime_type = finfo_buffer($f, $file, FILEINFO_MIME_TYPE);
                $split = explode( '/', $mime_type );
                $type = $split[1]; 
                $savedAs = $request->vehicle_identification_number .'.'. $type;
                $path = '/uploads/users/' . $user->id . '/my-vehicles/' .  $savedAs;
                $filePath = $this->uploadFile($path, $file);
                $userVehicle->image =  $path;
                $userVehicle->update();
            }
            $data = $userVehicle;
            return $this->success_response($data, 'Your New Vehicle added successfully', $request->redirect_url);

        } catch (\Throwable $e) {
            return $this->throw_catch_error($e);
        }
    }
    public function wallet_details(Request $request){
        
        $requestData = $request->all();
        $user = $request->user('api');

        $data = [
            'id' => $user->id,
            'wallet_amount' => $user->wallet_amount ?? 0,
        ];
        return $this->success_response($data, 'Wallet Details');

    }
    public function edit_new_vehicle(Request $request){
        $requestData = $request->all();
        $user = $request->user('api');
        $id = $request->vehicle_id;
        $validate = Validator::make($request->all(), [
            'vehicle_make' => 'required',
            'model' => 'required',
            'vehicle_identification_number' => [
                'required',
                Rule::unique('user_vehicle')->ignore($id),
            ],
        ]);
        if($validate->fails()){
            return $this->validation_fail($validate->errors());
        }
        
        $userVehicle = UserVehicle::where('id', $id)->first();
        if($userVehicle){
            try {
                $requestData['user_id'] = $user->id;
                if(isset($requestData['image'])){
                    $image = $requestData['image'];
                    $file = base64_decode($image);
                    $f = finfo_open();
                    $mime_type = finfo_buffer($f, $file, FILEINFO_MIME_TYPE);
                    $split = explode( '/', $mime_type );
                    $type = $split[1]; 
                    $savedAs = $request->vehicle_identification_number .'.'. $type;
                    $path = '/uploads/users/' . $user->id . '/my-vehicles/' .  $savedAs;
                    $filePath = $this->uploadFile($path, $file);
                    $requestData['image'] =  $path;
                }
                $userVehicle->update($requestData);
                $data = $userVehicle;
                return $this->success_response($data, 'Your Vehicle Updated successfully', $request->redirect_url);

            } catch (\Throwable $e) {
                return $this->throw_catch_error($e);
            }
        }
    }
    public function my_vehicles(Request $request){
        $requestData = $request->all();
        $user = $request->user('api');
        $myVehicles = UserVehicle::whereNull('deleted_at')->where('user_id', $user->id)->get();
        $response = UserVehicleResource::collection($myVehicles);
        return $this->success_response($response);
    }
    public function notifications(Request $request){
        $requestData = $request->all();
        $user = $request->user('api');   
        $deviceId =  request()->header('deviceId');
        $userNotification = [];
        if($deviceId){
            $userNotification = UserNotification::whereNull('deleted_at')->orderBy('created_at', 'DESC')->get();
        }
        if(empty($userNotification)){
            $userNotification = $user->notifications;
        }
        $response = UserNotificationResource::collection($user->notifications);
        foreach($user->notifications as $notification){
            $notification->readed = 1;
            $notification->update();
        }
        return $this->success_response($response);
    }
    public function destroy_notification(Request $request, $id){
        $requestData = $request->all();
        $userNotification = UserNotification::findOrFail($id);
        $userNotification->deleted_at = date('Y-m-d H:i:s');
        $userNotification->update();
        $user = $request->user('api');      

        $response = UserNotificationResource::collection($user->notifications);
        return $this->success_response($response, 'Notification deleted successfully');
    }
    
}
