<?php

namespace App\Http\Controllers;

use App\Models\Flipkart;
use App\Models\PLReport;
use App\Models\Users\UserData;
use App\Models\Users\UserVehicle;
use App\Models\User;
use Illuminate\Http\Request;
use Carbon\Carbon;
use DateInterval;
use DatePeriod;

class FlipkartController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

          $users = User::join('user_data', 'user_data.user_id', '=', 'users.id')
          ->select('user_data.employee_id','users.name')->where('user_type','Rider')
          ->get();

          $data = [];
  
  
          foreach ($users as $user) {
              $employeeId = $user->employee_id;
  
              $codCount = PLReport::where('EmployeeID', $employeeId)->distinct('ShipmentId')->where('ShipmentType', 'COD')->count();
              $ppCount = PLReport::where('EmployeeID', $employeeId)->distinct('ShipmentId')->where('ShipmentType', 'PP')->count();
              $rvpCount = PLReport::where('EmployeeID', $employeeId)->distinct('ShipmentId')->where('ShipmentType', 'RVP')->count();
              $totalShipments = PLReport::where('EmployeeID', $employeeId)->distinct('ShipmentId')->count('ShipmentId');
              $Delivery = PLReport::where('EmployeeID', $employeeId)->distinct('ShipmentId')->where('ShipmentStatus', 'Delivered')->count();
              $codTotal = PLReport::where('EmployeeID', $employeeId)->where('ShipmentType', 'COD')->where('ShipmentStatus', 'Delivered')->sum('ShipmentPrice');
              $undelivered = $totalShipments - $Delivery;
          
              $userData = [
                  'employee_id' => $employeeId,
                  'registration_number' => $user->registration_number,
                  'name' => $user->name,
                  'cod_count' => $codCount,
                  'pp_count' => $ppCount,
                  'rvp_count' => $rvpCount,
                  'total_shipments' => $totalShipments,
                  'cod_total' => $codTotal,
                  'total_delivery' => $Delivery,
                  'non_delivery' => $undelivered,
              ];
  
              $data[] = $userData;
          }
          return view('admin.report.3pl.flipkart.index', compact('data'));         
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {

        $start = Carbon::parse($request->date_from);
        $startDate = $start->format('m/d/Y');
        $end = Carbon::parse($request->date_to);
        $endDate = $end->format('m/d/Y');

        $user = PLReport::all();

        $u = PLReport::where('ShipmentUpdate',$startDate)->get();
 
        $users = PLReport::join('user_data', 'user_data.employee_id', '=', 'pl_reports.EmployeeID')
        ->join('users', 'user_data.user_id', '=', 'users.id')
        ->whereBetween('ShipmentUpdate', [$startDate, $endDate])
        ->get();

        $username = User::join('user_data', 'user_data.user_id', '=', 'users.id')
        ->select('user_data.employee_id','users.name')->where('user_type','Rider')
        ->get();

      //  dd($username);

      //  $user = User::where('id', $userId)->first();

       // $employeeId = $user->get()->employee_id;
        $data = [];

        foreach ($username as $user) {   
            $employeeId = $user->employee_id;
        
            $codCount = PLReport::where('EmployeeID', $employeeId)->whereBetween('ShipmentUpdate', [$startDate, $endDate])->distinct('ShipmentId')->where('ShipmentType', 'COD')->count();
        
            $ppCount = PLReport::where('EmployeeID', $employeeId)->whereBetween('ShipmentUpdate', [$startDate, $endDate])->distinct('ShipmentId')->where('ShipmentType', 'PP')->count();
        
            $rvpCount = PLReport::where('EmployeeID', $employeeId)->whereBetween('ShipmentUpdate', [$startDate, $endDate])->distinct('ShipmentId')->where('ShipmentType', 'RVP')->count();
        
            $totalShipments = PLReport::where('EmployeeID', $employeeId)->whereBetween('ShipmentUpdate', [$startDate, $endDate])->distinct('ShipmentId')->whereNotNull('ShipmentId')->count();
        
            $Delivery = PLReport::where('EmployeeID', $employeeId)->whereBetween('ShipmentUpdate', [$startDate, $endDate])->distinct('ShipmentId')->where('ShipmentStatus', 'Delivered')->count();
        
            $codTotal = PLReport::where('EmployeeID', $employeeId)->whereBetween('ShipmentUpdate', [$startDate, $endDate])->distinct('ShipmentId')->where('ShipmentType', 'COD')->sum('ShipmentPrice');
        
            $undelivered = $totalShipments - $Delivery;
        
            $userData = [
                'employee_id' => $employeeId,
                'name' => $user->name, 
                'cod_count' => $codCount,
                'pp_count' => $ppCount,
                'rvp_count' => $rvpCount,
                'total_shipments' => $totalShipments,
                'cod_total' => $codTotal,
                'total_delivery' => $Delivery,
                'non_delivery' => $undelivered,
            ];
        
            $data[] = $userData;
        }
        

        return view('admin.report.3pl.flipkart.index', compact('data'));
    
    }

    public function show(Request $request)
    {
        $requestData = $request->all();
        $userCall  = str_replace(url('/'), '', url()->previous());

        $flipkartreports = ((new PLReport()))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new PLReport()))->count();
        $date=$workreports[0]['created_at']->format('d/m/Y');
  

        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($flipkartreports->isEmpty()) {
            
        }
        else{
           
            foreach($flipkartreports as $workreport){
                $data['data'][] = [
                    'id'=> $workreport->id,
                    'RunsheetId' => $workreport->RunsheetId,
                    'ShipmentUpdate' => $workreport->ShipmentUpdate,
                    'AgentName' => $workreport->AgentName,
                    'EmployeeID' => $workreport->EmployeeID,
                    'DeliveryHub' => $workreport->DeliveryHub,
                    'City' => $workreport->City,
                    'Zone' => $workreport->Zone,
                    'State' => $workreport->State,
                    'ShipmentId' => $workreport->ShipmentId,
                    'ShipmentType' => $workreport->ShipmentType,
                    'ShipmentPrice' => $workreport->ShipmentPrice,
                    'ShipmentStatus' => $workreport->ShipmentStatus,
                  

                ];
            }
        }
         return response()->json($data, 200);
    }
}
