<?php

namespace App\Http\Controllers;

use App\Models\VehicleOem;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;

use Illuminate\Http\Request;

class VehicleOemController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $vehicleOemList = VehicleOem::get();
        return view('admin.master.vehicle_oem.index', compact('vehicleOemList'));
    }

    public function tab_index(Request $request){
        $requestData = $request->all();

        $vehicleOems = ((new VehicleOem()))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new VehicleOem()))->count();
        
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($vehicleOems->isEmpty()) {
            
        }else{
            foreach($vehicleOems as $oem){
                $data['data'][] = [
                    'id' => $oem->id,
                    'Vehicle_OEM' => $oem->Vehicle_OEM,
                    'created_at' => $oem->created_at,
                    'updated_at' => $oem->updated_at ,
                    'action' => '<a href="'. route('vehicleoem.edit', ['vehicleoem' => $oem->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('vehicleoem.destroy', ['vehicleoem' => $oem->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>'            
                ];
            }
        }
        return response()->json($data, 200);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.master.vehicle_oem.create');

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $vehicleOems = VehicleOem::create($requestData);
        return redirect('admin/vehicle-oem')->with('flash_message', 'Vehicle Oem added!');
    
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\VehicleOem  $vehicleOem
     * @return \Illuminate\Http\Response
     */
    public function show(VehicleOem $vehicleOem)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\VehicleOem  $vehicleOem
     * @return \Illuminate\Http\Response
     */


    public function edit($id)
    {
        $propertyType = VehicleOem::findOrFail($id);
        
        return view('admin.master.vehicle_oem.edit', compact('propertyType'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\VehicleOem  $vehicleOem
     * @return \Illuminate\Http\Response
     */ 
    

        

        // Assuming you are in a controller method...
        
        public function update(Request $request, $id)
        {
            $requestData = $request->all();
        
            $propertyType = VehicleOem::findOrFail($id);
        
            $validate = Validator::make($request->all(), [
                'Vehicle_OEM' => [
                    'required',
                    Rule::unique('vehicle_oems')->ignore($propertyType->id),
                ],
            ]);
        
            if ($validate->fails()) {
                return redirect()->back()->withErrors($validate)->withInput();
            }
        
            $propertyType->update($requestData);
        
            return redirect('admin/vehicleoem')->with('flash_message', 'Vehicle Oem Updated!');
        }
        
    

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\VehicleOem  $vehicleOem
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        VehicleOem::destroy($id);

        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'VehicleOem Type deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/vehicleoem')->with('flash_message', 'VehicleOem Type deleted!');
    }
}
