<?php

namespace App\Http\Controllers;

use App\Models\Assets\vendoroem_model;
use Illuminate\Http\Request;
use App\Models\VehicleOem;
use App\Models\Master\ProductType;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;




class VendoroemModelController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $vehicleOemmodelList = vendoroem_model::get();

        return view('admin.master.vehicle_model.index',compact('vehicleOemmodelList'));
    }

    public function tab_index(Request $request){
        $requestData = $request->all();

        $vendoroemmodel = ((new vendoroem_model()))->skip($requestData['start'])->take($requestData['length'])->get();
        $totalRecords = ((new vendoroem_model()))->count();
        $data = [
            'draw' => $requestData['draw'],
            'iTotalRecords' => $totalRecords,
            'iTotalDisplayRecords' => $totalRecords,
        ];
        if ($vendoroemmodel->isEmpty()) {
            
        }else{
            foreach($vendoroemmodel as $model){
                $data['data'][] = [
                    'id' => $model->id,
                    'asset_product' => $model->asssetproduct->product_type ?? '',
                    'Vehicle_OEM' => $model->oem->Vehicle_OEM ?? '',
                    'Vehicle_OEM_model' => $model->vehicle_oem_model,
                    'created_at' => $model->created_at,
                    'updated_at' => $model->updated_at ,
                    'action' => '<a href="'. route('vehicleoemmodel.edit', ['vehicleoemmodel' => $model->id]) . '"><i class="mdi mdi-pencil font-size-16 text-success me-1"></i></a>
                    <a  href="#" class="delete" data-url="'.  route('vehicleoemmodel.destroy', ['vehicleoemmodel' => $model->id]) .'">  <i  class="mdi mdi-trash-can font-size-16 text-danger me-1"></i> </a>'            
                ];
            }
        }
        return response()->json($data, 200);
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $vehicleOemList = VehicleOem::get();
        $assetTypeList = ProductType::whereNull('deleted_at')->get();
        return view('admin.master.vehicle_model.create',compact('vehicleOemList','assetTypeList'));

    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $requestData = $request->all();
        $vehicleOems = Vendoroem_model::create($requestData);
        return redirect('admin/vehicleoemmodel')->with('flash_message', 'Vehicle Oem Model added!');
    
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Assets\vendoroem_model  $vendoroem_model
     * @return \Illuminate\Http\Response
     */
    public function show(vendoroem_model $vendoroem_model)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Assets\vendoroem_model  $vendoroem_model
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $vendorOemmodel = vendoroem_model::findOrFail($id);

        $vehicleOemList = VehicleOem::get();
        $assetTypeList = ProductType::whereNull('deleted_at')->get();
                return view('admin.master.vehicle_model.edit', compact('vehicleOemList','assetTypeList','vendorOemmodel'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Assets\vendoroem_model  $vendoroem_model
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request,$id)
    {
        $requestData = $request->all();
        
            $propertyType = vendoroem_model::findOrFail($id);
        
            $validate = Validator::make($request->all(), [
                'vehicle_oem_model' => ['required',
                
                    Rule::unique('vendoroem_models')->ignore($propertyType->id),
                ],
            ]);
        
            if ($validate->fails()) {
                return redirect()->back()->withErrors($validate)->withInput();
            }
        
            $propertyType->update($requestData);
        
            return redirect('admin/vehicleoemmodel')->with('flash_message', 'Vehicle Oem Updated!');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Assets\vendoroem_model  $vendoroem_model
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        vendoroem_model::destroy($id);

        if($request->ajax()){
            return response()->json([
                'status' => true,
                'message' => 'VehicleOem Type deleted!',
                'errors' => ''
            ], 200);
        }
        return redirect('admin/vehicleoemmodel')->with('flash_message', 'VehicleOem Type deleted!');
    }
}
