<?php

namespace App\Http\Resources\CMS;

use App\Http\Resources\JsonResource;
use App\Http\Resources\CMS\FormFields;
use App\Http\Resources\CMS\FormFieldsCollection;
use App\Http\Resources\CMS\FormButtons;
use App\Models\User;

use App\Models\Master\VerificationType;
use App\Models\Master\FormFieldGroup;
use App\Models\Assets\Vehicle;
use App\Models\SubscriptionPlan\Vehicle as VehicleSubscription;
use App\Models\SubscriptionPlan\Battery as BatterySubscription;
use App\Models\SubscriptionPlan\AngelService as AngelServiceSubscription;
use App\Models\Assets\ChargingStation;
use App\Http\Resources\Assets\Vehicle as VehicleResource;
use App\Http\Resources\SubscriptionPlan\Vehicle as VehicleSubscriptionResource;
use App\Http\Resources\SubscriptionPlan\Battery as BatterySubscriptionResource;
use App\Http\Resources\Assets\ChargingStation as ChargingStationResource;
use App\Http\Resources\SubscriptionPlan\AngelService as AngelServiceSubscriptionResource;


class Forms extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request, $asset  = '')
    {
        $user = auth('api')->user();
        if(empty($user)){
            $user = $this->getAuthPwUser($request);
        }
        $data = [];
        if($user){
            $data = User::with(['userData', 'address', 'address.city',  'address.state',  'address.district',  'address.zone', 'userDocuments'])->where('id', '=', $user->id)->first()->toArray();
        }
        $image_width = $this->image_width;
        $image_width_type = $this->image_width_type;
        $image_height = $this->image_height;
        $image_height_type = $this->image_height_type;
        $bottom_image_width = $this->bottom_image_width;
        $bottom_image_width_type = $this->bottom_image_width_type;
        $bottom_image_height = $this->bottom_image_height;
        $bottom_image_height_type = $this->bottom_image_height_type;

        $type = $image_width ? settype($image_width, $image_width_type) : '';
        $type = $image_height ? settype($image_height, $image_height_type) : '';
        $type = $bottom_image_width ? settype($bottom_image_width, $bottom_image_width_type) : '';
        $type = $bottom_image_height ? settype($bottom_image_height, $bottom_image_height_type) : '';

        $response = [
            'slug' => $this->slug,
            'title' => $this->title,
            'sub_title' => $this->sub_title,
            'description' => $this->description,
            'image' => empty($this->image) ? null : base64_encode(file_get_contents(public_path().'/storage'.$this->image, true)),
            'image_width' => $image_width ?? null,
            'image_height' => $image_height ?? null,
            'bottom_image' => empty($this->bottom_image) ? null : base64_encode(file_get_contents(public_path().'/storage'.$this->bottom_image, true)),
            'bottom_image_width' => $bottom_image_height ?? null,
            'bottom_image_height' => $bottom_image_height ?? null,
            //'content' => $this->content,
            'is_back_button' => ($this->is_back_button == '1') ? true : false,
            //'fields' => formFields::collection($this->formFields)->groupBy('formFieldGroup.field_group'),
            //'buttons' => formButtons::collection($this->formButtons),
        ];

        $i = 0;
        $kycField = 0;
        if($this->have_section == 1){
            $response['sections'] = [];
            $sectionList = $this->formFields->sortBy('formFieldGroup.priority')->groupBy('formFieldGroup.field_group');
            foreach($sectionList as $key => $sectionField){
                
                $response['sections'][] = [
                    'section_id' => ++$i,
                    'slug' => $key,
                    'title' => $sectionField[0]->formFieldGroup->title ?? null,
                    'sub_title' => $sectionField[0]->formFieldGroup->sub_title  ?? null,
                    'fields' => new FormFieldsCollection($sectionField),
                ];
            }
        }else{
            $response['fields'] = FormFields::collection($this->formFields);
        }
        if($this->slug == 'kyc-form'){
            $userDocs = 
            $verificationParams = VerificationType::whereNull('deleted_at')->get();
                    
            foreach($verificationParams as $verificationParam){
                if($verificationParam->role->name == $user->user_type){
                    $verification_parameter = strtolower($verificationParam->verification_parameter);
                    $verification_parameter = str_replace(' ', '_', $verification_parameter);
                    $docName = $verificationParam->verification_parameter;
                    $userDoc = [];
                    foreach($data['user_documents'] as $userDocuments){
                        if($userDocuments['doc_name'] == $docName){
                            $userDoc = $userDocuments; 
                        }
                    }
                    $kyc['fields'] = [];
                    $kyc['fields'][]  = [
                        'id' => ++$kycField,
                        'type' => 'text',
                        'title' => $verificationParam->verification_parameter . ' Number',
                        'name' => $verification_parameter . "_doc_number",
                        'is_required' => $verificationParam->proof_required == 'Yes' ? True : false,
                        'visible' => true,
                        'value' => isset($userDoc['doc_number']) ? $userDoc['doc_number'] : '',
                        'padding' => 8.0,
                    ];
                    $kyc['fields'][]= [
                        "id" => $verificationParam->id,
                        "type" => "multipleImageUpload",
                        'title' => 'Upload your ' . $verificationParam->verification_parameter,
                        "name" => $verification_parameter,
                        'files_upload' => [[
                            'id' => ++$kycField,
                            'type' => 'singleImageUpload',
                            'title' => 'Front',
                            'name' => $verification_parameter . "_doc_front_page",
                            //'value' => isset($userDoc['doc_front_page']) ? $userDoc['doc_front_page'] : null,
                            'value' => empty($userDoc['doc_front_page']) ? null : base64_encode(file_get_contents(public_path().'/storage'. $userDoc['doc_front_page'] , true)),
                        ],[
                            'id' => ++$kycField,
                            'type' => 'singleImageUpload',
                            'title' => 'Back',
                            'name' => $verification_parameter . "_doc_back_page",
                            //'value' => isset($userDoc['doc_back_page']) ? $userDoc['doc_back_page'] : null,
                            'value' => empty($userDoc['doc_back_page']) ? null : base64_encode(file_get_contents(public_path().'/storage'. $userDoc['doc_back_page'] , true)),
                        ]],
                        'is_required' => $verificationParam->proof_required == 'Yes' ? True : false,
                        'visible' => $verificationParam->proof_required == 'Yes' ? True : false,
                    ];
                    
                    $response['sections'][] = [
                        'section_id' => ++$i,
                        'slug' =>  $docName,
                        "title" => $docName,
                        'sub_title' => $docName,
                        'fields' => $kyc['fields']
                    ];
                }
               // print_r( $response['fields']); exit;
            }
        }
        $response['buttons'] = FormButtons::collection($this->formButtons);

        $subscriptionData = [];
        $assetData = [];
        if($this->slug == 'ev-booking' && $request->subscription_id){
            $ubscription = VehicleSubscription::findOrFail($request->subscription_id);
            $subscriptionData = new VehicleSubscriptionResource($ubscription);
        }
        if($this->slug == 'battery-swap' && $request->subscription_id){
            $ubscription = BatterySubscription::findOrFail($request->subscription_id);
            $subscriptionData = new BatterySubscriptionResource($ubscription);
        }
        if($this->slug == 'charging-station' && $request->asset_id){
            $asset = ChargingStation::findOrFail($request->asset_id);
            $assetData = new ChargingStationResource($asset);
        }
        if($this->slug == 'angel-service' && $request->subscription_id){
            $ubscription = AngelServiceSubscription::findOrFail($request->subscription_id);
            $subscriptionData = new AngelServiceSubscriptionResource($ubscription);
        }

        if(!empty($subscriptionData)){
            $response['subscriptionData'] = $subscriptionData;
        }
        if(!empty($assetData)){
            $response['assetData'] = $assetData;
        }
        return $response;
    }
}
