<?php

namespace App\Http\Resources;

use App\Http\Resources\JsonResource;
use App\Http\Resources\Users\UserDocuments as UserDocumentsResource;
use App\Http\Resources\User as UserResource;

use App\Http\Resources\SubscriptionPlan\Vehicle as VehicleSubscriptionResource;
use App\Http\Resources\SubscriptionPlan\Battery as BatterySubscriptionResource;

class Order extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        $response =  [
            'id' => $this->id,
            'order_number' => $this->order_number,
            'user_type' => $this->user_type,
            'customer_name' => $this->customer_name,
            'customer_email' => $this->customer_email,
            'customer_phone' => $this->customer_phone,
            'duration' => $this->duration,
            'duration_start' => $this->duration_start,
            'duration_start_time' => $this->duration_start_time,
            'duration_end' => $this->duration_end,
            'duration_end_time' => $this->duration_end_time,
            'source_latitude' => $this->source_latitude ?? '',
            'source_longitude' => $this->source_longitude ?? '',
            'source_place_id' => $this->source_place_id ?? '',
            'source_address' => $this->source_address ?? '',
            'asset_location' => $this->source_address ?? '',  // dinesh requirement
            'source_postal_code' => $this->source_postal_code ?? '',
            'destination_latitude' => $this->destination_latitude ?? '',
            'destination_longitude' => $this->destination_longitude ?? '',
            'destination_place_id' => $this->destination_place_id ?? '',
            'destination_address' => $this->destination_address ?? '',
            'delivery_location' => $this->destination_address ?? '', // dinesh requirement
            'destination_postal_code' => $this->destination_postal_code ?? '',
            'distance' => $this->distance,
            'asset_type' => $this->asset_type,
            'order_type' => $this->order_type ?? 'Rent EV',
            'value_added_service_id' => $this->value_added_service_id,
            'delivery_type' => $this->delivery_type,
            'order_description' => $this->order_description ?? '',
            'angel_assign_datetime' => $this->angel_assign_datetime,
            'delivery_date' => $this->delivery_date,
            'delivery_time' => $this->delivery_time,
            'cost' => $this->cost,
            'value_added_service_amount' => $this->value_added_service_amount ?? 0,
            'discount' => $this->discount ?? 0,
            'angel_tips' => $this->angel_tips ?? 0,
            'convenience_fee' => $this->convenience_fee ?? 0,
            'delivery_charge' => $this->delivery_charge ?? 0,
            'order_sub_total' => $this->order_sub_total ?? 0,
            'order_grand_total' => $this->order_grand_total ?? 0,
            'payment_method' => $this->payment_method,
            'split_payment' => $this->split_payment,
            'wallet_amount' => $this->wallet_amount ?? 0,
            'status' => $this->status,
            'payment_status' => $this->payment_status ?? 'Pending',
            'payment_type' => $this->payment_type,
            'model_name' => $this->model_name,
            'battery_id' => $this->battery_id
        ];
        if($this->angel_id){
            $response['angel_name'] = $this->angel->name;
            $response['angel_email'] = $this->angel->email;
            $response['angel_phonel'] = $this->angel->phone_number;
        }
        if($this->subscription_id){
            if(strtolower($this->asset_type) == 'vehicle'){
                 $response['subscription_plan'] = $this->vehicleSubscription?->plan_name;
                 $response['subscription_data'] = (new VehicleSubscriptionResource($this->vehicleSubscription))->order($this);

            } 
            if(strtolower($this->asset_type) == 'battery'){
                 $response['subscription_plan'] = $this->batterySubscription?->plan_name;
                 $response['subscription_data'] = (new BatterySubscriptionResource($this->batterySubscription))->order($this);
            }
        }
        if($this->orderFeedback){
            $response['feedback'] = $this->orderFeedback->feedback;
            $response['rating'] = $this->orderFeedback->rating;
            $response['impression_points'] = $this->orderFeedback->impression_points;
            
        }
        

        
        return $response;
    }
}
