<?php

namespace App\Http\Resources\Orders;

use App\Http\Resources\JsonResource;
use App\Http\Resources\Users\UserDocuments as UserDocumentsResource;
use App\Http\Resources\User as UserResource;
use App\Models\Orders\OrderAngelService as OrderAngelServiceModel;
use App\Http\Resources\SubscriptionPlan\Vehicle as VehicleSubscriptionResource;
use App\Http\Resources\SubscriptionPlan\AngelService as AngelServiceSubscriptionResource;

class OrderAngelService extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    
    public function toArray($request)
    {
        $status =[
            'TO SWAP',
            'INPROGRESS',
            'DRIED',
        ];
        $response =  [
            'id' => $this->id,
            'order_number' => $this->order_number,
            'angel_id' => $this->angel_id,
            'user_type' => $this->order->user_type,
            'customer_name' => $this->order->customer_name,
            'customer_email' => $this->order->customer_email,
            'customer_phone' => $this->order->customer_phone,
            'source_latitude' => $this->source_latitude ?? '',
            'source_longitude' => $this->source_longitude ?? '',
            'source_place_id' => $this->source_place_id ?? '',
            'source_address' => $this->source_address ?? '',
            'asset_location' => $this->source_address ?? '', // dinesh requirement
            'source_postal_code' => $this->source_postal_code ?? '',
            'destination_latitude' => $this->destination_latitude ?? '',
            'destination_longitude' => $this->destination_longitude ?? '',
            'destination_place_id' => $this->destination_place_id ?? '',
            'destination_address' => $this->destination_address ?? '',
            'delivery_location' => $this->destination_address ?? '', // dinesh requirement
            'destination_postal_code' => $this->destination_postal_code ?? '',
            'distance' => $this->distance,
            'asset_type' => 'angel-service',
            'order_type' => 'Angel Sevice',
            'value_added_service_id' => $this->value_added_service_id,
            'delivery_type' => $this->delivery_type,
            'order_description' => $this->order_description ?? '',
            'angel_assign_datetime' => $this->angel_assign_datetime,
            'delivery_date' => $this->delivery_date,
            'delivery_time' => $this->delivery_time,
            'cost' => $this->cost,
            'value_added_service_amount' => $this->value_added_service_amount ?? 0,
            'discount' => $this->discount ?? 0,
            'angel_tips' => $this->angel_tips ?? 0,
            'convenience_fee' => $this->convenience_fee ?? 0,
            'delivery_charge' => $this->delivery_charge ?? 0,
            'order_sub_total' => $this->order_sub_total ?? 0,
            'order_grand_total' => $this->order_grand_total ?? 0,
            'payment_method' => $this->payment_method,
            'split_payment' => $this->split_payment,
            'wallet_amount' => $this->wallet_amount ?? 0,
            'status' => $status[$this->status] ?? "TO SWAP",
            'payment_status' => $this->payment_status ?? 'Pending',
            'payment_type' => $this->payment_type,
            'model_name' => $this->model_name,
        ];

        

        if($this->angel_id){
            $response['angel_name'] = $this->angel->name;
            $response['angel_email'] = $this->angel->email;
            $response['angel_phonel'] = $this->angel->phone_number;
        }
        if($this->subscription_id){
            $response['subscription_plan'] = $this->angelServiceSubscription?->plan_name;
            $response['subscription_data'] = (new AngelServiceSubscriptionResource($this->angelServiceSubscription))->order($this);            
        }
        if($this->orderFeedback){
            $response['feedback'] = $this->orderFeedback->feedback;
            $response['rating'] = $this->orderFeedback->rating;
            $response['impression_points'] = $this->orderFeedback->impression_points;
        }
                
        return $response;
    }
}
