<?php

namespace App\Mail;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Mail\Mailable;
use Illuminate\Mail\Mailables\Content;
use Illuminate\Mail\Mailables\Envelope;
use Illuminate\Queue\SerializesModels;
use App\Models\MailVariable;

class DynamicMail extends Mailable
{
    use Queueable, SerializesModels;


    public $mailData;
    public $template;
    public $templateVariables;



    /**
     * Create a new message instance.
     *
     * @return void
     * 
     * Mail Data sample 
     * $mailData = [
     *       'template' => $mailTemplate,
     *      'data' => [
     *           'user' => $user,
     *           'data' => $user->userData
     *       ]
     *   ];
     */
    public function __construct($mailData)
    {
        $this->mailData = $mailData['data'];
        $this->template = $mailData['template'];
        $variables = MailVariable::get()->toArray();
        
        $this->templateVariables = $variables;

    }

    /**
     * Get the message envelope.
     *
     * @return \Illuminate\Mail\Mailables\Envelope
     */
    public function envelope()
    {
        return new Envelope(
            subject: $this->template->subject,
        );
    }

    /**
     * Get the message content definition.
     *
     * @return \Illuminate\Mail\Mailables\Content
     */
    public function content()
    {
        return new Content(
            view: 'admin.mail_templates.mail_templates',
        );
    }

    /**
     * Get the attachments for the message.
     *
     * @return array
     */
    public function attachments()
    {
        return [];
    }
}
