<?php

namespace App\Models\Assets;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class ChargingEquipment extends Model
{
    use HasFactory;
    
    
    
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }

    
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'a_charging_equipment';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'product_id',
        'charging_equipment_type',
        'model_name',
        'email',
        'charger_type',
        'model_number',
        'kwh_units',
        'gun_type',
        'gun_type',
        'qr_code',
        'oem_id',
        'charging_equipment_dealer_id',
        'purchased_invoice_number',
        'purchased_date',
        'location_id',
        'city_id',
        'district_id',
        'state_id',
        'zone_id',
        'status',
        'created_by',
        'updated_by',
        'deleted_at',
    ];
    
    public function createdUser(){
        return $this->belongsTo('App\Models\User', 'created_by');
    }
    public function updatedUser(){
        return $this->belongsTo('App\Models\User', 'updated_by');
    }
    public function vendorOem(){
        return $this->belongsTo('App\Models\Vendors\VendorOem', 'oem_id');
    }
    public function chargingEquipmentDealer(){
        return $this->belongsTo('App\Models\Vendors\ChargingStation', 'charging_equipment_dealer_id');
    }
    public function product(){
        return $this->belongsTo('App\Models\Master\ProductType', 'product_id');
    }
    public function location(){
        return $this->belongsTo('App\Models\Location', 'location_id');
    }
    public function zone(){
        return $this->belongsTo('App\Models\Master\Zone', 'zone_id');
    }
    public function state(){
        return $this->belongsTo('App\Models\Master\ZoneState', 'state_id');
    }
    public function district(){
        return $this->belongsTo('App\Models\Master\ZoneDistrict', 'district_id');
    }
    public function city(){
        return $this->belongsTo('App\Models\Master\ZoneCity', 'city_id');
    }
    public function parts(){
        return $this->hasMany('App\Models\Assets\ChargingEquipmentParts', 'charging_equipment_id');
    }
    public function images(){
        return $this->hasMany('App\Models\Assets\ChargingEquipmentImages', 'charging_equipment_id');
    }
    public function servicePlan(){
        return $this->hasMany('App\Models\Assets\ChargingEquipmentServicePlan', 'charging_equipment_id');
    }
    public function insurancePlan(){
        return $this->hasMany('App\Models\Assets\ChargingEquipmentInsurancePlan', 'charging_equipment_id');
    }
    public function chargingStation(){
        return $this->hasOne('App\Models\Assets\ChargingStation', 'location_id', 'location_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');
        if($requestData['city_id']){
            $query->where('city_id', '=', $requestData['city_id']);
        }
        if($requestData['district_id']){
            $query->where('district_id', '=', $requestData['district_id']);
        }
        if($requestData['state_id']){
            $query->where('state_id', '=', $requestData['state_id']);
        }
        if($requestData['zone_id']){
            $query->where('zone_id', '=', $requestData['zone_id']);
        }
        if($requestData['oem_id']){
            $query->where('oem_id', '=', $requestData['oem_id']);
        }
        if($requestData['charging_equipment_dealer_id']){
            $query->where('charging_equipment_dealer_id', '=', $requestData['charging_equipment_dealer_id']);
        }
        if($requestData['search'] != '' ){
            $query->where('model_name', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('model_number', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('charger_type', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('kwh_units', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('gun_type', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('purchased_invoice_number', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('updated_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('vendorOem', 'vendor_oem', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('chargingEquipmentDealer', 'station_dealer', 'like', '%'.$requestData['search'].'%');
            //$query->orwhereRelation('servicePlan', 'station_dealer', 'like', '%'.$requestData['search'].'%');
            // $query->orwhereRelation('zone', 'zone', 'like', '%'.$requestData['search'].'%');
            // $query->orwhereRelation('state', 'state', 'like', '%'.$requestData['search'].'%');
            // $query->orwhereRelation('district', 'district', 'like', '%'.$requestData['search'].'%');
            // $query->orwhereRelation('city', 'city', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
