<?php

namespace App\Models\Assets;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Traits\App;

class ChargingStation extends Model
{
    use HasFactory;
    use App;
    
    
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'a_charging_station';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'product_id',
        'property_id',
        'charging_station_type',
        'model_name',
        'email',
        'vin_number',
        'qr_code',
        'oem_id',
        'charging_station_dealer_id',
        'purchased_invoice_number',
        'purchased_date',
        'location_id',
        'city_id',
        'district_id',
        'state_id',
        'zone_id',
        'status',
        'created_by',
        'updated_by',
        'deleted_at',
    ];
    
    public function vendorOem(){
        return $this->belongsTo('App\Models\Vendors\VendorOem', 'oem_id');
    }
    public function chargingStationDealer(){
        return $this->belongsTo('App\Models\Vendors\Battery', 'charging_station_dealer_id');
    }
    public function product(){
        return $this->belongsTo('App\Models\Master\ProductType', 'product_id');
    }
    public function property(){
        return $this->belongsTo('App\Models\Master\PropertyType', 'property_id');
    }
    public function location(){
        return $this->belongsTo('App\Models\Location', 'location_id');
    }
    public function zone(){
        return $this->belongsTo('App\Models\Master\Zone', 'zone_id');
    }
    public function state(){
        return $this->belongsTo('App\Models\Master\ZoneState', 'state_id');
    }
    public function district(){
        return $this->belongsTo('App\Models\Master\ZoneDistrict', 'district_id');
    }
    public function city(){
        return $this->belongsTo('App\Models\Master\ZoneCity', 'city_id');
    }
    public function parts(){
        return $this->hasMany('App\Models\Assets\ChargingStationParts', 'charging_station_id');
    }
    public function images(){
        return $this->hasMany('App\Models\Assets\ChargingStationImages', 'charging_station_id');
    }
    public function servicePlan(){
        return $this->hasMany('App\Models\Assets\ChargingStationServicePlan', 'charging_station_id');
    }
    public function insurancePlan(){
        return $this->hasMany('App\Models\Assets\ChargingStationInsurancePlan', 'charging_station_id');
    }
    public function chargingEquipments(){
        return $this->hasMany('App\Models\Assets\ChargingEquipment', 'location_id', 'location_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');
        if($requestData['city_id']){
            $query->where('city_id', '=', $requestData['city_id']);
        }
        if($requestData['district_id']){
            $query->where('district_id', '=', $requestData['district_id']);
        }
        if($requestData['state_id']){
            $query->where('state_id', '=', $requestData['state_id']);
        }
        if($requestData['zone_id']){
            $query->where('zone_id', '=', $requestData['zone_id']);
        }
        if($requestData['oem_id']){
            $query->where('oem_id', '=', $requestData['oem_id']);
        }
        if($requestData['charging_station_dealer_id']){
            $query->where('charging_station_dealer_id', '=', $requestData['charging_station_dealer_id']);
        }
        if($requestData['search'] != '' ){
            $query->where('model_name', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
        //    $query->orwhereRelation('vendorOem', 'vendor_oem', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('chargingEquipmentDealer', 'chargingEquipmentDealer', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('zone', 'zone', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('state', 'state', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('district', 'district', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('city', 'city', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
