<?php

namespace App\Models\Assets;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Models\VehicleOem;
use App\Models\Assets\vendoroem_model;
class Vehicle extends Model
{
    use HasFactory;
    
    
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'a_vehicle';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'product_id',
        'property_type_id',
        'vehicle_type',
        'vehicle_name',
        'model_name',
        'registeration_number',
        'email',
        'vin_number',
        'qr_code',
        'oem_id',
        'vehicle_dealer_id',
        'purchased_invoice_number',
        'purchased_date',
        'location_id',
        'city_id',
        'district_id',
        'state_id',
        'zone_id',
        'status',
        'created_by',
        'updated_by',
        'deleted_at',
        'rc_book',
    ];

    public function vendorsoem(){
        return $this->belongsTo('App\Models\VehicleOem', 'vehicle_name');
    }

    public function vendorOeems(){
        return $this->belongsTo('App\Models\VehicleOem', 'oem_id');
    }
    
    public function vendorOeemsmodel(){
        return $this->belongsTo('App\Models\Assets\vendoroem_model', 'model_name');
    }
    public function vendorOem(){
        return $this->belongsTo('App\Models\Vendors\VendorOem', 'oem_id');
    }
    public function vehicleDealer(){
        return $this->belongsTo('App\Models\Vendors\Vehicle', 'vehicle_dealer_id');
    }
    public function product(){
        return $this->belongsTo('App\Models\Master\ProductType', 'product_id');
    }
    public function propertyType(){
        return $this->belongsTo('App\Models\Master\PropertyType', 'property_type_id');
    }
    public function location(){
        return $this->belongsTo('App\Models\Location', 'location_id');
    }
    public function zone(){
        return $this->belongsTo('App\Models\Master\Zone', 'zone_id');
    }
    public function state(){
        return $this->belongsTo('App\Models\Master\ZoneState', 'state_id');
    }
    public function district(){
        return $this->belongsTo('App\Models\Master\ZoneDistrict', 'district_id');
    }
    public function city(){
        return $this->belongsTo('App\Models\Master\ZoneCity', 'city_id');
    }
    public function parts(){
        return $this->hasMany('App\Models\Assets\VehicleParts', 'vehicle_id');
    }
    public function images(){
        return $this->hasMany('App\Models\Assets\VehicleImages', 'asset_id');
    }
    public function servicePlan(){
        return $this->hasMany('App\Models\Assets\VehicleServicePlan', 'asset_id');
    }
    public function insurancePlan(){
        return $this->hasMany('App\Models\Assets\VehicleInsurancePlan', 'asset_id');
    }
    public function ratings(){
        return $this->hasMany('App\Models\Assets\VehicleRatings', 'asset_id');
    }
    public function subscriptionPlanAsset(){
        return $this->hasMany('App\Models\SubscriptionPlan\Vehicle', 'model_name', 'model_name');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');
        if($requestData['city_id']){
            $query->where('city_id', '=', $requestData['city_id']);
        }
        if($requestData['district_id']){
            $query->where('district_id', '=', $requestData['district_id']);
        }
        if($requestData['state_id']){
            $query->where('state_id', '=', $requestData['state_id']);
        }
        if($requestData['zone_id']){
            $query->where('zone_id', '=', $requestData['zone_id']);
        }
        if($requestData['oem_id']){
            $query->where('oem_id', '=', $requestData['oem_id']);
        }
        if($requestData['vehicle_dealer_id']){
            $query->where('vehicle_dealer_id', '=', $requestData['vehicle_dealer_id']);
        }
        if($requestData['search'] != '' ){
            $query->where('model_name', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
        //    $query->orwhereRelation('vendorOem', 'vendor_oem', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('vehicleDealer', 'vehicle_dealer', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('zone', 'zone', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('state', 'state', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('district', 'district', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('city', 'city', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
