<?php

namespace App\Models\CMS;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Announcement extends Model
{
    use HasFactory;
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'cms_announcement';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'announcement_name',
        'mobile_user',
        'image',
        'link_page',
        'location',
        'created_by',
        'updated_by',
        'deleted_at',
    ];
    
    public function createdUser(){        
        return $this->belongsTo('App\Models\User', 'created_by');
    }
    public function updatedUser(){        
        return $this->belongsTo('App\Models\User', 'updated_by');
    }
    public function announcementLocation(){
        return $this->hasOne('App\Models\CMS\AnnouncementLocation', 'announcement_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');

        if($requestData['announcement_name'] != '' ){
            $query->where('announcement_name', $requestData['announcement_name']);
        }
        if($requestData['location'] != '' ){
            $query->where('location', $requestData['location']);
        }
        if($requestData['updated_by'] != '' ){
            $query->where('updated_by', $requestData['updated_by']);
        }
        if($requestData['search'] != '' ){
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
