<?php

namespace App\Models\CMS;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class EmergencyService extends Model
{
    use HasFactory;
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'cms_emergency_services';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'emergency_service_id',
        'mobile_user',
        'description',
        'steps_to_be_done',
        'search_tag',
        'phone_number',
        'created_by',
        'updated_by',
        'deleted_at',
    ];
    
    public function emergencyService(){        
        return $this->belongsTo('App\Models\Master\EmergencyService', 'emergency_service_id');
    }
    public function createdUser(){        
        return $this->belongsTo('App\Models\User', 'created_by');
    }
    public function updatedUser(){        
        return $this->belongsTo('App\Models\User', 'updated_by');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');

        if($requestData['emergency_service_id'] != '' ){
            $query->where('emergency_service_id', $requestData['emergency_service_id']);
        }
        if($requestData['updated_by'] != '' ){
            $query->where('updated_by', $requestData['updated_by']);
        }
        if($requestData['search'] != '' ){
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
