<?php

namespace App\Models\CMS;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class FeedbackRating extends Model
{
    use HasFactory;

    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'cms_feedback_rating';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'feedback_rating_for',
        'mobile_user',
        'star_rating',
        'allow_remark',
        'created_by',
        'updated_by',
        'deleted_at',
    ];
    
    public function createdUser(){        
        return $this->belongsTo('App\Models\User', 'created_by');
    }
    public function updatedUser(){        
        return $this->belongsTo('App\Models\User', 'updated_by');
    }
    public function ratingImpression(){        
        return $this->hasMany('App\Models\CMS\FeedbackRatingImpression', 'feedback_rating_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');

        if($requestData['feedback_rating_for'] != '' ){
            $query->where('feedback_rating_for', $requestData['feedback_rating_for']);
        }
        if($requestData['updated_by'] != '' ){
            $query->where('updated_by', $requestData['updated_by']);
        }
        if($requestData['search'] != '' ){
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
