<?php

namespace App\Models\CMS;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Forms extends Model
{
    use HasFactory;

    
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'cms_forms';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'slug',
        'name',
        'title', 
        'sub_title', 
        'description', 
        'image',
        'image_width',
        'image_width_type',
        'image_height',
        'image_height_type',
        'bottom_image',
        'bottom_image_width',
        'bottom_image_width_type',
        'bottom_image_height',
        'bottom_image_height_type',
        'content', 
        'is_before_login',
        'is_back_button', 
        'have_section', 
        'fields_have_values', 
        'priority',
        'created_by',
    ];
    
    public function createdUser(){        
        return $this->belongsTo('App\Models\User', 'created_by');
    }
    public function updatedUser(){        
        return $this->belongsTo('App\Models\User', 'updated_by');
    }
    public function formButtons(){
        return $this->hasMany('App\Models\CMS\FormButtons', 'form_id');
    }
    public function formFields(){
        return $this->hasMany('App\Models\CMS\FormFields', 'form_id')->orderBy('priority');;
    }
    
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');

        if($requestData['title'] != '' ){
            $query->where('title', $requestData['title']);
        }
        if($requestData['slug'] != '' ){
            $query->where('slug', $requestData['slug']);
        }
        if($requestData['search'] != '' ){
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'DESC');
        //$query->orderBy('priority', 'asc');
        return $query;
   }
}
