<?php

namespace App\Models\CMS;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Menu extends Model
{
    use HasFactory;
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'cms_menu';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'title',
        'mobile_user',
        'business_category_id',
        'business_model_id',
        'title_color',
        'have_suffix_title',
        'suffix_title',
        'suffix_title_color',
        'redirect_url',
        'redirect_type',
        'priority',
        'created_by',
        'updated_by',
        'deleted_at',
    ];
    
    public function createdUser(){        
        return $this->belongsTo('App\Models\User', 'created_by');
    }
    public function updatedUser(){        
        return $this->belongsTo('App\Models\User', 'updated_by');
    }
    public function userData(){
        return $this->hasOne('App\Models\Users\UserData', 'user_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');

        if($requestData['title'] != '' ){
            $query->where('title', $requestData['title']);
        }
        if($requestData['search'] != '' ){
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
