<?php

namespace App\Models\CMS;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class TabMenu extends Model
{
    use HasFactory;
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'cms_form_field_tab_menu';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'form_id',
        'form_field_id',
        'menu',
        'deleted_at',
    ];
    
    public $timestamps = false;

    public function form(){
       return $this->belongsTo('App\Models\CMS\Forms', 'form_id');
    }
    public function formField(){
        return $this->belongsTo('App\Models\CMS\FormFields', 'form_field_id');
    }
    public function tabMenuInputs(){
        return $this->hasMany('App\Models\CMS\TabMenuInput', 'tab_menu_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');

        if($requestData['form_id'] != '' ){
            $query->where('form_id', $requestData['form_id']);
        }
        if($requestData['form_field_id'] != '' ){
            $query->where('form_field_id', $requestData['form_field_id']);
        }
        if($requestData['search'] != '' ){
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        $query->groupBy('form_field_id');
        return $query;
   }
}
