<?php

namespace App\Models\CMS;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class WalkaroundChecklist extends Model
{
    use HasFactory;

    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'cms_walkaround_checklist';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'product_type_id',
        'product_model',
        'subscription_plan_id',
        'mobile_user',
        'created_by',
        'updated_by',
        'deleted_at',
    ];
    
    public function createdUser(){
        return $this->belongsTo('App\Models\User', 'created_by');
    }
    public function updatedUser(){
        return $this->belongsTo('App\Models\User', 'updated_by');
    }
    public function walkaroundQuestions(){
        return $this->hasMany('App\Models\CMS\WalkaroundQuestion', 'walkaround_checklis_id');
    }
    public function walkaroundCategories(){
        return $this->hasMany('App\Models\CMS\WalkaroundCategory', 'walkaround_checklis_id');
    }
    public function productType(){
        return $this->belongsTo('App\Models\Master\ProductType', 'product_type_id');
    }
    public function vehiclePlan(){
        return $this->belongsTo('App\Models\SubscriptionPlan\Vehicle', 'subscription_plan_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');

        if($requestData['product_model'] != '' ){
            $query->where('product_model', $requestData['product_model']);
        }
        if($requestData['category_id'] != '' ){
            $query->where('product_model', $requestData['product_model']);
        }
        if($requestData['product_type_id'] != '' ){
            $query->where('product_type_id', $requestData['product_type_id']);
        }
        if($requestData['updated_by'] != '' ){
            $query->where('updated_by', $requestData['updated_by']);
        }
        if($requestData['search'] != '' ){
            $query->orWhere('product_model', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('product_type_id', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('updatedUser', 'name', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('walkaroundCategories', 'category_name', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('productType', 'product_type', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
