<?php

namespace App\Models\Marketing;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Discount extends Model
{
    use HasFactory;
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'mr_discount';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'discount_code',
        'business_category_id',
        'image',
        'link_page',
        'city_id',
        'district_id',
        'state_id',
        'zone_id',
        'subscription_plan_id',
        'minimum_order_cost',
        'discount',
        'up_to_cost',
        'expiry_date',
        'created_by',
        'deleted_at',
    ];
    
    public function businessCategory(){
        return $this->belongsTo('App\Models\Master\BusinessCategory', 'business_category_id');
    }
    public function zone(){
        return $this->belongsTo('App\Models\Master\Zone', 'zone_id');
    }
    public function state(){
        return $this->belongsTo('App\Models\Master\ZoneState', 'state_id');
    }
    public function district(){
        return $this->belongsTo('App\Models\Master\ZoneDistrict', 'district_id');
    }
    public function city(){
        return $this->belongsTo('App\Models\Master\ZoneCity', 'city_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');
        if($requestData['city_id']){
            $query->where('city_id', '=', $requestData['city_id']);
        }
        if($requestData['district_id']){
            $query->where('district_id', '=', $requestData['district_id']);
        }
        if($requestData['state_id']){
            $query->where('state_id', '=', $requestData['state_id']);
        }
        if($requestData['zone_id']){
            $query->where('zone_id', '=', $requestData['zone_id']);
        }
        if($requestData['search'] != '' ){
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('zone', 'zone', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('state', 'state', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('district', 'district', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('city', 'city', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
