<?php

namespace App\Models\Master;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class ZoneDistrict extends Model
{
    use HasFactory;
    
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'master_zone_district';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'zone_id',
        'state_id',
        'district',
        'created_by',
        'deleted_at',
    ];
    
    public function zone(){
        return $this->belongsTo('App\Models\Master\Zone', 'zone_id');
    }
    public function state(){
        return $this->belongsTo('App\Models\Master\ZoneState', 'state_id');
    }
    
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::with(['zone', 'state'])->whereNull('deleted_at');
        if($requestData['zone_id'] > 0 ){
            $query->where('zone_id', '=', $requestData['zone_id']);
        }
        if($requestData['state_id'] > 0 ){
            $query->where('state_id', '=', $requestData['state_id']);
        }
        if($requestData['district'] > 0 ){
            $query->where('district', '=', $requestData['district']);
        }
        if($requestData['search'] != '' ){
            $query->where('district', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('zone', 'zone', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('state', 'state', 'like', '%'.$requestData['search'].'%');
            // $asset->whereHas('category', function (Builder $query) {
            //     $query->orWhere('category_name', 'like', '%batte%');
            // });
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
   public function districts_by_zone($zone_id){
        return self::where('zone_id', $zone_id)->get();
   }
   
   public function districts_by_state($state_id){
    return self::where('state_id', $state_id)->get();
    }
}
