<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Order extends Model
{
    use HasFactory;
    
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'orders';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'order_number',
        'user_id',
        'angel_id', 
        'user_type', 
        'customer_name', 
        'customer_email',
        'customer_phone',
        'duration', 
        'duration_start',  
        'duration_start_time', 
        'duration_end', 
        'duration_end_time', 
        'source_latitude', 
        'source_longitude', 
        'source_place_id', 
        'source_address', 
        'source_postal_code', 
        'destination_latitude', 
        'destination_longitude', 
        'destination_place_id', 
        'destination_address', 
        'destination_postal_code', 
        'distance', 
        'flat_no', 
        'user_address', 
        'landmark',
        'country',
        'district',
        'state_name',
        'city_name',
        'source_postal_code',
        'destination_postal_code',
        'source_google_place_id',
        'destination_google_place_id',
        'location_name',
        'order_type',
        'asset_type',
        'asset_id',
        'model_name',
        'subscription_id',
        'value_added_service_id',
        'delivery_type',
        'order_description',
        'angel_assign_datetime',
        'delivery_date',
        'delivery_time',
        'delivered_time',
        'cost',
        'value_added_service_amount',
        'discount',
        'angel_tips',
        'convenience_fee',
        'delivery_charge',
        'order_sub_total',
        'order_grand_total',
        'payment_method',
        'payment_method_id',
        'split_payment',
        'wallet_amount',
        'failed_reason',
        'status_id',
        'status',
        'payment_status',
        'payment_type',
        'ip',
        'device_id'
    ];
    
    public function user(){
        return $this->belongsTo('App\Models\User', 'user_id');
    }
    public function angel(){
        return $this->belongsTo('App\Models\User', 'angel_id');
    }
    public function vehicleAsset(){
        return $this->belongsTo('App\Models\Assets\Vehicle', 'asset_id');
    }
    // public function batteryAsset(){
    //     return $this->belongsTo('App\Models\Assets\Battery', 'asset_id');
    // }
    public function batteryAsset(){
        return $this->belongsTo('App\Models\Assets\Battery', 'battery_id');
    }
    public function userSubscription(){
        return $this->hasOne('App\Models\Users\UserSubscription', 'order_id');
    }
    public function vehicleSubscription(){
        return $this->belongsTo('App\Models\SubscriptionPlan\Vehicle', 'subscription_id');
    }
    // public function batterySubscription(){
    //     return $this->belongsTo('App\Models\SubscriptionPlan\Battery', 'subscription_id');
    // }
    public function orderFeedback(){
        return $this->hasOne('App\Models\Orders\OrderFeedback', 'order_id');
    }
    public function orderWalkaround(){
        return $this->hasMany('App\Models\Orders\OrderWalkaround', 'order_id');
    }
    public function orderWalkaroundCategory(){
        return $this->hasMany('App\Models\Orders\OrderWalkaroundCategory', 'order_id');
    }
    public function orderBattery(){
        return $this->hasMany('App\Models\Orders\OrderBattery', 'order_id')->orderBy('created_at', 'DESC'); // Order by important -  to change status while assign un user subscription
    }
    public function orderAngelService(){
        return $this->hasMany('App\Models\Orders\OrderAngelService', 'order_id')->orderBy('created_at', 'DESC'); // Order by important -  to change status while assign un user subscription
    }
    public function orderChargingStation(){
        return $this->hasMany('App\Models\Orders\OrderChargingStation', 'order_id')->orderBy('created_at', 'DESC'); // Order by important -  to change status while assign un user subscription
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::with(['user', 'angel'])->whereNull('deleted_at');
        
        //if($requestData['search'] != '' ){
            //$query->where('name', 'like', '%'.$requestData['search'].'%');
           // $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
           // $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
           // $query->orwhereRelation('category', 'category_name', 'like', '%'.$requestData['search'].'%');
            // $asset->whereHas('category', function (Builder $query) {
            //     $query->orWhere('category_name', 'like', '%batte%');
            // });
        //}
        $query->orderBy('id', 'desc');
        return $query;
    }
}
