<?php

namespace App\Models\Orders;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Traits\App;

class OrderBattery extends Model
{
    use App;

    use HasFactory;
    
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'order_battery';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'order_id',
        'order_number',
        'battery_id',
        'dry_battery_id',
        'booking_date',
        'source_latitude', 
        'source_longitude', 
        'source_place_id', 
        'source_address', 
        'source_postal_code', 
        'destination_latitude', 
        'destination_longitude', 
        'destination_place_id', 
        'destination_address', 
        'destination_postal_code', 
        'distance', 
        'source_google_place_id',
        'destination_google_place_id',
        'model_name',
        'asset_type',
        'asset_id',
        'subscription_id',
        'value_added_service_id',
        'delivery_type',
        'order_description',
        'angel_assign_datetime',
        'delivery_date',
        'delivery_time',
        'delivered_time',
        'cost',
        'value_added_service_amount',
        'discount',
        'angel_tips',
        'convenience_fee',
        'delivery_charge',
        'order_sub_total',
        'order_grand_total',
        'payment_method',
        'payment_method_id',
        'split_payment',
        'wallet_amount',
        'failed_reason',
        'status_id',
        'status',
        'payment_status',
        'payment_type',
        'created_by',
        'updated_by',
        'deleted_at'
    ];
    
    public function order(){
        return $this->belongsTo('App\Models\Order', 'order_id');
    }
    public function batteryAsset(){
        return $this->belongsTo('App\Models\Assets\Battery', 'battery_id');
    }
    public function dryBatteryAsset(){
        return $this->belongsTo('App\Models\Assets\Battery', 'dry_battery_id');
    }
    public function batterySubscription(){
        return $this->belongsTo('App\Models\SubscriptionPlan\Battery', 'subscription_id');
    }
    public function orderFeedback(){
        return $this->hasOne('App\Models\Orders\OrderFeedback', 'order_battery_id');
    }
    public function orderWalkaround(){
        return $this->hasMany('App\Models\Orders\OrderWalkaround', 'order_battery_id');
    }
    public function orderWalkaroundCategory(){
        return $this->hasMany('App\Models\Orders\OrderWalkaroundCategory', 'order_battery_id');
    }


    
    public function createQuery($requestData){
        $query = self::whereNull('deleted_at');
        
        if($requestData['order_id']){
            $query->where('order_id', '=', $requestData['order_id']);
        }
        //if($requestData['search'] != '' ){
            //$query->where('name', 'like', '%'.$requestData['search'].'%');
           // $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
           // $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
           // $query->orwhereRelation('category', 'category_name', 'like', '%'.$requestData['search'].'%');
            // $asset->whereHas('category', function (Builder $query) {
            //     $query->orWhere('category_name', 'like', '%batte%');
            // });
        //}
        $query->orderBy('id', 'desc');
        return $query;
    }
}
