<?php

namespace App\Models\PrchasedService;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class ChargingStation extends Model
{
    use HasFactory;
    
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'ps_charging_station';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'purchased_service_id',
        'location_id',
        'vendor_workshop_id',
        'asset_type_id',
        'asset_id',
        'bill_number',
        'service_cost',
        'start_date',
        'estimated_delivery_date',
        'actual_delivery_date',
        'remarks',
        'created_by',
        'updated_by',
        'deleted_at',
    ];
    
    public function purchasedService(){
        return $this->belongsTo('App\Models\Master\PurchasedService', 'purchased_service_id');
    }
    public function location(){
        return $this->belongsTo('App\Models\Location', 'location_id');
    }
    public function serviceWorkshop(){
        return $this->belongsTo('App\Models\Vendors\ServiceWorkshop', 'vendor_workshop_id');
    }
    public function asset(){
        return $this->belongsTo('App\Models\Assets\ChargingStation', 'asset_id');
    }
    public function assetType(){
        return $this->belongsTo('App\Models\Master\ProductType', 'asset_type_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');
        if($requestData['purchased_service_id']){
            $query->where('purchased_service_id', '=', $requestData['purchased_service_id']);
        }
        if($requestData['location_id']){
            $query->where('location_id', '=', $requestData['location_id']);
        }
        if($requestData['vendor_workshop_id']){
            $query->where('vendor_workshop_id', '=', $requestData['vendor_workshop_id']);
        }
        if($requestData['asset_type_id']){
            $query->where('asset_type_id', '=', $requestData['asset_type_id']);
        }
        if($requestData['search'] != '' ){
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('purchasedService', 'purchased_service', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
