<?php

namespace App\Models\PrchasedService;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Manpower extends Model
{
    use HasFactory;
    
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'ps_manpower';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'purchased_service_id',
        'location_id',
        'vendor_manpower_id',
        'resource_name',
        'work_call',
        'designation_id',
        'gozap_prefix',
        'gozap_number',
        'gozap_id',
        'duration_id',
        'bill_number',
        'service_cost',
        'start_date',
        'end_date',
        'remarks',
        'created_by',
        'updated_by',
        'deleted_at',
    ];
    
    public function purchasedService(){
        return $this->belongsTo('App\Models\Master\PurchasedService', 'purchased_service_id');
    }
    public function location(){
        return $this->belongsTo('App\Models\Location', 'location_id');
    }
    public function duration(){
        return $this->belongsTo('App\Models\Master\Duration', 'duration_id');
    }
    public function designation(){
        return $this->belongsTo('App\Models\Master\Designation', 'designation_id');
    }
    public function vendorManpower(){
        return $this->belongsTo('App\Models\Vendors\Manpower', 'vendor_manpower_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');
        if($requestData['purchased_service_id']){
            $query->where('purchased_service_id', '=', $requestData['purchased_service_id']);
        }
        if($requestData['location_id']){
            $query->where('location_id', '=', $requestData['location_id']);
        }
        if($requestData['vendor_manpower_id']){
            $query->where('vendor_manpower_id', '=', $requestData['vendor_manpower_id']);
        }
        if($requestData['search'] != '' ){
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('purchasedService', 'purchased_service', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
