<?php

namespace App\Models\SubscriptionPlan;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Traits\App;

class AngelService extends Model
{
    use HasFactory;
    use App;
   
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'subs_angel_service';


    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'plan_name',
        'business_category_id',
        'business_model_id',
        'service_type_id',
        'product_overview',
        'fixed_price',
        'base_plan',
        'have_convenience_price',
        'convenience_price',
        'have_delivery_charge',
        'delivery_charge',
        'created_by',
        'updated_by',
        'deleted_at',
        'fixed_price_taxation_profile_id',
        'convenience_price_taxation_profile_id',
        'delivery_charge_taxation_profile_id',
    ];
    
    public function businessCategory(){
        return $this->belongsTo('App\Models\Master\BusinessCategory', 'business_category_id');
    }
    public function businessModel(){
        return $this->belongsTo('App\Models\Master\BusinessModels', 'business_model_id');
    }
    public function location(){
        return $this->hasMany('App\Models\SubscriptionPlan\AngelServiceLocation', 'plan_id');
    }
    public function terms(){
        return $this->hasMany('App\Models\SubscriptionPlan\AngelServiceTermsCondition', 'plan_id');
    }
    public function serviceType(){
        return $this->belongsTo('App\Models\Master\AngelService', 'service_type_id');
    }
    
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');
        if($requestData['plan_name']){
            $query->where('plan_name', '=', $requestData['plan_name']);
        }
        if($requestData['business_category_id']){
            $query->where('business_category_id', '=', $requestData['business_category_id']);
        }
        if($requestData['service_type_id']){
            $query->where('service_type_id', '=', $requestData['service_type_id']);
        }
        if($requestData['search'] != '' ){
            $query->where('plan_name', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
        //    $query->orwhereRelation('vendorOem', 'vendor_oem', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('businessCategory', 'business_categor', 'like', '%'.$requestData['search'].'%');
            $query->orwhereRelation('serviceType', 'service_type', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
