<?php

namespace App\Models\SubscriptionPlan;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class ChargingEquipment extends Model
{
    use HasFactory;
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
        static::updating(function ($model) {
            $model->updated_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'subs_charging_equipment';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'plan_name',
        'business_category_id',
        'business_model_id',
        'asset_type_id',
        'oem_id',
        'charger_type',
        'model_name',
        'kwh_units',
        'value_added_service_id',
        'product_overview',
        'fixed_price',
        'unit_count',
        'have_convenience_price',
        'convenience_price',
        'have_delivery_charge',
        'delivery_charge',
        'base_plan',
        'charging_duration',
        'by_units',
        'by_slab_units',
        'created_by',
        'updated_by',
        'deleted_at',
        'fixed_price_taxation_profile_id',
        'convenience_price_taxation_profile_id',
        'delivery_charge_taxation_profile_id',
    ];
    
    public function businessCategory(){
        return $this->belongsTo('App\Models\Master\BusinessCategory', 'business_category_id');
    }
    public function businessModel(){
        return $this->belongsTo('App\Models\Master\BusinessModels', 'business_model_id');
    }
    public function assetType(){
        return $this->belongsTo('App\Models\Master\ProductType', 'asset_type_id');
    }
    public function location(){
        return $this->hasMany('App\Models\SubscriptionPlan\ChargingEquipmentLocation', 'plan_id');
    }
    public function terms(){
        return $this->hasMany('App\Models\SubscriptionPlan\ChargingEquipmentTermsCondition', 'plan_id');
    }
    public function parts(){
        return $this->hasMany('App\Models\SubscriptionPlan\ChargingEquipmentAssetPart', 'plan_id');
    }
    public function vaService(){
        return $this->hasMany('App\Models\SubscriptionPlan\ChargingEquipmentAssetVAService', 'plan_id');
    }
    public function assets(){
        return $this->hasMany('App\Models\Assets\ChargingEquipment',  'model_name', 'model_name');
    }
    public function basePriceTaxationProfile(){
        return $this->belongsTo('App\Models\Master\Taxationprofile', 'base_price_taxation_profile_id');
    }
    public function convenienceFeeTaxationProfile(){
        return $this->belongsTo('App\Models\Master\Taxationprofile', 'convenience_fee_taxation_profile_id');
    }
    public function deliveryFeeTaxationProfile(){
        return $this->belongsTo('App\Models\Master\Taxationprofile', 'delivery_fee_taxation_profile_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');
        // if($requestData['city_id']){
        //     $query->where('city_id', '=', $requestData['city_id']);
        // }
        if($requestData['search'] != '' ){
           
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
