<?php

namespace App\Models\SubscriptionPlan;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Traits\App;

class ValueAddedService extends Model
{
    use HasFactory;
    use App;
    
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'subs_value_added_service';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'plan_name',
        'business_category_id',
        'business_model_id',
        'va_service_id',
        'product_overview',
        'fixed_price',
        'base_plan',
        'billing_period_id',
        'grace_time_hr',
        'grace_time',
        'lock_bike',
        'have_convenience_price',
        'convenience_price',
        'have_delivery_charge',
        'delivery_charge',
        'created_by',
        'updated_by',
        'deleted_at',
        'fixed_price_taxation_profile_id',
        'convenience_price_taxation_profile_id',
        'delivery_charge_taxation_profile_id',
    ];
    
    public function businessCategory(){
        return $this->belongsTo('App\Models\Master\BusinessCategory', 'business_category_id');
    }
    public function businessModel(){
        return $this->belongsTo('App\Models\Master\BusinessModels', 'business_model_id');
    }
    public function location(){
        return $this->hasMany('App\Models\SubscriptionPlan\ValueAddedServiceLocation', 'plan_id');
    }
    public function terms(){
        return $this->hasMany('App\Models\SubscriptionPlan\ValueAddedServiceTermsCondition', 'plan_id');
    }
    public function vaService(){
        return $this->belongsTo('App\Models\Master\VAServiceType', 'va_service_id');
    }
    public function duration(){
        return $this->belongsTo('App\Models\Master\Duration', 'billing_period_id');
    }
    public function basePriceTaxationProfile(){
        return $this->belongsTo('App\Models\Master\Taxationprofile', 'base_price_taxation_profile_id');
    }
    public function convenienceFeeTaxationProfile(){
        return $this->belongsTo('App\Models\Master\Taxationprofile', 'convenience_fee_taxation_profile_id');
    }
    public function deliveryFeeTaxationProfile(){
        return $this->belongsTo('App\Models\Master\Taxationprofile', 'delivery_fee_taxation_profile_id');
    }
    public function createQuery($request){
        $requestData = $request->all();
        $query = self::whereNull('deleted_at');
        if($requestData['plan_name']){
            $query->where('plan_name', '=', $requestData['plan_name']);
        }
        if($requestData['location_id']){
            $query->whereRelation('location', 'location_id', $requestData['location_id']);
        }
        if($requestData['search'] != '' ){
           
            $query->where('id', 'like', '%'.$requestData['search'].'%');
            $query->where('plan_name', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('product_overview', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('created_at', 'like', '%'.$requestData['search'].'%');
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
}
