<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
//use Itstructure\LaRbac\Interfaces\RbacUserInterface;
//use Itstructure\LaRbac\Traits\Administrable;
use Illuminate\Support\Facades\Validator;
use App\Models\Auth\PasswordReset;
use Spatie\Permission\Traits\HasRoles;

class User extends Authenticatable 
{
    use HasApiTokens, HasFactory, Notifiable;
    use HasRoles;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'email',
        'password',
        'user_type',
        'phone_number',
        'email_verified_at',
        'remember_token',
        'roles',
        'last_seen',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];
    public function hasRole($hasRole)
    {
        foreach ($this->roles()->get() as $role) {
            if($role->name == $hasRole){
                return true;
            }else{
                return false;
            }
        }
    }
    public function userData(){
        return $this->hasOne('App\Models\Users\UserData', 'user_id');
    }
    
    public function userCorporate(){
        return $this->hasOne('App\Models\Users\UserCorporate', 'user_id');
    }
    public function userStaffLocation(){
        return $this->hasMany('App\Models\Users\UserStaffLocation', 'user_id');
    }
    public function address(){
        return $this->hasOne('App\Models\Users\UserLocation', 'user_id')->where('name', 'Main');
    }
    public function locations(){
        return $this->hasMany('App\Models\Users\UserLocation', 'user_id'); 
    }

    public function hasPermissionViaRole($permission)
    {
      return $this->roles->flatMap->permissions->pluck('name')->contains($permission);
    }
    public function hasPermissions (){
        return $this->hasMany('App\Models\Users\Permission', 'id'); 
    }
    public function userDocuments(){
        return $this->hasMany('App\Models\Users\UserDocuments', 'user_id');
    }
    public function myVehicles(){
        return $this->hasMany('App\Models\Users\UserVehicle', 'user_id');
    }
    public function permissions()
    {
    return $this->hasMany('App\Models\Users\Permission','id');
    }
    public function devices(){
        return $this->hasMany('App\Models\Users\UserDevices', 'user_id');
    }
    public function notifications(){
        return $this->hasMany('App\Models\Users\UserNotification', 'user_id')->whereNull('deleted_at')->orderBy('created_at', 'DESC');
    }
    public function createQuery($requestData){
        $query = self::with('UserData');
        if($requestData['user_type']){
            $query->where('user_type', '=', $requestData['user_type']);
        }
        if($requestData['search'] != '' ){
            $query->where('user_type', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('name', 'like', '%'.$requestData['search'].'%');
            $query->orWhere('id', 'like', '%'.$requestData['search'].'%');
           // $query->orwhereRelation('email', 'category_name', 'like', '%'.$requestData['search'].'%');
            // $asset->whereHas('category', function (Builder $query) {
            //     $query->orWhere('category_name', 'like', '%batte%');
            // });
        }
        $query->orderBy('id', 'desc');
        return $query;
    }

    public function signupValidate($request){
        $validate = Validator::make($request->all(), [
            'email' => 'required|email',
            'first_name' => 'required',
            'last_name' => 'required',
            'phone_number' => 'required',
            'user_type' => 'required',
        ]);
        if($validate->fails()){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => $validate->errors()
            ], 400);
        }
        $postData = $request->all();
        $userPhone = User::with(['UserData'])->whereRelation('UserData', 'phone_number', '=', $postData['phone_number'])->first();
        if($userPhone){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => 'Phone number already exist'
            ], 400);
        }
        $userEmail = User::with(['UserData'])->where('email', '=', $postData['email'])->first();
        if($userEmail){
            return response()->json([
                'status' => false,
                'message' => 'Validation errors in your request',
                'errors' => 'Email already exist'
            ], 400);
        }
        return response()->json([
            'status' => true,
            'message' => 'sucess',
            'errors' => ''
        ], 200);
    }
    public function createPasswordResetToken(){
        $token = hash('sha256', 'Token to reset password or Set password to new user'. time(). rand(0000, 9999));
        $passwordRest = PasswordReset::where('phone_number', '=', $this->phone_number)->first();
        if(empty($passwordRest)){
            $passwordRest = PasswordReset::where('email', '=', $this->email)->first();
        }
        if($passwordRest){
            PasswordReset::destroy($passwordRest->id);
        }
        $new = 1;
        if($this->password){
            $new = 0;
        }
        PasswordReset::create([
            'token' => $token,
            'new' => 1,
            'phone_number' => $this->phone_number,
            'email' => $this->email,
        ]);
        //$this->email_verified_at = null;
        //$this->phone_ve = null;
        $this->save();
        return $token;
    }
}
