<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Vendor extends Model
{
    use HasFactory;
    
    protected $fillable = [
        'category_id',
        'oem_id',
        'vendor_number',
        'vendor_name',
        'contact_name',
        'contact_phone',
        'contact_email',
        'address',
        'postal_code',
        'city_id',
        'district_id',
        'state_id',
        'zone_id',
        'vendor_image',
        'logo_name',
        'description',
        'status',
        'meta_url',
        'meta_title',
        'meta_keyword',
        'meta_description',
        'deleted_at'
    ];

    public function createQuery($request){

        $requestData = $request->all();
        $query = self::whereNull('deleted_at'); 
        if($requestData['category_id']){
            $query->where('category_id', '=', $requestData['category_id']);
        }
        if($requestData['oem_id']){
            $query->where('oem_id', '=', $requestData['oem_id']);
        }
        
        if($requestData['city_id']){
            $query->where('city_id', '=', $requestData['city_id']);
        }
        if($requestData['district_id']){
            $query->where('district_id', '=', $requestData['district_id']);
        }
        if($requestData['state_id']){
            $query->where('state_id', '=', $requestData['state_id']);
        }
        if($requestData['zone_id']){
            $query->where('zone_id', '=', $requestData['zone_id']);
        }
        $query->orderBy('id', 'desc');
        return $query;
   }
   
    public function vendorCategory(){
        return $this->belongsTo('App\Models\Vendors\VendorCategory', 'category_id');
    }
    public function vendorOem(){
        return $this->belongsTo('App\Models\Vendors\VendorOem', 'oem_id');
    }
    
    public function zone(){
        return $this->belongsTo('App\Models\Master\Zone', 'zone_id');
    }
    public function state(){
        return $this->belongsTo('App\Models\Master\ZoneState', 'state_id');
    }
    public function district(){
        return $this->belongsTo('App\Models\Master\ZoneDistrict', 'district_id');
    }
    public function city(){
        return $this->belongsTo('App\Models\Master\ZoneCity', 'city_id');
    }
}
