<?php

namespace App\Models\Vendors;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Models\VehicleOem;
use App\Models\Assets\vendoroem_model;


class VendorOem extends Model
{
    use HasFactory;
    
    protected static function booted()
    {
        static::creating(function ($model) {
            $model->created_by = auth()->user()->id;
        });
    }
    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'vendor_oem';

    /**
    * The database primary key value.
    *
    * @var string
    */
    protected $primaryKey = 'id';

    /**
     * Attributes that should be mass-assignable.
     *
     * @var array
     */
    protected $fillable = [
        'vendor_category_id',
        'vendor_oem',
        'oem_model',
        'created_by',
        'deleted_at',
    ];
    
    public function createQuery($request){
        $requestData = $request->all();
       // dd($requestData);
        $query = self::whereNull('deleted_at'); 

      //  dd($query);

        $query->orderBy('id', 'desc');
        return $query;
   }

   public function vehicleOemmodel()
   {
       return $this->belongsTo(vendoroem_model::class, 'oem_model');
   }

   public function vehicleOem()
   {
       return $this->belongsTo(VehicleOem::class, 'vendor_oem');
   }
   
    public function vendorCategory(){
        return $this->belongsTo('App\Models\Vendors\VendorCategory', 'vendor_category_id');
    }
    public function vendor_oem_by_category($vendor_category_id){
        return self::whereNull('deleted_at')->where('vendor_category_id', $vendor_category_id)->get();
    }
    
    public function vehicle(){
        return $this->hasMany('App\Models\Vendors\Vehicle', 'oem_id');
    }
    public function battery(){
        return $this->hasMany('App\Models\Vendors\Battery', 'oem_id');
    }
    public function chargingStation(){
        return $this->hasMany('App\Models\Vendors\ChargingStation', 'oem_id');
    }
    public function oemList($oem_id, $with=''){
        $oem = self::with(['vehicle', 'battery', 'chargingStation'])->whereNull('deleted_at')->where('id', $oem_id)->first();
        if($with == 'vehicle'){
            return $oem->vehicle;
        }elseif($with == 'battery'){
            return $oem->battery;
        }elseif($with == 'chargingStation'){
            return $oem->chargingStation;
        }elseif($with == 'oem'){
            return $oem;
        }else{
            return self::with(['vehicle', 'battery', 'chargingStation'])->whereNull('deleted_at')->get();
        }
    }
}
