@extends('layouts.master')

@section('title') @lang('translation.Announcement') @endsection

@section('css')
<!-- select2 css -->
<link href="{{ URL::asset('/assets/libs/select2/select2.min.css') }}" rel="stylesheet" type="text/css" />

<!-- dropzone css -->
<link href="{{ URL::asset('/assets/libs/dropzone/dropzone.min.css') }}" rel="stylesheet" type="text/css" />
@endsection

@section('content')

@component('components.breadcrumb')
@slot('li_1') Announcement @endslot
@slot('title') Edit Announcement @endslot
@endcomponent

<div class="row">
    <div class="col-12">
        
    <form  class="needs-validation" id="edit_form" action="{{ route('cms.announcement.update', ['announcement' => $announcement->id] ) }}" method="post" enctype="multipart/form-data" novalidate>
    @method('put')
    @csrf
    <input name="id" type="hidden"  value="{{ $announcement->id }}" />
    
    <div class="card">
            <div class="card-body">
                <h5>Announcement Details</h5><br>
                <div class="mb-3 row">
                    <label for="announcement_name" class="col-md-2 col-form-label">Announcement Name</label>
                    <div class="col-md-6">
                        <input id="announcement_name" name="announcement_name" type="text" class="form-control" placeholder="Announcement Name" value="{{ $announcement->announcement_name }}" required>
                        <div  id="announcement_name_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="mobile_user" class="col-md-2 col-form-label">Mobile User</label>
                    <div class="col-md-6">
                        <select id="mobile_user" name="mobile_user" class="form-select">
                            <option value=''>Select...</option>
                            <option value="Customer App" {{ $announcement->mobile_user == 'Customer App' ? 'selected' : '' }}>Customer App</option>
                            <option value="Angel Driver" {{ $announcement->mobile_user == 'Angel Driver' ? 'selected' : '' }}>Angel Driver</option>
                            <option value="OPS Angel" {{ $announcement->mobile_user == 'OPS Angel' ? 'selected' : '' }}>OPS Angel</option>
                        </select>
                        <div  id="mobile_user_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <h5>Announcement Program Details</h5><br>
                <div class="mb-3 row">
                    <label for="image" class="col-md-2 col-form-label">Image</label>
                    <div class="col-md-6">
                        @if($announcement->image)
                            <div  class="mb-3 row">
                                <img src="{{ $announcement->image }}" style="width: 150px;" />
                            </div>
                        @endif
                        <input id="image" name="image" type="file" class="form-control"  />
                        <small>Choose an image from the computer</small>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="link_page" class="col-md-2 col-form-label">Linking Page</label>
                    <div class="col-md-6">
                        <input id="link_page" name="link_page" type="text" class="form-control" placeholder="Linking Page" value="{{ $announcement->link_page }}" />
                        <small>Add/Type the URL which will open when the image is clicked on mobile APP</small>
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <h5>Applicable Location</h5><br>
                <div class="mb-3 row">
                    <div class="col-md-2">
                        <input class="form-check-input location" type="radio" name="location" id="location1" value="All Locations" {{ $announcement->location == 'All Locations' ? 'checked' : '' }}/>
                        <label class="form-check-label" for="location1">
                        All Locations
                        </label>
                    </div>
                    <div class="col-md-6">
                        <input class="form-check-input location" type="radio" name="location" id="location2"  value="Selected Location" {{ $announcement->location == 'Selected Location' ? 'checked' : '' }} />
                        <label class="form-check-label" for="location2">
                            Selected Location
                        </label>
                    </div>
                </div>
                <div class="location-field" style=" {{ $announcement->location == 'All Locations' ? 'display:none;' : '' }}">
                    <div class="mb-3 row">
                        <label for="city_id" class="col-md-2 col-form-label">City</label>
                        <div class="col-md-6">
                            <select id="city_id" name="city_id" class="form-control" required>
                                <option value=''>Select...</option>
                                @foreach($cities as $city)
                                    <option value="{{ $city->id }}" {{ ((isset($announcement->announcementLocation->city_id)) ? ($announcement->announcementLocation->city_id == $city->id ) ? 'selected' : '' : '') }} >{{ $city->city}}</option>
                                @endforeach 
                            </select>
                            <div  id="city_id_errors"  class="invalid-feedback">
                                Required
                            </div>
                        </div>
                    </div>
                    <div class="mb-3 row">
                        <label for="district_id" class="col-md-2 col-form-label">District</label>
                        <div class="col-md-6">
                            <select id="district_id" name="district_id" class="form-control" required>
                                <option value=''>Select...</option>
                            </select>
                            <div  id="district_id_errors"  class="invalid-feedback">
                                Required
                            </div>
                        </div>
                    </div>
                    <div class="mb-3 row">
                        <label for="state_id" class="col-md-2 col-form-label">State</label>
                        <div class="col-md-6">
                            <select id="state_id" name="state_id" class="form-control" required>
                                <option value=''>Select...</option>
                            </select>
                            <div  id="state_id_errors"  class="invalid-feedback">
                                Required
                            </div>
                        </div>
                    </div>
                    <div class="mb-3 row">
                        <label for="zone_id" class="col-md-2 col-form-label">Zone</label>
                        <div class="col-md-6">
                            <select id="zone_id" name="zone_id" class="form-control" required>
                                <option value=''>Select...</option>
                            </select>
                            <div  id="zone_id_errors"  class="invalid-feedback">
                                Required
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <div class="d-flex flex-wrap gap-2">
                    <button type="submit" class="btn btn-primary waves-effect waves-light">Save Changes</button>
                </div>
            </div>
        </div>
   </form>
    </div>
</div>
<!-- end row -->

@endsection
@section('script')
    <!-- select 2 plugin -->
    <script src="{{ URL::asset('/assets/libs/select2/select2.min.js') }}"></script>

    <!-- dropzone plugin -->
    <script src="{{ URL::asset('/assets/libs/dropzone/dropzone.min.js') }}"></script>

    <!-- init js -->
    <script src="{{ URL::asset('/assets/js/pages/ecommerce-select2.init.js') }}"></script>
    <!--tinymce js-->
    <script src="{{ URL::asset('/assets/libs/tinymce/tinymce.min.js') }}"></script>

    <!-- init js -->
    <script src="{{ URL::asset('/assets/js/pages/form-editor.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/parsleyjs/parsleyjs.min.js') }}"></script>

    <script src="{{ URL::asset('/assets/js/pages/form-validation.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
    $(document).ready(function(){
        
        $(document).on("change", ".location", function(){
            conditionField = $(".location-field");
            if($(this).val() == 'Selected Location'){
                conditionField.show();
            }else{
                conditionField.hide();
            }
        }).trigger('change');
        var token = "{{ csrf_token() }}";
        actionUrl = "{{ route('city') }}";
        updateStateOptions(actionUrl, token);
        updateDistrictOptions(actionUrl, token);
        updateZoneOptions(actionUrl, token);
        $('#city_id').on('change', function() {
            actionUrl = "{{ route('city') }}";
            updateStateOptions(actionUrl, token);
            updateDistrictOptions(actionUrl, token);
            updateZoneOptions(actionUrl, token);
        });
        $( "#edit_form" ).submit(function( event ) {
            event.preventDefault();
            actionUrl = "{{ route('cms.announcement.validate') }}";
            form = $( "#edit_form" );
            $.ajax({
                type: "POST",
                url: actionUrl,
                data: form.serialize(), // serializes the form's elements.
                success: function(data){ 
                    $('.needs-validation').addClass('validated');
                    form.unbind().submit(); 
                },
                error: function (data) {
                    console.log('An error occurred.');
                    response = data.responseJSON;
                    if(response.mode == false){
                        $.each(response.errors, function(i, item) {
                             $('#'+i+'_errors').html(response.errors[i]); 
                            $('#'+i+'_errors').css('display', 'block');
                        });
                    }
                },
            });
        });
    });
    
    </script>
@endsection