@extends('layouts.master')

@section('title') @lang('translation.Announcement') @endsection

@section('css')
    <!-- DataTables -->
    <link href="{{ URL::asset('/assets/libs/datatables/datatables.min.css') }}" rel="stylesheet" type="text/css" />
    <!-- <link href="https://cdn.datatables.net/searchpanes/2.1.0/css/searchPanes.bootstrap4.min.css" rel="stylesheet" type="text/css" />
    <link href="https://cdn.datatables.net/select/1.5.0/css/select.bootstrap4.min.css" rel="stylesheet" type="text/css" /> -->
@endsection
@section('content')

    @component('components.breadcrumb')
        @slot('li_1')  Content Management @endslot
        @slot('title') Announcement @endslot
    @endcomponent

    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">
                    <div class="row mb-2">
                        <div class="col-sm-2">
                            <select id="announcement_name" class="form-control select2">
                                <option value=''>--By Announcement--</option>
                                @foreach($announcementList as $announcement)
                                    <option value="{{ $announcement->announcement_name }}">{{ $announcement->announcement_name}}</option>
                                @endforeach 
                            </select>
                        </div> 
                        <div class="col-sm-2">
                            <select id="location" class="form-control select2">
                                <option value=''>--By Location--</option>
                                @foreach($announcementList as $announcement)
                                    <option value="{{ $announcement->location }}">{{ $announcement->location}}</option>
                                @endforeach 
                            </select>
                        </div> 
                        <div class="col-sm-2">
                            <select id="updated_by" class="form-control select2">
                                <option value=''>--By Updated status--</option>
                                @foreach($announcementList as $announcement)
                                    @if($announcement->updatedUser))
                                    <option value="{{ $announcement->updatedUser->id }}">{{ $announcement->updatedUser->name }}</option>
                                    @endif
                                @endforeach 
                            </select>
                        </div> <!--<label class="col-sm-1" >Search: </label>-->
                        <div class="col-sm-2">
                            <input type="search" class="form-control" id="search" placeholder="Search" aria-controls="datatable-buttons">
                        </div>
                        <div class="col-sm-1">
                        </div>
                        <div class="col-sm-3">
                            <div class="text-sm-end">
                                <a href="{{ route('cms.announcement.create')}}" class="btn btn-success btn-rounded waves-effect waves-light mb-2 me-2"><i class="mdi mdi-plus me-1"></i> New Announcement</a>
                            </div>
                        </div><!-- end col-->
                    </div>
                    <div class="row mb-2">
                        
                    </div>

                    <div class="table-responsive">
                        <table id="agax_datatable" class="table align-middle table-nowrap">
                            <thead>
                                <tr>
                                    <th> id</th>
                                    <th> Announcement Name</th>
                                    <th> Mobile User</th>
                                    <th> Location </th>
                                    <th> Updated By </th>
                                    <th> Created At </th>
                                    <th> Updated At </th>
                                    <th> Action </th>
                                </tr>
                            </thead>
                        </table>
                    </div>
                    
                </div>
            </div>
        </div>
    </div>
    <!-- end row -->
@endsection
@section('script')
    <!-- Required datatable js -->
    <script src="{{ URL::asset('/assets/libs/datatables/datatables.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/jszip/jszip.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/pdfmake/pdfmake.min.js') }}"></script>
    <!-- Datatable init js -->
    <script src="{{ URL::asset('/assets/js/pages/datatables.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
        $(document).ready(function(){
            
            updateTables();
            $('#announcement_name').on('change', function() {
                updateTables();
            });
            $('#location').on('change', function() {
                updateTables();
            });
            $('#updated_by').on('change', function() {
                updateTables();
            });
            $('#search').on('change', function() {
                updateTables();
            });
            $(document).on("click",".delete",function(e) {
                e.preventDefault();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    }
                });
                var url = $(this).attr('data-url');
                // confirm then
                $.ajax({
                    url: url,
                    type: 'DELETE',
                    dataMode: 'json',
                    data: {
                      //  method: 'DELETE', 
                        submit: true,
                        "_token": "{{ csrf_token() }}"
                    }
                }).always(function (data) {
                    updateTables();
                });
            });
            
        });

        
        function updateTables() {
            $("#agax_datatable").DataTable().destroy();
            var table = $('#agax_datatable').DataTable( {
                serverSide: true,
                processing: true,
                searching:false,
                paging: true,
                "ajax": {
                    "url": "{{ route('cms.announcement.tab-index') }}",
                    "type": "POST",
                    'data': {
                        "announcement_name": $('#announcement_name').val(),
                        "location": $('#location').val(),
                        "updated_by": $('#updated_by').val(),
                        "search": $('#search').val(),
                        "_token": "{{ csrf_token() }}"
                    }
                },
                dom: 'Blfrtip',
                "columns": [
                    { "data": "id" },
                    { "data": "announcement_name" },
                    { "data": "mobile_user" },
                    { "data": "location" },
                    { "data": "updated_by" },
                    { "data": "updated_at" },
                    { "data": "created_at" },
                    { "data": "action" },

                ],
                "buttons":[

                ],
            });
            //table.draw(); 
        }
    </script>
@endsection
