@extends('layouts.master')

@section('title') @lang('translation.FAQ') @endsection

@section('css')
<!-- select2 css -->
<link href="{{ URL::asset('/assets/libs/select2/select2.min.css') }}" rel="stylesheet" type="text/css" />

<!-- dropzone css -->
<link href="{{ URL::asset('/assets/libs/dropzone/dropzone.min.css') }}" rel="stylesheet" type="text/css" />
@endsection

@section('content')

@component('components.breadcrumb')
@slot('li_1') FAQ @endslot
@slot('title') Add FAQ @endslot
@endcomponent

<div class="row">
    <div class="col-12">
        
    <form  class="needs-validation" id="create_form" action="{{ route('cms.faq.store') }}" method="post" enctype="multipart/form-data" novalidate>
    @csrf
        <div class="card">
            <div class="card-body">
                <h5>FAQ Details</h5><br>
                <div class="mb-3 row">
                    <label for="faq_category" class="col-md-2 col-form-label">FAQ Category</label>
                    <div class="col-md-6">
                        <input id="faq_category" name="faq_category" type="text" class="form-control" placeholder="FAQ Category" required>
                        <div  id="faq_category_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="mobile_user" class="col-md-2 col-form-label">Mobile User</label>
                    <div class="col-md-6">
                        <select id="mobile_user" name="mobile_user" class="form-select">
                            <option value=''>Select...</option>
                            <option value="Customer App">Customer App</option>
                            <option value="Angel Driver">Angel Driver</option>
                            <option value="OPS Angel">OPS Angel</option>
                        </select>
                        <div  id="mobile_user_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <div class="repeater" enctype="multipart/form-data">
                    <div class="mb-3 row">
                        <div class="col-md-10">
                            <h5>FAQ Program Details</h5>
                        </div>
                        <div class="col-md-2">
                            <input data-repeater-create type="button"  class="faq-question-add-btn btn btn-primary waves-effect waves-light" value="Add Questions" />
                        </div>
                    </div>
                    <div data-repeater-list="faq-questions" class="faq-questions">
                        <div data-repeater-item class="row">
                            <div class="mb-3 row ">
                                <label for="question_priority" class="col-md-2 col-form-label">Question Priority</label>
                                <div class="col-md-6 faq-question-div">
                                    <select id="question_priority" name="question_priority" class="question_priority form-select">
                                        <option value=''>Select...</option>
                                        @foreach (range(1,20) as $option)
                                        <option value='{{ $option }}'>{{ $option }}</option>
                                        @endforeach
                                    </select>
                                    <div  id="question_priority_errors"  class="invalid-feedback">
                                        Required
                                    </div>
                                </div>
                            </div>
                            <div class="mb-3 row">
                                <label for="question" class="col-md-2 col-form-label">Type you Question</label>
                                <div class="col-md-6">
                                    <input id="question" name="question" type="text" class="form-control" placeholder="Question" />
                                </div>
                            </div>
                            <div class="mb-3 row">
                                <label for="search_tag" class="col-md-2 col-form-label">Search Tag</label>
                                <div class="col-md-6">
                                    <input id="search_tag" name="search_tag" type="text" class="form-control" placeholder="Search Tag" />
                                </div>
                            </div>
                            <div class="mb-3 row">
                                <label for="search_answer" class="col-md-2 col-form-label">Search Answer</label>
                                <div class="col-md-6">
                                    <textarea id="search_answer" name="search_answer" class="form-control" placeholder="Search Answer" /></textarea>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <div class="d-flex flex-wrap gap-2">
                    <button type="submit" class="btn btn-primary waves-effect waves-light">Save Changes</button>
                </div>
            </div>
        </div>
    </form>
    </div>
</div>
<!-- end row -->

@endsection
@section('script')
    <!-- select 2 plugin -->
    <script src="{{ URL::asset('/assets/libs/select2/select2.min.js') }}"></script>

    <!-- dropzone plugin -->
    <script src="{{ URL::asset('/assets/libs/dropzone/dropzone.min.js') }}"></script>

    <!-- init js -->
    <script src="{{ URL::asset('/assets/js/pages/ecommerce-select2.init.js') }}"></script>
    <!--tinymce js-->
    <script src="{{ URL::asset('/assets/libs/tinymce/tinymce.min.js') }}"></script>

    <!-- init js -->
    <script src="{{ URL::asset('/assets/js/pages/form-editor.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/parsleyjs/parsleyjs.min.js') }}"></script>

    <script src="{{ URL::asset('/assets/js/pages/form-validation.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/jquery-repeater/jquery-repeater.min.js') }}"></script>

    <script src="{{ URL::asset('/assets/js/pages/form-repeater.int.js') }}"></script>
    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
    $(document).ready(function(){
        
        $( "#create_form" ).submit(function( event ) {
            event.preventDefault();
            actionUrl = "{{ route('cms.faq.validate') }}";
            form = $( "#create_form" );
            $.ajax({
                type: "POST",
                url: actionUrl,
                data: form.serialize(), // serializes the form's elements.
                success: function(data){ 
                    $('.needs-validation').addClass('validated');
                    form.unbind().submit(); 
                },
                error: function (data) {
                    console.log('An error occurred.');
                    response = data.responseJSON;
                    if(response.mode == false){
                        $.each(response.errors, function(i, item) {
                             $('#'+i+'_errors').html(response.errors[i]); 
                            $('#'+i+'_errors').css('display', 'block');
                        });
                    }
                },
            });
        });
        
    });
    </script>
@endsection