@extends('layouts.master')

@section('title') @lang('translation.Input Attributes') @endsection

@section('css')
<!-- select2 css -->
<link href="{{ URL::asset('/assets/libs/select2/select2.min.css') }}" rel="stylesheet" type="text/css" />

<!-- dropzone css -->
<link href="{{ URL::asset('/assets/libs/dropzone/dropzone.min.css') }}" rel="stylesheet" type="text/css" />
@endsection

@section('content')

@component('components.breadcrumb')
@slot('li_1') Input Attributes @endslot
@slot('title') Edit Input Attributes @endslot
@endcomponent

<div class="row">
    <div class="col-12">
        
    <form  class="needs-validation" id="edit_form" action="{{ route('cms.input-attribute.update', ['input_attribute' => $inputAttribute->id] ) }}" method="post" enctype="multipart/form-data" novalidate>
    @method('put')
    @csrf
    <input name="id" type="hidden"  value="{{ $inputAttribute->id }}" />
    
        <div class="card">
            <div class="card-body">
                <h5>Input Attributes Details</h5><br>
                <div class="mb-3 row">
                    <label for="form_id" class="col-md-2 col-form-label">Select Form Slug</label>
                    <div class="col-md-6">
                        <select id="form_id" name="form_id" class="form-select" required>
                            <option value=''>Select...</option>
                            @foreach($forms as $form)
                                <option value="{{ $form->id }}"{{ $form->id == $inputAttribute->form_id ? 'selected' : '' }}>{{ $form->slug}}</option>
                            @endforeach 
                        </select>
                        <div  id="form_id_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="form_field_id" class="col-md-2 col-form-label">Form Fields</label>
                    <div class="col-md-6">
                        <select id="form_field_id" name="form_field_id" class="form-select" data-selected="{{ $inputAttribute->form_field_id }}" required>
                            <option value=''>Select...</option>
                        </select>
                        <div  id="form_field_id_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="type" class="col-md-2 col-form-label">Type</label>
                    <div class="col-md-6">
                        <input type="text" id="type" class="form-control" name="type" placeholder="Type" value="{{ $inputAttribute->type }}" required />
                        <small>Enter the Name of the attribute - Ex: string, int,double... </small>
                        <div  id="type_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="key" class="col-md-2 col-form-label">Key</label>
                    <div class="col-md-6">
                        <input type="text" id="key" class="form-control" name="key" placeholder="Key" value="{{ $inputAttribute->key }}" required />
                        <small>Enter the Name of the attribute Ex: Min, Max...</small>
                        <div  id="key_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="value" class="col-md-2 col-form-label">Value</label>
                    <div class="col-md-6">
                        <input type="text" id="value" class="form-control" name="value" placeholder="value" value="{{ $inputAttribute->value }}" required />
                        <small>Enter the Value of the attribute </small>
                        <div  id="value_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <div class="d-flex flex-wrap gap-2">
                    <button type="submit" class="btn btn-primary waves-effect waves-light">Save Changes</button>
                </div>
            </div>
        </div>
    </form>
    </div>
</div>
<!-- end row -->

@endsection
@section('script')
    <!-- select 2 plugin -->
    <script src="{{ URL::asset('/assets/libs/select2/select2.min.js') }}"></script>

    <!-- dropzone plugin -->
    <script src="{{ URL::asset('/assets/libs/dropzone/dropzone.min.js') }}"></script>

    <!-- init js -->
    <script src="{{ URL::asset('/assets/js/pages/ecommerce-select2.init.js') }}"></script>
    <!--tinymce js-->
    <script src="{{ URL::asset('/assets/libs/tinymce/tinymce.min.js') }}"></script>

    <!-- init js -->
    <script src="{{ URL::asset('/assets/js/pages/form-editor.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/parsleyjs/parsleyjs.min.js') }}"></script>

    <script src="{{ URL::asset('/assets/js/pages/form-validation.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
    $(document).ready(function(){
        
        
        var token = "{{ csrf_token() }}";
        actionUrl = "{{ route('cms.form-fields-by-form') }}";
        updateFormFieldByForm(actionUrl, token);
        $('#form_id').on('change', function() {
            updateFormFieldByForm(actionUrl, token);
        });
    });
    
    </script>
@endsection