@extends('layouts.master')

@section('title') @lang('Tab Menu Input') @endsection

@section('css')
    <!-- DataTables -->
    <link href="{{ URL::asset('/assets/libs/datatables/datatables.min.css') }}" rel="stylesheet" type="text/css" />
    <!-- <link href="https://cdn.datatables.net/searchpanes/2.1.0/css/searchPanes.bootstrap4.min.css" rel="stylesheet" type="text/css" />
    <link href="https://cdn.datatables.net/select/1.5.0/css/select.bootstrap4.min.css" rel="stylesheet" type="text/css" /> -->
@endsection
@section('content')

    @component('components.breadcrumb')
        @slot('li_1')  Content Management @endslot
        @slot('title') Tab Menu Input @endslot
    @endcomponent

    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">
                    <div class="row mb-2">
                        <div class="col-sm-2">
                            <select id="tab_menu_id" name="tab_menu_id" class="form-select" required>
                                <option value=''>-- By Tab Menu --</option>
                                @foreach($tabMenuList as $tabMenu)
                                    <option value="{{ $tabMenu->id }}">{{ $tabMenu->menu}}</option>
                                @endforeach 
                            </select>
                        </div> 
                        <div class="col-sm-2">
                            <input type="search" class="form-control" id="search" placeholder="Search" aria-controls="datatable-buttons">
                        </div>
                        <div class="col-sm-3">
                        </div>
                        <div class="col-sm-2">
                        </div> 
                        <div class="col-sm-3">
                            <div class="text-sm-end">
                                <a href="{{ route('cms.tab-menu-input.create')}}" class="btn btn-success btn-rounded waves-effect waves-light mb-2 me-2"><i class="mdi mdi-plus me-1"></i> New Tab Menu Inputs</a>
                            </div>
                        </div><!-- end col-->
                    </div>
                    <div class="row mb-2">
                        
                    </div>

                    <div class="table-responsive">
                        <table id="agax_datatable" class="table align-middle table-nowrap">
                            <thead>
                                <tr>
                                    <th> id</th>
                                    <th> Form Page</th>
                                    <th> Form Field</th>
                                    <th> Tab Menu</th>
                                    <th> Action </th>
                                </tr>
                            </thead>
                        </table>
                    </div>
                    
                </div>
            </div>
        </div>
    </div>
    <!-- end row -->
@endsection
@section('script')
    <!-- Required datatable js -->
    <script src="{{ URL::asset('/assets/libs/datatables/datatables.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/jszip/jszip.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/pdfmake/pdfmake.min.js') }}"></script>
    <!-- Datatable init js -->
    <script src="{{ URL::asset('/assets/js/pages/datatables.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
        $(document).ready(function(){
            updateTables();
        var token = "{{ csrf_token() }}";
        $('#form_id').on('change', function() {
            actionUrl = "{{ route('cms.form-fields-by-form') }}";
            updateFormFieldByForm(actionUrl, token);
            updateTables();
        });
            $('#form_field_id').on('change', function() {
                updateTables();
            });
            $(document).on("click",".delete",function(e) {
                e.preventDefault();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    }
                });
                var url = $(this).attr('data-url');
                // confirm then
                $.ajax({
                    url: url,
                    type: 'DELETE',
                    dataMode: 'json',
                    data: {
                      //  method: 'DELETE', 
                        submit: true,
                        "_token": "{{ csrf_token() }}"
                    }
                }).always(function (data) {
                    updateTables();
                });
            });
            
        });

        
        function updateTables() {
            $("#agax_datatable").DataTable().destroy();
            var table = $('#agax_datatable').DataTable( {
                serverSide: true,
                processing: true,
                searching:false,
                paging: true,
                "ajax": {
                    "url": "{{ route('cms.tab-menu-input.tab-index') }}",
                    "type": "POST",
                    'data': {
                        "tab_menu_id": $('#tab_menu_id').val(),
                        "form_field_id": $('#form_field_id').val(),
                        "search": $('#search').val(),
                        "_token": "{{ csrf_token() }}"
                    }
                },
                dom: 'Blfrtip',
                "columns": [
                    { "data": "id" },
                    { "data": "form_id" },
                    { "data": "form_field_id" },
                    { "data": "menu" },
                    { "data": "action" },

                ],
                "buttons":[

                ],
            });
            //table.draw(); 
        }
    </script>
@endsection
