@extends('layouts.master')

@section('title') @lang('Operation Location') @endsection

@section('css')
    <!-- DataTables -->
    <link href="{{ URL::asset('/assets/libs/datatables/datatables.min.css') }}" rel="stylesheet" type="text/css" />
    <!-- <link href="https://cdn.datatables.net/searchpanes/2.1.0/css/searchPanes.bootstrap4.min.css" rel="stylesheet" type="text/css" />
    <link href="https://cdn.datatables.net/select/1.5.0/css/select.bootstrap4.min.css" rel="stylesheet" type="text/css" /> -->
@endsection
@section('content')

    
<div class="row content-panel-header">
    <div class="col-sm-4 page-title-box">
        <h4 class="mb-sm-0 font-size-18">Operation Locations</h4>
    </div>
    <div class="col-sm-8">
        <div class="text-sm-end">
            <a href="{{ route('location.create')}}" class="btn btn-primary waves-effect waves-light"><i class="mdi mdi-plus me-1"></i> Create New</a>
        </div>
    </div>
</div>


    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">
                    <div class="row mb-2">
                        <div class="col-sm-2">
                            <select id="location_classification_id" class="form-control select2">
                                <option value=''>--By Classification--</option>
                                @foreach($locationClassification as $classification)
                                    <option value="{{ $classification->id }}">{{ $classification->location_classification}}</option>
                                @endforeach 
                            </select>
                        </div> 
                        <div class="col-sm-2">
                            <select id="zone_id" class="form-control select2">
                                <option value=''>--By Zone--</option>
                                @foreach($zones as $zone)
                                    <option value="{{ $zone->id }}">{{ $zone->zone}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <select id="state_id" class="form-control select2">
                                <option value=''>--By State--</option>
                                @foreach($states as $state)
                                    <option value="{{ $state->id }}">{{ $state->state}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <select id="district_id" class="form-control select2">
                                <option value=''>--By District--</option>
                                @foreach($districts as $district)
                                    <option value="{{ $district->id }}">{{ $district->district}}</option>
                                @endforeach 
                            </select>
                        </div>
                        
                        <div class="col-sm-2">
                            <select id="city_id" class="form-control select2">
                                <option value=''>--By City--</option>
                                @foreach($cities as $city)
                                    <option value="{{ $city->id }}">{{ $city->city}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <div class="text-sm-end">
                                <input type="search" class="form-control" id="search" placeholder="Search" aria-controls="datatable-buttons">
                            </div>
                        </div><!-- end col-->
                    </div>

                    <div class="table-responsive">
                        <table id="agax_datatable" class="table align-middle table-nowrap">
                            <thead>
                                <tr>
                                    <th> id</th>
                                    <th> Zone</th>
                                    <th> State </th>
                                    <th> District</th>
                                    <th> City</th>
                                    <th> Location</th>
                                    <th> Classification</th>
                                    <th> Property Type</th>
                                    <th> Address</th>
                                    <th> Pin Code</th>
                                    <th> Created At</th>
                                    <th> Created By   </th>
                                    <th> Updated At </th>
                                    <th> Updated By </th>
                                    <th> Action </th>
                                </tr>
                            </thead>
                        </table>
                    </div>
                    
                </div>
            </div>
        </div>
    </div>
    <!-- end row -->
@endsection
@section('script')
    <!-- Required datatable js -->
    <script src="{{ URL::asset('/assets/libs/datatables/datatables.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/jszip/jszip.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/pdfmake/pdfmake.min.js') }}"></script>
    <!-- Datatable init js -->
    <script src="{{ URL::asset('/assets/js/pages/datatables.init.js') }}"></script>
    <!-- <script src="https://cdn.datatables.net/searchpanes/2.1.0/js/dataTables.searchPanes.min.js"></script>
    <script src="https://cdn.datatables.net/searchpanes/2.1.0/js/searchPanes.bootstrap4.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.5.0/js/dataTables.select.min.js"></script> -->
    <script type="text/javascript">
        $(document).ready(function(){
            updateTables();
           
            $('#location').on('change', function() {
                $('#location_input').val($(this).val());
                updateTables();
            });
            $('#location_classification_id').on('change', function() {
                updateTables();
            });
            $('#city_id').on('change', function() {
                updateTables();
            });
            $('#district_id').on('change', function() {
                updateTables();
            });
            $('#state_id').on('change', function() {
                updateTables();
            });
             
            $('#search').on('change', function() {
                updateTables();
            });
             
            $(document).on("click",".delete",function(e) {
                e.preventDefault();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    }
                });
                var url = $(this).attr('data-url');
                // confirm then
                $.ajax({
                    url: url,
                    type: 'DELETE',
                    dataMode: 'json',
                    data: {
                      //  method: 'DELETE', 
                        submit: true,
                        "_token": "{{ csrf_token() }}"
                    }
                }).always(function (data) {
                    updateTables();
                });
            });
            
        });

        
        function updateTables() {
            $("#agax_datatable").DataTable().destroy();
            var table = $('#agax_datatable').DataTable( {
                serverSide: true,
                processing: true,
                searching:false,
                paging: true,
                "ajax": {
                    "url": "{{ route('location.tab-index') }}",
                    "type": "POST",
                    'data': {
                        "location_classification_id": $('#location_classification_id').val(),
                        "city_id": $('#city_id').val(),
                        "district_id": $('#district_id').val(),
                        "state_id": $('#state_id').val(),
                        "zone_id": $('#zone_id').val(),
                        "search": $('#search').val(),
                        "_token": "{{ csrf_token() }}"
                    }
                },
                dom: 'Blfrtip',
                "columns": [
                    { "data": "id" },
                    { "data": "zone_id" },
                    { "data": "state_id" },
                    { "data": "district_id" },
                    { "data": "city_id" },
                    { "data": "location" },
                    { "data": "location_classification_id" },
                    { "data": "property_type_id" },
                    { "data": "address" },
                    { "data": "postal_code" },
                    { "data": "created_at" },
                    { "data": "created_by" },
                    { "data": "updated_at" },
                    { "data": "updated_by" },
                    { "data": "action" },

                ],
                "buttons":[

                ],
            });
            //table.draw(); 
        }
    </script>
@endsection
