@extends('layouts.master')

@section('title') @lang('translation.Discount') @endsection

@section('css')
    <!-- DataTables -->
    <link href="{{ URL::asset('/assets/libs/datatables/datatables.min.css') }}" rel="stylesheet" type="text/css" />
    <!-- <link href="https://cdn.datatables.net/searchpanes/2.1.0/css/searchPanes.bootstrap4.min.css" rel="stylesheet" type="text/css" />
    <link href="https://cdn.datatables.net/select/1.5.0/css/select.bootstrap4.min.css" rel="stylesheet" type="text/css" /> -->
@endsection
@section('content')

    @component('components.breadcrumb')
        @slot('li_1')  Marketing @endslot
        @slot('title') Discount @endslot
    @endcomponent

    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">
                    <div class="row mb-2">
                        <div class="col-sm-2">
                            <select id="discount_code" class="form-control select2">
                                <option value=''>--By Discount--</option>
                                @foreach($discountList as $discount)
                                    <option value="{{ $discount->discount_code }}">{{ $discount->discount_code}}</option>
                                @endforeach 
                            </select>
                        </div> 
                        <div class="col-sm-2">
                            <select id="business_category_id" class="form-control select2">
                                <option value=''>--By Category--</option>
                                @foreach($businessCategoryList as $businessCategory)
                                    <option value="{{ $businessCategory->id }}">{{ $businessCategory->business_category}}</option>
                                @endforeach 
                            </select>
                        </div> 
                        <div class="col-sm-2">
                            <select id="zone_id" class="form-control select2">
                                <option value=''>--By Zone--</option>
                                @foreach($zones as $zone)
                                    <option value="{{ $zone->id }}">{{ $zone->zone}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <select id="state_id" class="form-control select2">
                                <option value=''>--By State--</option>
                                @foreach($states as $state)
                                    <option value="{{ $state->id }}">{{ $state->state}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <select id="district_id" class="form-control select2">
                                <option value=''>--By District--</option>
                                @foreach($districts as $district)
                                    <option value="{{ $district->id }}">{{ $district->district}}</option>
                                @endforeach 
                            </select>
                        </div>
                        
                        <div class="col-sm-2">
                            <select id="city_id" class="form-control select2">
                                <option value=''>--By City--</option>
                                @foreach($cities as $city)
                                    <option value="{{ $city->id }}">{{ $city->city}}</option>
                                @endforeach 
                            </select>
                        </div><!-- end col-->
                    </div>
                    <div class="row mb-2">
                        <!--<label class="col-sm-1" >Search: </label>-->
                        <div class="col-sm-2">
                            <input type="search" class="form-control" id="search" placeholder="Search" aria-controls="datatable-buttons">
                        </div>
                        <div class="col-sm-8">
                        </div>
                        <div class="col-sm-2">
                            <div class="text-sm-end">
                                <a href="{{ route('marketing.discount.create')}}" class="btn btn-success btn-rounded waves-effect waves-light mb-2 me-2"><i class="mdi mdi-plus me-1"></i> New Discount</a>
                            </div>
                        </div><!-- end col-->
                    </div>

                    <div class="table-responsive">
                        <table id="agax_datatable" class="table align-middle table-nowrap">
                            <thead>
                                <tr>
                                    <th> id</th>
                                    <th> Discount Code</th>
                                    <th> Business Catgory</th>
                                    <th> City</th>
                                    <th> District</th>
                                    <th> State</th>
                                    <th> Zone </th>
                                    <th> Subscription Plan </th>
                                    <th> Minimum Order Cost </th>
                                    <th> Discount %t </th>
                                    <th> Up to Cost </th>
                                    <th> Discount Expiry On </th>
                                    <th> Created At </th>
                                    <th> Action </th>
                                </tr>
                            </thead>
                        </table>
                    </div>
                    
                </div>
            </div>
        </div>
    </div>
    <!-- end row -->
@endsection
@section('script')
    <!-- Required datatable js -->
    <script src="{{ URL::asset('/assets/libs/datatables/datatables.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/jszip/jszip.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/pdfmake/pdfmake.min.js') }}"></script>
    <!-- Datatable init js -->
    <script src="{{ URL::asset('/assets/js/pages/datatables.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
        $(document).ready(function(){
            
            var actionUrl = "{{ route('vendor-oem.oem-by-category') }}";
            var token = "{{ csrf_token() }}";
            updateVendorOemOption(actionUrl, token);
            updateTables();
            $('#discount_code').on('change', function() {
                updateTables();
            });
            $('#business_category_id').on('change', function() {
                updateTables();
            });
            $('#city_id').on('change', function() {
                updateTables();
            });
            $('#district_id').on('change', function() {
                updateTables();
            });
            $('#state_id').on('change', function() {
                updateTables();
            });
            $('#zone_id').on('change', function() {
                updateTables();
            });
            $('#search').on('change', function() {
                updateTables();
            });
            $(document).on("click",".delete",function(e) {
                e.preventDefault();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    }
                });
                var url = $(this).attr('data-url');
                // confirm then
                $.ajax({
                    url: url,
                    type: 'DELETE',
                    dataMode: 'json',
                    data: {
                      //  method: 'DELETE', 
                        submit: true,
                        "_token": "{{ csrf_token() }}"
                    }
                }).always(function (data) {
                    updateTables();
                });
            });
            
        });

        
        function updateTables() {
            $("#agax_datatable").DataTable().destroy();
            var table = $('#agax_datatable').DataTable( {
                serverSide: true,
                processing: true,
                searching:false,
                paging: true,
                "ajax": {
                    "url": "{{ route('marketing.discount.tab-index') }}",
                    "type": "POST",
                    'data': {
                        "discount_code": $('#discount_code').val(),
                        "business_category_id": $('#business_category_id').val(),
                        "city_id": $('#city_id').val(),
                        "district_id": $('#district_id').val(),
                        "state_id": $('#state_id').val(),
                        "zone_id": $('#zone_id').val(),
                        "search": $('#search').val(),
                        "_token": "{{ csrf_token() }}"
                    }
                },
                dom: 'Blfrtip',
                "columns": [
                    { "data": "id" },
                    { "data": "discount_code" },
                    { "data": "business_category_id" },
                    { "data": "city_id" },
                    { "data": "district_id" },
                    { "data": "state_id" },
                    { "data": "zone_id" },
                    { "data": "subscription_plan_id" },
                    { "data": "minimum_order_cost" },
                    { "data": "discount" },
                    { "data": "up_to_cost" },
                    { "data": "expiry_date" },
                    { "data": "created_at" },
                    { "data": "action" },

                ],
                "buttons":[

                ],
            });
            //table.draw(); 
        }
    </script>
@endsection
