@extends('layouts.master')

@section('title') @lang('translation.Business Models') @endsection

@section('css')
<!-- select2 css -->
<link href="{{ URL::asset('/assets/libs/select2/select2.min.css') }}" rel="stylesheet" type="text/css" />

<!-- dropzone css -->
<link href="{{ URL::asset('/assets/libs/dropzone/dropzone.min.css') }}" rel="stylesheet" type="text/css" />
@endsection

@section('content')

<div class="row content-panel-header">
    <div class="col-sm-4 page-title-box">
        <h4 class="mb-sm-0 font-size-18">business models</h4>
    </div>
</div>
<div class="row">
    <div class="col-12">
        
    <form  class="needs-validation" id="sbusiness_model_form" action="{{ route('business-models.update', ['business_model' => $businessModel->id] ) }}" method="post" enctype="multipart/form-data" novalidate>
    @method('put')
    @csrf
    <input type="hidden" name="id" value="{{ $businessModel->id }}" />
        <div class="card">
            <div class="card-body">
                <div class="card-title content-card-title">Edit Model</div>
                <div class="mb-3 row">
                    <label for="business_category" class="col-md-2 col-form-label">Business Category</label>
                    <div class="col-md-6">
                        <select name="business_category_id" id="business_category" class="form-select" required>
                                <option value='' >Select...</option>
                                @foreach($businessCategory as $category)
                                    <option value="{{ $category->id }}" {{ (($category->id == $businessModel->business_category_id) ? 'selected' : '') }}>{{ $category->business_category}}</option>
                                @endforeach 
                        </select>
                        <div  id="business_category_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="business_model" class="col-md-2 col-form-label">Name the Model</label>
                    <div class="col-md-6">
                        <input id="business_model" name="business_model" type="text" class="form-control" placeholder="Name the Model" value="{{ $businessModel->business_model }}" required>
                        <div  id="business_model_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <?php 
                    $modelAssets = [
                        ['asset_type' => 'People'],
                        ['asset_type' => 'Vehicle'],
                        ['asset_type' => 'Add on Asset'],
                    ];
                    $assetTypes = explode(',', $businessModel->asset_types);
                   //print_r($assetTypes); exit;
                ?>
                <div class="mb-3 row">
                    <label for="asset_types" class="col-md-2 col-form-label">Model Assets</label>
                    <div class="col-md-6">
                        @foreach($modelAssets as $modelAsset)
                            <div class="form-check mb-3">
                            <input class="form-check-input" type="checkbox" id="assets_type1" name="asset_types[]" value="{{ $modelAsset['asset_type'] }}" {{ (in_array($modelAsset['asset_type'] , $assetTypes) ? 'checked' : '') }} required />
                            <label class="form-check-label" for="assets_type1">
                                {{ $modelAsset['asset_type'] }}
                            </label>
                        </div>
                        @endforeach 
                        <div  id="asset_types_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>

            </div>
        </div>

        <div class="card btn-card">
            <div class="card-body">
                <div class="d-flex flex-wrap gap-2 btn-sm-end">
                    <button type="submit" class="btn btn-primary waves-effect waves-light">Update</button>
                </div>
            </div>
        </div>
    </form>
    </div>
</div>
<!-- end row -->

@endsection
@section('script')
    <!-- select 2 plugin -->
    <script src="{{ URL::asset('/assets/libs/select2/select2.min.js') }}"></script>

    <!-- dropzone plugin -->
    <script src="{{ URL::asset('/assets/libs/dropzone/dropzone.min.js') }}"></script>

    <!-- init js -->
    <script src="{{ URL::asset('/assets/js/pages/ecommerce-select2.init.js') }}"></script>
    <!--tinymce js-->
    <script src="{{ URL::asset('/assets/libs/tinymce/tinymce.min.js') }}"></script>

    <!-- init js -->
    <script src="{{ URL::asset('/assets/js/pages/form-editor.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/parsleyjs/parsleyjs.min.js') }}"></script>

    <script src="{{ URL::asset('/assets/js/pages/form-validation.init.js') }}"></script>
    
    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
    $(document).ready(function(){
        
        $( "#sbusiness_model_form" ).submit(function( event ) {
            event.preventDefault();
            actionUrl = "{{ route('business-model.validate') }}";
            form = $( "#sbusiness_model_form" );
            $.ajax({
                type: "POST",
                url: actionUrl,
                data: form.serialize(), // serializes the form's elements.
                success: function(data){ 
                    //$('.needs-validation').addClass('validated');
                    form.unbind().submit(); 
                },
                error: function (data) {
                    console.log('An error occurred.');
                    response = data.responseJSON;
                    if(response.status == false){
                       
                        validationErrors(response);
                    }
                },
            });
        });
    });
    </script>
@endsection