@extends('layouts.master')

@section('title') @lang('translation.City') @endsection

@section('css')
    <!-- DataTables -->
    <link href="{{ URL::asset('/assets/libs/datatables/datatables.min.css') }}" rel="stylesheet" type="text/css" />
    <!-- <link href="https://cdn.datatables.net/searchpanes/2.1.0/css/searchPanes.bootstrap4.min.css" rel="stylesheet" type="text/css" />
    <link href="https://cdn.datatables.net/select/1.5.0/css/select.bootstrap4.min.css" rel="stylesheet" type="text/css" /> -->
@endsection
@section('content')

    <div class="row content-panel-header">
        <div class="col-sm-4 page-title-box">
            <h4 class="mb-sm-0 font-size-18">cities </h4>
        </div>
        <div class="col-sm-8">
            <div class="text-sm-end">
                <a href="{{ route('cities.create')}}" class="btn btn-primary waves-effect waves-light"><i class="mdi mdi-plus me-1"></i> Create New</a>
            </div>
        </div>
    </div> 
    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">
                    <div class="row mb-2">
                        <div class="col-sm-2">
                            <input type="hidden" id="zone_id_input" />
                            <select id="zone_id" class="form-control">
                                <option value=''>--By Zone--</option>
                                @foreach($zones as $zone)
                                    <option value="{{ $zone->id }}">{{ $zone->zone}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <select id="state_id" class="form-control" name="state_id">
                                <option value=''>--By State--</option>
                                @foreach($states as $state)
                                    <option value="{{ $state->id }}">{{ $state->state}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <select id="district_id" class="form-control" name="district_id">
                                <option value=''>--By District--</option>
                                @foreach($districts as $district)
                                    <option value="{{ $district->id }}">{{ $district->district}}</option>
                                @endforeach 
                            </select>
                        </div>
                        
                        <div class="col-sm-2">
                            <select id="city" class="form-control" name="city">
                                <option value=''>--By City--</option>
                                @foreach($citys as $city)
                                    <option value="{{ $city->city }}">{{ $city->city}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <!--<input type="search" id="search" name="search" class="form-control" placeholder="Search">-->
                        </div>
                        <div class="col-sm-2">
                            <div class="text-sm-end">
                                <input type="search" id="search" name="search" class="form-control" placeholder="Search">
                            </div>
                        </div><!-- end col-->
                    </div>

                    <?php $i = 0 ?>
                    <div class="table-responsive">
                        <table id="city_datatable" class="table align-middle table-nowrap">
                            <thead>
                                <tr>
                                    <th> id</th>
                                    <th> Zone</th>
                                    <th> State</th>
                                    <th> District</th>
                                    <th> City</th>
                                    <th> Created At </th>
                                    <th> Updated At </th>
                                    <th> Action </th>
                                </tr>
                            </thead>
                        </table>
                    </div>
                    
                </div>
            </div>
        </div>
    </div>
    <!-- end row -->
@endsection
@section('script')
    <!-- Required datatable js -->
    <script src="{{ URL::asset('/assets/libs/datatables/datatables.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/jszip/jszip.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/pdfmake/pdfmake.min.js') }}"></script>
    <!-- Datatable init js -->
    <script src="{{ URL::asset('/assets/js/pages/datatables.init.js') }}"></script>
    <!-- <script src="https://cdn.datatables.net/searchpanes/2.1.0/js/dataTables.searchPanes.min.js"></script>
    <script src="https://cdn.datatables.net/searchpanes/2.1.0/js/searchPanes.bootstrap4.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.5.0/js/dataTables.select.min.js"></script> -->
    
    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
        $(document).ready(function(){
            // var table = $('#datatable-assets').DataTable({
            //     searchPanes: true
            // });
            // table.searchPanes.container().prependTo(table.table().container());
            // table.searchPanes.resizePanes();
            updateTables();
           
            $('#zone_id').on('change', function() {
                updateTables();
                updateStateOptions();
            });
            $('#state_id').on('change', function() {
                updateTables();
                updateDistrictOptions()
            });
            $('#district_id').on('change', function() {
                updateTables();
                updateCityOptions();
            });
            $("#search").change(function(){
                updateTables();
            });
            
            $(document).on("click",".delete",function(e) {
                e.preventDefault();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    }
                });
                var url = $(this).attr('data-url');
                // confirm then
                $.ajax({
                    url: url,
                    type: 'DELETE',
                    dataType: 'json',
                    data: {
                      //  method: 'DELETE', 
                        submit: true,
                        "_token": "{{ csrf_token() }}"
                    }
                }).always(function (data) {
                    updateTables();
                });
            });
            
        });

        function updateStateOptions(){

            var zone_id = $('#zone_id').val();
            var states = [];
            actionUrl = "{{ route('state.states-by-zone') }}";
            $.ajax({
                type: "POSt",
                url: actionUrl,
                data: {
                    "zone_id":zone_id,
                    "_token": "{{ csrf_token() }}"
                },
                success: function(data){ 
                    if(data['data']){
                        var sel = $("#state_id");
                        sel.find('option').remove().end();
                        sel.append('<option value="">Select...</option>');
                        $.each(data['data'], function(index, item) {
                            if(item.state != ''){
                                sel.append('<option value="'+ item.id +'">'+ item.state +'</option>');
                            }
                        });
                    }
                },
                error: function (data) {
                    console.log(actionUrl+' Failes.');
                },
            });
        }
        function updateDistrictOptions(){
            var state_id =  $('#state_id').val();
            var states = [];
            actionUrl = "{{ route('district.districts-by-state') }}";
            $.ajax({
                type: "POSt",
                url: actionUrl,
                data: {
                    "state_id":state_id,
                    "_token": "{{ csrf_token() }}"
                },
                success: function(data){ 
                    if(data['data']){
                        var sel = $("#district_id");
                        sel.find('option').remove().end();
                        sel.append('<option value="">Select...</option>');
                        $.each(data['data'], function(index, item) {
                            if(item.state != ''){
                                sel.append('<option value="'+ item.id +'">'+ item.district +'</option>');
                            }
                        });
                    }
                },
                error: function (data) {
                    console.log(actionUrl+' Failes.');
                },
            });
        }
        function updateCityOptions(){
            var district_id =  $('#district_id').val();
            var states = [];
            actionUrl = "{{ route('city.cities-by-district') }}";
            $.ajax({
                type: "POSt",
                url: actionUrl,
                data: {
                    "state_id":state_id,
                    "_token": "{{ csrf_token() }}"
                },
                success: function(data){ 
                    if(data['data']){
                        var sel = $("#city");
                        sel.find('option').remove().end();
                        sel.append('<option value="">Select...</option>');
                        $.each(data['data'], function(index, item) {
                            if(item.state != ''){
                                sel.append('<option value="'+ item.city +'">'+ item.city +'</option>');
                            }
                        });
                    }
                },
                error: function (data) {
                    console.log(actionUrl+' Failes.');
                },
            });
        }
        function updateTables() {
            $("#city_datatable").DataTable().destroy();
            var table = $('#city_datatable').DataTable( {
                serverSide: true,
                processing: true,
                searching:false,
                paging: true,
                "ajax": {
                    "url": "{{ route('city.tab-index') }}",
                    "type": "POST",
                    'data': {
                        "zone_id": $('#zone_id').val(),
                        "state_id": $('#state_id').val(),
                        "district_id": $('#district_id').val(),
                        "city": $('#city').val(),
                        "search": $('#search').val(),
                        "_token": "{{ csrf_token() }}"
                    }
                },
                dom: 'Blfrtip',
                "columns": [
                    { "data": "id" },
                    { "data": "zone" },
                    { "data": "state" },
                    { "data": "district" },
                    { "data": "city" },
                    { "data": "created_at" },
                    { "data": "updated_at" },
                    { "data": "action" },

                ],
                "buttons":[

                ],
                columnDefs: [{
                    "defaultContent": "-",
                    "targets": "_all"
                }]
            });
            //table.draw(); 
        }
    </script>
@endsection
