@extends('layouts.master')

@section('title') @lang('State') @endsection

@section('css')
    <!-- DataTables -->
    <link href="{{ URL::asset('/assets/libs/datatables/datatables.min.css') }}" rel="stylesheet" type="text/css" />
    <!-- <link href="https://cdn.datatables.net/searchpanes/2.1.0/css/searchPanes.bootstrap4.min.css" rel="stylesheet" type="text/css" />
    <link href="https://cdn.datatables.net/select/1.5.0/css/select.bootstrap4.min.css" rel="stylesheet" type="text/css" /> -->
@endsection
@section('content')

    <div class="row content-panel-header">
        <div class="col-sm-4 page-title-box">
            <h4 class="mb-sm-0 font-size-18">States</h4>
        </div>
        <div class="col-sm-8">
            <div class="text-sm-end">
                <a href="{{ route('states.create')}}" class="btn btn-primary waves-effect waves-light"><i class="mdi mdi-plus me-1"></i> Create New</a>
            </div>
        </div>
    </div>  
    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">
                    <div class="row mb-2">
                        <div class="col-sm-2">
                            <input type="hidden" id="zone_id_input" />
                            <select id="zone_id" class="form-control select2">
                                <option value=''>--By Category--</option>
                                @foreach($zones as $zone)
                                    <option value="{{ $zone->id }}">{{ $zone->zone}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <input type="hidden" id="state_input" />
                            <select id="state" class="form-control select2" name="state">
                                <option value=''>--By State--</option>
                                @foreach($states as $state)
                                    <option value="{{ $state->state }}">{{ $state->state}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                           
                        </div>
                        
                        <div class="col-sm-4">
                            
                        </div>
                        <div class="col-sm-2">
                             <div class="text-sm-end">
                                <input type="search" class="form-control" id="search" placeholder="Search" aria-controls="datatable-buttons">
                            </div>
                        </div><!-- end col-->
                    </div>

                    <?php $i = 0 ?>
                    <div class="table-responsive">
                        <table id="states_datatable" class="table align-middle table-nowrap">
                            <thead>
                                <tr>
                                    <th> id</th>
                                    <th> Zone</th>
                                    <th> Region (State)</th>
                                    <th> Created At </th>
                                    <th> Updated At </th>
                                    <th> Action </th>
                                </tr>
                            </thead>
                        </table>
                    </div>
                    
                </div>
            </div>
        </div>
    </div>
    <!-- end row -->
@endsection
@section('script')
    <!-- Required datatable js -->
    <script src="{{ URL::asset('/assets/libs/datatables/datatables.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/jszip/jszip.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/pdfmake/pdfmake.min.js') }}"></script>
    <!-- Datatable init js -->
    <script src="{{ URL::asset('/assets/js/pages/datatables.init.js') }}"></script>
    <!-- <script src="https://cdn.datatables.net/searchpanes/2.1.0/js/dataTables.searchPanes.min.js"></script>
    <script src="https://cdn.datatables.net/searchpanes/2.1.0/js/searchPanes.bootstrap4.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.5.0/js/dataTables.select.min.js"></script> -->
    
    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
        $(document).ready(function(){
            // var table = $('#datatable-assets').DataTable({
            //     searchPanes: true
            // });
            // table.searchPanes.container().prependTo(table.table().container());
            // table.searchPanes.resizePanes();
            updateTables();
           
            $('#zone_id').on('change', function() {
                $('#zone_id_input').val($(this).val());
                updateTables();
            });
            $('#state').on('change', function() {
                $('#state_input').val($(this).val());
                updateTables();
            });
            $("#search").change(function(){
                updateTables();
            });
             
            $(document).on("click",".delete",function(e) {
                e.preventDefault();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    }
                });
                var url = $(this).attr('data-url');
                // confirm then
                $.ajax({
                    url: url,
                    type: 'DELETE',
                    dataType: 'json',
                    data: {
                      //  method: 'DELETE', 
                        submit: true,
                        "_token": "{{ csrf_token() }}"
                    }
                }).always(function (data) {
                    updateTables();
                });
            });
            
        });

        
        function updateTables() {
            $("#states_datatable").DataTable().destroy();
            var table = $('#states_datatable').DataTable( {
                serverSide: true,
                processing: true,
                searching:false,
                paging: true,
                "ajax": {
                    "url": "{{ route('state.tab-index') }}",
                    "type": "POST",
                    'data': {
                        "zone_id": $('#zone_id').val(),
                        "state": $('#state').val(),
                        "search": $('#search').val(),
                        "_token": "{{ csrf_token() }}"
                    }
                },
                dom: 'Blfrtip',
                "columns": [
                    { "data": "id" },
                    { "data": "zone" },
                    { "data": "state" },
                    { "data": "created_at" },
                    { "data": "updated_at" },
                    { "data": "action" },

                ],
                "buttons":[

                ],
            });
            //table.draw(); 
        }
    </script>
@endsection
