@extends('layouts.master')

@section('title') @lang('Purchased Service Battery') @endsection

@section('css')
    <!-- DataTables -->
    <link href="{{ URL::asset('/assets/libs/datatables/datatables.min.css') }}" rel="stylesheet" type="text/css" />
    <!-- <link href="https://cdn.datatables.net/searchpanes/2.1.0/css/searchPanes.bootstrap4.min.css" rel="stylesheet" type="text/css" />
    <link href="https://cdn.datatables.net/select/1.5.0/css/select.bootstrap4.min.css" rel="stylesheet" type="text/css" /> -->
@endsection
@section('content')

    @component('components.breadcrumb')
        @slot('li_1')  Purchased Service @endslot
        @slot('title') Battery @endslot
    @endcomponent

    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">
                    <div class="row mb-2">
                        <div class="col-sm-2">
                            <select id="purchased_service_id" class="form-select select2">
                                <option value=''>--By Purchased Service--</option>
                                @foreach($purchasedServiceList as $purchasedService)
                                    <option value="{{ $purchasedService->id }}">{{ $purchasedService->purchased_service}}</option>
                                @endforeach 
                            </select>
                        </div> 
                        <div class="col-sm-2">
                            <select id="location_id" class="form-select select2">
                                <option value=''>--By Location--</option>
                                @foreach($locationList as $location)
                                    <option value="{{ $location->id }}">{{ $location->location}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <select id="vendor_workshop_id" class="form-select select2">
                                <option value=''>--By Service Workshop--</option>
                                @foreach($serviceWorkshopList as $serviceWorkshop)
                                    <option value="{{ $serviceWorkshop->id }}" address="{{ $serviceWorkshop->address }}">{{ $serviceWorkshop->service_workshop}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <select id="asset_type_id" class="form-select select2">
                                <option value=''>--By Asset Type--</option>
                                @foreach($assetTypeList as $assetType)
                                    <option value="{{ $assetType->id }}" >{{ $assetType->product_type }}</option>
                                @endforeach 
                            </select>
                        </div>
                        
                        <div class="col-sm-2">
                            <input type="search" class="form-control" id="search" placeholder="Search" aria-controls="datatable-buttons">
                        </div>
                        <div class="col-sm-2">
                            <div class="text-sm-end">
                                <a href="{{ route('purchased-service.battery.create')}}" class="btn btn-success btn-rounded waves-effect waves-light mb-2 me-2"><i class="mdi mdi-plus me-1"></i> New Battery</a>
                            </div>
                        </div><!-- end col-->
                    </div>

                    <div class="table-responsive">
                        <table id="agax_datatable" class="table align-middle table-nowrap">
                            <thead>
                                <tr>
                                    <th> id</th>
                                    <th> Purchased Service</th>
                                    <th> Location </th>
                                    <th> Service Workshop </th>
                                    <th> Asset Type</th>
                                    <th> Asset</th>
                                    <th> Bill No</th>
                                    <th> Service Cost</th>
                                    <th> Start Date</th>
                                    <th> Estimated Delivery Date</th>
                                    <th> Actual Delivery Date</th>
                                    <th> Remarks   </th>
                                    <th> Created At </th>
                                    <th> Action </th>
                                </tr>
                            </thead>
                        </table>
                    </div>
                    
                </div>
            </div>
        </div>
    </div>
    <!-- end row -->
@endsection
@section('script')
    <!-- Required datatable js -->
    <script src="{{ URL::asset('/assets/libs/datatables/datatables.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/jszip/jszip.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/pdfmake/pdfmake.min.js') }}"></script>
    <!-- Datatable init js -->
    <script src="{{ URL::asset('/assets/js/pages/datatables.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
        $(document).ready(function(){
            
            updateTables();
           
            $('#purchased_service_id').on('change', function() {
                updateTables();
            });
            $('#location_id').on('change', function() {
                updateTables();
            });
            $('#vendor_workshop_id').on('change', function() {
                updateTables();
            });
            $('#asset_type_id').on('change', function() {
                updateTables();
            });
            $('#search').on('change', function() {
                updateTables();
            });
            $(document).on("click",".delete",function(e) {
                e.preventDefault();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    }
                });
                var url = $(this).attr('data-url');
                // confirm then
                $.ajax({
                    url: url,
                    type: 'DELETE',
                    dataMode: 'json',
                    data: {
                      //  method: 'DELETE', 
                        submit: true,
                        "_token": "{{ csrf_token() }}"
                    }
                }).always(function (data) {
                    updateTables();
                });
            });
            
        });

        
        function updateTables() {
            $("#agax_datatable").DataTable().destroy();
            var table = $('#agax_datatable').DataTable( {
                serverSide: true,
                processing: true,
                searching:false,
                paging: true,
                "ajax": {
                    "url": "{{ route('purchased-service.battery.tab-index') }}",
                    "type": "POST",
                    'data': {
                        "purchased_service_id": $('#purchased_service_id').val(),
                        "location_id": $('#location_id').val(),
                        "vendor_workshop_id": $('#vendor_workshop_id').val(),
                        "asset_type_id": $('#asset_type_id').val(),
                        "search": $('#search').val(),
                        "_token": "{{ csrf_token() }}"
                    }
                },
                dom: 'Blfrtip',
                "columns": [
                    { "data": "id" },
                    { "data": "purchased_service_id" },
                    { "data": "location_id" },
                    { "data": "vendor_workshop_id" },
                    { "data": "asset_type_id" },
                    { "data": "asset_id" },
                    { "data": "bill_number" },
                    { "data": "service_cost" },
                    { "data": "start_date" },
                    { "data": "estimated_delivery_date" },
                    { "data": "actual_delivery_date" },
                    { "data": "remarks" },
                    { "data": "created_at" },
                    { "data": "action" },

                ],
                "buttons":[

                ],
            });
            //table.draw(); 
        }
    </script>
@endsection
