@extends('layouts.master')

@section('title') @lang('Manpower Purchased Service') @endsection

@section('css')
    <!-- select2 css -->
    <link href="{{ URL::asset('/assets/libs/select2/select2.min.css') }}" rel="stylesheet" type="text/css" />

    <!-- dropzone css -->
    <link href="{{ URL::asset('/assets/libs/dropzone/dropzone.min.css') }}" rel="stylesheet" type="text/css" />
    <link href="{{ URL::asset('/assets/libs/bootstrap-datepicker/bootstrap-datepicker.min.css') }}" rel="stylesheet" type="text/css">
    <link rel="stylesheet" href="{{ URL::asset('/assets/libs/datepicker/datepicker.min.css') }}">
@endsection

@section('content')

@component('components.breadcrumb')
@slot('li_1') Manpower @endslot
@slot('title') Add Manpower @endslot
@endcomponent

<div class="row">
    <div class="col-12">
        
    <form  class="needs-validation" id="create_form" action="{{ route('purchased-service.manpower.store') }}" method="post" enctype="multipart/form-data" novalidate>
    @csrf
        <div class="card">
            <div class="card-body">
                <h5>Purchased Service Details</h5><br>
                <div class="mb-3 row">
                    <label for="purchased_service_id" class="col-md-2 col-form-label">Purchased Service</label>
                    <div class="col-md-6">
                        <select id="purchased_service_id" name="purchased_service_id" class="form-select" required>
                            <option value=''>Select...</option>
                            @foreach($purchasedServiceList as $purchasedService)
                                <option value="{{ $purchasedService->id }}">{{ $purchasedService->purchased_service}}</option>
                            @endforeach 
                        </select>
                        <div  id="purchased_service_id_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="location_id" class="col-md-2 col-form-label">Location</label>
                    <div class="col-md-6">
                        <select id="location_id" name="location_id" class="form-control" required>
                            <option value=''>Select...</option>
                            @foreach($locationList as $location)
                                <option value="{{ $location->id }}">{{ $location->location}}</option>
                            @endforeach 
                        </select>
                        <div  id="location_id_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="vendor_manpower_id" class="col-md-2 col-form-label">Service Vendor (Agency)</label>
                    <div class="col-md-6">
                        <select id="vendor_manpower_id" name="vendor_manpower_id" class="form-select" required>
                            <option value=''>Select...</option>
                            @foreach($manpowerList as $manpower)
                                <option value="{{ $manpower->id }}" address="{{ $manpower->address }}">{{ $manpower->organisation_name}}</option>
                            @endforeach 
                        </select>
                        <div  id="vendor_manpower_id_errors"  class="invalid-feedback">
                            Required
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="vendor_address" class="col-md-2 col-form-label">Vendor Address</label>
                    <div class="col-md-6">
                        <input id="vendor_address" name="vendor_address" type="text" class="form-control" placeholder="Name the Manpower Dealer" readonly>
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <h5>Work Details</h5><br>
                <div class="mb-3 row">
                    <label for="resource_name" class="col-md-2 col-form-label">Name of the Resource</label>
                    <div class="col-md-6">
                        <input id="resource_name" name="resource_name" type="text" class="form-control" placeholder="Name of the Resource" >
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="work_call" class="col-md-2 col-form-label">Work Call</label>
                    <div class="col-md-6">
                        <input id="work_call" name="work_call" type="text" class="form-control" placeholder="Work Call" >
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="designation_id" class="col-md-2 col-form-label">Designation / Skill Type</label>
                    <div class="col-md-6">
                        <select id="designation_id" name="designation_id" class="form-select" required>
                            <option value=''>Select...</option>
                            @foreach($designationList as $designation)
                                <option value="{{ $designation->id }}" >{{ $designation->designation}}</option>
                            @endforeach 
                        </select>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="gozap_id" class="col-md-2 col-form-label">GoZap ID</label>
                    <div class="col-md-6">
                        <div class="row">
                            <label for="gozap_prefix" class="col-sm-2 col-form-label">Prefix</label>
                            <div class="col-sm-4">
                                <input id="gozap_prefix" name="gozap_prefix" type="text" class="form-control" placeholder="Prefix" />
                            </div>
                            <label for="gozap_number" class="col-sm-2 col-form-label">Number</label>
                            <div class="col-sm-4">
                                <input id="gozap_number" name="gozap_number" type="text" class="form-control" placeholder="Number" />
                            </div>
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="duration" class="col-md-2 col-form-label">Duration/Term</label>
                    <div class="col-md-6">
                        <select id="duration" name="duration" class="form-select" >
                            <option value=''>Select...</option>
                            @foreach($durationList as $duration)
                                <option value="{{ $duration->id }}" >{{ $duration->duration}}</option>
                            @endforeach 
                        </select>
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <h5>Service Details</h5><br>
               
                <div class="mb-3 row">
                    <label for="bill_number" class="col-md-2 col-form-label">Bill No</label>
                    <div class="col-md-6">
                        <input id="bill_number" name="bill_number" type="text" class="form-control" placeholder="Bill No" />
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="service_cost" class="col-md-2 col-form-label">Service Cost</label>
                    <div class="col-md-6">
                        <input id="service_cost" name="service_cost" type="text" class="form-control" placeholder="Service Cost" />
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="start_date" class="col-md-2 col-form-label">Start date</label>
                    <div class="col-md-6">
                        <div class="input-group" id="datepicker2">
                            <input type="text" class="form-control" id="start_date" name="start_date" placeholder="Start Date"
                                data-date-format="dd-mm-yyyy" data-date-container='#datepicker2'
                                data-provide="datepicker" data-date-autoclose="true">

                            <span class="input-group-text"><i class="mdi mdi-calendar"></i></span>
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="end_date" class="col-md-2 col-form-label">End date</label>
                    <div class="col-md-6">
                        <div class="input-group" id="datepicker2">
                            <input type="text" class="form-control" id="end_date" name="end_date" placeholder="Start Date"
                                data-date-format="dd-mm-yyyy" data-date-container='#datepicker2'
                                data-provide="datepicker" data-date-autoclose="true">

                            <span class="input-group-text"><i class="mdi mdi-calendar"></i></span>
                        </div>
                    </div>
                </div>
                <div class="mb-3 row">
                    <label for="remarks" class="col-md-2 col-form-label">Remarks</label>
                    <div class="col-md-6">
                        <input id="remarks" name="remarks" type="text" class="form-control" placeholder="Remarks" />
                    </div>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">

                    <div class="d-flex flex-wrap gap-2">
                        <button type="submit" class="btn btn-primary waves-effect waves-light">Save Changes</button>
                    </div>
            </div>
        </div>
    </form>
    </div>
</div>
<!-- end row -->

@endsection
@section('script')
    <!-- select 2 plugin -->
    <script src="{{ URL::asset('/assets/libs/select2/select2.min.js') }}"></script>

    <!-- dropzone plugin -->
    <script src="{{ URL::asset('/assets/libs/dropzone/dropzone.min.js') }}"></script>

    <!-- init js -->
    <script src="{{ URL::asset('/assets/js/pages/ecommerce-select2.init.js') }}"></script>
    <!--tinymce js-->
    <script src="{{ URL::asset('/assets/libs/tinymce/tinymce.min.js') }}"></script>

    <!-- init js -->
    <script src="{{ URL::asset('/assets/js/pages/form-editor.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/parsleyjs/parsleyjs.min.js') }}"></script>

    <script src="{{ URL::asset('/assets/js/pages/form-validation.init.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/bootstrap-datepicker/bootstrap-datepicker.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/datepicker/datepicker.min.js') }}"></script>

    <script src="{{ URL::asset('/assets/js/custom.js') }}"></script>
    <script type="text/javascript">
    $(document).ready(function(){
        
        
        $('#vendor_manpower_id').on('change', function() {
            let address = $(this).find("option:selected").attr('address');
            $('#vendor_address').val(address);

        });
        $('#asset_id').on('change', function() {
            let model_name = $(this).find("option:selected").attr('model_name');
            let vin_number = $(this).find("option:selected").attr('vin_number');
            $('#model_name').val(model_name);
            $('#vin_number').val(vin_number);
        });
        $( "#create_form" ).submit(function( event ) {
            event.preventDefault();
            actionUrl = "{{ route('purchased-service.manpower.validate') }}";
            form = $( "#create_form" );
            $.ajax({
                type: "POST",
                url: actionUrl,
                data: form.serialize(), // serializes the form's elements.
                success: function(data){ 
                    $('.needs-validation').addClass('validated');
                    form.unbind().submit(); 
                },
                error: function (data) {
                    console.log('An error occurred.');
                    response = data.responseJSON;
                    if(response.mode == false){
                        $.each(response.errors, function(i, item) {
                             $('#'+i+'_errors').html(response.errors[i]); 
                            $('#'+i+'_errors').css('display', 'block');
                        });
                    }
                },
            });
        });
    });
    </script>
@endsection