@extends('layouts.master')

@section('title') @lang('translation.Vendors') @endsection

@section('css')
    <!-- DataTables -->
    <link href="{{ URL::asset('/assets/libs/datatables/datatables.min.css') }}" rel="stylesheet" type="text/css" />
    <!-- <link href="https://cdn.datatables.net/searchpanes/2.1.0/css/searchPanes.bootstrap4.min.css" rel="stylesheet" type="text/css" />
    <link href="https://cdn.datatables.net/select/1.5.0/css/select.bootstrap4.min.css" rel="stylesheet" type="text/css" /> -->
@endsection
@section('content')

    @component('components.breadcrumb')
        @slot('li_1') Vendors @endslot
        @slot('title') Vendors @endslot
    @endcomponent

    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">
                    
                <div class="row mb-2">
                        <div class="col-sm-2">
                            <select id="category_id" class="form-control select2">
                                <option value=''>--By Classification--</option>
                                @foreach($vendorCategoryList as $vendorCategory)
                                    <option value="{{ $vendorCategory->id }}">{{ $vendorCategory->vendor_category}}</option>
                                @endforeach 
                            </select>
                        </div> 
                        <div class="col-sm-2">
                            <select id="oem_id" class="form-control select2">
                                <option value=''>--By Classification--</option>
                                @foreach($vendorOemList as $vendorOem)
                                    <option value="{{ $vendorOem->id }}">{{ $vendorOem->vendor_oem}}</option>
                                @endforeach 
                            </select>
                        </div> 
                        <div class="col-sm-2">
                            <select id="zone_id" class="form-control select2">
                                <option value=''>--By Zone--</option>
                                @foreach($zones as $zone)
                                    <option value="{{ $zone->id }}">{{ $zone->zone}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <select id="state_id" class="form-control select2">
                                <option value=''>--By State--</option>
                                @foreach($states as $state)
                                    <option value="{{ $state->id }}">{{ $state->state}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-2">
                            <select id="district_id" class="form-control select2">
                                <option value=''>--By District--</option>
                                @foreach($districts as $district)
                                    <option value="{{ $district->id }}">{{ $district->district}}</option>
                                @endforeach 
                            </select>
                        </div>
                        
                        <div class="col-sm-2">
                            <select id="city_id" class="form-control select2">
                                <option value=''>--By City--</option>
                                @foreach($cities as $city)
                                    <option value="{{ $city->id }}">{{ $city->city}}</option>
                                @endforeach 
                            </select>
                        </div>
                        <div class="col-sm-10"></div>
                        <div class="col-sm-2">
                            <div class="text-sm-end">
                                <a href="{{ route('vendors.create')}}" class="btn btn-success btn-rounded waves-effect waves-light mb-2 me-2"><i class="mdi mdi-plus me-1"></i> New Vendor</a>
                            </div>
                        </div><!-- end col-->
                    </div>

                    <div class="table-responsive">
                        <table id="agax_datatable" class="table align-middle table-nowrap">
                            <thead>
                                <tr>
                                    <th>Id</th>
                                    <th>Vendor Category</th>
                                    <th>Vendor OEM</th>
                                    <th>Vendor Name</th>
                                    <th> Zone </th>
                                    <th> State </th>
                                    <th> District </th>
                                    <th> City </th>
                                    <th> Postal Code </th>
                                    <th> Address </th>
                                    <th> Phone Number </th>
                                    <th> Created At </th>
                                    <th>Action</th>
                                </tr>
                            </thead>
                        </table>
                    </div>
                    
                </div>
            </div>
        </div>
    </div>
    <!-- end row -->
@endsection
@section('script')
    <!-- Required datatable js -->
    <script src="{{ URL::asset('/assets/libs/datatables/datatables.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/jszip/jszip.min.js') }}"></script>
    <script src="{{ URL::asset('/assets/libs/pdfmake/pdfmake.min.js') }}"></script>
    <!-- Datatable init js -->
    <script src="{{ URL::asset('/assets/js/pages/datatables.init.js') }}"></script>
    <!-- <script src="https://cdn.datatables.net/searchpanes/2.1.0/js/dataTables.searchPanes.min.js"></script>
    <script src="https://cdn.datatables.net/searchpanes/2.1.0/js/searchPanes.bootstrap4.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.5.0/js/dataTables.select.min.js"></script> -->
    <script type="text/javascript">
        $(document).ready(function(){
            updateTables();
           
            $('#category_id').on('change', function() {
                updateTables();
            });
            $('#oem_id').on('change', function() {
                updateTables();
            });
            $('#zone_id').on('change', function() {
                updateTables();
            });
            $('#city_id').on('change', function() {
                updateTables();
            });
            $('#district_id').on('change', function() {
                updateTables();
            });
            $('#state_id').on('change', function() {
                updateTables();
            });
             
            $(document).on("click",".delete",function(e) {
                e.preventDefault();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    }
                });
                var url = $(this).attr('data-url');
                // confirm then
                $.ajax({
                    url: url,
                    type: 'DELETE',
                    dataMode: 'json',
                    data: {
                      //  method: 'DELETE', 
                        submit: true,
                        "_token": "{{ csrf_token() }}"
                    }
                }).always(function (data) {
                    updateTables();
                });
            });
            
        });

        
        function updateTables() {
            $("#agax_datatable").DataTable().destroy();
            var table = $('#agax_datatable').DataTable( {
                serverSide: true,
                processing: true,
                searching:false,
                paging: true,
                "ajax": {
                    "url": "{{ route('vendor.tab-index') }}",
                    "type": "POST",
                    'data': {
                        "category_id": $('#category_id').val(),
                        "oem_id": $('#oem_id').val(),
                        "city_id": $('#city_id').val(),
                        "district_id": $('#district_id').val(),
                        "state_id": $('#state_id').val(),
                        "zone_id": $('#zone_id').val(),
                        "_token": "{{ csrf_token() }}"
                    }
                },
                dom: 'Blfrtip',
                "columns": [
                    { "data": "id" },
                    { "data": "category_id" },
                    { "data": "oem_id" },
                    { "data": "vendor_name" },
                    { "data": "zone_id" },
                    { "data": "state_id" },
                    { "data": "district_id" },
                    { "data": "city_id" },
                    { "data": "postal_code" },
                    { "data": "address" },
                    { "data": "phone_number" },
                    { "data": "created_at" },
                    { "data": "action" },

                ],
                "buttons":[

                ],
            });
            //table.draw(); 
        }
    </script>
@endsection
