<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Api\v1\LoginController;
use App\Http\Controllers\Api\v1\CmsController;
use App\Http\Controllers\Api\v1\AssetController;
use App\Http\Controllers\Api\v1\UserController;
use App\Http\Controllers\Api\v1\OrderController;
use App\Http\Controllers\Api\v1\AttendanceController;


/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

// Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
//     return $request->user();
// });
Route::get('/forms/{slug}', [CmsController::class, 'get_forms'])->name('forms.cms-forms');
Route::get('/onboard', [CmsController::class, 'get_onboard'])->name('onboard.get_onboard');


Route::post('/signup', [LoginController::class, 'register'])->name('customer.signup');
Route::post('/send-otp', [LoginController::class, 'send_otp'])->name('send-otp');
Route::post('/verify-otp', [LoginController::class, 'verify_user'])->name('verify-otp');
Route::post('/update-user', [LoginController::class, 'register_verified_user'])->name('update.user');//signupview2
Route::post('/forgot-password', [LoginController::class, 'forgot_password'])->name('forgot_password');
Route::post('/set-password', [LoginController::class, 'set_password'])->name('set_password');


Route::get('/home', [CmsController::class, 'home'])->name('cms.home');
Route::post('/assets/{asset}', [AssetController::class, 'asset_list'])->name('asset.list');
Route::post('/asset/scan', [AssetController::class, 'scan'])->name('asset.scan');

Route::post('/login', [LoginController::class, 'login'])->name('customer.login');

Route::post('/resend-otp', [LoginController::class, 're_send_otp'])->name('resend-otp');
Route::get('/menu', [CmsController::class, 'menu_list'])->name('menu.list');
Route::get('/faq', [CmsController::class, 'faqs'])->name('cms.faqs');
Route::get('faq-question', [CmsController::class, 'faq_question'])->name('cms.faq_question');
Route::get('/about-us', [CmsController::class, 'about_us'])->name('cms.about_us');
Route::get('/privacy-policy', [CmsController::class, 'privacy_policy'])->name('cms.privacy_policy');
Route::get('/terms-condition', [CmsController::class, 'terms_condition'])->name('cms.terms_condition');

Route::group([
    'middleware' => 'auth:sanctum',
], function () {
    Route::get('/user', [LoginController::class, 'user_details'])->name('user_details');
    Route::get('/user/logout/options', [LoginController::class, 'logout_options'])->name('user.logout.options');
    Route::get('/user/logout', [LoginController::class, 'logout'])->name('user.logout');
    Route::get('/user/logout/{device_id}', [LoginController::class, 'logout'])->name('user.device.logout');

    Route::get('/forms/{slug}/{id}', [CmsController::class, 'get_forms'])->name('user.forms.cms-forms');

    Route::post('/kyc', [LoginController::class, 'kyc'])->name('kyc');
    Route::post('/add-new-vehicle', [UserController::class, 'add_new_vehicle'])->name('user.add_new_vehicle');
    Route::post('/user/address/add', [UserController::class, 'add_address'])->name('user.address.add');
    //Route::get('/forms/{slug}/{id}', [CmsController::class, 'get_module_forms'])->name('forms.cms-forms-asset');
    Route::post('/edit-my-vehicle', [UserController::class, 'edit_new_vehicle'])->name('user.edit-my-vehicle');
    Route::get('/my-vehicles', [UserController::class, 'my_vehicles'])->name('user.my_vehicles');
    Route::get('/notifications', [UserController::class, 'notifications'])->name('user.notifications');
    Route::get('/notifications/delete/{id}', [UserController::class, 'destroy_notification'])->name('user.destroy_notification');


    Route::post('/send-otp', [LoginController::class, 'send_otp'])->name('send-otp');

    Route::post('/booking/{slug}', [OrderController::class, 'booking'])->name('order.booking');
    Route::get('/booking-summary/{id}', [OrderController::class, 'booking_summary'])->name('order.booking_summary');
    Route::get('/payment-options/{id}', [OrderController::class, 'payment_options'])->name('payment-options');
    Route::post('/place-order', [OrderController::class, 'place_order'])->name('place-order');
    Route::get('/order-history', [OrderController::class, 'order_history'])->name('order-history');
    Route::get('/order-history/{id}', [OrderController::class, 'order_history_details'])->name('order-history-data');
    Route::post('/feed-back/{category}', [OrderController::class, 'feed_back'])->name('order-feed-back');
    Route::get('/walkaround-checklist/{order_id}', [OrderController::class, 'walkaround_checklist'])->name('order-walkaround-checklist');
    Route::post('/walkaround-check/{order_id}', [OrderController::class, 'walkaround_check'])->name('order-walkaround-check');
    Route::get('/track-order/{order_id}', [OrderController::class, 'track_order'])->name('track-order');
    Route::post('/change-order-status/{order_id}', [OrderController::class, 'change_order_status'])->name('change-order-status');

    Route::get('/3plattendance', [AttendanceController::class, 'index']);
    Route::post('/3plattendance/check', [AttendanceController::class, 'Checkin']);
    Route::post('/3plattendance/checkout', [AttendanceController::class, 'Checkout']);
    Route::get('/flipkartreport', [AttendanceController::class, 'workreport']);
    Route::post('filterflipkart',[AttendanceController::class,'create']);

    Route::patch('/fcm-token', [HomeController::class, 'updateToken'])->name('fcmToken');

});

Route::fallback(function() {
    return response()->json([
        'data' => [],
        'success' => false,
        'status' => 404,
        'message' => 'Invalid Route'
    ]);
});
