<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\AppController;
use Itstructure\LaRbac\Http\Controllers\{UserController, RoleController, PermissionController};
use App\Http\Controllers\Admin\UserController as Admin;
use App\Http\Controllers\App\UserController as User;
use App\Http\Controllers\CheckoutController;
use App\Http\Controllers\CmsController;
use App\Http\Controllers\FlipkartController;
use App\Http\Controllers\VehicleOemController;
use App\Http\Controllers\VendorOemController;

Route::get('/optimize', function () {
    Artisan::call('optimize');
    echo 'optimized';
});

Route::get('/migrate', function () {
    Artisan::call('migrate');
    echo 'migrated';
});

Route::get('/', function () {
    return redirect('admin/login');
})->name('/');

Route::get('/root', function () {
    return view('welcome');
})->name('root');
//login
Route::get('/admin', [AppController::class, 'admin'])->name('admin');
Route::get('/admin/login', [App\Http\Controllers\Admin\LoginController::class, 'admin_login_form']);
Route::post('admin/login', [App\Http\Controllers\Admin\LoginController::class, 'admin_login'])->name('admin.login');
Route::get('/admin/forgot', [App\Http\Controllers\Admin\LoginController::class, 'admin_forgot_form']);

Route::get('/login', [User::class, 'login'])->name('login');
Route::post('/signup', [User::class, 'signup'])->name('signup');
//Language Translation
Route::get('/translate/{locale}', [AppController::class, 'lang'])->name('translate');
Route::get('/products', [CheckoutController::class, 'index'])->name('checkout.index');
Route::get('/checkout', [CheckoutController::class, 'checkout'])->name('checkout');
Route::get('/add-to-cart/{id}', [CheckoutController::class, 'add_to_cart'])->name('add.to.cart');

Route::get('faqs', [CmsController::class, 'faqs'])->name('app.faqs');
Route::get('faq-question', [CmsController::class, 'faq_question'])->name('app.faq_question');
Route::get('faq/{category}', [CmsController::class, 'faq_category'])->name('app.faq_category');
//users
Route::group(['prefix' => 'admin',
['middleware' => 'role:super-admin']
],function () {

Route::get('/dashboard', [AppController::class, 'dashboard'])->name('admin.dashboard')->middleware('auth');
Route::post('logout',  [AppController::class, 'logout'])->name('admin.logout');
Route::get('/usersnew', [UserController::class, 'index']);
// Users (members)
//Route::resource('users', 'App\Http\Controllers\Admin\UserController');

// Route::resource('orders', 'App\Http\Controllers\Admin\Order\OrderController');
// Route::post('order-tab-index', [App\Http\Controllers\Admin\Order\OrderController::class, 'tab_index'])->name('order.tab-index');
// Route::post('order-validate', [App\Http\Controllers\Admin\Order\OrderController::class, 'validate'])->name('order.validate');
// Route::post('order-status-change', [App\Http\Controllers\Admin\Order\OrderController::class, 'change_order_status'])->name('order.status_change');
// Route::post('order-payment-status-change', [App\Http\Controllers\Admin\Order\OrderController::class, 'payment_status_change'])->name('order.payment_status_change');
// Route::get('order-battery-swap/{order_id}', [App\Http\Controllers\Admin\Order\OrderController::class, 'battery_index'])->name('order.battery_index');
// Route::post('order-battery-swap-tab-inedex/{order_id}', [App\Http\Controllers\Admin\Order\OrderController::class, 'tab_battery_index'])->name('order.tab_battery_index');
// Route::post('order-battery-status-change', [App\Http\Controllers\Admin\Order\OrderController::class, 'change_battery_order_status'])->name('order.change_battery_order_status');
//MASTERS
//Assets Master
Route::group([
    'middleware' => ['auth']
    ],  function () {
    
Route::resource('property-types', 'App\Http\Controllers\Admin\Master\PropertyTypesController');
Route::match(['PUT', 'POST'],'property-types-validate', [App\Http\Controllers\Admin\Master\PropertyTypesController::class, 'validate'])->name('property-type.validate');
Route::post('property-type-tab-index', [App\Http\Controllers\Admin\Master\PropertyTypesController::class, 'tab_index'])->name('property-type.tab-index');

Route::resource('product-types', 'App\Http\Controllers\Admin\Master\ProductTypesController');
Route::match(['PUT', 'POST'],'product-types-validate', [App\Http\Controllers\Admin\Master\ProductTypesController::class, 'validate'])->name('product-type.validate');
Route::post('product-type-tab-index', [App\Http\Controllers\Admin\Master\ProductTypesController::class, 'tab_index'])->name('product-type.tab-index');

Route::get('vehicle-oem', [App\Http\Controllers\VehicleOemController::class,'index'])->name('vehicle.index');
Route::get('vehicleoem', [App\Http\Controllers\VehicleOemController::class,'create'])->name('vehicle.create');
Route::post('vehicle-oems', [App\Http\Controllers\VehicleOemController::class,'store'])->name('vehicle.store');
Route::post('vehicle_oem-tab-index', [App\Http\Controllers\VehicleOemController::class, 'tab_index'])->name('vehicle_oem.tab-index');
Route::resource('vehicleoem', 'App\Http\Controllers\VehicleOemController');
//After Sale Service Master
Route::resource('maintenance-types', 'App\Http\Controllers\Admin\Master\MaintentanceTypeController');
Route::match(['PUT', 'POST'],'maintenance-types-validate', [App\Http\Controllers\Admin\Master\MaintentanceTypeController::class, 'validate'])->name('maintenance-type.validate');
Route::post('maintenance-type-tab-index', [App\Http\Controllers\Admin\Master\MaintentanceTypeController::class, 'tab_index'])->name('maintenance-type.tab-index');

Route::resource('insurance-types', 'App\Http\Controllers\Admin\Master\InsuranceTypeController');
Route::match(['PUT', 'POST'],'insurance-type-validate', [App\Http\Controllers\Admin\Master\InsuranceTypeController::class, 'validate'])->name('insurance-type.validate');
Route::post('insurance-type-tab-index', [App\Http\Controllers\Admin\Master\InsuranceTypeController::class, 'tab_index'])->name('insurance-type.tab-index');

Route::resource('emergency-services', 'App\Http\Controllers\Admin\Master\EmergencyServiceController');
Route::match(['PUT', 'POST'],'emergency-service-validate', [App\Http\Controllers\Admin\Master\EmergencyServiceController::class, 'validate'])->name('emergency-service.validate');
Route::post('emergency-service/tab-index',[App\Http\Controllers\Admin\Master\EmergencyServiceController::class, 'tab_index'])->name('emergency-service.tab-index');

Route::resource('va-service-types', 'App\Http\Controllers\Admin\Master\VAServiceTypeController');
Route::match(['PUT', 'POST'],'va-service-type-validate', [App\Http\Controllers\Admin\Master\VAServiceTypeController::class, 'validate'])->name('va-service-type.validate');
Route::post('va-service-type-tab-index', [App\Http\Controllers\Admin\Master\VAServiceTypeController::class, 'tab_index'])->name('va-service-type.tab-index');

Route::resource('purchased-services', 'App\Http\Controllers\Admin\Master\PurchasedServiceController');
Route::match(['PUT', 'POST'],'purchased-service-validate', [App\Http\Controllers\Admin\Master\PurchasedServiceController::class, 'validate'])->name('purchased-service.validate');
Route::post('purchased-service-tab-index', [App\Http\Controllers\Admin\Master\PurchasedServiceController::class, 'tab_index'])->name('purchased-service.tab-index');
// Business Master
Route::resource('business-models', 'App\Http\Controllers\Admin\Master\BusinessController');
Route::match(['PUT', 'POST'],'business-model-validate', [App\Http\Controllers\Admin\Master\BusinessController::class, 'validate'])->name('business-model.validate');
Route::post('business-model/tab-index', [App\Http\Controllers\Admin\Master\BusinessController::class, 'tab_index'])->name('business-model.tab-index');

Route::resource('business-categories', 'App\Http\Controllers\Admin\Master\BusinessCategoryController');
Route::match(['PUT', 'POST'],'business-category-validate', [App\Http\Controllers\Admin\Master\BusinessCategoryController::class, 'validate'])->name('business-category.validate');
Route::post('business-categories-tab-index', [App\Http\Controllers\Admin\Master\BusinessCategoryController::class, 'tab_index'])->name('business-category.tab-index');

Route::post('businessmodelwise', [App\Http\Controllers\Admin\Master\BusinessController::class, 'businesscategorywise'])->name('businessmodelwise');
Route::post('businessmodelmenuwise', [App\Http\Controllers\Admin\CMS\MenuController::class, 'businessmodelmenuwise'])->name('businessmodelmenuwise');
//Finance Master
Route::resource('payment-types', 'App\Http\Controllers\Admin\Master\PaymentTypeController');
Route::match(['PUT', 'POST'],'payment-type-validate', [App\Http\Controllers\Admin\Master\PaymentTypeController::class, 'validate'])->name('payment-type.validate');
Route::post('payment-type/tab-index', [App\Http\Controllers\Admin\Master\PaymentTypeController::class, 'tab_index'])->name('payment-type.tab-index');

Route::resource('billing-types', 'App\Http\Controllers\Admin\Master\BillingTypeController');
Route::match(['PUT', 'POST'],'billing-type-validate', [App\Http\Controllers\Admin\Master\BillingTypeController::class, 'validate'])->name('billing-type.validate');
Route::post('billing-type/tab-index', [App\Http\Controllers\Admin\Master\BillingTypeController::class, 'tab_index'])->name('billing-type.tab-index');

Route::resource('taxation-profile', 'App\Http\Controllers\Admin\Master\TaxationprofileController');
Route::match(['PUT', 'POST'],'taxation-profile-validate', [App\Http\Controllers\Admin\Master\TaxationprofileController::class, 'validate'])->name('taxation-profile.validate');
Route::post('taxation-profile/tab-index', [App\Http\Controllers\Admin\Master\TaxationprofileController::class, 'tab_index'])->name('taxation-profile.tab-index');

Route::resource('tax-percentage', 'App\Http\Controllers\Admin\Master\TaxPercentageController');
Route::match(['PUT', 'POST'],'tax-percentage-validate', [App\Http\Controllers\Admin\Master\TaxPercentageController::class, 'validate'])->name('tax-percentage.validate');
Route::post('tax-percentage-tab-index', [App\Http\Controllers\Admin\Master\TaxPercentageController::class, 'tab_index'])->name('tax-percentage.tab-index');
//Location Master
Route::resource('zones', 'App\Http\Controllers\Admin\Master\ZoneController');
Route::match(['PUT', 'POST'],'zones-validate', [App\Http\Controllers\Admin\Master\ZoneController::class, 'validate'])->name('zone.validate');
Route::post('zone-tab-index', [App\Http\Controllers\Admin\Master\ZoneController::class, 'tab_index'])->name('zone.tab-index');

Route::resource('states', 'App\Http\Controllers\Admin\Master\ZoneStateController');
Route::match(['PUT', 'POST'],'state-validate', [App\Http\Controllers\Admin\Master\ZoneStateController::class, 'validate'])->name('state.validate');
Route::post('state/tab-index', [App\Http\Controllers\Admin\Master\ZoneStateController::class, 'tab_index'])->name('state.tab-index');
Route::post('state/states-by-zone', [App\Http\Controllers\Admin\Master\ZoneStateController::class, 'states_by_zone'])->name('state.states-by-zone');

Route::resource('districts', 'App\Http\Controllers\Admin\Master\ZoneDistrictController');
Route::match(['PUT', 'POST'],'district-validate', [App\Http\Controllers\Admin\Master\ZoneDistrictController::class, 'validate'])->name('district.validate');
Route::post('district/tab-index', [App\Http\Controllers\Admin\Master\ZoneDistrictController::class, 'tab_index'])->name('district.tab-index');
Route::post('district/districts-by-zone', [App\Http\Controllers\Admin\Master\ZoneDistrictController::class, 'districts_by_zone'])->name('district.districts-by-zone');
Route::post('district/districts-by-state', [App\Http\Controllers\Admin\Master\ZoneDistrictController::class, 'districts_by_state'])->name('district.districts-by-state');
  
Route::resource('cities', 'App\Http\Controllers\Admin\Master\ZoneCityController');
Route::match(['PUT', 'POST'],'city-validate', [App\Http\Controllers\Admin\Master\ZoneCityController::class, 'validate'])->name('city.validate');
Route::post('cities/{city}', [App\Http\Controllers\Admin\Master\ZoneCityController::class, 'update'])->name('cities.post.update');
Route::post('city/tab-index', [App\Http\Controllers\Admin\Master\ZoneCityController::class, 'tab_index'])->name('city.tab-index');
Route::post('city/cities-by-zone', [App\Http\Controllers\Admin\Master\ZoneCityController::class, 'cities_by_zone'])->name('city.cities-by-zone');
Route::post('city/cities-by-state', [App\Http\Controllers\Admin\Master\ZoneCityController::class, 'cities_by_state'])->name('city.city-by-state');
Route::post('city/cities-by-district', [App\Http\Controllers\Admin\Master\ZoneCityController::class, 'cities_by_district'])->name('city.cities-by-district');
Route::post('city', [App\Http\Controllers\Admin\Master\ZoneCityController::class, 'city'])->name('city');

Route::resource('location-classifications', 'App\Http\Controllers\Admin\Master\LocationClassificationController');
Route::match(['PUT', 'POST'],'location-classifications-validate', [App\Http\Controllers\Admin\Master\LocationClassificationController::class, 'validate'])->name('location-classification.validate');
Route::post('location-classification-tab-index', [App\Http\Controllers\Admin\Master\LocationClassificationController::class, 'tab_index'])->name('location-classification.tab-index');

Route::resource('location', 'App\Http\Controllers\Admin\LocationController');
Route::match(['PUT', 'POST'],'location-validate', [App\Http\Controllers\Admin\LocationController::class, 'validate'])->name('location.validate');
Route::post('location-tab-index', [App\Http\Controllers\Admin\LocationController::class, 'tab_index'])->name('location.tab-index');
//Mobile Form Master
Route::resource('form-field-type', 'App\Http\Controllers\Admin\Master\FormFieldTypeController');
Route::match(['PUT', 'POST'],'form-field-type-validate', [App\Http\Controllers\Admin\Master\FormFieldTypeController::class, 'validate'])->name('form-field-type.validate');
Route::post('form-field-type-tab-index', [App\Http\Controllers\Admin\Master\FormFieldTypeController::class, 'tab_index'])->name('form-field-type.tab-index');

Route::resource('form-field-group', 'App\Http\Controllers\Admin\Master\FormFieldGroupController');
Route::match(['PUT', 'POST'],'form-field-group-validate', [App\Http\Controllers\Admin\Master\FormFieldGroupController::class, 'validate'])->name('form-field-group.validate');
Route::post('form-field-group-tab-index', [App\Http\Controllers\Admin\Master\FormFieldGroupController::class, 'tab_index'])->name('form-field-group.tab-index');
//Operation Master
Route::resource('activity-status', 'App\Http\Controllers\Admin\Master\ActivityStatusController');
Route::match(['PUT', 'POST'],'activity-status-validate', [App\Http\Controllers\Admin\Master\ActivityStatusController::class, 'validate'])->name('activity-status.validate');
Route::post('activity-status-tab-index', [App\Http\Controllers\Admin\Master\ActivityStatusController::class, 'tab_index'])->name('activity-status.tab-index');

Route::resource('angel-service', 'App\Http\Controllers\Admin\Master\AngelServiceController', [ 'as' => 'master' ]);
Route::match(['PUT', 'POST'],'angel-service-validate', [App\Http\Controllers\Admin\Master\AngelServiceController::class, 'validate'])->name('master.angel-service.validate');
Route::post('master-angel-service-tab-index', [App\Http\Controllers\Admin\Master\AngelServiceController::class, 'tab_index'])->name('master.angel-service.tab-index');
Route::get('master-angel-delete-service-type-image/{id}', [App\Http\Controllers\Admin\Master\AngelServiceController::class, 'destroy_service_type_image'])->name('master.angel.delete-service-type-image');

Route::resource('delivery-types', 'App\Http\Controllers\Admin\Master\DeliveryTypeController');
Route::match(['PUT', 'POST'],'delivery-type-validate', [App\Http\Controllers\Admin\Master\DeliveryTypeController::class, 'validate'])->name('delivery-type.validate');
Route::post('delivery-type-tab-index', [App\Http\Controllers\Admin\Master\DeliveryTypeController::class, 'tab_index'])->name('delivery-type.tab-index');

Route::resource('designation', 'App\Http\Controllers\Admin\Master\DesignationController');
Route::match(['PUT', 'POST'],'designation-validate', [App\Http\Controllers\Admin\Master\DesignationController::class, 'validate'])->name('designation.validate');
Route::post('designation-tab-index', [App\Http\Controllers\Admin\Master\DesignationController::class, 'tab_index'])->name('designation.tab-index');

Route::resource('duration', 'App\Http\Controllers\Admin\Master\DurationController');
Route::match(['PUT', 'POST'],'duration-validate', [App\Http\Controllers\Admin\Master\DurationController::class, 'validate'])->name('duration.validate');
Route::post('duration-tab-index', [App\Http\Controllers\Admin\Master\DurationController::class, 'tab_index'])->name('duration.tab-index');

Route::resource('service-types', 'App\Http\Controllers\Admin\Master\ServiceTypeController');
Route::match(['PUT', 'POST'],'service-type-validate', [App\Http\Controllers\Admin\Master\ServiceTypeController::class, 'validate'])->name('service-type.validate');
Route::post('service-type-tab-index', [App\Http\Controllers\Admin\Master\ServiceTypeController::class, 'tab_index'])->name('service-type.tab-index');

Route::resource('sop-categories', 'App\Http\Controllers\Admin\Master\SopCategoryController');
Route::match(['PUT', 'POST'],'sop-categories-validate', [App\Http\Controllers\Admin\Master\SopCategoryController::class, 'validate'])->name('sop-category.validate');
Route::post('sop-category/tab-index', [App\Http\Controllers\Admin\Master\SopCategoryController::class, 'tab_index'])->name('sop-category.tab-index');

Route::resource('verification-mode', 'App\Http\Controllers\Admin\Master\VerificationModeController');
Route::match(['PUT', 'POST'],'verification-mode-validate', [App\Http\Controllers\Admin\Master\VerificationModeController::class, 'validate'])->name('verification-mode.validate');
Route::post('verification-mode-tab-index', [App\Http\Controllers\Admin\Master\VerificationModeController::class, 'tab_index'])->name('verification-mode.tab-index');

Route::resource('verification-types', 'App\Http\Controllers\Admin\Master\VerficationTypeController');
Route::match(['PUT', 'POST'],'verification-type-validate', [App\Http\Controllers\Admin\Master\VerficationTypeController::class, 'validate'])->name('verification-type.validate');
Route::post('verification-type/tab-index', [App\Http\Controllers\Admin\Master\VerficationTypeController::class, 'tab_index'])->name('verification-type.tab-index');
//Staff Master
Route::resource('permissions', 'App\Http\Controllers\Admin\Master\PermissionController');
Route::match(['PUT', 'POST'],'permissions-validate', [App\Http\Controllers\Admin\Master\PermissionController::class, 'validate'])->name('permission.validate');
Route::post('permission-tab-index', [App\Http\Controllers\Admin\Master\PermissionController::class, 'tab_index'])->name('permission.tab-index');

Route::resource('roles', 'App\Http\Controllers\Admin\Master\RoleController');
Route::match(['PUT', 'POST'],'roles-validate', [App\Http\Controllers\Admin\Master\RoleController::class, 'validate'])->name('role.validate');
Route::post('role-tab-index', [App\Http\Controllers\Admin\Master\RoleController::class, 'tab_index'])->name('role.tab-index');

Route::resource('insurance-durations', 'App\Http\Controllers\Admin\Master\InsuranceDurationController');
Route::match(['PUT', 'POST'],'insurance-duration-validate', [App\Http\Controllers\Admin\Master\InsuranceDurationController::class, 'validate'])->name('insurance-duration.validate');
});
});
// Vendors 
Route::group(['prefix' => 'admin',
'middleware' => ['auth']
], function () {
  
Route::resource('vendor-category', 'App\Http\Controllers\Admin\Vendors\VendorCategoryController');
Route::match(['PUT', 'POST'],'vendor-category-validate', [App\Http\Controllers\Admin\Vendors\VendorCategoryController::class, 'validate'])->name('vendor-category.validate');
Route::post('vendor-category-tab-index', [App\Http\Controllers\Admin\Vendors\VendorCategoryController::class, 'tab_index'])->name('vendor-category.tab-index');

Route::get('vendor-oem', [App\Http\Controllers\Admin\Vendors\VendorOemController::class,'index'])->name('vendor-oem.index');
Route::get('vendor-oems', [App\Http\Controllers\Admin\Vendors\VendorOemController::class,'create'])->name('vendoroem.create');
Route::post('vendoroems', [App\Http\Controllers\Admin\Vendors\VendorOemController::class,'store'])->name('vendoroem.store');
Route::resource('vendor-oem', 'App\Http\Controllers\Admin\Vendors\VendorOemController');
Route::post('oemmodelwise', [App\Http\Controllers\Admin\Vendors\VendorOemController::class, 'oems'])->name('oemmodelwise');

Route::match(['PUT', 'POST'],'vendor-oem-validate', [App\Http\Controllers\Admin\Vendors\VendorOemController::class, 'validate'])->name('vendor-oem.validate');
Route::post('vendor-oem-tab-index', [App\Http\Controllers\Admin\Vendors\VendorOemController::class, 'tab_index'])->name('vendor-oem.tab-index');
Route::post('vendor-oem/oem-by-category', [App\Http\Controllers\Admin\Vendors\VendorOemController::class, 'vendor_oem_by_category'])->name('vendor-oem.oem-by-category');
Route::post('vendor-oem-oem', [App\Http\Controllers\Admin\Vendors\VendorOemController::class, 'oem'])->name('vendor-oem.oem');

Route::resource('vehicleoemmodel', 'App\Http\Controllers\VendoroemModelController');
Route::match(['PUT', 'POST'],'vendor-oem-validate]', [App\Http\Controllers\Admin\Vendors\VendorOemController::class, 'validate'])->name('vendor-oem-validate]');
Route::post('vehicleoemmodels', [App\Http\Controller\VendoroemModelController::class,'store'])->name('vehicleoemmodels.store');
Route::post('vehicle_oem_model-tab-index', [App\Http\Controllers\VendoroemModelController::class, 'tab_index'])->name('vehicle_oem_model.tab-index');
Route::post('vehiclemodelwise', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'vehiclemodelwise'])->name('vehiclemodelwise');
});
//vendor Management
Route::group(['prefix' => 'vendor',
'middleware' => ['auth']
], function () {

Route::resource('vehicles', 'App\Http\Controllers\Admin\Vendors\VehiclesController');
Route::match(['PUT', 'POST'],'vendor-vehicle-validate', [App\Http\Controllers\Admin\Vendors\VehiclesController::class, 'validate'])->name('vendor.vehicle.validate');
Route::post('vendor-vehicle-tab-index', [App\Http\Controllers\Admin\Vendors\VehiclesController::class, 'tab_index'])->name('vendor.vehicle.tab-index');

Route::resource('battery', 'App\Http\Controllers\Admin\Vendors\BatteryController');
Route::match(['PUT', 'POST'],'battery-validate', [App\Http\Controllers\Admin\Vendors\BatteryController::class, 'validate'])->name('vendor.battery.validate');
Route::post('vendor-battery-tab-index', [App\Http\Controllers\Admin\Vendors\BatteryController::class, 'tab_index'])->name('vendor.battery.tab-index');

Route::resource('charging-station', 'App\Http\Controllers\Admin\Vendors\ChargingStationController');
Route::match(['PUT', 'POST'],'charging-station-validate', [App\Http\Controllers\Admin\Vendors\ChargingStationController::class, 'validate'])->name('vendor.charging-station.validate');
Route::post('vendor-charging-station-tab-index', [App\Http\Controllers\Admin\Vendors\ChargingStationController::class, 'tab_index'])->name('vendor.charging-station.tab-index');

Route::resource('manpower', 'App\Http\Controllers\Admin\Vendors\ManpowerController');
Route::match(['PUT', 'POST'],'manpower-validate', [App\Http\Controllers\Admin\Vendors\ManpowerController::class, 'validate'])->name('vendor.manpower.validate');
Route::post('vendor-manpower-tab-index', [App\Http\Controllers\Admin\Vendors\ManpowerController::class, 'tab_index'])->name('vendor.manpower.tab-index');

Route::resource('service-workshop', 'App\Http\Controllers\Admin\Vendors\ServiceWorkshopController');
Route::match(['PUT', 'POST'],'service-workshop-validate', [App\Http\Controllers\Admin\Vendors\ServiceWorkshopController::class, 'validate'])->name('vendor.service-workshop.validate');
Route::post('vendor-service-workshop-tab-index', [App\Http\Controllers\Admin\Vendors\ServiceWorkshopController::class, 'tab_index'])->name('vendor.service-workshop.tab-index');

Route::resource('ev-rental', 'App\Http\Controllers\Admin\Vendors\EvRentalController');
Route::match(['PUT', 'POST'],'ev-rental-validate', [App\Http\Controllers\Admin\Vendors\EvRentalController::class, 'validate'])->name('vendor.ev-rental.validate');
Route::post('vendor-ev-rental-tab-index', [App\Http\Controllers\Admin\Vendors\EvRentalController::class, 'tab_index'])->name('vendor.ev-rental.tab-index');
});
// Asset Management 
Route::group(['prefix' => 'asset',
'middleware' => ['permission:edit-asset','auth']
], function () {

Route::resource('vehicles', 'App\Http\Controllers\Admin\Assets\VehiclesController', [ 'as' => 'asset' ]);
Route::match(['PUT', 'POST'],'asset-vehicle-validate', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'validate'])->name('asset.vehicle.validate');
Route::post('asset-vehicle-tab-index', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'tab_index'])->name('asset.vehicle.tab-index');
Route::get('delete-parts/{id}', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'destroy_parts'])->name('asset.vehicle.delete-parts');
Route::get('delete-service-plan/{id}', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'destroy_service_plan'])->name('asset.vehicle.delete-service-plan');
Route::get('delete-insurance-plan/{id}', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'destroy_insurance_plan'])->name('asset.vehicle.delete-insurance-plan');
Route::post('asset-vehicle-list', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'asset_vehicle_list'])->name('asset.asset-vehicle-list');
Route::post('asset-vehicle-list-by-type', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'list_by_type'])->name('asset.vehicle.list-by-type');
Route::post('asset-vehicle-list-by-model', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'list_by_model'])->name('asset.vehicle.list-by-model');
Route::post('asset-vehicle-part-list-by-asset', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'part_list_by_asset'])->name('asset.vehicle.part-list-by-asset');
Route::get('asset-vehicle-asset-qr/{id}', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'asset_qr'])->name('asset.vehicle.asset-qr');
Route::get('delete-rc-book/{id}', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'delete_rc_book'])->name('asset.vehicle.delete-rc-book');
Route::get('asset-vehicle-delete-images/{id}', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'destroy_images'])->name('asset.vehicle.delete-images');
Route::get('copy-vehicle/{id}', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'copy_model'])->name('asset.vehicle.copy');
Route::get('assets-delete-image/{id}', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'destroyAssetImage'])->name('assets.vehicles.delete-image');
Route::get('assetproduct', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'asset'])->name('assetproduct');
Route::post('dealeroem', [App\Http\Controllers\Admin\Assets\VehiclesController::class, 'dealeroem'])->name('dealeroem');


Route::resource('assets', 'App\Http\Controllers\Admin\AssetController');
Route::post('asset/tab-index', [App\Http\Controllers\Admin\AssetController::class, 'tab_index'])->name('asset.tab-index');
Route::match(['PUT', 'POST'],'assets-validate', [App\Http\Controllers\Admin\AssetController::class, 'validate'])->name('asset.validate');
Route::post('assets/{id}', [App\Http\Controllers\Admin\AssetController::class, 'update'])->name('assets.post.update');
Route::get('asset/categories', [App\Http\Controllers\Admin\AssetController::class, 'categories'])->name('assets.categories');
Route::get('asset/categories/create', [App\Http\Controllers\Admin\AssetController::class, 'categories_create'])->name('assets.category.create');
Route::post('assets/categories-validate', [App\Http\Controllers\Admin\AssetController::class, 'categories_validate'])->name('asset.category.validate');
Route::post('assets/categories/store', [App\Http\Controllers\Admin\AssetController::class, 'caegory_store'])->name('assets.category.store');
Route::get('assets/categories/edit/{category}', [App\Http\Controllers\Admin\AssetController::class, 'caegory_edit'])->name('assets.category.edit');
Route::post('assets/categories/update/{category}', [App\Http\Controllers\Admin\AssetController::class, 'caegory_update'])->name('assets.category.update');
Route::get('assets/categories/delete/{category}', [App\Http\Controllers\Admin\AssetController::class, 'caegory_destroy'])->name('assets.category.destroy');

Route::resource('battery', 'App\Http\Controllers\Admin\Assets\BatteryController', [ 'as' => 'asset' ]);
Route::match(['PUT', 'POST'],'battery-validate', [App\Http\Controllers\Admin\Assets\BatteryController::class, 'validate'])->name('asset.battery.validate');
Route::post('asset-battery-tab-index', [App\Http\Controllers\Admin\Assets\BatteryController::class, 'tab_index'])->name('asset.battery.tab-index');
Route::get('asset-battery-delete-parts/{id}', [App\Http\Controllers\Admin\Assets\BatteryController::class, 'destroy_parts'])->name('asset.battery.delete-parts');
Route::get('asset-battery-delete-service-plan/{id}', [App\Http\Controllers\Admin\Assets\BatteryController::class, 'destroy_service_plan'])->name('asset.battery.delete-service-plan');
Route::get('asset-battery-delete-insurance-plan/{id}', [App\Http\Controllers\Admin\Assets\BatteryController::class, 'destroy_insurance_plan'])->name('asset.battery.delete-insurance-plan');
Route::post('asset-battery-list-by-type', [App\Http\Controllers\Admin\Assets\BatteryController::class, 'list_by_type'])->name('asset.battery.list-by-type');
Route::post('asset-battery-list', [App\Http\Controllers\Admin\Assets\BatteryController::class, 'asset_battery_list'])->name('asset.asset-battery-list');
Route::get('asset-battery-delete-images/{id}', [App\Http\Controllers\Admin\Assets\BatteryController::class, 'destroy_images'])->name('asset.battery.delete-images');
Route::get('asset-battery-asset-qr/{id}', [App\Http\Controllers\Admin\Assets\BatteryController::class, 'asset_qr'])->name('asset.battery.asset-qr');
Route::post('batterydealer', [App\Http\Controllers\Admin\Assets\BatteryController::class, 'batterydealer'])->name('batterydealer');


Route::resource('charger', 'App\Http\Controllers\Admin\Assets\ChargerController', [ 'as' => 'asset' ]);
Route::match(['PUT', 'POST'],'charger-validate', [App\Http\Controllers\Admin\Assets\ChargerController::class, 'validate'])->name('asset.charger.validate');
Route::post('asset-charger-tab-index', [App\Http\Controllers\Admin\Assets\ChargerController::class, 'tab_index'])->name('asset.charger.tab-index');
Route::get('asset-charger-delete-parts/{id}', [App\Http\Controllers\Admin\Assets\ChargerController::class, 'destroy_parts'])->name('asset.charger.delete-parts');
Route::get('asset-charger-delete-service-plan/{id}', [App\Http\Controllers\Admin\Assets\ChargerController::class, 'destroy_service_plan'])->name('asset.charger.delete-service-plan');
Route::get('asset-charger-delete-insurance-plan/{id}', [App\Http\Controllers\Admin\Assets\ChargerController::class, 'destroy_insurance_plan'])->name('asset.charger.delete-insurance-plan');

Route::resource('charging-equipment', 'App\Http\Controllers\Admin\Assets\ChargingEquipmentController', [ 'as' => 'asset' ]);
Route::match(['PUT', 'POST'],'charging-equipment-validate', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'validate'])->name('asset.charging-equipment.validate');
Route::post('asset-charging-equipment-tab-index', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'tab_index'])->name('asset.charging-equipment.tab-index');
Route::get('asset-charging-equipment-delete-parts/{id}', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'destroy_parts'])->name('asset.charging-equipment.delete-parts');
Route::get('asset-charging-equipment-delete-service-plan/{id}', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'destroy_service_plan'])->name('asset.charging-equipment.delete-service-plan');
Route::get('asset-charging-equipment-delete-insurance-plan/{id}', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'destroy_insurance_plan'])->name('asset.charging-equipment.delete-insurance-plan');
Route::get('asset-charging-equipment-delete-images/{id}', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'destroy_images'])->name('asset.charging-equipment.delete-images');
Route::get('asset-charging-equipment-asset-qr/{id}', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'asset_qr'])->name('asset.charging-equipment.asset-qr');

Route::post('asset-charging-equipment-list', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'asset_charging_equipment_list'])->name('asset.asset-charging-equipment-list');
Route::post('asset-charging-equipment-list-by-type', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'list_by_type'])->name('asset.charging-equipment.list-by-type');
Route::post('asset-charging-equipment-list-by-model', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'list_by_model'])->name('asset.charging-equipment.list-by-model');
Route::post('asset-charging-equipment-part-list-by-asset', [App\Http\Controllers\Admin\Assets\ChargingEquipmentController::class, 'part_list_by_asset'])->name('asset.charging-equipment.part-list-by-asset');

Route::resource('charging-station', 'App\Http\Controllers\Admin\Assets\ChargingStationController', [ 'as' => 'asset' ]);
Route::match(['PUT', 'POST'],'charging-station-validate', [App\Http\Controllers\Admin\Assets\ChargingStationController::class, 'validate'])->name('asset.charging-station.validate');
Route::post('asset-charging-station-tab-index', [App\Http\Controllers\Admin\Assets\ChargingStationController::class, 'tab_index'])->name('asset.charging-station.tab-index');
Route::get('asset-charging-station-delete-parts/{id}', [App\Http\Controllers\Admin\Assets\ChargingStationController::class, 'destroy_parts'])->name('asset.charging-station.delete-parts');
Route::get('asset-charging-station-delete-service-plan/{id}', [App\Http\Controllers\Admin\Assets\ChargingStationController::class, 'destroy_service_plan'])->name('asset.charging-station.delete-service-plan');
Route::get('asset-charging-station-delete-insurance-plan/{id}', [App\Http\Controllers\Admin\Assets\ChargingStationController::class, 'destroy_insurance_plan'])->name('asset.charging-station.delete-insurance-plan');
Route::post('asset-charging-station-list-by-type', [App\Http\Controllers\Admin\Assets\ChargingStationController::class, 'list_by_type'])->name('asset.charging-station.list-by-type');
Route::get('asset-charging-station-delete-images/{id}', [App\Http\Controllers\Admin\Assets\ChargingStationController::class, 'destroy_images'])->name('asset.charging-station.delete-images');
});
// Subscription Management
Route::group(['prefix' => 'subscription-plan',
'middleware' => ['permission:edit-subscription-plan','auth']
], function () {

Route::resource('vehicles', 'App\Http\Controllers\Admin\SubscriptionPlan\VehiclesController', [ 'as' => 'subscription-plan' ]);
Route::match(['PUT', 'POST'],'subscription-plan-vehicle-validate', [App\Http\Controllers\Admin\SubscriptionPlan\VehiclesController::class, 'validate'])->name('subscription-plan.vehicle.validate');
Route::post('subscription-plan-vehicle-tab-index', [App\Http\Controllers\Admin\SubscriptionPlan\VehiclesController::class, 'tab_index'])->name('subscription-plan.vehicle.tab-index');
Route::post('subscription-plan-vehicle-plan-data', [App\Http\Controllers\Admin\SubscriptionPlan\VehiclesController::class, 'vehicle_plan'])->name('subscription-plan.vehicle.plan-data');

Route::get('subscription-plan-delete-asset-parts/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\VehiclesController::class, 'destroy_asset_parts'])->name('subscription-plan.vehicle.delete-asset-parts');
Route::get('subscription-plan-delete-base-plan/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\VehiclesController::class, 'destroy_base_plan'])->name('subscription-plan.vehicle.delete-base-plan');
Route::get('subscription-plan-vehicle-delete-location/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\VehiclesController::class, 'destroy_locatoin_region'])->name('subscription-plan.vehicle.delete-location');
Route::get('subscription-plan-delete-terms-condition/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\VehiclesController::class, 'destroy_terms_condition'])->name('subscription-plan.vehicle.terms-condition');
Route::get('subscription-plan-delete-vehicle-terms-condition-image/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\VehiclesController::class, 'destroy_terms_condition_image'])->name('subscription-plan.vehicle.terms-condition-image');

Route::resource('charging-equipment', 'App\Http\Controllers\Admin\SubscriptionPlan\ChargingEquipmentController', [ 'as' => 'subscription-plan' ]);
Route::match(['PUT', 'POST'],'subscription-plan-charging-equipment-validate', [App\Http\Controllers\Admin\SubscriptionPlan\ChargingEquipmentController::class, 'validate'])->name('subscription-plan.charging-equipment.validate');
Route::post('subscription-plan-charging-equipment-tab-index', [App\Http\Controllers\Admin\SubscriptionPlan\ChargingEquipmentController::class, 'tab_index'])->name('subscription-plan.charging-equipment.tab-index');
Route::post('subscription-plan-charging-equipment-plan-data', [App\Http\Controllers\Admin\SubscriptionPlan\ChargingEquipmentController::class, 'charging_equipment_plan'])->name('subscription-plan.charging-equipment.plan-data');
Route::get('subscription-plan-charging-equipment-delete-location/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\ChargingEquipmentController::class, 'destroy_locatoin_region'])->name('subscription-plan.charging-equipment.delete-location');
Route::get('subscription-plan-delete-charging-equipment-terms-condition/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\ChargingEquipmentController::class, 'destroy_terms_condition'])->name('subscription-plan.charging-equipment.terms-condition');
Route::get('subscription-plan-delete-charging-equipment-terms-condition-image/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\ChargingEquipmentController::class, 'destroy_terms_condition_image'])->name('subscription-plan.charging-equipment.terms-condition-image');

Route::resource('battery', 'App\Http\Controllers\Admin\SubscriptionPlan\BatteryController', [ 'as' => 'subscription-plan' ]);
Route::match(['PUT', 'POST'],'subscription-plan-battery-validate', [App\Http\Controllers\Admin\SubscriptionPlan\BatteryController::class, 'validate'])->name('subscription-plan.battery.validate');
Route::post('subscription-plan-battery-tab-index', [App\Http\Controllers\Admin\SubscriptionPlan\BatteryController::class, 'tab_index'])->name('subscription-plan.battery.tab-index');
Route::post('subscription-plan-battery-plan-data', [App\Http\Controllers\Admin\SubscriptionPlan\BatteryController::class, 'vehicle_plan'])->name('subscription-plan.battery.plan-data');

Route::get('subscription-plan-battery-delete-asset-parts/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\BatteryController::class, 'destroy_asset_parts'])->name('subscription-plan.battery.delete-asset-parts');
Route::get('subscription-plan-battery-delete-base-plan/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\BatteryController::class, 'destroy_base_plan'])->name('subscription-plan.battery.delete-base-plan');
Route::get('subscription-plan-battery-delete-location/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\BatteryController::class, 'destroy_locatoin_region'])->name('subscription-plan.battery.delete-location');
Route::get('subscription-plan-battery-delete-terms-condition/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\BatteryController::class, 'destroy_terms_condition'])->name('subscription-plan.battery.terms-condition');
Route::get('subscription-plan-battery-delete-terms-condition-image/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\BatteryController::class, 'destroy_terms_condition_image'])->name('subscription-plan.battery.terms-condition-image');

Route::resource('angel-service', 'App\Http\Controllers\Admin\SubscriptionPlan\AngelServiceController', [ 'as' => 'subscription-plan' ]);
Route::match(['PUT', 'POST'],'subscription-plan-angel-service-validate', [App\Http\Controllers\Admin\SubscriptionPlan\AngelServiceController::class, 'validate'])->name('subscription-plan.angel-service.validate');
Route::post('subscription-plan-angel-service-tab-index', [App\Http\Controllers\Admin\SubscriptionPlan\AngelServiceController::class, 'tab_index'])->name('subscription-plan.angel-service.tab-index');

Route::get('subscription-plan-angel-service-delete-location/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\AngelServiceController::class, 'destroy_locatoin_region'])->name('subscription-plan.angel-service.delete-location');
Route::get('subscription-plan-angel-service-delete-terms-condition/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\AngelServiceController::class, 'destroy_terms_condition'])->name('subscription-plan.angel-service.terms-condition');
Route::get('subscription-plan-angel-service-delete-terms-condition-image/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\AngelServiceController::class, 'destroy_terms_condition_image'])->name('subscription-plan.angel-service.terms-condition-image');

Route::resource('value-added-service', 'App\Http\Controllers\Admin\SubscriptionPlan\ValueAddedServiceController', [ 'as' => 'subscription-plan' ]);
Route::match(['PUT', 'POST'],'subscription-plan-value-added-service-validate', [App\Http\Controllers\Admin\SubscriptionPlan\ValueAddedServiceController::class, 'validate'])->name('subscription-plan.value-added-service.validate');
Route::post('subscription-plan-value-added-service-tab-index', [App\Http\Controllers\Admin\SubscriptionPlan\ValueAddedServiceController::class, 'tab_index'])->name('subscription-plan.value-added-service.tab-index');
Route::post('subscription-plan-value-added-service-plan-data', [App\Http\Controllers\Admin\SubscriptionPlan\ValueAddedServiceController::class, 'value_added_service_plan'])->name('subscription-plan.value-added-service.plan-data');
Route::get('subscription-plan-value-added-service-delete-location/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\ValueAddedServiceController::class, 'destroy_locatoin_region'])->name('subscription-plan.value-added-service.delete-location');
Route::get('subscription-plan-delete-value-added-service-terms-condition/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\ValueAddedServiceController::class, 'destroy_terms_condition'])->name('subscription-plan.value-added-service.terms-condition');
Route::get('subscription-plan-delete-value-added-service-terms-condition-image/{id}', [App\Http\Controllers\Admin\SubscriptionPlan\ValueAddedServiceController::class, 'destroy_terms_condition_image'])->name('subscription-plan.value-added-service.terms-condition-image');
});
//orders Management
Route::group(['prefix' => 'orders',
'middleware' => ['auth']
],  function () {

Route::resource('vehicle', 'App\Http\Controllers\Admin\Order\OrderController', [ 'as' => 'orders' ]);
Route::post('order-tab-vehicle-index', [App\Http\Controllers\Admin\Order\OrderController::class, 'tab_index'])->name('order.vehicle.tab_index');
Route::post('order-vehicle-validate', [App\Http\Controllers\Admin\Order\OrderController::class, 'validate'])->name('order.vehicle.validate');
Route::post('order-vehicle-status-change', [App\Http\Controllers\Admin\Order\OrderController::class, 'change_order_status'])->name('order.status_change');
Route::post('order-payment-vehicle-status-change', [App\Http\Controllers\Admin\Order\OrderController::class, 'payment_status_change'])->name('order.payment_status_change');
Route::get('order-battery-swap/{order_id}', [App\Http\Controllers\Admin\Order\OrderController::class, 'battery_index'])->name('order.battery_index');
Route::post('order-battery-swap-tab-inedex/{order_id}', [App\Http\Controllers\Admin\Order\OrderController::class, 'tab_battery_index'])->name('order.tab_battery_index');
Route::post('order-battery-status-change', [App\Http\Controllers\Admin\Order\OrderController::class, 'change_battery_order_status'])->name('order.change_battery_order_status');

Route::resource('battery-swap', 'App\Http\Controllers\Admin\Order\BatterySwapController', [ 'as' => 'orders' ]);
Route::post('order-battery-swap-index', [App\Http\Controllers\Admin\Order\BatterySwapController::class, 'tab_index'])->name('order.battery-swap.tab_index');

Route::resource('charging-station', 'App\Http\Controllers\Admin\Order\ChargingStationController', [ 'as' => 'orders' ]);
Route::post('order-charging-station-index', [App\Http\Controllers\Admin\Order\ChargingStationController::class, 'tab_index'])->name('order.charging-station.tab_index');
Route::post('order-charging-station-status-change', [App\Http\Controllers\Admin\Order\ChargingStationController::class, 'change_charging_station_order_status'])->name('order.change_charging_station_order_status');

Route::resource('angel-service', 'App\Http\Controllers\Admin\Order\AngelServiceController', [ 'as' => 'orders' ]);
Route::post('order-angel-service-index', [App\Http\Controllers\Admin\Order\AngelServiceController::class, 'tab_index'])->name('order.angel-service.tab_index');
Route::post('order-angel-service-status-change', [App\Http\Controllers\Admin\Order\AngelServiceController::class, 'change_angel_service_order_status'])->name('order.change_angel_service_order_status');
});
//Rider Management
Route::group([
'middleware' => ['auth']
],  function () {
    
Route::get('/users/subscribers/{slug}', [Admin::class, 'customers'])->name('admin.customers')->middleware('auth');
Route::get('/users/subscribers/add/{slug}', [Admin::class, 'add_customer'])->name('add_customer_form')->middleware('auth');
Route::post('/users/customer/store/{slug}', [Admin::class, 'store_customer'])->name('add_customer')->middleware('auth');
Route::get('/users/subscribers/edit/{id}/{slug}', [Admin::class, 'edit_customer'])->name('edit_customer')->middleware('auth');
Route::post('/users/subscribers/update/{id}/{slug}', [Admin::class, 'update_customer'])->name('update_customer')->middleware('auth');
Route::get('/users/{id}/show/{slug}', [Admin::class, 'show'])->name('user.show');
Route::get('/users/{id}/destroy/{slug}', [Admin::class, 'destroy'])->name('user.destroy');
Route::post('/vehicleregister', [Admin::class, 'vehicleregister'])->name('vehicleregister');
Route::post('/vehiclevinnumber', [Admin::class, 'vehiclevinnumber'])->name('vehiclevinnumber');
Route::post('/batteryvinnumber', [Admin::class, 'batteryvinnumber'])->name('batteryvinnumber');

Route::post('users/tab-subscribers/{slug}', [Admin::class, 'tab_customers'])->name('users.tab-customers');
Route::post('users/subscribers/tap-wallet-history/{user_id}', [Admin::class, 'tab_wallet_history'])->name('users.tap-wallet-historys');

Route::post('/users-validate', [Admin::class, 'new_user_form_validate'])->name('user.validate');
Route::get('/users/angel/add', [Admin::class, 'add_angel'])->name('add_angel');
Route::get('/users', [UserController::class, 'index'])->name('list_usersss');
Route::get('users/delete-kyc/{id}', [Admin::class, 'destroyUserDoc'])->name('user.delete-kyc');
Route::post('/user/by-phone-number', [Admin::class, 'user_by_phone_number'])->name('user.by-phone-number');
});
//3pl Management
Route::group([
'middleware' => ['auth']
],  function () {

Route::get('/users/3pl/workreport', [Admin::class, 'workreport'])->name('user.3plreport');
Route::post('/users/3plworkdata',[Admin::class,'workdata'])->name('admin.3plworkdata');
Route::get('/users/3pl',[Admin::class,'attendance'])->name('plreport');
Route::post('/users/3plattendance',[Admin::class,'attendancedata'])->name('admin.3pldata');
Route::get('/users/3plreport',[Admin::class,'search'])->name('importreport.search');
Route::get('/export-users',[Admin::class,'export'])->name('export-users');
Route::post('/users/3plreport',[Admin::class,'import'])->name('import.report');
 });
// CMS   
Route::group(['prefix' => 'cms', 
'middleware' => ['auth']
],function () {

Route::resource('banner', 'App\Http\Controllers\Admin\CMS\BannerController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'banner-validate', [App\Http\Controllers\Admin\CMS\BannerController::class, 'validate'])->name('cms.banner.validate');
Route::post('cms-banner-tab-index', [App\Http\Controllers\Admin\CMS\BannerController::class, 'tab_index'])->name('cms.banner.tab-index');
//Route::get('cms-banner-delete-banner-location/{id}', [App\Http\Controllers\Admin\CMS\BannerController::class, 'destroy_Location'])->name('cms.banner.delete-banner-location');

Route::resource('announcement', 'App\Http\Controllers\Admin\CMS\AnnouncementController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'announcement-validate', [App\Http\Controllers\Admin\CMS\AnnouncementController::class, 'validate'])->name('cms.announcement.validate');
Route::post('cms-announcement-tab-index', [App\Http\Controllers\Admin\CMS\AnnouncementController::class, 'tab_index'])->name('cms.announcement.tab-index');

Route::resource('incidental-info', 'App\Http\Controllers\Admin\CMS\IncidentalInfoController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'incidental-info-validate', [App\Http\Controllers\Admin\CMS\IncidentalInfoController::class, 'validate'])->name('cms.incidental-info.validate');
Route::post('cms-incidental-info-tab-index', [App\Http\Controllers\Admin\CMS\IncidentalInfoController::class, 'tab_index'])->name('cms.incidental-info.tab-index');

Route::resource('input-attribute', 'App\Http\Controllers\Admin\CMS\InputAttributeController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'input-attribute-validate', [App\Http\Controllers\Admin\CMS\InputAttributeController::class, 'validate'])->name('cms.input-attribute.validate');
Route::post('cms-input-attribute-tab-index', [App\Http\Controllers\Admin\CMS\InputAttributeController::class, 'tab_index'])->name('cms.input-attribute.tab-index');
Route::post('cms-form-fields-by-form', [App\Http\Controllers\Admin\CMS\InputAttributeController::class, 'form_fields_by_form'])->name('cms.form-fields-by-form');

Route::resource('tab-menu', 'App\Http\Controllers\Admin\CMS\TabMenuController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'tab-menu-validate', [App\Http\Controllers\Admin\CMS\TabMenuController::class, 'validate'])->name('cms.tab-menu.validate');
Route::post('cms-tab-menu-tab-index', [App\Http\Controllers\Admin\CMS\TabMenuController::class, 'tab_index'])->name('cms.tab-menu.tab-index');
Route::post('cms-tab-menu-by-form-field', [App\Http\Controllers\Admin\CMS\TabMenuController::class, 'tab_menu_by_form_field'])->name('cms.tab-menu-by-form-field');

Route::resource('tab-menu-input', 'App\Http\Controllers\Admin\CMS\TabMenuInputController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'tab-menu-input-validate', [App\Http\Controllers\Admin\CMS\TabMenuInputController::class, 'validate'])->name('cms.tab-menu-input.validate');
Route::post('cms-tab-menu-input-tab-index', [App\Http\Controllers\Admin\CMS\TabMenuInputController::class, 'tab_index'])->name('cms.tab-menu-input.tab-index');
    
Route::resource('onboard', 'App\Http\Controllers\Admin\CMS\OnboardController');
Route::match(['PUT', 'POST'],'onboard-validate', [App\Http\Controllers\Admin\CMS\OnboardController::class, 'validate'])->name('onboard.validate');
Route::post('onboard-tab-index', [App\Http\Controllers\Admin\CMS\OnboardController::class, 'tab_index'])->name('onboard.tab-index');
Route::post('onboard-save-description', [App\Http\Controllers\Admin\CMS\OnboardController::class, 'save_description'])->name('onboard.save-description');

Route::get('delete-onboard-list/{id}', [App\Http\Controllers\Admin\CMS\OnboardController::class, 'delete_onboard_list'])->name('delete-onboard-list');
Route::get('delete-onboard-permission/{id}', [App\Http\Controllers\Admin\CMS\OnboardController::class, 'delete_onboard_permission'])->name('delete-onboard-permission');
Route::get('delete-onboard-permission-description/{id}', [App\Http\Controllers\Admin\CMS\OnboardController::class, 'delete_onboard_permission_description'])->name('delete-onboard-permission-description');
       
Route::resource('forms', 'App\Http\Controllers\Admin\CMS\FormsController', [ 'as' => 'cms' ]);
Route::post('forms-tab-index', [App\Http\Controllers\Admin\CMS\FormsController::class, 'tab_index'])->name('cms.forms.tab-index');
Route::post('forms-order-tab-index', [App\Http\Controllers\Admin\CMS\FormsController::class, 'order_tab_index'])->name('cms.forms.order-tab-index');
Route::match(['PUT', 'POST'],'cms-forms-validate', [App\Http\Controllers\Admin\CMS\FormsController::class, 'validate'])->name('cms.forms.validate');
Route::get('cms/forms/delete-form-field/{id}', [App\Http\Controllers\Admin\CMS\FormsController::class, 'destroyFormField'])->name('cms.forms.delete-form-field');
Route::get('cms/delete-form-button/{id}', [App\Http\Controllers\Admin\CMS\FormsController::class, 'destroyFormButton'])->name('cms.forms.delete-form-button');
Route::get('cms/delete-form-image/{id}/{field}', [App\Http\Controllers\Admin\CMS\FormsController::class, 'destroyFormImage'])->name('cms.forms.delete-form-image');

Route::resource('terms-condition', 'App\Http\Controllers\Admin\CMS\TermsConditionController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'terms-condition-validate', [App\Http\Controllers\Admin\CMS\TermsConditionController::class, 'validate'])->name('cms.terms-condition.validate');
Route::post('cms-terms-condition-tab-index', [App\Http\Controllers\Admin\CMS\TermsConditionController::class, 'tab_index'])->name('cms.terms-condition.tab-index');

Route::resource('faq', 'App\Http\Controllers\Admin\CMS\FaqCategoryController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'faq-validate', [App\Http\Controllers\Admin\CMS\FaqCategoryController::class, 'validate'])->name('cms.faq.validate');
Route::post('cms-faq-tab-index', [App\Http\Controllers\Admin\CMS\FaqCategoryController::class, 'tab_index'])->name('cms.faq.tab-index');
Route::post('cms-faq-question-delete', [App\Http\Controllers\Admin\CMS\FaqCategoryController::class, 'destroy_faqs'])->name('cms-faq-question-delete');
Route::get('cms-faq-priority-list', [App\Http\Controllers\Admin\CMS\FaqCategoryController::class, 'priority_list'])->name('cms-faq-priority-list');

Route::resource('emergency-service', 'App\Http\Controllers\Admin\CMS\EmergencyServiceController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'emergency-service-validate', [App\Http\Controllers\Admin\CMS\EmergencyServiceController::class, 'validate'])->name('cms.emergency-service.validate');
Route::post('cms-emergency-service-tab-index', [App\Http\Controllers\Admin\CMS\EmergencyServiceController::class, 'tab_index'])->name('cms.emergency-service.tab-index');

Route::resource('feedback-rating', 'App\Http\Controllers\Admin\CMS\FeedbackRatingController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'feedback-rating-validate', [App\Http\Controllers\Admin\CMS\FeedbackRatingController::class, 'validate'])->name('cms.feedback-rating.validate');
Route::post('cms-feedback-rating-tab-index', [App\Http\Controllers\Admin\CMS\FeedbackRatingController::class, 'tab_index'])->name('cms.feedback-rating.tab-index');
Route::post('cms-feedback-rating-question-delete', [App\Http\Controllers\Admin\CMS\FeedbackRatingController::class, 'destroy_feedback_rating_impression'])->name('cms-feedback-rating-question-delete');

Route::resource('menu', 'App\Http\Controllers\Admin\CMS\MenuController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'menu-validate', [App\Http\Controllers\Admin\CMS\MenuController::class, 'validate'])->name('cms.menu.validate');
Route::post('cms-menu-tab-index', [App\Http\Controllers\Admin\CMS\MenuController::class, 'tab_index'])->name('cms.menu.tab-index');
Route::get('cms-menu-priority-list', [App\Http\Controllers\Admin\CMS\MenuController::class, 'priority_list'])->name('cms-menu-priority-list');

Route::resource('walkaround-checklist', 'App\Http\Controllers\Admin\CMS\WalkaroundChecklistController', [ 'as' => 'cms' ]);
Route::match(['PUT', 'POST'],'walkaround-checklist-validate', [App\Http\Controllers\Admin\CMS\WalkaroundChecklistController::class, 'validate'])->name('cms.walkaround-checklist.validate');
Route::post('cms-walkaround-checklist-tab-index', [App\Http\Controllers\Admin\CMS\WalkaroundChecklistController::class, 'tab_index'])->name('cms.walkaround-checklist.tab-index');
Route::get('cms-walkaround-checklist-priority-list', [App\Http\Controllers\Admin\CMS\WalkaroundChecklistController::class, 'priority_list'])->name('cms-walkaround-checklist-priority-list');
Route::post('cms-walkaround-checklist-create-category', [App\Http\Controllers\Admin\CMS\WalkaroundChecklistController::class, 'create_category'])->name('cms.walkaround-checklist.create-category');
Route::post('cms-walkaround-checklist-add-nistruction-checklist', [App\Http\Controllers\Admin\CMS\WalkaroundChecklistController::class, 'add_nistruction_checklist'])->name('cms.walkaround-checklist.add-nistruction-checklist');
Route::post('cms-walkaround-checklist-delete-media-file', [App\Http\Controllers\Admin\CMS\WalkaroundChecklistController::class, 'delete_media_file'])->name('cms.walkaround-checklist.delete-media-file');
});
//Purchased Services 
Route::group(['prefix' => 'purchased-service',
'middleware' => ['permission:edit-purchased-service','auth']
], function () {

Route::resource('vehicles', 'App\Http\Controllers\Admin\PurchasedService\VehiclesController', [ 'as' => 'purchased-service']);
Route::match(['PUT', 'POST'],'purchased-service-vehicle-validate', [App\Http\Controllers\Admin\PurchasedService\VehiclesController::class, 'validate'])->name('purchased-service.vehicle.validate');
Route::post('purchased-service-vehicle-tab-index', [App\Http\Controllers\Admin\PurchasedService\VehiclesController::class, 'tab_index'])->name('purchased-service.vehicle.tab-index');

Route::resource('battery', 'App\Http\Controllers\Admin\PurchasedService\BatteryController', [ 'as' => 'purchased-service']);
Route::match(['PUT', 'POST'],'purchased-service-battery-validate', [App\Http\Controllers\Admin\PurchasedService\BatteryController::class, 'validate'])->name('purchased-service.battery.validate');
Route::post('purchased-service-battery-tab-index', [App\Http\Controllers\Admin\PurchasedService\BatteryController::class, 'tab_index'])->name('purchased-service.battery.tab-index');

Route::resource('charging-station', 'App\Http\Controllers\Admin\PurchasedService\ChargingStationController', [ 'as' => 'purchased-service']);
Route::match(['PUT', 'POST'],'purchased-service-charging-station-validate', [App\Http\Controllers\Admin\PurchasedService\ChargingStationController::class, 'validate'])->name('purchased-service.charging-station.validate');
Route::post('purchased-service-charging-station-tab-index', [App\Http\Controllers\Admin\PurchasedService\ChargingStationController::class, 'tab_index'])->name('purchased-service.charging-station.tab-index');

Route::resource('manpower', 'App\Http\Controllers\Admin\PurchasedService\ManpowerController', [ 'as' => 'purchased-service']);
Route::match(['PUT', 'POST'],'purchased-service-manpower-validate', [App\Http\Controllers\Admin\PurchasedService\ManpowerController::class, 'validate'])->name('purchased-service.manpower.validate');
Route::post('purchased-service-manpower-tab-index', [App\Http\Controllers\Admin\PurchasedService\ManpowerController::class, 'tab_index'])->name('purchased-service.manpower.tab-index');
});
// Marketing   
Route::group(['prefix' => 'marketing',
'middleware' => ['auth']
],  function () {

Route::resource('reward', 'App\Http\Controllers\Admin\Marketing\RewardController', [ 'as' => 'marketing' ]);
Route::match(['PUT', 'POST'],'reward-validate', [App\Http\Controllers\Admin\Marketing\RewardController::class, 'validate'])->name('marketing.reward.validate');
Route::post('marketing-reward-tab-index', [App\Http\Controllers\Admin\Marketing\RewardController::class, 'tab_index'])->name('marketing.reward.tab-index');

Route::resource('discount', 'App\Http\Controllers\Admin\Marketing\DiscountController', [ 'as' => 'marketing' ]);
Route::match(['PUT', 'POST'],'discount-validate', [App\Http\Controllers\Admin\Marketing\DiscountController::class, 'validate'])->name('marketing.discount.validate');
Route::post('marketing-discount-tab-index', [App\Http\Controllers\Admin\Marketing\DiscountController::class, 'tab_index'])->name('marketing.discount.tab-index');

Route::resource('cashback', 'App\Http\Controllers\Admin\Marketing\CashbackController', [ 'as' => 'marketing' ])->middleware('auth');
Route::match(['PUT', 'POST'],'cashback-validate', [App\Http\Controllers\Admin\Marketing\CashbackController::class, 'validate'])->name('marketing.cashback.validate');
Route::post('marketing-cashback-tab-index', [App\Http\Controllers\Admin\Marketing\CashbackController::class, 'tab_index'])->name('marketing.cashback.tab-index');
}); 
//Notifications
Route::resource('email-templates', 'App\Http\Controllers\Admin\EmailController')->middleware('auth');
Route::post('email-templates-validate', [App\Http\Controllers\Admin\EmailController::class, 'validate'])->name('email-templates.validate');
Route::post('email-templates/{email_template}', [App\Http\Controllers\Admin\EmailController::class, 'update'])->name('email-templates.post.update');
//Reports
Route::group([
'middleware' => ['auth']
],  function () {

Route::get('flipkart', [App\Http\Controllers\FlipkartController::class, 'index'])->name('flipkart.report');
Route::get('filterflipkart',[App\Http\Controllers\FlipkartController::class,'create'])->name('filterflipkart');
Route::get('flipkartattendance', [App\Http\Controllers\Admin\UserController::class, 'flipkartattendance'])->name('attendance.report');
}); 
//Settings
Route::get('settings', [App\Http\Controllers\Admin\SettingController::class, 'index'])->name('settings.index')->middleware('auth');
Route::post('settings/store', [App\Http\Controllers\Admin\SettingController::class, 'store'])->name('settings.store');
Route::patch('/fcm-token',[App\Http\Controllers\AppController::class, 'update_fcm_token'])->name('fcm.token');  